@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "FindAlgorithm.h"
 
@@ -59,7 +70,7 @@ static void findInAmino(
                      FindAlgorithmStrand strand,
                      bool insDel,
                      const char* seq, 
-                     const LRegion& range,  
+                     const U2Region& range,  
                      const char* pattern, 
                      int patternLen, 
                      bool singleShot, 
@@ -85,7 +96,7 @@ static void findInAmino(
         StrandContext(width, height, insDel, revPattern.data())
     };
 
-    int onePercentLen = range.len / 100;
+    int onePercentLen = range.length / 100;
     int leftTillPercent = onePercentLen;
 
     percentsCompleted = 0;
@@ -130,7 +141,7 @@ static void findInAmino(
             if (err <= maxErr) {
                 int newLen = dt.getLastLen();
                 newLen *= 3;
-                if (res.isEmpty() || res.err > err || (res.err == err && newLen < res.region.len)) {
+                if (res.isEmpty() || res.err > err || (res.err == err && newLen < res.region.length)) {
                     assert(newLen + 3  * maxErr >= patternLenInNucl);
                     int newStart = i - newLen + 3;
                     if (insDel || (range.contains(newStart) && range.contains(newStart + newLen - 1))) {//boundary check for mismatch mode
@@ -139,9 +150,9 @@ static void findInAmino(
                         assert(newStart+newLen <= range.endPos());
 
                         res.region.startPos = newStart;
-                        res.region.len = newLen;
+                        res.region.length = newLen;
                         res.err = err;
-                        res.complement = ci == 1;
+                        res.strand = (ci == 1) ? U2Strand::Complementary : U2Strand::Direct;
                         res.translation = true;
                         if( !insDel && singleShot ) {
                             rl->onResult( res );
@@ -163,7 +174,7 @@ static void findInAmino(
     }
     for (int i=0; i < 6; i++) {
         if (!context[i].res.isEmpty()) { //todo: order by startpos?
-            assert(insDel || context[i].res.region.len == patternLenInNucl);
+            assert(insDel || context[i].res.region.length == patternLenInNucl);
             rl->onResult(context[i].res);
         }
     }
@@ -174,7 +185,7 @@ static void findInAmino_subst(
                               DNATranslation* complTT, 
                               FindAlgorithmStrand strand,
                               const char* seq, 
-                              const LRegion& range,  
+                              const U2Region& range,  
                               const char* pattern, 
                               int patternLen, 
                               bool singleShot, 
@@ -185,7 +196,7 @@ static void findInAmino_subst(
 {
     assert(aminoTT->getSrcAlphabet()->isNucleic() && aminoTT->getDstAlphabet()->isAmino());
     int patternLenInNucl =  3 * patternLen;
-    if( range.len < patternLenInNucl ) {
+    if( range.length < patternLenInNucl ) {
         currentPos = range.endPos();
         return;
     }
@@ -197,7 +208,7 @@ static void findInAmino_subst(
     QByteArray translatedPiece2( patternLen, 0 );
     QByteArray translatedPiece3( patternLen, 0 );
 
-    int tail = range.len - patternLenInNucl - 2;
+    int tail = range.length - patternLenInNucl - 2;
     tail = tail > 0 ? 0 : tail;
     aminoTT->translate( seq + range.startPos, patternLenInNucl + tail + 2, translatedPiece1.data(), patternLen );
     aminoTT->translate( seq + range.startPos+1, patternLenInNucl + tail + 1, translatedPiece2.data(), patternLen );
@@ -210,7 +221,7 @@ static void findInAmino_subst(
     complTT->translate( seq + range.startPos, patternLenInNucl + tail + 2, compl_seq.data(), patternLenInNucl + tail + 2);
     TextUtils::reverse( compl_seq.data(), compl_seq.size() );
 
-    int compl_tail = qBound( 0, range.len - patternLenInNucl, 2);
+    int compl_tail = qBound( 0, int(range.length - patternLenInNucl), 2);
     int if0slot = 0 == compl_tail;
     int if1slot = 1 == compl_tail;
     int if2slot = 2 == compl_tail;
@@ -228,7 +239,7 @@ static void findInAmino_subst(
         StrandContext(translatedPiece3c, patternLen, revPattern.data()),
     };
 
-    int onePercentLen = range.len / 100;
+    int onePercentLen = range.length / 100;
     int leftTillPercent = onePercentLen;
 
     percentsCompleted = 0;
@@ -247,7 +258,8 @@ static void findInAmino_subst(
             const char * p = ctx.pattern;
             FindAlgorithmResult & res = ctx.res; 
             bool match = true;
-            for ( int j = 0, curErr = 0; j < patternLen; j++ ) {
+            int curErr = 0;
+            for ( int j = 0; j < patternLen; j++ ) {
                 char rollchar = ctx.rollArr.get(j);
                 if( rollchar != p[j] && ++curErr > maxErr ) {
                     match = false;
@@ -266,9 +278,9 @@ static void findInAmino_subst(
             if( match ) {
                 currentPos += 1; 
                 res.region.startPos = i;
-                res.region.len = patternLenInNucl;
-                res.err = 0;
-                res.complement = ci == 1;
+                res.region.length = patternLenInNucl;
+                res.err = curErr;
+                res.strand = (ci == 1) ? U2Strand::Complementary : U2Strand::Direct;
                 res.translation = true;
 
                 rl->onResult(res);
@@ -291,16 +303,87 @@ static void findInAmino_subst(
     currentPos = range.endPos();
 }
 
+static char* createAmbiguousBaseMap() {
+
+    // Source: http://www.ncbi.nlm.nih.gov/blast/fasta.shtml
+    // Unknown symbol is zero: no match
+
+    const int SIZE = 128;
+    static char map[SIZE];
+
+    for (int i = 0; i < SIZE; i++) {
+        map[i] = 0x00;
+    }
+
+    map['A'] = 0x01; // Bitmask: 00000001
+    map['C'] = 0x02; // Bitmask: 00000010
+    map['G'] = 0x04; // Bitmask: 00000100
+    map['T'] = 0x08; // Bitmask: 00001000
+    map['U'] = 0x08; // Bitmask: 00001000
+    map['M'] = 0x03; // Bitmask: 00000011
+    map['R'] = 0x05; // Bitmask: 00000101
+    map['W'] = 0x09; // Bitmask: 00001001
+    map['S'] = 0x06; // Bitmask: 00000110
+    map['Y'] = 0x0A; // Bitmask: 00001010
+    map['K'] = 0x0C; // Bitmask: 00001100
+    map['V'] = 0x07; // Bitmask: 00000111
+    map['H'] = 0x0B; // Bitmask: 00001011
+    map['D'] = 0x0D; // Bitmask: 00001101
+    map['B'] = 0x0E; // Bitmask: 00001110
+    map['N'] = 0x0F; // Bitmask: 00001111
+    map['X'] = 0x0F; // Bitmask: 00001111
+
+    return &map[0];
+}
+
+
+inline bool cmpAmbiguous( char a, char b){
+    static char* charMap = createAmbiguousBaseMap();
+
+    assert( a >= 0 && b >= 0 );
+
+    char c1 = charMap[uchar(a)];
+    char c2 = charMap[uchar(b)];
+
+    return c1 & c2;
+}
+
+inline bool match_pattern(const char* seq, const char* p, int start, int patternLen, int maxErr, int& curErr ) {
+    bool match = true;
+    curErr = 0;
+    for ( int j = 0; j < patternLen; j++ ) {
+        if( seq[start+j] != p[j] && ++curErr > maxErr ) {
+            match = false;
+            break;
+        }
+    }
+    return match;
+}
+
+inline bool match_pattern_ambiguous(const char* seq, const char* p, int start, int patternLen, int maxErr, int& curErr ) {
+    bool match = true;
+    curErr = 0;
+    for ( int j = 0; j < patternLen; j++ ) {
+        if( !cmpAmbiguous(seq[start+j],p[j]) && ++curErr > maxErr ) {
+            match = false;
+            break;
+        }
+    }
+    return match;
+}
+
+
 static void find_subst(
     FindAlgorithmResultsListener* rl, 
     DNATranslation* aminoTT, 
     DNATranslation* complTT, 
     FindAlgorithmStrand strand,
     const char* seq, 
-    const LRegion& range,  
+    const U2Region& range,  
     const char* pattern, 
     int patternLen, 
-    bool singleShot, 
+    bool singleShot,
+    bool useAmbiguousBases,
     int maxErr,
     int& stopFlag, 
     int& percentsCompleted, 
@@ -313,7 +396,7 @@ static void find_subst(
             pattern, patternLen, singleShot, maxErr, stopFlag, percentsCompleted, currentPos);
         return;
     }
-    if( range.len - patternLen < 0 ) {
+    if( range.length - patternLen < 0 ) {
         currentPos = range.endPos();
         return;
     }
@@ -331,8 +414,8 @@ static void find_subst(
         StrandContext(0, 0, false, pattern), 
         StrandContext(0, 0, false, complPattern)
     };
-
-    int onePercentLen = range.len/100;
+    
+    int onePercentLen = range.length/100;
     int leftTillPercent = onePercentLen;
     percentsCompleted = 0;
     currentPos = range.startPos;
@@ -346,20 +429,20 @@ static void find_subst(
             StrandContext& ctx = context[ci];
             const char* p = ctx.pattern;
             FindAlgorithmResult& res = ctx.res; 
+            
             bool match = true;
-            for ( int j = 0, curErr = 0; j < patternLen; j++ ) {
-                if( seq[i+j] != p[j] && ++curErr > maxErr ) {
-                    match = false;
-                    break;
-                }
+            int curErr = 0;
+            if (useAmbiguousBases) {
+                match = match_pattern_ambiguous(seq, p, i, patternLen, maxErr, curErr);
+            } else {
+                match = match_pattern(seq, p, i, patternLen, maxErr, curErr);
             }
-
             if( match ) {
                 ++currentPos;
                 res.region.startPos = i;
-                res.region.len = patternLen;
-                res.err = 0;
-                res.complement = ci == 1;
+                res.region.length = patternLen;
+                res.err = curErr;
+                res.strand = (ci == 1) ? U2Strand::Complementary : U2Strand::Direct;
 
                 rl->onResult(res);
 //                res.clear();
@@ -387,9 +470,10 @@ void FindAlgorithm::find(
                          DNATranslation* complTT, // if complTT!=NULL -> sequence is complemented before comparison with pattern
                          FindAlgorithmStrand strand, // if not direct there complTT must not be NULL
                          bool insDel,
+                         bool useAmbiguousBases,
                          const char* seq, 
                          int seqLen, 
-                         const LRegion& range,  
+                         const U2Region& range,  
                          const char* pattern, 
                          int patternLen, 
                          bool singleShot, 
@@ -404,7 +488,7 @@ void FindAlgorithm::find(
 
     if( !insDel ) {
         find_subst( rl, aminoTT, complTT, strand, seq, range, pattern, patternLen,
-            singleShot, maxErr, stopFlag, percentsCompleted, currentPos );
+            singleShot, useAmbiguousBases, maxErr, stopFlag, percentsCompleted, currentPos );
         return;
     }
 
@@ -431,7 +515,7 @@ void FindAlgorithm::find(
         StrandContext(width, height, insDel, complPattern)
     };
 
-    int onePercentLen = range.len/100;
+    int onePercentLen = range.length/100;
     int leftTillPercent = onePercentLen;
     percentsCompleted = 0;
     currentPos = range.startPos;
@@ -468,7 +552,7 @@ void FindAlgorithm::find(
 
             if (err <= maxErr) {
                 int newLen = dt.getLastLen();
-                if (res.isEmpty() || res.err > err || (res.err == err && newLen < res.region.len)) {
+                if (res.isEmpty() || res.err > err || (res.err == err && newLen < res.region.length)) {
                     //                    assert(newLen + maxErr >= patternLen);
                     int newStart = i-newLen+1;
                     if (insDel || (range.contains(newStart) && range.contains(newStart + newLen - 1))) {//boundary check for mismatch mode                      
@@ -477,9 +561,10 @@ void FindAlgorithm::find(
                         assert(newStart+newLen <= range.endPos());
 
                         res.region.startPos = newStart;
-                        res.region.len = newLen;
+                        res.region.length = newLen;
                         res.err = err;
-                        res.complement = ci == 1;
+                        res.strand = (ci == 1) ? U2Strand::Complementary : U2Strand::Direct;
+                        res.translation = (aminoTT != NULL) ? true : false; 
                         if( !insDel && singleShot ) {
                             rl->onResult( res );
                             res.clear();
@@ -502,10 +587,15 @@ void FindAlgorithm::find(
 
     for (int i=0; i<2; i++) {
         if (!context[i].res.isEmpty()) { //todo: order by startpos?
-            assert(insDel || context[i].res.region.len == patternLen);
+            assert(insDel || context[i].res.region.length == patternLen);
             rl->onResult(context[i].res);
         }
     }
 }
 
+
+
+
+
+
 }//namespace
