@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "SArrayIndex.h"
 #include "SArrayIndexSerializer.h"
@@ -76,18 +87,20 @@ void CreateSArrayIndexTask::cleanup() {
 SArrayIndex::SArrayIndex(const char *_seqStart, const quint32* _bitTable, int _bitCharLen)
 :  w(0), w4(0), wRest(0), skipGap(0), gapOffset(0),
 arrLen(0), sArray(NULL), bitMask(NULL), bitFilter(0),
-wCharsInMask(0), wAfterBits(0), seqStart(_seqStart), seqLen(0),
-l1Step(0), L1_SIZE(0), l1bitMask(NULL),
-bitTable(_bitTable), bitCharLen(_bitCharLen)
+wCharsInMask(0), wAfterBits(0),
+bitTable(_bitTable), bitCharLen(_bitCharLen),
+seqStart(_seqStart), seqLen(0),
+l1Step(0), L1_SIZE(0), l1bitMask(NULL)
 {
 
 }
 
+
 SArrayIndex::SArrayIndex(const char* seq, quint32 seqSize,  quint32 _len, TaskStateInfo& ti, 
                          char unknownChar, const quint32* _bitTable,  int _bitCharLen, int _gap, int _gapOffset)
-                         : w(_len), w4(_len/4), wRest(_len%4), skipGap(_gap),
-                         gapOffset(_gapOffset), l1Step(0), L1_SIZE(0), l1bitMask(NULL),
-                         bitTable(_bitTable), bitCharLen(_bitCharLen)
+                         : w(_len), w4(_len/4), wRest(_len%4), skipGap(_gap), gapOffset(_gapOffset),
+                         bitTable(_bitTable), bitCharLen(_bitCharLen),
+                         l1Step(0), L1_SIZE(0), l1bitMask(NULL)
 {
     quint64 t1 = GTimer::currentTimeMicros();
     seqLen = seqSize;
