@@ -1,12 +1,25 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
+
+#include <QtCore/QStack>
 
 #include "MAlignment.h"
 
@@ -306,6 +319,9 @@ void MAlignmentRow::setName(const QString& newName) {
 }
 
 bool MAlignmentRow::operator==(const MAlignmentRow& row) const {
+    if (row.name != this->name) {
+        return false;
+    }
     if (offset == row.offset && sequence == row.sequence) {
         return true;
     }
@@ -478,20 +494,20 @@ int MAlignment::estimateMemorySize() const {
     return result;
 }
 
-bool MAlignment::crop(const LRegion& range, const QSet<QString>& seqNames ){
+bool MAlignment::crop(const U2Region& range, const QSet<QString>& seqNames ){
     MAStateCheck check(this);
 
     QList<MAlignmentRow> newList, oldList = rows;
     foreach(const MAlignmentRow& row, rows){
         const QString& rowName = row.getName();
         if (seqNames.contains(rowName)){
-            MAlignmentRow newRow = row.mid(range.startPos, range.len);
+            MAlignmentRow newRow = row.mid(range.startPos, range.length);
             newList.append(newRow);
         }
     }
     //TODO: is modified?
     rows = newList;
-    length = range.len;
+    length = range.length;
     return true;
 }
 
@@ -686,6 +702,38 @@ void MAlignment::sortRowsByName(bool asc) {
 }
 
 
+void MAlignment::moveRowsBlock( int startRow, int numRows, int delta )
+{
+    MAStateCheck check(this);
+
+    // Assumption: numRows is rather big, delta is small (1~2) 
+    // It's more optimal to move abs(delta) of rows then the block itself
+    
+    int i = 0;
+    int k = qAbs(delta);
+
+    assert ( ( delta > 0 && startRow + numRows + delta - 1 < rows.length() )
+        || (delta < 0 && startRow + delta >= 0 && startRow + qAbs(delta) <= rows.length() )  );
+
+    QStack<MAlignmentRow> toMove;
+    int fromRow = delta > 0 ? startRow + numRows  : startRow + delta; 
+
+    while (i <  k ) {
+        MAlignmentRow row = rows.takeAt(fromRow);
+        toMove.push(row);
+        i++;
+    }
+    
+    int toRow = delta > 0 ? startRow : startRow + numRows - k;
+
+    while ( toMove.count() > 0 ) {
+        MAlignmentRow row = toMove.pop();
+        rows.insert(toRow, row);
+    }
+    
+}
+
+
 QStringList MAlignment::getRowNames() const {
     QStringList rowNames;
     foreach(const MAlignmentRow& r, rows) {
@@ -704,6 +752,11 @@ void MAlignment::check() const {
 #endif
 }
 
+static bool _registerMeta() {
+    qRegisterMetaType<MAlignment>("MAlignment");
+    return true;
+}
 
+bool MAlignment::registerMeta = _registerMeta();
 
-}//namespace
+}//namespace U2
