@@ -1,23 +1,37 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "AnnotationTableObject.h"
 #include "GObjectTypes.h"
 #include "DNASequenceObject.h"
+
 #include <U2Core/Timer.h>
 #include <U2Core/DNATranslation.h>
 #include <U2Core/TextUtils.h>
-#include <QtCore/QBitArray>
+#include <U2Core/U2SafePoints.h>
 
+#include <QtCore/QBitArray>
 // for Qt::escape
 #include <QtGui/QTextDocument>
+#include <U2Core/AppContext.h>
 
 
 namespace U2 {
@@ -31,7 +45,7 @@ Annotation::~Annotation() {
 }
 
 bool Annotation::isValidQualifierName(const QString& s) {
-    return !s.isEmpty() && s.length() < 20;
+    return !s.isEmpty() && s.length() < 20 && TextUtils::fits(TextUtils::QUALIFIER_NAME_CHARS, s.toAscii().data(), s.length());
 }
 
 bool Annotation::isValidQualifierValue(const QString& s) {
@@ -57,7 +71,7 @@ bool Annotation::isValidAnnotationName(const QString& n) {
     if (name[0] == ' ' || name[name.size() - 1] == ' ') {
         return false;
     }
-    return true;
+    return TextUtils::fits(TextUtils::ANNOTATIONS_NAME_CHARS, n.toAscii().data(), n.length());
 }
 
 QString Annotation::getQualifiersTip(int maxRows, DNASequenceObject* seq, DNATranslation* comlTT, DNATranslation* aminoTT) const {
@@ -67,11 +81,11 @@ QString Annotation::getQualifiersTip(int maxRows, DNASequenceObject* seq, DNATra
     if (d->qualifiers.size() != 0) {
         tip += "<nobr>";
         bool first = true;
-        foreach (Qualifier q, d->qualifiers) {
+        foreach (const U2Qualifier& q, d->qualifiers) {
             if (++rows > maxRows) {
                 break;
             }
-            QString val = q.getQualifierValue();
+            QString val = q.value;
             if(val.length() > QUALIFIER_VALUE_CUT) {
                 val = val.left(QUALIFIER_VALUE_CUT) + " ...";
             }
@@ -80,14 +94,14 @@ QString Annotation::getQualifiersTip(int maxRows, DNASequenceObject* seq, DNATra
             } else {
                 tip +=  "<br>";
             }
-            tip += "<b>" + Qt::escape(q.getQualifierName()) + "</b> = " + Qt::escape(val);
+            tip += "<b>" + Qt::escape(q.name) + "</b> = " + Qt::escape(val);
         }
         tip += "</nobr>";
     }
-    if (seq && rows <= maxRows && (!isOnComplementStrand() || comlTT != NULL)) {
-        QList<LRegion> loc(getLocation());
-        if (isOnComplementStrand()) {
-            qStableSort(loc.begin(), loc.end(), qGreater<LRegion>()); 
+    if (seq && rows <= maxRows && (getStrand().isCompementary() || comlTT != NULL)) {
+        QVector<U2Region> loc = getRegions();
+        if (getStrand().isCompementary()) {
+            qStableSort(loc.begin(), loc.end(), qGreater<U2Region>()); 
         }
         QString seqVal;
         QString aminoVal;
@@ -100,12 +114,12 @@ QString Annotation::getQualifiersTip(int maxRows, DNASequenceObject* seq, DNATra
             if (!aminoVal.isEmpty()) {
                 aminoVal += "^";
             }
-            const LRegion& r = loc.at(i);
-            int len = qMin(r.len, QUALIFIER_VALUE_CUT - seqVal.length());
-            if (len != r.len) {
+            const U2Region& r = loc.at(i);
+            int len = qMin(int(r.length), QUALIFIER_VALUE_CUT - seqVal.length());
+            if (len != r.length) {
                 complete = false;
             }
-            if (isOnComplementStrand()) {
+            if (getStrand().isCompementary()) {
                 const char* str = seq->getSequence().constData() + r.endPos() - len;
                 QByteArray ba(str, len);
                 comlTT->translate(ba.data(), len);
@@ -131,9 +145,9 @@ QString Annotation::getQualifiersTip(int maxRows, DNASequenceObject* seq, DNATra
         }
         if(!complete || seqVal.length() > QUALIFIER_VALUE_CUT) {
             seqVal = seqVal.left(QUALIFIER_VALUE_CUT) + " ...";
-            if (aminoVal.length() > QUALIFIER_VALUE_CUT) {
-                aminoVal = aminoVal.left(QUALIFIER_VALUE_CUT) + " ...";
-            }
+        }
+        if(!complete || aminoVal.length() > QUALIFIER_VALUE_CUT) {
+            aminoVal = aminoVal.left(QUALIFIER_VALUE_CUT) + " ...";
         }
         if (!tip.isEmpty()) {
             tip+="<br>";
@@ -150,19 +164,47 @@ QString Annotation::getQualifiersTip(int maxRows, DNASequenceObject* seq, DNATra
     return tip;
 }
 
-const QString& Annotation::getAnnotationName() const {
-    return d->name;
+bool Annotation::annotationLessThan(Annotation *first, Annotation *second) {
+    QListIterator<AnnotationGroup *> firstIterator(first->getGroups());
+    QListIterator<AnnotationGroup *> secondIterator(second->getGroups());
+    while(firstIterator.hasNext() && secondIterator.hasNext()) {
+        if (firstIterator.peekNext()->getGroupName() < secondIterator.peekNext()->getGroupName()) {
+            return true;
+        }
+        if (firstIterator.peekNext()->getGroupName() > secondIterator.peekNext()->getGroupName()) {
+            return false;
+        }
+        firstIterator.next();
+        secondIterator.next();
+    }
+    if (secondIterator.hasNext()) {
+        if(first->getAnnotationName() < secondIterator.peekNext()->getGroupName()) {
+            return true;
+        }
+        if(first->getAnnotationName() > secondIterator.peekNext()->getGroupName()) {
+            return false;
+        }
+        secondIterator.next();
+    }
+    if (firstIterator.hasNext()) {
+        if(firstIterator.peekNext()->getGroupName() < second->getAnnotationName()) {
+            return true;
+        }
+        if(firstIterator.peekNext()->getGroupName() > second->getAnnotationName()) {
+            return false;
+        }
+        firstIterator.next();
+    }
+    if (secondIterator.hasNext()) {
+        return true;
+    }
+    if (firstIterator.hasNext()) {
+        return false;
+    }
+    return (first->getAnnotationName() < second->getAnnotationName());
 }
 
-TriState Annotation::getAminoFrame() const {
-    return d->aminoFrame;
-}
-
-const QList<LRegion>& Annotation::getLocation() const  {
-    return d->location;
-}
-
-const QVector<Qualifier>& Annotation::getQualifiers() const {
+const QVector<U2Qualifier>& Annotation::getQualifiers() const {
     return d->qualifiers;
 }
 
@@ -170,7 +212,7 @@ void Annotation::setAnnotationName(const QString& newName) {
     if (newName == d->name) {
         return;
     }
-    assert(!newName.isEmpty());
+    SAFE_POINT(!newName.isEmpty(), "Annotation name is empty!",);
     QString oldName = d->name;
     d->name = newName;
     if (obj!=NULL) {
@@ -180,11 +222,11 @@ void Annotation::setAnnotationName(const QString& newName) {
     }
 }
 
-void Annotation::setOnComplementStrand(bool v) {
-    if (d->complement == v) {
+void Annotation::setLocationOperator(U2LocationOperator op) {
+    if (op == getLocationOperator()) {
         return;
     }
-    d->complement = v;
+    d->setLocationOperator(op);
     if (obj!=NULL) {
         obj->setModified(true);
         AnnotationModification md(AnnotationModification_LocationChanged, this);
@@ -192,11 +234,11 @@ void Annotation::setOnComplementStrand(bool v) {
     }
 }
 
-void Annotation::setOrder(bool v) {
-    if (d->order== v) {
+void Annotation::setStrand(U2Strand s) {
+    if (s == getStrand()) {
         return;
     }
-    d->order = v;
+    d->setStrand(s);
     if (obj!=NULL) {
         obj->setModified(true);
         AnnotationModification md(AnnotationModification_LocationChanged, this);
@@ -204,11 +246,9 @@ void Annotation::setOrder(bool v) {
     }
 }
 
-void Annotation::setaminoFrame(TriState v) {
-    if (getAminoFrame() == v) {
-        return;
-    }
-    d->aminoFrame = v;
+
+void Annotation::addLocationRegion(const U2Region& reg) {
+    d->location->regions.append(reg);
     if (obj!=NULL) {
         obj->setModified(true);
         AnnotationModification md(AnnotationModification_LocationChanged, this);
@@ -216,22 +256,7 @@ void Annotation::setaminoFrame(TriState v) {
     }
 }
 
-void Annotation::addLocationRegion(const LRegion& reg) {
-#ifdef _DEBUG
-    //check that annotation region does not cross other regions
-    foreach(const LRegion& tmp, getLocation()) {
-        assert(!tmp.intersects(reg));
-    }
-#endif
-    d->location.append(reg);
-    if (obj!=NULL) {
-        obj->setModified(true);
-        AnnotationModification md(AnnotationModification_LocationChanged, this);
-        obj->emit_onAnnotationModified(md);
-    }
-}
-
-void Annotation::addQualifier(const Qualifier& q) {
+void Annotation::addQualifier(const U2Qualifier& q) {
     d->qualifiers.append(q);
     if (obj!=NULL) {
         obj->setModified(true);
@@ -240,28 +265,8 @@ void Annotation::addQualifier(const Qualifier& q) {
     }
 }
 
-void Annotation::removeLocationRegion(const LRegion& reg) {
-    d->location.removeOne(reg);
-    if (obj!=NULL) {
-        obj->setModified(true);
-        AnnotationModification md(AnnotationModification_LocationChanged, this);
-        obj->emit_onAnnotationModified(md);
-    }
-}
 
-void Annotation::replaceLocationRegions(const QList<LRegion>& reg){
-    d->location.clear();
-    foreach(LRegion region, reg){
-        d->location.append(region);
-    }
-    if (obj!=NULL) {
-        obj->setModified(true);
-        AnnotationModification md(AnnotationModification_LocationChanged, this);
-        obj->emit_onAnnotationModified(md);
-    }
-}
-
-void Annotation::removeQualifier(const Qualifier& q) {
+void Annotation::removeQualifier(const U2Qualifier& q) {
     assert(d->qualifiers.contains(q));
     int idx = d->qualifiers.indexOf(q);
     d->qualifiers.remove(idx);
@@ -272,6 +277,25 @@ void Annotation::removeQualifier(const Qualifier& q) {
     }
 }
 
+void Annotation::setLocation(const U2Location& location ) {
+    d->location = location;
+    if (obj!=NULL) {
+        AnnotationModification md(AnnotationModification_LocationChanged, this);
+        obj->emit_onAnnotationModified(md);
+    }
+}
+
+void Annotation::replaceRegions(const QVector<U2Region>& regions) {
+    if (d->location->regions == regions) {
+        return;
+    }
+    d->location->regions = regions;
+    if (obj!=NULL) {
+        AnnotationModification md(AnnotationModification_LocationChanged, this);
+        obj->emit_onAnnotationModified(md);
+    }
+}
+
 //////////////////////////////////////////////////////////////////////////
 // Group
 
@@ -302,7 +326,7 @@ void AnnotationGroup::addAnnotation(Annotation* a) {
         return;
     }
 
-    assert(a->getGObject() == obj);
+    SAFE_POINT(a->getGObject() == obj, "Illegal object!",);
     assert(/*!annotations.contains(a) && */! a->groups.contains(this));
 
     obj->setModified(true);
@@ -341,7 +365,7 @@ void AnnotationGroup::removeAnnotations(const QList<Annotation*>& ans) {
 void AnnotationGroup::removeAnnotation(Annotation* a) {
     assert(annotations.contains(a) && a->groups.contains(this));
     if (a->groups.size() == 1) {
-        assert(a->groups.first() == this);
+        SAFE_POINT(a->groups.first() == this, "Illegal group!",);
         obj->removeAnnotation(a);
     } else {
         annotations.removeOne(a);
@@ -404,14 +428,11 @@ AnnotationGroup* AnnotationGroup::getSubgroup(const QString& path, bool create)
 }
 
 void AnnotationGroup::removeSubgroup(AnnotationGroup* g) {
-    assert(g->getParentGroup() == this);
-    if (g->getParentGroup() != this) {
-        return;
-    }
+    SAFE_POINT(g->getParentGroup() == this, "Illegal parent group!",);
+    
     obj->setModified(true);
     g->clear();
     subgroups.removeOne(g);
-    g->obj = NULL;
     obj->emit_onGroupRemoved(this, g);
     delete g;
 }
@@ -549,7 +570,8 @@ GObject* AnnotationTableObject::clone() const {
 }
 
 void AnnotationTableObject::addAnnotation(Annotation* a, const QString& groupName) {
-    assert(a->obj == NULL);
+    SAFE_POINT(a->obj == NULL, "Annotation belongs to another object", );
+
     a->obj = this;
     const QString& aName = a->getAnnotationName();
     AnnotationGroup* defaultGroup = rootGroup->getSubgroup(groupName.isEmpty() ? aName : groupName, true); 
@@ -561,7 +583,7 @@ void AnnotationTableObject::addAnnotation(Annotation* a, const QString& groupNam
 }
 
 void AnnotationTableObject::addAnnotation(Annotation* a, QStringList& groupsNames) {
-    assert(a->obj == NULL);
+    SAFE_POINT(a->obj == NULL, "Annotation belongs to another object", );
     if(groupsNames.isEmpty()){
         addAnnotation(a);
         return;
@@ -625,6 +647,53 @@ void AnnotationTableObject::removeAnnotations(const QList<Annotation*>& annotati
     qDeleteAll(annotations);
 }
 
+void AnnotationTableObject::removeAnnotationsInGroup(const QList<Annotation*>& _annotations, AnnotationGroup *group) {
+    /*annotations = annotations.toSet().subtract(_annotations.toSet()).toList();
+    foreach(Annotation* a, _annotations) {
+        a->obj = NULL;
+        foreach(AnnotationGroup* ag, a->getGroups()) {
+            ag->annotations.removeOne(a);
+        }
+    }*/
+    int recv = receivers(SIGNAL(si_onAnnotationsInGroupRemoved(const QList<Annotation*>&, AnnotationGroup*)));
+    annLocker.setToDelete(_annotations, group, recv);
+    DeleteAnnotationsFromObjectTask *task = new DeleteAnnotationsFromObjectTask(_annotations, this, group);
+    AppContext::getTaskScheduler()->registerTopLevelTask(task);
+    
+    /*int recv = receivers(SIGNAL(si_onAnnotationsInGroupRemoved(const QList<Annotation*>&, AnnotationGroup*)));
+    annLocker.setToDelete(_annotations, group, recv);
+    emit si_onAnnotationsInGroupRemoved(_annotations, group);
+    setModified(true);*/
+    //qDeleteAll(annotations);
+}
+
+void DeleteAnnotationsFromObjectTask::run() {
+    /*aobj->annotations = aobj->annotations.toSet().subtract(anns.toSet()).toList();
+    foreach(Annotation* a, anns) {
+        a->obj = NULL;
+        foreach(AnnotationGroup* ag, a->getGroups()) {
+            ag->annotations.removeOne(a);
+        }
+    }*/
+    foreach(Annotation* a, anns) {
+        aobj->_removeAnnotation(a);
+    }
+}
+
+Task::ReportResult DeleteAnnotationsFromObjectTask::report() {
+    aobj->emit_onAnnotationsInGroupRemoved(anns, group);
+    aobj->setModified(true);
+    return ReportResult_Finished;
+}
+
+void AnnotationTableObject::releaseLocker() {
+    annLocker.releaseLocker();
+}
+
+bool AnnotationTableObject::isLocked() const {
+    return annLocker.isLocked();
+}
+
 void AnnotationTableObject::removeAnnotation(Annotation* a) {
     QList<Annotation*> v; 
     v<<a;
@@ -635,7 +704,7 @@ void AnnotationTableObject::removeAnnotation(Annotation* a) {
 }
 
 void AnnotationTableObject::_removeAnnotation(Annotation* a) {
-    assert(a->getGObject() == this);
+    SAFE_POINT(a->getGObject() == this, "Illegal annotation object!",);
     a->obj = NULL;
     annotations.removeOne(a);
     foreach(AnnotationGroup* ag, a->getGroups()) {
@@ -654,10 +723,11 @@ void AnnotationTableObject::selectAnnotationsByName(const QString& name, QList<A
 
 bool AnnotationTableObject::checkConstraints(const GObjectConstraints* c) const {
     const AnnotationTableObjectConstraints* ac = qobject_cast<const AnnotationTableObjectConstraints*>(c);
-    assert(ac!=NULL);
+    SAFE_POINT(ac != NULL, "Illegal constraints type!", false);
+
     int fitSize = ac->sequenceSizeToFit;
     foreach(Annotation* a, annotations) {
-        foreach(const LRegion& r, a->getLocation()) {
+        foreach(const U2Region& r, a->getRegions()) {
             if (r.endPos() > fitSize) {
                 return false;
             }
@@ -666,6 +736,11 @@ bool AnnotationTableObject::checkConstraints(const GObjectConstraints* c) const
     return true;
 }
 
+void AnnotationTableObject::cleanAnnotations() {
+    assert(!annLocker.isLocked());
+    annLocker.sl_Clean();
+
+}
 AnnotationTableObjectConstraints::AnnotationTableObjectConstraints(const AnnotationTableObjectConstraints& c, QObject* p) 
 : GObjectConstraints(GObjectTypes::ANNOTATION_TABLE, p), sequenceSizeToFit(c.sequenceSizeToFit)
 {
@@ -679,12 +754,11 @@ AnnotationTableObjectConstraints::AnnotationTableObjectConstraints(QObject* p)
 
 
 bool annotationLessThanByRegion(const Annotation* a1, const Annotation* a2) {
-    assert(!a1->getLocation().isEmpty());
-    assert(!a2->getLocation().isEmpty());
+    assert(!a1->getLocation()->isEmpty());
+    assert(!a2->getLocation()->isEmpty());
 
-    const LRegion& r1 = a1->getLocation().first();
-    const LRegion& r2 = a2->getLocation().first();
-    
+    const U2Region& r1 = a1->getRegions().first();
+    const U2Region& r2 = a2->getRegions().first();
     return r1 < r2;
 }
 
@@ -692,5 +766,32 @@ bool annotationGreaterThanByRegion( const Annotation* a1, const Annotation* a2 )
     return annotationLessThanByRegion(a2, a1);
 }
 
+
+void AnnotationsLocker::setToDelete( const QList<Annotation*>& _anns, AnnotationGroup *_parentGroup, int counter ) {
+    anns = _anns;
+    parentGroup = _parentGroup;
+    deleteCounter = counter;
+}
+
+void AnnotationsLocker::releaseLocker(){
+    if(deleteCounter) {
+        deleteCounter--;
+    }
+}
+
+bool AnnotationsLocker::isLocked() const{
+    return deleteCounter != 0;
+}
+
+void AnnotationsLocker::sl_Clean(){
+    if(deleteCounter == 0) {
+        qDeleteAll(anns);
+        anns.clear();
+        parentGroup->getParentGroup()->removeSubgroup(parentGroup);
+    }
+}
+
+AnnotationsLocker::AnnotationsLocker(): parentGroup(NULL), deleteCounter(0) {
+}
 }//namespace
 
