@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <U2Core/DocumentModel.h>
 #include <U2Core/GObject.h>
@@ -48,6 +59,16 @@ Document* DocumentFormat::loadDocument(IOAdapterFactory* iof, const GUrl& url, T
     return doc;
 }
 
+GObject* DocumentFormat::loadObject(IOAdapter*, TaskStateInfo& ti) {
+    ti.setError("This document format is not support streaming reading mode");
+    return NULL;
+}
+
+DNASequence* DocumentFormat::loadSequence(IOAdapter*, TaskStateInfo& ti) {
+    ti.setError("This document format is not support streaming reading mode");
+    return NULL;
+}
+
 void DocumentFormat::storeDocument( Document* , TaskStateInfo& ts, IOAdapter* ) {
     assert(0);
     ts.setError(tr("Writing is not supported for this format (%1). Feel free to send a feature request though.").arg(getFormatName()));
@@ -98,7 +119,7 @@ bool DocumentFormat::checkConstraints(const DocumentFormatConstraints& c) const
         return false; // filtered by exclude flags
     }
 
-    if (c.checkRawData && checkRawData(c.rawData) < c.minDataCheckResult) {
+    if (c.checkRawData && checkRawData(c.rawData).score < c.minDataCheckResult) {
         return false; //raw data is not matched
     }
 
@@ -136,34 +157,40 @@ bool DocumentFormat::isObjectOpSupported(const Document* d, DocObjectOp op, GObj
 
 Document::Document(DocumentFormat* _df, IOAdapterFactory* _io, const GUrl& _url, const QList<UnloadedObjectInfo>& unloadedObjects,
                    const QVariantMap& hints, const QString& instanceModLockDesc)
-: StateLockableTreeItem(), df(_df), io(_io), url(_url)
+                   : StateLockableTreeItem(), df(_df), io(_io), url(_url)
 {
     ctxState = new GHintsDefaultImpl(hints);
-
     name = url.fileName();
-    qFill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock*)NULL);    
     
+    qFill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock*)NULL);    
+
+    loadStateChangeMode = true;
     addUnloadedObjects(unloadedObjects);
+    loadStateChangeMode = false;
+    
     initModLocks(instanceModLockDesc, false);
     checkUnloadedState();
+    assert(!isModified());
 }
 
 Document::Document(DocumentFormat* _df, IOAdapterFactory* _io, const GUrl& _url, 
                    const QList<GObject*>& _objects, const QVariantMap& hints, const QString& instanceModLockDesc)
-: StateLockableTreeItem(), df(_df), io(_io), url(_url)
+                   : StateLockableTreeItem(), df(_df), io(_io), url(_url)
 {
     ctxState = new GHintsDefaultImpl(hints);
     name = url.fileName();
-    
-    qFill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock*)NULL);
 
+    loadStateChangeMode = true;
+    qFill(modLocks, modLocks + DocumentModLock_NUM_LOCKS, (StateLock*)NULL);
     foreach(GObject* o, _objects) {
         _addObject(o);
     }
+    loadStateChangeMode = false;
 
     initModLocks(instanceModLockDesc, true);
     
     checkLoadedState();
+    assert(!isModified());
 }
 
 Document::~Document() {
@@ -175,7 +202,7 @@ Document::~Document() {
         }
     }
     foreach(GObject* obj, objects) {
-        obj->setGHints(new GHintsDefaultImpl());
+        obj->setGHints(NULL);
     }
     delete ctxState;
 }
@@ -191,19 +218,15 @@ void Document::addObject(GObject* obj){
     _addObject(obj);
 }
 
-void Document::_addObjectToHierarchy(GObject* obj, bool ignoreLocks) {
-    assert(!isStateLocked() || ignoreLocks);
-    
-    bool modify = !ignoreLocks;
-    obj->setParentStateLockItem(this, ignoreLocks, modify);
+void Document::_addObjectToHierarchy(GObject* obj) {
+    obj->setParentStateLockItem(this);
     obj->setGHints(new ModTrackHints(this, obj->getGHintsMap(), true));
+    obj->setModified(false);
     objects.append(obj);
 }
 
-void Document::_addObject(GObject* obj, bool ignoreLocks) {
-    obj->setModified(false);
-    _addObjectToHierarchy(obj, ignoreLocks);
-
+void Document::_addObject(GObject* obj) {
+    _addObjectToHierarchy(obj);
     assert(objects.size() == getChildItems().size());
     emit si_objectAdded(obj);
 }
@@ -213,12 +236,11 @@ void Document::removeObject(GObject* obj) {
     _removeObject(obj);
 }
 
-void Document::_removeObject(GObject* obj, bool ignoreLocks) {
+void Document::_removeObject(GObject* obj) {
     assert(obj->getParentStateLockItem() == this);
     obj->setModified(false);
 
-    bool modify = !ignoreLocks;
-    obj->setParentStateLockItem(NULL, ignoreLocks, modify);
+    obj->setParentStateLockItem(NULL);
     objects.removeOne(obj);
     obj->setGHints(new GHintsDefaultImpl());
 
@@ -288,6 +310,7 @@ void Document::checkLoadedState() const {
 #endif
 }
 
+
 static StateLock* NULL_LOCK = NULL;
 
 void Document::loadFrom(const Document* d) {
@@ -305,14 +328,17 @@ void Document::loadFrom(const Document* d) {
     int totalLocks = locks.count();    
     assert(totalLocks == nDocLocks);
 #endif
+    
+    loadStateChangeMode = true;
 
     QMap<QString, UnloadedObjectInfo> unloadedInfo;
     foreach(GObject* obj, objects) { //remove all unloaded objects
         unloadedInfo.insert(obj->getGObjectName(), UnloadedObjectInfo(obj));
-        _removeObject(obj, true);
+        _removeObject(obj);
     }
-
-    ctxState->setMap(d->getGHints()->getMap());
+    ctxState->setAll(d->getGHints()->getMap());
+    
+    lastUpdateTime = d->getLastUpdateTime();
 
     //copy instance modlocks if any
     StateLock* mLock = modLocks[DocumentModLock_FORMAT_AS_INSTANCE];
@@ -326,9 +352,7 @@ void Document::loadFrom(const Document* d) {
         modLocks[DocumentModLock_FORMAT_AS_INSTANCE] = new StateLock(dLock->getUserDesc());
         lockState(modLocks[DocumentModLock_FORMAT_AS_INSTANCE]);
     }
-
-    setLoaded(true); 
-
+    
     QList<GObject*> objects = d->getObjects();
     foreach(GObject* origObj, objects) {
         GObject* clonedObj = origObj->clone();
@@ -337,15 +361,20 @@ void Document::loadFrom(const Document* d) {
         if (info.type == clonedObj->getGObjectType()) {
             QVariantMap mergedHints = clonedObj->getGHintsMap();
             foreach(const QString& k, info.hints.keys()) {
-                mergedHints.insert(k, info.hints.value(k));
+                if (!mergedHints.contains(k)) {
+                    mergedHints.insert(k, info.hints.value(k));
+                }
             }
             clonedObj->getGHints()->setMap(mergedHints);
         }
-        _addObject(clonedObj, true);
+        _addObject(clonedObj);
     }
     
+    setLoaded(true); 
+    
     //TODO: rebind local objects relations if url!=d.url
-    setModified(false);
+    
+    loadStateChangeMode = false;
     
     checkLoadedState();
 }
@@ -476,6 +505,8 @@ bool Document::unload() {
         return false;
     }
 
+    loadStateChangeMode = true;
+
     int nDocLocks = 0; 
     qCount(modLocks, modLocks + DocumentModLock_NUM_LOCKS, NULL_LOCK, nDocLocks);
     nDocLocks = DocumentModLock_NUM_LOCKS - nDocLocks;
@@ -487,44 +518,60 @@ bool Document::unload() {
     QList<UnloadedObjectInfo> unloadedInfo;
     foreach(GObject* obj, objects) { //Note: foreach copies object list
         unloadedInfo.append(UnloadedObjectInfo(obj));
-        _removeObject(obj, true);
+        _removeObject(obj);
     }
     addUnloadedObjects(unloadedInfo);
     
-    StateLock* fl =modLocks[DocumentModLock_FORMAT_AS_INSTANCE];
-    if (fl!=NULL) {
+    StateLock* fl = modLocks[DocumentModLock_FORMAT_AS_INSTANCE];
+    if (fl != NULL) {
         unlockState(fl);
         modLocks[DocumentModLock_FORMAT_AS_INSTANCE] = NULL;
     }
     
     setLoaded(false);
-    setModified(false);
+    
+    loadStateChangeMode = false;
 
     return true;
 }
 
+void Document::setModified(bool modified, const QString& modType) {
+    if (loadStateChangeMode && modified && modType == StateLockModType_AddChild) { //ignore modification events during loading/unloading
+        return;    
+    }
+    StateLockableTreeItem::setModified(modified, modType);
+}
+
+bool Document::isModificationAllowed(const QString& modType) {
+    bool ok = loadStateChangeMode && modType == StateLockModType_AddChild;
+    ok = ok || StateLockableTreeItem::isModificationAllowed(modType);
+    return ok;
+}
+
+
 void Document::setGHints(GHints* newHints) {
     assert(newHints!=NULL);
-
     //gobjects in document keep states in parent document map -> preserve gobject hints
-    QList<QVariantMap> objStates;
-    for (int i=0;i<objects.size();i++) {
-        objStates.append(objects[i]->getGHintsMap());
+    QList<QVariantMap> objectHints;
+    for (int i = 0; i < objects.size(); i++) {
+        GObject* obj = objects[i];
+        objectHints.append(obj->getGHintsMap());
     }
     
     delete ctxState;
     ctxState = newHints;
 
-    for (int i=0;i<objects.size();i++) {
-        objects[i]->getGHints()->setMap(objStates[i]);
+    for (int i = 0;i < objects.size(); i++) {
+        const QVariantMap& hints = objectHints[i];
+        GObject* obj = objects[i];
+        obj->getGHints()->setMap(hints);
     }
-
 }
 
 void Document::addUnloadedObjects(const QList<UnloadedObjectInfo>& info) {
     foreach(const UnloadedObjectInfo& oi, info) {
         UnloadedObject* obj = new UnloadedObject(oi);
-        _addObjectToHierarchy(obj, true);
+        _addObjectToHierarchy(obj);
         assert(obj->getDocument() == this);
         emit si_objectAdded(obj);    
     }
@@ -545,5 +592,24 @@ void Document::fromScriptValue(const QScriptValue &object, Document* &out)
 {
     out = qobject_cast<Document*>(object.toQObject()); 
 };
+
+void Document::setLastUpdateTime() {
+    QFileInfo fi(getURLString());
+    if (fi.exists()) {
+        lastUpdateTime = fi.lastModified();
+    }
+}
+void Document::propagateModLocks(Document* doc)  const {
+    for (int i = 0; i < DocumentModLock_NUM_LOCKS; i++) {
+        StateLock* lock = modLocks[i];
+        if (lock != NULL && doc->modLocks[i] != NULL) {
+            StateLock* newLock = new StateLock(lock->getUserDesc(), lock->getFlags());
+            doc->modLocks[i] = newLock;
+            doc->lockState(newLock);
+        }
+    }
+}
+
+
 }//namespace
 
