@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <U2Core/AppContext.h>
 #include <U2Core/AppSettings.h>
@@ -65,6 +76,7 @@ LoadRemoteDocumentTask::LoadRemoteDocumentTask( const QString& accId, const QStr
 Task("LoadRemoteDocument", TaskFlags_NR_FOSCOE | TaskFlag_MinimizeSubtaskErrorText), copyDataTask(NULL),
 loadDocumentTask(NULL), doc(NULL), accNumber(accId), dbName(dbNm) {
     
+    RemoteDBRegistry::getRemoteDBRegistry().convertAlias(dbName);
     sourceUrl = GUrl(RemoteDBRegistry::getRemoteDBRegistry().getURL(accId, dbName));
     
     if (sourceUrl.isHyperLink()) {
@@ -81,11 +93,13 @@ LoadRemoteDocumentTask::LoadRemoteDocumentTask(const QString & accId, const QStr
 Task("LoadRemoteDocument", TaskFlags_NR_FOSCOE | TaskFlag_MinimizeSubtaskErrorText), copyDataTask(NULL), 
 loadDocumentTask(NULL), doc(NULL), accNumber(accId), dbName(dbNm) {
     
+    RemoteDBRegistry::getRemoteDBRegistry().convertAlias(dbName);
     sourceUrl = GUrl(RemoteDBRegistry::getRemoteDBRegistry().getURL(accId, dbName));
     if( sourceUrl.isHyperLink() ) {
         fileName = sourceUrl.fileName();
     } else {
         format = getFileFormat(dbName);
+        accNumber.replace(";",",");
         QStringList accIds = accNumber.split(",");
         if (accIds.size() == 1 ) {
             fileName = accNumber + "." + format;
@@ -168,8 +182,13 @@ void LoadRemoteDocumentTask::prepare() {
     } else {
         assert(sourceUrl.isLocalFile());
         QString dbId = RemoteDBRegistry::getRemoteDBRegistry().getDbEntrezName(dbName);
-        loadDataFromEntrezTask = new LoadDataFromEntrezTask(dbId, accNumber,format,fullPath);
-        addSubTask(loadDataFromEntrezTask);
+        if(dbId.isEmpty()) {
+            setError(tr("Undefined database: '%1'").arg(dbName));
+            return;
+        } else {
+            loadDataFromEntrezTask = new LoadDataFromEntrezTask(dbId, accNumber,format,fullPath);
+            addSubTask(loadDataFromEntrezTask);
+        }
     }
 }
 
@@ -181,7 +200,7 @@ Task::ReportResult LoadRemoteDocumentTask::report()
 QList<Task*> LoadRemoteDocumentTask::onSubTaskFinished( Task* subTask )
 {
     QList<Task*> subTasks;
-    if (subTask->hasErrors()) {
+    if (subTask->hasError()) {
         if( subTask == copyDataTask || subTask == loadDataFromEntrezTask ) {
             setError(tr("Cannot find %1 in %2 database").arg(accNumber).arg(dbName) + ": " + subTask->getError());
         }
@@ -222,12 +241,12 @@ bool LoadRemoteDocumentTask::initLoadDocumentTask(  )
 
     // Detect format
     if (formatId.isEmpty()) {
-        QList<DocumentFormat*> formats = DocumentUtils::detectFormat(fullPath);
+        QList<FormatDetectionResult> formats = DocumentUtils::detectFormat(fullPath);
         if (formats.isEmpty()) {
             stateInfo.setError("Unknown file format!");
             return false;
         } else {
-            formatId = formats.first()->getFormatId();
+            formatId = formats.first().format->getFormatId();
         }
     }
     IOAdapterFactory * iow = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::LOCAL_FILE);
@@ -297,7 +316,13 @@ RecentlyDownloadedCache::~RecentlyDownloadedCache()
 
 
 LoadDataFromEntrezTask::LoadDataFromEntrezTask( const QString& dbId, const QString& accNum, const QString& retType, const QString& path )
-: Task("LoadDataFromEntrez", TaskFlags_FOSCOE | TaskFlag_MinimizeSubtaskErrorText), db(dbId), accNumber(accNum), fullPath(path), format(retType) {
+: Task("LoadDataFromEntrez", TaskFlags_FOSCOE | TaskFlag_MinimizeSubtaskErrorText), db(dbId), 
+accNumber(accNum), fullPath(path), format(retType) {
+}
+
+LoadDataFromEntrezTask::~LoadDataFromEntrezTask() {
+    delete loop;
+    delete networkManager;
 }
 
 void LoadDataFromEntrezTask::run()
@@ -306,7 +331,7 @@ void LoadDataFromEntrezTask::run()
     ioLog.trace("Load data from Entrez started...");
     loop = new QEventLoop;
 
-    networkManager = new QNetworkAccessManager(this);
+    networkManager = new QNetworkAccessManager();
     connect(networkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(sl_replyFinished(QNetworkReply*)));
     
     NetworkConfiguration* nc = AppContext::getAppSettings()->getNetworkConfiguration();
@@ -329,7 +354,7 @@ void LoadDataFromEntrezTask::run()
     if (resultIndex.isEmpty()) {
         stateInfo.setError("Result not found");
     }
-    if (stateInfo.hasErrors()  ) {
+    if (stateInfo.hasError()  ) {
         return;
     }
     
@@ -352,15 +377,20 @@ void LoadDataFromEntrezTask::run()
     loop->exec();
     ioLog.trace("Download finished.");
     
+    QByteArray result = downloadReply->readAll();
+    if ( ( result.size() < 100 ) && result.contains("Nothing has been found")) {
+        setError(tr("Sequence with ID=%1 is not found.").arg(accNumber));
+        return;
+    }
+
     QFile downloadedFile(fullPath);
     if (!downloadedFile.open(QIODevice::WriteOnly)) {
         stateInfo.setError("Cannot open file to write!");
         return;
     }
-
-    downloadedFile.write(downloadReply->readAll());
-    downloadedFile.close();
     
+    downloadedFile.write(result);
+    downloadedFile.close();
 }
 
 void LoadDataFromEntrezTask::sl_replyFinished( QNetworkReply* reply )
@@ -383,7 +413,6 @@ void LoadDataFromEntrezTask::sl_replyFinished( QNetworkReply* reply )
         
     }
     loop->exit();
-    
 }
 
 void LoadDataFromEntrezTask::sl_onError( QNetworkReply::NetworkError error )
@@ -439,12 +468,6 @@ bool ESearchResultHandler::fatalError( const QXmlParseException &exception )
 {
     Q_UNUSED(exception);
     assert(0);
-//     QMessageBox::information( NULL, QObject::tr("SAX Bookmarks"),
-//         QObject::tr("Parse error at line %1, column %2:\n"
-//         "%3")
-//         .arg(exception.lineNumber())
-//         .arg(exception.columnNumber())
-//         .arg(exception.message()));
     return false;
 
 }
@@ -455,6 +478,12 @@ RemoteDBRegistry::RemoteDBRegistry()
 {
     queryDBs.insert(GENBANK_DNA,  GENBANK_NUCLEOTIDE_ID);
     queryDBs.insert(GENBANK_PROTEIN, GENBANK_PROTEIN_ID);
+
+    aliases.insert("genbank", GENBANK_DNA);
+    aliases.insert("genbank-protein", GENBANK_PROTEIN);
+    aliases.insert("pdb", PDB);
+    aliases.insert("swissprot", SWISS_PROT);
+    aliases.insert("uniprot", UNIPROTKB_SWISS_PROT);
     
     const QMap<QString,DBXRefInfo>& entries = AppContext::getDBXRefRegistry()->getEntries();
     foreach(const DBXRefInfo& info, entries.values()) {
@@ -507,4 +536,12 @@ QString RemoteDBRegistry::getHint( const QString& dbName )
 
 }
 
+void RemoteDBRegistry::convertAlias( QString& dbName )
+{
+    if (aliases.contains(dbName)) {
+        dbName = aliases.value(dbName);
+    }
+
+}
+
 } //namespace
