@@ -1,17 +1,29 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 
 
 #include <U2Core/Log.h>
 #include <U2Core/AppContext.h>
+#include <U2Core/DocumentModel.h>
 #include <U2Lang/IntegralBusModel.h>
 #include <U2Misc/DialogUtils.h>
 #include <U2Core/SaveDocumentTask.h>
@@ -19,6 +31,7 @@
 
 #include "DelegateEditors.h"
 #include <U2Lang/WorkflowUtils.h>
+#include <U2Core/GUrlUtils.h>
 
 namespace U2 {
 
@@ -29,10 +42,11 @@ QWidget *SpinBoxDelegate::createEditor(QWidget *parent,
     const QStyleOptionViewItem &/* option */,
     const QModelIndex &/* index */) const
 {
-    QSpinBox *editor = new QSpinBox(parent);
-    WorkflowUtils::setQObjectProperties(*editor, spinProperties);
+    currentEditor = new QSpinBox(parent);
+    connect(currentEditor, SIGNAL(valueChanged(int)), SIGNAL(si_valueChanged(int)));
+    WorkflowUtils::setQObjectProperties(*currentEditor, spinProperties);
 
-    return editor;
+    return currentEditor;
 }
 
 void SpinBoxDelegate::setEditorData(QWidget *editor,
@@ -59,6 +73,13 @@ QVariant SpinBoxDelegate::getDisplayValue( const QVariant& v) const {
     return editor.text();
 }
 
+void SpinBoxDelegate::setEditorProperty(const char* name, const QVariant& val ) {
+    spinProperties[name] = val;
+    if (!currentEditor.isNull()) {
+        currentEditor->setProperty(name, val);
+    }
+}
+
 /********************************
 * DoubleSpinBoxDelegate
 ********************************/
@@ -146,21 +167,62 @@ QVariant ComboBoxDelegate::getDisplayValue(const QVariant& val) const {
 ********************************/
 void URLLineEdit::sl_onBrowse() {
     LastOpenDirHelper lod(type);
+    QString lastDir = lod.dir;
+    if(!text().isEmpty()) {
+        QString curPath(text());
+        int slashPos = curPath.lastIndexOf("/");
+        slashPos = qMax(slashPos, curPath.lastIndexOf("\\"));
+        if (slashPos >= 0) {
+            QDir dir(curPath.left(slashPos + 1));
+            if (dir.exists()) {
+                lastDir = dir.absolutePath();
+            }
+        }
+    }
 
     QString name;
     if(isPath){
-        lod.url = name = QFileDialog::getExistingDirectory(NULL, tr("Select a directory"), lod.dir);
+        lod.url = name = QFileDialog::getExistingDirectory(NULL, tr("Select a directory"), lastDir);
     }else if (multi) {
-        QStringList lst = QFileDialog::getOpenFileNames(NULL, tr("Select file(s)"), lod.dir, FileFilter);
+        QStringList lst = QFileDialog::getOpenFileNames(NULL, tr("Select file(s)"), lastDir, FileFilter);
         name = lst.join(";");
         if (!lst.isEmpty()) {
             lod.url = lst.first();
         }
     } else {
         if(saveFile) {
-            lod.url = name = QFileDialog::getSaveFileName(NULL, tr("Select a file"), lod.dir, FileFilter, 0, QFileDialog::DontConfirmOverwrite);
+            lod.url = name = QFileDialog::getSaveFileName(NULL, tr("Select a file"), lastDir, FileFilter, 0, QFileDialog::DontConfirmOverwrite);
+            DocumentFormat *format = AppContext::getDocumentFormatRegistry()->getFormatById(fileFormat);
+            if (NULL != format && !name.isEmpty()) {
+                QString newName(name);
+                GUrl url(newName);
+                QString lastSuffix = url.lastFileSuffix();
+                if ("gz" == lastSuffix) {
+                    int dotPos = newName.length() - lastSuffix.length() - 1;
+                    if ((dotPos >= 0) && (QChar('.') == newName[dotPos])) {
+                        newName = url.getURLString().left(dotPos);
+                        GUrl tmp(newName);
+                        lastSuffix = tmp.lastFileSuffix(); 
+                    }
+                }
+                bool foundExt = false;
+                foreach (QString supExt, format->getSupportedDocumentFileExtensions()) {
+                    if (lastSuffix == supExt) {
+                        foundExt = true;
+                        break;
+                    }
+                }
+                if (!foundExt) {
+                    name = name + "." + format->getSupportedDocumentFileExtensions().first();
+                } else {
+                    int dotPos = newName.length() - lastSuffix.length() - 1;
+                    if ((dotPos < 0) || (QChar('.') != newName[dotPos])) {
+                        name = name + "." + format->getSupportedDocumentFileExtensions().first();
+                    }
+                }
+            }
         } else {
-            lod.url = name = QFileDialog::getOpenFileName(NULL, tr("Select a file"), lod.dir, FileFilter );
+            lod.url = name = QFileDialog::getOpenFileName(NULL, tr("Select a file"), lastDir, FileFilter );
         }
     }
     if (!name.isEmpty()) {
@@ -170,6 +232,11 @@ void URLLineEdit::sl_onBrowse() {
     setFocus();
 }
 
+void URLLineEdit::focusOutEvent ( QFocusEvent * ) {
+    emit si_finished();
+}
+
+
 /********************************
 * URLDelegate
 ********************************/
@@ -178,7 +245,7 @@ QWidget *URLDelegate::createEditor(QWidget *parent,
                                        const QModelIndex &/* index */) const
 {
     QWidget * widget = new QWidget(parent);
-    URLLineEdit* documentURLEdit = new URLLineEdit(FileFilter, type, multi, isPath, saveFile, widget);
+    URLLineEdit* documentURLEdit = new URLLineEdit(FileFilter, type, multi, isPath, saveFile, widget, fileFormat);
     documentURLEdit->setObjectName("URLLineEdit");
     documentURLEdit->setFrame(false);
     documentURLEdit->setSizePolicy(QSizePolicy(QSizePolicy::Preferred,QSizePolicy::Preferred));
@@ -196,13 +263,21 @@ QWidget *URLDelegate::createEditor(QWidget *parent,
     layout->addWidget(toolButton);
 
     currentEditor = widget;
-    connect(documentURLEdit, SIGNAL(editingFinished()), SLOT(sl_commit()));
-    
+    connect(documentURLEdit, SIGNAL(si_finished()), SLOT(sl_commit()));
     return widget;
 }
 
 void URLDelegate::sl_commit() {
-    emit commitData(currentEditor);
+    URLLineEdit *edit = static_cast<URLLineEdit*>(sender());
+    //sender()->disconnect(this);
+    if(edit->text() != text) {
+        text = edit->text();
+        if (currentEditor) {
+            emit commitData(currentEditor);
+        }
+        //currentEditor->setFocusPolicy(Qt::NoFocus);
+    }
+    //connect(sender(), SIGNAL(editingFinished()), SLOT(sl_commit()));
 }
 
 void URLDelegate::setEditorData(QWidget *editor,
@@ -234,6 +309,19 @@ void URLDelegate::sl_showEditorButton( bool show ) {
     showButton = show;
 }
 
+void URLDelegate::sl_formatChanged(const QString &newFormat) {
+    if (newFormat.isEmpty()) {
+        return;
+    }
+
+    DocumentFormat *format = AppContext::getDocumentFormatRegistry()->getFormatById(newFormat);
+    if (NULL != format) {
+        FileFilter = DialogUtils::prepareDocumentsFileFilter(newFormat, true);
+    } else {
+        FileFilter = newFormat + " files (*." + newFormat + ")";
+    }
+    fileFormat = newFormat;
+}
 
 /********************************
 * FileModeDelegate
@@ -406,6 +494,10 @@ void StingListEdit::sl_onExpand()
     }
 }
 
+void StingListEdit::focusOutEvent ( QFocusEvent * ) {
+    emit si_finished();
+}
+
 /* class ListEditDelegate : public PropertyDelegate */
 
 const QString StringListDelegate::EDITOR("ListLineEdit");
@@ -432,12 +524,13 @@ QWidget* StringListDelegate::createEditor(QWidget *parent, const QStyleOptionVie
     layout->addWidget(button);
 
     currentEditor = widget;
-    connect(edit, SIGNAL(editingFinished()), SLOT(sl_commit()));
+    connect(edit, SIGNAL(si_finished()), SLOT(sl_commit()));
 
     return widget;
 }
 
 void StringListDelegate::sl_commit() {
+    //sender()->disconnect(this);
     emit commitData(currentEditor);
 }
 
@@ -475,7 +568,7 @@ void StringListDelegate::sl_showEditorButton(bool show) {
  * StringSelectorDelegate
 ********************************/
 
-QWidget *StringSelectorDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const {
+QWidget *StringSelectorDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &) const {
     QWidget * editor = new QWidget(parent);
     valueEdit = new QLineEdit(editor);
     valueEdit->setObjectName("valueEdit");
@@ -502,6 +595,7 @@ QWidget *StringSelectorDelegate::createEditor(QWidget *parent, const QStyleOptio
 }
 
 void StringSelectorDelegate::sl_commit() {
+    //sender()->disconnect(this);
     emit commitData(currentEditor);
 }
 
@@ -514,12 +608,12 @@ void StringSelectorDelegate::sl_onClick() {
     delete dlg;
 }
 
-void StringSelectorDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const {
+void StringSelectorDelegate::setEditorData(QWidget *, const QModelIndex &index) const {
     QString val = index.model()->data(index, ConfigurationEditor::ItemValueRole).toString();
     valueEdit->setText(val);
 }
 
-void StringSelectorDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const {
+void StringSelectorDelegate::setModelData(QWidget *, QAbstractItemModel *model, const QModelIndex &index) const {
     QString val = valueEdit->text().trimmed();
     model->setData(index, val, ConfigurationEditor::ItemValueRole);
     if (multipleSelection) {
