@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "QDScheduler.h"
 
@@ -18,27 +29,37 @@
 #include <U2Core/Timer.h>
 #include <U2Core/GObjectUtils.h>
 #include <U2Core/DocumentModel.h>
+#include <U2Core/ProjectModel.h>
+#include <U2Core/AppContext.h>
 #include <U2Core/LoadDocumentTask.h>
 #include <U2Core/AnnotationTableObject.h>
 
-#include <QtGui/QMessageBox>
-
 
 namespace U2 {
 //QDScheduler
 //////////////////////////////////////////////////////////////////////////
+static int PROCESSING_PROGRESS_WEIGHT(80);
+
 QDScheduler::QDScheduler(const QDRunSettings& _settings)
-: Task(tr("QDScheduler"), TaskFlags_NR_FOSCOE), settings(_settings), importTask(NULL) 
-{
+: Task(tr("QDScheduler"), TaskFlags_NR_FOSCOE), settings(_settings) {
     GCOUNTER( cvar, tvar, "QueryDesignerScheduler" );
     loadTask = NULL;
+    createAnnsTask = NULL;
     linker = new QDResultLinker(this);
     settings.scheme->adaptActorsOrder();
     currentStep = new QDStep(settings.scheme);
 
     tpm = Progress_Manual;
     stateInfo.progress = 0;
-    progressDelta = 100 / settings.scheme->getActors().size();
+    // if annotation table is not added to project
+    // annotations will be added in subtask thread
+    // => leave some progress bar space for it
+    Document* annObjDoc = settings.annotationsObj == NULL ? NULL : settings.annotationsObj->getDocument();
+    if (annObjDoc) {
+        progressDelta = 100 / settings.scheme->getActors().size();
+    } else {
+        progressDelta = PROCESSING_PROGRESS_WEIGHT / settings.scheme->getActors().size();
+    }
 
     if (settings.annotationsObj == NULL) {
         GObject* ao = GObjectUtils::selectObjectByReference(settings.annotationsObjRef, UOF_LoadedAndUnloaded);
@@ -61,15 +82,11 @@ QDScheduler::~QDScheduler() {
 
 QList<Task*> QDScheduler::onSubTaskFinished(Task* subTask) {
     QList<Task*> subs;
-    if (subTask->hasErrors()) {
+    if (subTask->hasError()) {
         propagateSubtaskError();
         return subs;
     }
-    if (isCanceled()) {
-        return subs;
-    }
-    if (linker->isCancelled()) {
-        QMessageBox::information(NULL, tr("Query Designer"), tr("No matches found."));
+    if (isCanceled() || linker->isCancelled() || subTask == createAnnsTask) {
         return subs;
     }
     
@@ -82,40 +99,42 @@ QList<Task*> QDScheduler::onSubTaskFinished(Task* subTask) {
         return subs;
     }
 
-    if (subTask = importTask) {
-        return subs;
-    }
-
     if (currentStep->hasNext()) {
         currentStep->next();
         QDTask* t = new QDTask(currentStep, linker);
         connect(t, SIGNAL(si_progressChanged()), SLOT(sl_updateProgress()));
         subs.append(t);
     } else {
-        /*importTask = new QDImportToTableTask(linker, "QD Results", "Result ");
-        subs << importTask;*/
-
-        // last task is finished, add annotation table object to view if needed
-        if (!settings.viewName.isEmpty()) {
-            GObjectViewWindow* viewWindow = GObjectViewUtils::findViewByName(settings.viewName);
-            if (viewWindow != NULL) {
-                viewWindow->getObjectView()->addObject(settings.annotationsObj);
-            }
-        }
+        createAnnsTask = new QDCreateAnnotationsTask(linker);
+        subs.append(createAnnsTask);
     }
     return subs;
 }
 
+#define PUSH_WEIGTH ( 1.0f - PROCESSING_PROGRESS_WEIGHT / 100.0f )
 void QDScheduler::sl_updateProgress() {
     Task* sub = qobject_cast<Task*>(sender());
     int numProcessed = currentStep->getLinkedActors().size();
-    stateInfo.progress = progressDelta * ( numProcessed + sub->getProgress()/100.0f );
+    if (numProcessed < settings.scheme->getActors().size()) {
+        stateInfo.progress = progressDelta * ( numProcessed + sub->getProgress()/100.0f );
+    } else {
+        stateInfo.progress = PROCESSING_PROGRESS_WEIGHT + PUSH_WEIGTH * sub->getProgress();
+    }
 }
 
 Task::ReportResult QDScheduler::report() {
-    if (linker->getCandidatesNumber() && !isCanceled()) {
-        linker->pushToTable("", "Result ");
+    if (stateInfo.isCanceled() || stateInfo.hasError()) {
+        return ReportResult_Finished;
     }
+    linker->pushToTable();
+    // last task is finished, add annotation table object to view if needed
+    if (!settings.viewName.isEmpty()) {
+        GObjectViewWindow* viewWindow = GObjectViewUtils::findViewByName(settings.viewName);
+        if (viewWindow != NULL) {
+            viewWindow->getObjectView()->addObject(settings.annotationsObj);
+        }
+    }
+
     return ReportResult_Finished;
 }
 
@@ -125,78 +144,40 @@ QDResultLinker::QDResultLinker(QDScheduler* _sched)
 : scheme(_sched->getSettings().scheme), sched(_sched), cancelled(false), currentStep(NULL),
 needInit(true) {}
 
-AnnotationTableObject* QDResultLinker::pushToTable(const QString& tableName, const QString& groupPrefix) {
-    Q_UNUSED(tableName);
-    const QDRunSettings& settings = sched->getSettings();
-    AnnotationTableObject* ato = settings.annotationsObj;
-    AnnotationGroup* root = ato->getRootGroup();
-    if (!settings.groupName.isEmpty()) {
-        root = root->getSubgroup(settings.groupName, true);
-    }
-    int counter = root->getSubgroups().count();
-
-    qint64 start, end;
-    int sss = candidates.size();
-    perfLog.details(QString("%1 groups").arg(sss));
-    start = GTimer::currentTimeMicros();
-    foreach(QDResultGroup* candidate, candidates) {
-        if (sched->isCanceled()) {
-            return NULL;
-        }
-        const QString& grpName = QString("%1 %2").arg(groupPrefix).arg(QString::number(++counter));
-        AnnotationGroup* newGroup = root->getSubgroup(grpName, true);
-        foreach(const QDResultUnit& res, candidate->getResultsList()) {
-            Annotation* a = result2annotation.value(res, NULL);
-            if (a == NULL) {
-                SharedAnnotationData ad(new AnnotationData());
-                QString aname = res->owner->getActor()->annotateAs();
-                if (aname=="<rsite>") {
-                    foreach(const Qualifier& qual, res->quals) {
-                        if (qual.getQualifierName()=="id") {
-                            aname = qual.getQualifierValue();
-                            break;
-                        }
-                    }
-                }
-                ad->name = aname;
-                ad->complement = res->complement;
-                ad->location << res->region;
-                ad->qualifiers = res->quals;
-                a = new Annotation(ad);
-                result2annotation[res] = a;
+QString QDResultLinker::prepareAnnotationName(const QDResultUnit& res) {
+    QString aname = res->owner->getActor()->annotateAs();
+    if (aname=="<rsite>") {
+        foreach(const U2Qualifier& qual, res->quals) {
+            if (qual.name == "id") {
+                return qual.value;
             }
-            newGroup->addAnnotation(a);
         }
-        candidates.removeOne(candidate);
-        delete candidate;
     }
-    end = GTimer::currentTimeMicros();
-    perfLog.details(QString("push to table in %1 ms").arg(GTimer::millisBetween(start, end)));
-    return ato;
+    return aname;
 }
 
 // for 1..3, 5..7 returns 1..7
-LRegion uniteRegions(const QList<LRegion>& regions) {
+U2Region uniteRegions(const QVector<U2Region>& regions) {
     assert(!regions.isEmpty());
-    int startPos = regions.first().startPos;
-    int endPos = regions.first().endPos();
+    qint64 startPos = regions.first().startPos;
+    qint64 endPos = regions.first().endPos();
     for (int i=1, n=regions.size(); i<n; i++) {
-        const LRegion& r = regions.at(i);
+        const U2Region& r = regions.at(i);
         startPos = qMin(startPos, r.startPos);
         endPos = qMax(endPos, r.endPos());
     }
-    return LRegion(startPos, endPos-startPos);
+    return U2Region(startPos, endPos-startPos);
 }
 
-QList<LRegion> joinRegions(QList<LRegion>& regions) {
-    QList<LRegion> result;
+QVector<U2Region> joinRegions(QVector<U2Region>& regions) {
+    QVector<U2Region> result;
     qSort(regions);
     for(int i=0, size=regions.size(); i<size;) {
-        LRegion joined = regions[i];
+        U2Region joined = regions[i];
         ++i;
         while (i<size && joined.intersects(regions.at(i))) {
-            const LRegion& next = regions.at(i);
-            joined = LRegion::join(joined, next);
+            const U2Region& next = regions.at(i);
+            joined = U2Region::containingRegion(joined, next);
             ++i;
         }
         result << joined;
@@ -204,8 +185,8 @@ QList<LRegion> joinRegions(QList<LRegion>& regions) {
     return result;
 }
 
-QList<LRegion> QDResultLinker::findLocation(QDStep* step) {
-    QList<LRegion> res;
+QVector<U2Region> QDResultLinker::findLocation(QDStep* step) {
+    QVector<U2Region> res;
     if (candidates.isEmpty()) {
         res << scheme->getDNA()->getSequenceRange();
         return res;
@@ -213,13 +194,14 @@ QList<LRegion> QDResultLinker::findLocation(QDStep* step) {
     QDActor* actor = step->getActor();
     const QList<QDSchemeUnit*>& units = actor->getSchemeUnits();
     foreach(QDResultGroup* candidate, candidates) {
-        QList<LRegion> actorLocation;
+        bool complement = candidate->strand == QDStrand_ComplementOnly;
+        QVector<U2Region> actorLocation;
         foreach(QDSchemeUnit* su, units) {
-            LRegion suRegion = scheme->getDNA()->getSequenceRange();
+            U2Region suRegion = scheme->getDNA()->getSequenceRange();
             foreach(const QDResultUnit& ru, candidate->getResultsList()) {
                 foreach(QDConstraint* c, step->getConstraints(su, ru->owner)) {
                     QDDistanceConstraint* dc = static_cast<QDDistanceConstraint*>(c);
-                    const LRegion& reg = QDConstraintController::matchLocation(dc, ru);
+                    const U2Region& reg = QDConstraintController::matchLocation(dc, ru, complement);
                     suRegion = suRegion.intersect(reg);
                 }
             }
@@ -231,7 +213,7 @@ QList<LRegion> QDResultLinker::findLocation(QDStep* step) {
             }
         }
         if (!actorLocation.isEmpty()) {
-            const LRegion& region4candidate = uniteRegions(actorLocation);
+            const U2Region& region4candidate = uniteRegions(actorLocation);
             res.append(region4candidate);
         }
     }
@@ -383,26 +365,90 @@ void QDResultLinker::processNewResults(int& progress) {
 void QDResultLinker::initCandidates(int& progress) {
     int i = 0;
     foreach(QDResultGroup* actorRes, currentResults) {
-        QDResultGroup* newCandidate = new QDResultGroup;
-        foreach(const QDResultUnit& res, actorRes->getResultsList()) {
-            newCandidate->add(res);
-        }
+        QDStrandOption candidateStrand = findResultStrand(actorRes);
+        QDResultGroup* newCandidate = new QDResultGroup(candidateStrand);
+        newCandidate->add(actorRes->getResultsList());
         candidates.append(newCandidate);
         progress = 100 * ++i / currentResults.size();
     }
 }
 
+QDStrandOption QDResultLinker::findResultStrand(QDResultGroup* actorRes) {
+    QDStrandOption curActorStrand = currentStep->getActor()->getStrand();
+    QDStrandOption resStrand = QDStrand_Both;
+    if (curActorStrand==QDStrand_DirectOnly) {
+        resStrand = actorRes->strand;
+    } else if (curActorStrand==QDStrand_ComplementOnly) {
+        if (actorRes->strand==QDStrand_DirectOnly) {
+            resStrand = QDStrand_ComplementOnly;
+        } else if (actorRes->strand==QDStrand_ComplementOnly) {
+            resStrand = QDStrand_DirectOnly;
+        } else {
+            resStrand = QDStrand_Both;
+        }
+    } else {
+        resStrand = scheme->getStrand();
+    }
+    return resStrand;
+}
+
 void QDResultLinker::updateCandidates(int& progress) {
     QList<QDResultGroup*> newCandidates;
     int i = 0;
+    
     foreach(QDResultGroup* candidate, candidates) {
         foreach(QDResultGroup* actorRes, currentResults) {
             if (sched->isCanceled()) {
                 return;
             }
-            if (canAdd(actorRes, candidate)) {
+
+            bool matches = false;
+            //define for what schema strand result is
+            QDStrandOption resStrand = findResultStrand(actorRes);
+            if ( resStrand!=QDStrand_Both && candidate->strand!=QDStrand_Both && resStrand!=candidate->strand ) {
+                continue;
+            }
+            //
+            bool complement;
+            if (scheme->getStrand()==QDStrand_DirectOnly) {
+                matches = canAdd(actorRes, candidate, false);
+                complement = false;
+            } else if (scheme->getStrand()==QDStrand_ComplementOnly) {
+                matches = canAdd(actorRes, candidate, true);
+                complement = true;
+            } else {
+                if (resStrand==QDStrand_DirectOnly) {
+                    matches = canAdd(actorRes, candidate, false);
+                    complement = false;
+                } else if (resStrand==QDStrand_ComplementOnly) {
+                    matches = canAdd(actorRes, candidate, true);
+                    complement = true;
+                } else {
+                    matches = canAdd(actorRes, candidate, false);
+                    if (!matches) {
+                        matches = canAdd(actorRes, candidate, true);
+                        complement = true;
+                    } else {
+                        complement = false;
+                    }
+                }
+            }
+            
+            if (matches) {
                 QDResultGroup* newCandidate = new QDResultGroup(*candidate);
                 newCandidate->add(actorRes->getResultsList());
+#ifdef DEBUG
+                if (newCandidate->strand==QDStrand_DirectOnly) {
+                    assert(!complement);
+                }
+                if (newCandidate->strand==QDStrand_ComplementOnly) {
+                    assert(complement);
+                }
+#endif
+                //if strand was not defined
+                if (newCandidate->strand == QDStrand_Both) {
+                    newCandidate->strand = complement ? QDStrand_ComplementOnly : QDStrand_DirectOnly;
+                }
                 newCandidates.append(newCandidate);
             }
         }
@@ -412,12 +458,21 @@ void QDResultLinker::updateCandidates(int& progress) {
     candidates = newCandidates;
 }
 
-bool QDResultLinker::canAdd(QDResultGroup* actorResult, QDResultGroup* candidate) const {
-    foreach(const QDResultUnit& actorResUnit, actorResult->getResultsList()) {
-        foreach(const QDResultUnit& candidateResUnit, candidate->getResultsList()) {
+bool QDResultLinker::canAdd(QDResultGroup* actorResult, QDResultGroup* candidate, bool complement) const {
+    QList<QDResultUnit> actorResults;
+    QList<QDResultUnit> candidateResults;
+    if (complement) {
+        actorResults = prepareComplResults(actorResult);
+        candidateResults = prepareComplResults(candidate);
+    } else {
+        actorResults = actorResult->getResultsList();
+        candidateResults = candidate->getResultsList();
+    }
+    foreach(const QDResultUnit& actorResUnit, actorResults) {
+        foreach(const QDResultUnit& candidateResUnit, candidateResults) {
             const QList<QDConstraint*>& cl = currentStep->getConstraints(actorResUnit->owner, candidateResUnit->owner);
             foreach(QDConstraint* c, cl) {
-                if(!QDConstraintController::match(c, actorResUnit, candidateResUnit)) {
+                if(!QDConstraintController::match(c, actorResUnit, candidateResUnit, complement)) {
                     return false;
                 }
             }
@@ -426,6 +481,135 @@ bool QDResultLinker::canAdd(QDResultGroup* actorResult, QDResultGroup* candidate
     return true;
 }
 
+QList<QDResultUnit> QDResultLinker::prepareComplResults( QDResultGroup* src ) const {
+    QList<QDResultUnit> res = src->getResultsList();
+    QList<QDActor*> simActors;
+    foreach (QDResultUnit ru, res) {
+        QDActor* a = ru->owner->getActor();
+        if (a->isSimmetric() && !simActors.contains(a)) {
+            simActors.append(a);
+
+            QList<QDSchemeUnit*> units = a->getSchemeUnits();
+            for (int i=0, n=units.size()/2; i<n; i++) {
+                QDSchemeUnit* begin = units[i];
+                QDSchemeUnit* end = units[units.size()-i-1];
+                QMutableListIterator<QDResultUnit> it(res);
+                while(it.hasNext()) {
+                    QDResultUnit& resUn = it.next();
+                    if (resUn->owner==begin) {
+                        resUn->owner = end;
+                    } else if (resUn->owner==end) {
+                        resUn->owner = begin;
+                    }
+                }
+            }
+        }
+    }
+    return res;
+}
+
+#define RESULT_PREFIX "Result"
+void QDResultLinker::prepareAnnotations() {
+    qint64 start(0), end(0);
+    perfLog.details(QString("%1 groups").arg(candidates.size()));
+    start = GTimer::currentTimeMicros();
+
+    if (sched->getSettings().outputType == QDRunSettings::Single ) {
+        createMergedAnnotations(RESULT_PREFIX);
+    } else {
+        createAnnotations(RESULT_PREFIX);
+    }
+
+    end = GTimer::currentTimeMicros();
+    perfLog.details(QString("push to table in %1 ms").arg(GTimer::millisBetween(start, end)));
+}
+
+void QDResultLinker::createAnnotations(const QString& groupPrefix) {
+    int counter = 0;
+    foreach(QDResultGroup* candidate, candidates) {
+        if (sched->isCanceled()) {
+            return;
+        }
+        const QString& grpName = QString("%1 %2")
+            .arg(groupPrefix)
+            .arg(QString::number(++counter));
+
+        QList<Annotation*> groupAnns;
+        
+        foreach(const QDResultUnit& res, candidate->getResultsList()) {
+            Annotation* a = result2annotation.value(res, NULL);
+            if (a == NULL) {
+                SharedAnnotationData ad(new AnnotationData());
+                ad->name = prepareAnnotationName(res);
+                ad->setStrand(res->strand);
+                ad->location->regions.append(res->region);
+                ad->qualifiers = res->quals;
+                a = new Annotation(ad);
+                result2annotation[res] = a;
+            }
+            groupAnns.append(a);
+        }
+        annotations[grpName] = groupAnns;
+        delete candidate;
+    }
+    candidates.clear();
+}
+
+void QDResultLinker::createMergedAnnotations(const QString& groupPrefix) {
+    const QDRunSettings& settings = sched->getSettings();
+    int offset = settings.offset;
+    const U2Region& seqRange = scheme->getDNA()->getSequenceRange();
+    QList<Annotation*> anns;
+    foreach(QDResultGroup* candidate, candidates) {
+        if (sched->isCanceled()) {
+            return;
+        }
+
+        qint64 startPos = candidate->getResultsList().first()->region.startPos;
+        qint64 endPos = candidate->getResultsList().first()->region.endPos();
+        foreach(QDResultUnit ru, candidate->getResultsList()) {
+            startPos = qMin(startPos, ru->region.startPos);
+            endPos = qMax(endPos, ru->region.endPos());
+        }
+        startPos = qMax(seqRange.startPos, startPos - offset);
+        endPos = qMin(seqRange.endPos(), endPos + offset);
+        U2Region r(startPos, endPos-startPos);
+
+        SharedAnnotationData ad(new AnnotationData());
+        ad->name = groupPrefix;
+        ad->location->regions.append(r);
+        anns.append(new Annotation(ad));
+        delete candidate;
+    }
+    candidates.clear();
+    annotations[""] = anns;
+}
+
+void QDResultLinker::pushToTable() {
+    const QDRunSettings& settings = sched->getSettings();
+    AnnotationTableObject* ao = settings.annotationsObj;
+    assert(ao != NULL);
+
+    AnnotationGroup* root = ao->getRootGroup();
+    if (!settings.groupName.isEmpty()) {
+        root = root->getSubgroup(settings.groupName, true);
+    }
+
+    QMapIterator< QString, QList<Annotation*> > iter(annotations);
+    while (iter.hasNext()) {
+        iter.next();
+        AnnotationGroup* ag = NULL;
+        if (iter.key().isEmpty()) {
+            ag = root;
+        } else {
+            ag = root->getSubgroup(iter.key(), true);
+        }
+        foreach(Annotation* a, iter.value()) {
+            ag->addAnnotation(a);
+        }
+    }
+}
+
 //QDStep
 //////////////////////////////////////////////////////////////////////////
 QDStep::QDStep(QDScheme* _scheme) : scheme(_scheme) {
@@ -553,7 +737,7 @@ QDTask::QDTask(QDStep* _step, QDResultLinker* _linker)
 
 QList<Task*> QDTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> subs;
-    if (subTask->hasErrors()) {
+    if (subTask->hasError()) {
         propagateSubtaskError();
         return subs;
     }
@@ -562,7 +746,7 @@ QList<Task*> QDTask::onSubTaskFinished(Task* subTask) {
     }
     if (subTask==findLocationTask) {
         stateInfo.progress = 10;
-        const QList<LRegion>& searchLocation = findLocationTask->getSearchLocation();
+        const QVector<U2Region>& searchLocation = findLocationTask->getSearchLocation();
         curActorLocation = findLocationTask->getResultLocation();
         if (searchLocation.isEmpty()) {
             return subs;
@@ -592,7 +776,6 @@ static const int LINK_START = (FIND_LOC_PROGRESS_WEIGHT + RUN_TASK_PROGRESS_WEIG
 void QDTask::sl_updateProgress() {
     Task* sub = qobject_cast<Task*>(sender());
     if (sub==findLocationTask) {
-        //
     } else if (sub==runTask) {
         stateInfo.progress = RUN_START + sub->getProgress() * RUN_TASK_PROGRESS_WEIGHT;
     } else { //linkTask
@@ -605,13 +788,13 @@ void QDTask::sl_updateProgress() {
 const int QDFindLocationTask::REGION_DELTA(10);
 
 void QDFindLocationTask::run() {
-    const LRegion& seqReg = linker->getScheduler()->getSettings().region;
+    const U2Region& seqReg = linker->getScheduler()->getSettings().region;
     if (step->hasPrev()) {
         resultLocation = linker->findLocation(step);
-        foreach(const LRegion& r, resultLocation) {
+        foreach(const U2Region& r, resultLocation) {
             int startPos = qMax(seqReg.startPos, r.startPos-REGION_DELTA);
             int endPos = qMin(seqReg.endPos(), r.endPos()+REGION_DELTA);
-            LRegion extended(startPos, endPos - startPos);
+            U2Region extended(startPos, endPos - startPos);
             searchLocation.append(extended);
         }
         searchLocation = joinRegions(searchLocation);
