@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ABIFormat.h"
 #include "IOLibUtils.h"
@@ -23,8 +34,9 @@
 #include <U2Core/GObjectRelationRoles.h>
 #include <U2Core/DNAChromatogramObject.h>
 #include <U2Core/TextObject.h>
-
+#include <U2Core/U2OpStatus.h>
 #include <U2Core/TextUtils.h>
+#include <U2Core/U2SafePoints.h>
 
 #include <time.h>
 
@@ -39,7 +51,7 @@ ABIFormat::ABIFormat(QObject* p) : DocumentFormat(p, DocumentFormatFlags(0), QSt
     supportedObjectTypes+=GObjectTypes::CHROMATOGRAM;
 }
 
-FormatDetectionResult ABIFormat::checkRawData(const QByteArray& rawData) const {
+RawDataCheckResult ABIFormat::checkRawData(const QByteArray& rawData, const GUrl&) const {
     const char* data = rawData.constData();
     int size = rawData.size();
 
@@ -69,7 +81,7 @@ Document* ABIFormat::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVaria
             break;
         }
     }
-    if (ti.hasErrors()) {
+    if (ti.hasError()) {
         return NULL;
     }
 
@@ -77,8 +89,8 @@ Document* ABIFormat::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVaria
     sf.head = readBuff.constData();
     sf.pos = 0;
     sf.size = readBuff.size();
-    Document* doc = parseABI(&sf, io, fs);
-    if (doc == NULL && !ti.hasErrors()) {
+    Document* doc = parseABI(&sf, io, fs, ti);
+    if (doc == NULL && !ti.hasError()) {
         ti.setError(tr("Not a valid ABIF file: %1").arg(io->toString()));
     }
     return doc;
@@ -388,7 +400,7 @@ static void replace_nl(char *string) {
     }
 }
 
-Document* ABIFormat::parseABI(SeekableBuf* fp, IOAdapter* io, const QVariantMap& fs) {
+Document* ABIFormat::parseABI(SeekableBuf* fp, IOAdapter* io, const QVariantMap& fs, U2OpStatus& os) {
 
     float fspacing; /* average base spacing */
     uint numPoints, numBases;
@@ -811,7 +823,11 @@ skip_bases:
     dna.info.insert(DNAInfo::ID, sequenceName);
 
     QList<GObject*> objects;
-    DNASequenceObject* seqObj = DocumentFormatUtils::addSequenceObject(objects, sequenceName, dna);
+    DNASequenceObject* seqObj = DocumentFormatUtils::addSequenceObject(objects, sequenceName, dna, fs, os);
+    if (os.hasError()) {
+        return NULL;
+    }
+    SAFE_POINT(seqObj != NULL, "DocumentFormatUtils::addSequenceObject returned NULL but didn't set error", NULL);
     DNAChromatogramObject* chromObj = new DNAChromatogramObject(cd, "Chromatogram");
     objects.append(chromObj);
     objects.append(new TextObject(sequenceComment, "Info"));
