@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QStringList>
 
@@ -43,7 +54,7 @@ ASNFormat::ASNFormat( QObject* p ) : DocumentFormat(p, DocumentFormatFlag(0), QS
 }
 
 
-FormatDetectionResult ASNFormat::checkRawData(const QByteArray& rawData) const {
+RawDataCheckResult ASNFormat::checkRawData(const QByteArray& rawData, const GUrl&) const {
     static const char* formatTag = "Ncbi-mime-asn1 ::= strucseq";
     
     if (!rawData.startsWith(formatTag)) {
@@ -78,7 +89,7 @@ Document* ASNFormat::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVaria
     }
     ti.progress = 80;
     
-    if (ti.hasErrors() || ti.cancelFlag) {
+    if (ti.hasError() || ti.cancelFlag) {
         return NULL;
     }
     ioLog.trace(QString("BioStruct3D loaded from ASN tree (%1)").arg(io->toString()));
@@ -268,7 +279,7 @@ void ASNFormat::BioStructLoader::loadModelCoordsFromNode( AsnNode* modelNode, At
         float z = (float) zCoords->children.at(i)->value.toInt() / scaleFactor;
         AtomData* a = new AtomData();
         a->chainIndex = chainId;
-        a->residueIndex = resId;
+        a->residueIndex = ResidueIndex(resId, ' ');
         a->coord3d = Vector3D(x,y,z);
         
         quint64 index = calcStdResidueIndex(chainId, resId);
@@ -360,7 +371,7 @@ void ASNFormat::BioStructLoader::loadMoleculeFromNode(AsnNode* moleculeNode, Mol
         ResidueData* resData = new ResidueData();
         resData->chainIndex = chainId;
         StdResidue stdResidue = loadResidueFromNode(resNode, resData);
-        molecule->residueMap.insert(resId, SharedResidue(resData));
+        molecule->residueMap.insert( ResidueIndex(resId, ' '), SharedResidue(resData));
         stdResidueCache.insert(calcStdResidueIndex(chainId, resId), stdResidue);
         
     }
@@ -553,8 +564,8 @@ void ASNFormat::BioStructLoader::loadIntraResidueBonds( BioStruct3D& struc )
         SharedMolecule& mol = struc.moleculeMap[chainId];
         int numModels = mol->models.count();
         for( int modelId = 0; modelId < numModels; ++modelId) {
-            foreach( int resId, mol->residueMap.keys()) {
-                quint64 index = calcStdResidueIndex(chainId, resId);
+            foreach( ResidueIndex resId, mol->residueMap.keys()) {
+                quint64 index = calcStdResidueIndex(chainId, resId.toInt());
                 if (!stdResidueCache.contains(index)) {
                     continue;
                 }
