@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 
 #include "EMBLGenbankAbstractDocument.h"
@@ -26,6 +37,10 @@
 
 #include <U2Core/DNAInfo.h>
 #include <U2Core/TextUtils.h>
+#include <U2Core/U2AnnotationUtils.h>
+#include <U2Core/U2SafePoints.h>
+
+#include <memory>
 
 namespace U2 {
 
@@ -50,7 +65,7 @@ Document* EMBLGenbankAbstractDocument::loadDocument(IOAdapter* io, TaskStateInfo
     QString writeLockReason;
     load(io, objects, fs, ti, writeLockReason, mode);
 
-    if (ti.hasErrors() || ti.cancelFlag) {
+    if (ti.hasError() || ti.cancelFlag) {
         return NULL;
     }
 
@@ -69,17 +84,17 @@ void EMBLGenbankAbstractDocument::load(IOAdapter* io, QList<GObject*>& objects,
     writeLockReason.clear();
 
     //get settings
-    int gapSize = qBound(-1, DocumentFormatUtils::getIntSettings(fs, MERGE_MULTI_DOC_GAP_SIZE_SETTINGS, -1), 1000*1000);
+    int gapSize = qBound(-1, DocumentFormatUtils::getMergeGap(fs), 1000*1000);
     bool merge = gapSize!=-1;
 
     QByteArray sequence;
     QByteArray  gapSequence((merge ? gapSize : 0), 0);
     AnnotationTableObject* mergedAnnotations = NULL;
     QStringList contigs;
-    QList<LRegion> mergedMapping;
+    QVector<U2Region> mergedMapping;
 
     int predictedSize = qMax(100*1000, 
-        DocumentFormatUtils::getIntSettings(fs, MERGE_MULTI_DOC_SEQUENCE_SIZE_SETTINGS, merge ? 0 : io->left()));
+        DocumentFormatUtils::getIntSettings(fs, DocumentReadingMode_SequenceMergingFinalSizeHint, merge ? 0 : io->left()));
 
     sequence.reserve(predictedSize + (merge ? gapSize : 0));
     
@@ -92,7 +107,7 @@ void EMBLGenbankAbstractDocument::load(IOAdapter* io, QList<GObject*>& objects,
     ParserState st(getFormatId() == BaseDocumentFormats::PLAIN_GENBANK ? 12 : 5, io, NULL, si);
     st.buff = readBuffer.data();
 
-    for (int i=0; !si.hasErrors() && !si.cancelFlag; i++) {
+    for (int i=0; !si.hasError() && !si.cancelFlag; i++) {
         if (!merge) {
             sequence.clear();
         } else if (sequence.size() > 0) {
@@ -102,7 +117,7 @@ void EMBLGenbankAbstractDocument::load(IOAdapter* io, QList<GObject*>& objects,
 
         EMBLGenbankDataEntry data;
         st.entry = &data;
-        si.setStateDesc(tr("Reading entry header"));
+        si.setDescription(tr("Reading entry header"));
         if (!readEntry(sequence, &st)) {
             break;
         }
@@ -145,7 +160,7 @@ void EMBLGenbankAbstractDocument::load(IOAdapter* io, QList<GObject*>& objects,
             assert(data.features.isEmpty());
         }
         
-        if (!si.hasErrors() && !si.cancelFlag) {
+        if (!si.hasError() && !si.cancelFlag) {
             int sequenceLen = sequence.size() - sequenceStart;
             QString sequenceName = genObjectName(usedNames, data.name, data.tags, i+1, GObjectTypes::SEQUENCE);
             if (merge && sequenceLen == 0 && annotationsObject!=NULL) {
@@ -153,12 +168,16 @@ void EMBLGenbankAbstractDocument::load(IOAdapter* io, QList<GObject*>& objects,
                 break;
             } else if (merge) {
                 contigs.append(sequenceName);
-                mergedMapping.append(LRegion(sequenceStart, sequenceLen));
+                mergedMapping.append(U2Region(sequenceStart, sequenceLen));
             } else if (sequenceLen!=0){
                 DNASequence seq(sequence);
                 seq.info = data.tags;
                 seq.circular = data.circular;
-                DNASequenceObject* seqObj = DocumentFormatUtils::addSequenceObject(objects, sequenceName, seq);
+                DNASequenceObject* seqObj = DocumentFormatUtils::addSequenceObject(objects, sequenceName, seq, fs, si);
+                if (si.hasError()) {
+                    break;
+                }
+                SAFE_POINT(seqObj != NULL, "DocumentFormatUtils::addSequenceObject returned NULL but didn't set error",);
                 if (annotationsObject!=NULL) {
                     sequenceRef.objName = seqObj->getGObjectName();
                     annotationsObject->addObjectRelation(GObjectRelation(sequenceRef, GObjectRelationRole::SEQUENCE));
@@ -170,11 +189,17 @@ void EMBLGenbankAbstractDocument::load(IOAdapter* io, QList<GObject*>& objects,
         }
     }
     
-    if (!si.hasErrors() && !si.cancelFlag && merge && !contigs.isEmpty()) {
+    if (!si.hasError() && !si.cancelFlag && merge && !contigs.isEmpty()) {
         assert(sequence.size() > gapSize);
         assert(qEqual(sequence.constEnd() - gapSize, sequence.constEnd(), gapSequence.constBegin()));
         sequence.resize(sequence.size() - gapSize);//remove last gap
-        DNASequenceObject* so = DocumentFormatUtils::addMergedSequenceObject(objects, io->getURL(), contigs, sequence, mergedMapping);
+        DNASequenceObject* so = DocumentFormatUtils::addMergedSequenceObject(objects, io->getURL(), contigs, sequence, mergedMapping, fs, si);
+        if (si.hasError()) {
+            qDeleteAll(objects);
+            delete mergedAnnotations;
+            return;
+        }
+        SAFE_POINT(so != NULL, "DocumentFormatUtils::addMergedSequenceObject returned NULL but didn't set error",);
         if (mergedAnnotations!=NULL) {
             sequenceRef.objName = so->getGObjectName();
             mergedAnnotations->addObjectRelation(GObjectRelation(sequenceRef, GObjectRelationRole::SEQUENCE));
@@ -182,7 +207,7 @@ void EMBLGenbankAbstractDocument::load(IOAdapter* io, QList<GObject*>& objects,
         }
     }
 
-    if (!si.hasErrors() && !si.cancelFlag && objects.isEmpty()) {
+    if (!si.hasError() && !si.cancelFlag && objects.isEmpty()) {
         si.setError(U2::Document::tr("Document is empty."));
     }
 
@@ -305,6 +330,19 @@ QString EMBLGenbankAbstractDocument::genObjectName(QSet<QString>& usedNames, con
     return res;
 }
 
+DNASequence* EMBLGenbankAbstractDocument::loadSequence( IOAdapter* io, TaskStateInfo& ti) {
+    while(true) {
+        std::auto_ptr<Document> document(loadDocument(io, ti, QVariantMap(), DocumentLoadMode_SingleObject));
+        if(ti.isCoR()) {
+            return NULL;
+        }
+        foreach(GObject *object, document->getObjects()) {
+            if(object->getGObjectType() == GObjectTypes::SEQUENCE) {
+                return new DNASequence(((DNASequenceObject *)object)->getDNASequence());
+            }
+        }
+    }
+}
 
 static void checkQuotes(const char* str, int len, bool& outerQuotes, bool& doubleQuotes) {
     char qChar = '\"';
@@ -337,21 +375,23 @@ SharedAnnotationData EMBLGenbankAbstractDocument::readAnnotation(IOAdapter* io,
         return SharedAnnotationData();
     }
 
-    Genbank::LocationParser::parseLocation(cbuff+21, qlen-21, a->complement, a->order, a->location);
-    if (a->location.empty()) {
+    Genbank::LocationParser::parseLocation(cbuff+21, qlen-21, a->location);
+    if (a->location->isEmpty()) {
         si.setError(EMBLGenbankAbstractDocument::tr("Error parsing location"));
         return SharedAnnotationData();
-    } else if (a->location.size() > 1) {
-        qSort(a->location);
     }
+    // omit sorting because of splitted annotations 
+    /*if (a->location->isMultiRegion()) {
+        qSort(a->location->regions);
+    }*/
     if (offset!=0) {
-        DocumentFormatUtils::addOffset(a->location, offset);
+        U2Region::shift(offset, a->location->regions);
     }
 
     const QBitArray& LINE_BREAKS = TextUtils::LINE_BREAKS;
     const QByteArray& aminoQ = GBFeatureUtils::QUALIFIER_AMINO_STRAND;
-    const QByteArray& aminoQYes = GBFeatureUtils::QUALIFIER_AMINO_STRAND_YES;
-    const QByteArray& aminoQNo = GBFeatureUtils::QUALIFIER_AMINO_STRAND_NO;
+    //const QByteArray& aminoQYes = GBFeatureUtils::QUALIFIER_AMINO_STRAND_YES;
+    //const QByteArray& aminoQNo = GBFeatureUtils::QUALIFIER_AMINO_STRAND_NO;
     const QByteArray& nameQ = GBFeatureUtils::QUALIFIER_NAME;
     
     //here we have valid key and location;
@@ -388,8 +428,8 @@ SharedAnnotationData EMBLGenbankAbstractDocument::readAnnotation(IOAdapter* io,
             qvalLen-=2;
         }
         if (qnameLen == aminoQ.length() && TextUtils::equals(qname, aminoQ.constData(), qnameLen)) {
-            a->aminoFrame = qvalLen == aminoQYes.length() && TextUtils::equals(qval, aminoQYes.constData(), qvalLen) ? TriState_Yes
-                         :  (qvalLen == aminoQNo.length()  && TextUtils::equals(qval, aminoQNo.constData(), qvalLen) ? TriState_No : TriState_Unknown);
+            //a->aminoFrame = qvalLen == aminoQYes.length() && TextUtils::equals(qval, aminoQYes.constData(), qvalLen) ? TriState_Yes
+            //             :  (qvalLen == aminoQNo.length()  && TextUtils::equals(qval, aminoQNo.constData(), qvalLen) ? TriState_No : TriState_Unknown);
         } else if (qnameLen == nameQ.length() && TextUtils::equals(qname, nameQ.constData(), qnameLen)) {
             a->name = QString::fromLocal8Bit(qval, qvalLen);
         } else {
@@ -398,7 +438,7 @@ SharedAnnotationData EMBLGenbankAbstractDocument::readAnnotation(IOAdapter* io,
             if (containsDoubleQuotes) {
                 valQStr = valQStr.replace("\"\"", "\"");
             }
-            a->qualifiers.append(Qualifier(nameQStr, valQStr));
+            a->qualifiers.append(U2Qualifier(nameQStr, valQStr));
         }
     }
     return f;
@@ -408,7 +448,7 @@ bool EMBLGenbankAbstractDocument::readSequence(QByteArray& res, ParserState* st)
     // FIXME use ParserState instead
     IOAdapter* io = st->io;
     TaskStateInfo& si = st->si;
-    si.setStateDesc(tr("Reading sequence %1").arg(st->entry->name));
+    si.setDescription(tr("Reading sequence %1").arg(st->entry->name));
     int headerSeqLen = st->entry->seqLen;
     res.reserve(res.size() + headerSeqLen);
 
@@ -478,7 +518,7 @@ bool EMBLGenbankAbstractDocument::readSequence(QByteArray& res, ParserState* st)
 
         si.progress = io->getProgress();
     }
-    if (!si.hasErrors() && !si.cancelFlag && buff[0] != '/') {
+    if (!si.hasError() && !si.cancelFlag && buff[0] != '/') {
         si.setError(tr("Sequence is truncated"));
     }
     writer.close();
@@ -486,7 +526,7 @@ bool EMBLGenbankAbstractDocument::readSequence(QByteArray& res, ParserState* st)
 }
 
 void EMBLGenbankAbstractDocument::readAnnotations(ParserState* st, int offset) {
-    st->si.setStateDesc(tr("Reading annotations %1").arg(st->entry->name));
+    st->si.setDescription(tr("Reading annotations %1").arg(st->entry->name));
     st->entry->hasAnnotationObjectFlag = true;
     do {
         if (st->hasKey("XX") && getFormatId() == BaseDocumentFormats::PLAIN_EMBL) {
@@ -529,7 +569,7 @@ QString ParserState::value() const {
 
 bool ParserState::readNextLine(bool emptyOK)
 {
-    if (si.cancelFlag || si.hasErrors()) {
+    if (si.cancelFlag || si.hasError()) {
         len = 0;
         return false;
     }
