@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "GenbankPlainTextFormat.h"
 #include "GenbankLocationParser.h"
@@ -39,12 +50,13 @@ namespace U2 {
 GenbankPlainTextFormat::GenbankPlainTextFormat(QObject* p)
 : EMBLGenbankAbstractDocument(BaseDocumentFormats::PLAIN_GENBANK, tr("Genbank"), 79, DocumentFormatFlags_SW, p)
 {
+    formatDescription = tr("GenBank Flat File Format is a rich format for storing sequences and associated annotations");
     fileExtensions << "gb" << "gbk" << "gen" << "genbank";
     sequenceStartPrefix = "ORIGIN";
     fPrefix = "  ";
 }
 
-FormatDetectionResult GenbankPlainTextFormat::checkRawData(const QByteArray& rawData) const {
+RawDataCheckResult GenbankPlainTextFormat::checkRawData(const QByteArray& rawData, const GUrl&) const {
     //TODO: improve handling
     const char* data = rawData.constData();
     int size = rawData.size();
@@ -53,7 +65,19 @@ FormatDetectionResult GenbankPlainTextFormat::checkRawData(const QByteArray& raw
         return FormatDetection_NotMatched;
     }
     bool startsWithLocus = TextUtils::equals("LOCUS ", data, 6);
-    return startsWithLocus ? FormatDetection_VeryHighSimilarity : FormatDetection_NotMatched;
+    if (!startsWithLocus) {
+        return FormatDetection_NotMatched;
+    }
+    RawDataCheckResult res(FormatDetection_VeryHighSimilarity);
+    
+    QByteArray seqStartPattern1 = "\n        1";
+    QByteArray seqStartPattern2 = "\nORIGIN";
+
+    res.properties[RawDataCheckResult_Sequence] = rawData.contains(seqStartPattern1) || rawData.contains(seqStartPattern2);
+
+    bool multi = (rawData.indexOf(seqStartPattern1) != rawData.lastIndexOf(seqStartPattern1)) || (rawData.indexOf(seqStartPattern2) != rawData.lastIndexOf(seqStartPattern2));
+    res.properties[RawDataCheckResult_MultipleSequences] = multi;
+    return res;
 }
 
 
@@ -108,7 +132,7 @@ bool GenbankPlainTextFormat::readEntry(QByteArray& sequence, ParserState* st) {
         }
         if (st->isNull()) {
             readIdLine(st);
-            assert(si.hasErrors() || !st->entry->name.isEmpty());
+            assert(si.hasError() || !st->entry->name.isEmpty());
             continue;
         }
         if (st->hasKey("FEATURES") && st->readNextLine()) {
@@ -183,7 +207,7 @@ bool GenbankPlainTextFormat::readEntry(QByteArray& sequence, ParserState* st) {
             st->entry->tags.insertMulti(lastTagName, st->value());
         }
     }
-    if (!st->isNull() && !si.hasErrors() && !si.cancelFlag) {
+    if (!st->isNull() && !si.hasError() && !si.cancelFlag) {
         si.setError(U2::EMBLGenbankAbstractDocument::tr("Record is truncated."));
     }
 
@@ -368,7 +392,7 @@ void GenbankPlainTextFormat::storeDocument( Document* doc, TaskStateInfo& si, IO
         // write annotations
         if (!aos.isEmpty()) {
             writeAnnotations(io, aos, si);
-            if (si.hasErrors()) {
+            if (si.hasError()) {
                 return;
             }
         }
@@ -376,7 +400,7 @@ void GenbankPlainTextFormat::storeDocument( Document* doc, TaskStateInfo& si, IO
         if (so) {
             //todo: store sequence alphabet!
             writeSequence(io, so, si);
-            if (si.hasErrors()) {
+            if (si.hasError()) {
                 return;
             }
         }
@@ -476,9 +500,9 @@ static void writeAnnotations(IOAdapter* io, QList<GObject*> aos, TaskStateInfo&
 
     //write every feature
     const char* spaceLine = TextUtils::SPACE_LINE.data();
-    const QByteArray& aminoQ = GBFeatureUtils::QUALIFIER_AMINO_STRAND;
-    const QByteArray& aminoQYes = GBFeatureUtils::QUALIFIER_AMINO_STRAND_YES;
-    const QByteArray& aminoQNo = GBFeatureUtils::QUALIFIER_AMINO_STRAND_NO;
+//    const QByteArray& aminoQ = GBFeatureUtils::QUALIFIER_AMINO_STRAND;
+//    const QByteArray& aminoQYes = GBFeatureUtils::QUALIFIER_AMINO_STRAND_YES;
+//    const QByteArray& aminoQNo = GBFeatureUtils::QUALIFIER_AMINO_STRAND_NO;
     const QByteArray& nameQ = GBFeatureUtils::QUALIFIER_NAME;
     const QByteArray& groupQ = GBFeatureUtils::QUALIFIER_GROUP;
     const QString& defaultKey = GBFeatureUtils::DEFAULT_KEY;
@@ -527,9 +551,9 @@ static void writeAnnotations(IOAdapter* io, QList<GObject*> aos, TaskStateInfo&
         }
 
         //write qualifiers
-        foreach (const Qualifier& q, a->getQualifiers()) {
-            writeQualifier(q.getQualifierName(), q.getQualifierValue(), io, si, spaceLine);
-            if (si.hasErrors()) {
+        foreach (const U2Qualifier& q, a->getQualifiers()) {
+            writeQualifier(q.name, q.value, io, si, spaceLine);
+            if (si.hasError()) {
                 return;
             }
         }
@@ -540,10 +564,10 @@ static void writeAnnotations(IOAdapter* io, QList<GObject*> aos, TaskStateInfo&
         }
 
         //write strand info
-        if (a->getAminoFrame() != TriState_Unknown) {
-            const QString& val = a->getAminoFrame() == TriState_No ? aminoQNo : aminoQYes;
-            writeQualifier(aminoQ, val, io, si, spaceLine);
-        }
+        //if (a->getAminoFrame() != TriState_Unknown) {
+        //    const QString& val = a->getAminoFrame() == TriState_No ? aminoQNo : aminoQYes;
+        //    writeQualifier(aminoQ, val, io, si, spaceLine);
+        //}
 
         //write group
         const QList<AnnotationGroup*>& groups = a->getGroups();
