@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "NEXUSFormat.h"
 #include "NEXUSParser.h"
@@ -571,7 +582,7 @@ bool NEXUSParser::readTreesContents(Context&) {
                 warnings.append(QString("Tree '%1' weights set by default (1.0)").arg(treeName));
             }
 
-            if (hasErrors()) {
+            if (hasError()) {
                 // clean up
                 PhyNode *n = nodeStack.pop();
                 delete n;  // PhyNode::~PhyNode() is recursive
@@ -620,7 +631,7 @@ QList<GObject*> NEXUSFormat::loadObjects(IOAdapter *io, TaskStateInfo &ti) {
     NEXUSParser parser(io, ti);
     QList<GObject*> objects = parser.loadObjects();
     
-    if (parser.hasErrors()) {
+    if (parser.hasError()) {
         QByteArray msg = "NEXUSParser: ";
         msg += parser.getErrors().first();
         ti.setError(tr(msg.data()));
@@ -633,7 +644,7 @@ Document* NEXUSFormat::loadDocument(IOAdapter *io, TaskStateInfo &ti, const QVar
     assert(io && "IO must exist");
 
     QList<GObject*> objects = loadObjects(io, ti);
-    if (ti.hasErrors())
+    if (ti.hasError())
     {
         qDeleteAll(objects);
         return 0;
@@ -808,7 +819,7 @@ void NEXUSFormat::storeDocument(Document *d, TaskStateInfo &ts, IOAdapter *io) {
     storeObjects(objects, io, ts);
 }
 
-FormatDetectionResult NEXUSFormat::checkRawData(const QByteArray &rawData) const {
+RawDataCheckResult NEXUSFormat::checkRawData(const QByteArray &rawData, const GUrl&) const {
     if (rawData.startsWith("#NEXUS")) {
         return FormatDetection_VeryHighSimilarity;
     }
