@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QStringList>
 
@@ -40,6 +51,8 @@ QHash<QByteArray, char> PDBFormat::acronymNameMap;
 PDBFormat::PDBFormat( QObject* p ) : DocumentFormat(p, DocumentFormatFlag(0), QStringList("pdb"))
 {
     formatName = tr("PDB");
+    formatDescription = tr("The Protein Data Bank (PDB) format provides a standard representation for macromolecular structure data derived from X-ray diffraction and NMR studies.");
+
     initUtilityMaps();
     AtomConstants::init();
     supportedObjectTypes+=GObjectTypes::BIOSTRUCTURE_3D;
@@ -47,7 +60,7 @@ PDBFormat::PDBFormat( QObject* p ) : DocumentFormat(p, DocumentFormatFlag(0), QS
     supportedObjectTypes+=GObjectTypes::ANNOTATION_TABLE;
 }
 
-FormatDetectionResult PDBFormat::checkRawData(const QByteArray& rawData) const {
+RawDataCheckResult PDBFormat::checkRawData(const QByteArray& rawData, const GUrl&) const {
     static const char* headerTag = "HEADER";
     static const char* atomTag = "ATOM";
     static const char* modelTag = "MODEL";
@@ -77,7 +90,7 @@ Document* PDBFormat::loadDocument( IOAdapter* io, TaskStateInfo& ti, const QVari
     clock_t t2 =  clock();
     perfLog.trace("PDB file parsing time: " + QString::number((float)( t2 - t1)/ CLOCKS_PER_SEC ));
     
-    if (ti.hasErrors() || ti.cancelFlag) {
+    if (ti.hasError() || ti.cancelFlag) {
         return NULL;
     }
     io->close();
@@ -152,6 +165,7 @@ PDBFormat::PDBParser::PDBParser(IOAdapter* _io) : io(_io), currentPDBLine(""), c
 
     currentChainIndex = 1;
     currentModelIndex = 0;
+    currentChainIndentifier = ' '; 
     flagMultipleModels = false;
     flagAtomRecordPresent = false;
 }
@@ -165,7 +179,7 @@ void PDBFormat::PDBParser::parseBioStruct3D( BioStruct3D& biostruct, TaskStateIn
     char* buf = readBuff.data();
     qint64 len = 0;
 
-    while (!ti.cancelFlag && !ti.hasErrors()) {
+    while (!ti.cancelFlag && !ti.hasError()) {
 
         bool lineOk = true;
 
@@ -215,6 +229,7 @@ void PDBFormat::PDBParser::parseBioStruct3D( BioStruct3D& biostruct, TaskStateIn
         }
 
         if (currentPDBLine.startsWith("MODEL")) {
+            currentChainIndex = 1;
             parseModel(biostruct, ti);
             continue;
         }
@@ -222,12 +237,11 @@ void PDBFormat::PDBParser::parseBioStruct3D( BioStruct3D& biostruct, TaskStateIn
         if (currentPDBLine.startsWith("ENDMDL")) {
             flagMultipleModels = true;
             ++currentModelIndex;
-            currentChainIndex = 1;
             continue;
         }
     }
     
-    if (ti.cancelFlag || ti.hasErrors()) {
+    if (ti.cancelFlag || ti.hasError()) {
         return;
     }
 
@@ -264,7 +278,7 @@ bool PDBFormat::PDBParser::seqResContains(char chainIdentifier, int residueIndex
         return true;
     }
     
-    if (!seqResMap.contains(chainIdentifier)) {
+    if (!seqResMap.contains(chainIdentifier) || residueIndex == 0) {
         return false;
     } 
     QByteArray sequence = seqResMap.value(chainIdentifier);
@@ -310,11 +324,13 @@ void PDBFormat::PDBParser::parseAtom( BioStruct3D& biostruct, TaskStateInfo&)
     int id = currentPDBLine.mid(6,5).toInt();
     QByteArray atomName = currentPDBLine.mid(12,4).toAscii().trimmed();
     QByteArray residueName = currentPDBLine.mid(17,3).toAscii().trimmed();
-    int residueIndex = currentPDBLine.mid(22,4).toInt();
+    int resId = currentPDBLine.mid(22,4).toAscii().toInt();
+    char insCode = currentPDBLine.at(26).toAscii();
     char residueAcronym = PDBFormat::getAcronymByName(residueName);
     char chainIdentifier = currentPDBLine.at(21).toAscii();
-    
-    bool atomIsInChain = !isHetero || seqResContains(chainIdentifier, residueIndex, residueAcronym );
+        
+    ResidueIndex residueIndex(resId,insCode);
+    bool atomIsInChain = !isHetero || seqResContains(chainIdentifier, residueIndex.toInt(), residueAcronym );
 
     QByteArray elementName = currentPDBLine.mid(76,2).toAscii().trimmed();
     
@@ -323,20 +339,18 @@ void PDBFormat::PDBParser::parseAtom( BioStruct3D& biostruct, TaskStateInfo&)
 
     int chainIndex = chainIndexMap.contains(chainIdentifier) ? chainIndexMap.value(chainIdentifier) : currentChainIndex;
 
+
     if ( currentModelIndex == 0 && atomIsInChain ) {
     
         // Process residue
 
         if (!biostruct.moleculeMap.contains(chainIndex)) {
-            SharedMolecule newMol( new MoleculeData );
-            newMol->name = QString("chain %1").arg(chainIdentifier);
-            biostruct.moleculeMap.insert(chainIndex,newMol);
-            chainIndexMap.insert(chainIdentifier, chainIndex);
+            createMolecule(chainIdentifier, biostruct, chainIndex);
         }
 
         SharedMolecule& mol = biostruct.moleculeMap[chainIndex];
         
-        if (!mol->residueMap.contains(residueIndex))  {
+        if (currentResidueIndex != residueIndex)  {
             SharedResidue residue( new ResidueData );
             residue->name = residueName;
             residue->acronym = residueAcronym;
@@ -344,6 +358,9 @@ void PDBFormat::PDBParser::parseAtom( BioStruct3D& biostruct, TaskStateInfo&)
                 ioLog.details(tr("PDB warning: unknown residue name: %1").arg(residue->name.constData()));
             }
             residue->chainIndex = chainIndex;
+            currentResidueIndex = residueIndex;
+            residueOrder++;
+            residueIndex.setOrder(residueOrder);
             mol->residueMap.insert(residueIndex, residue);
         }
 
@@ -584,7 +601,7 @@ void PDBFormat::PDBParser::parseSequence( BioStruct3D& biostruct, TaskStateInfo&
     if (!seqResMap.contains(chainIdentifier)) {
         seqResMap.insert(chainIdentifier, QByteArray());
     }
-    
+
     QStringList residues = currentPDBLine.mid(19).split(QRegExp("\\s+"), QString::SkipEmptyParts);
     QByteArray sequencePart;
     foreach (QString name, residues ) {
@@ -682,10 +699,27 @@ void PDBFormat::PDBParser::updateSecStructChainIndexes( BioStruct3D& biostruc )
     while (i.hasNext()) {
         SharedSecondaryStructure& secStruc = i.next();
         char chainIdentifier = secStruc->chainIdentifier;
-        Q_ASSERT(chainIndexMap.contains(chainIdentifier));
+        if (!chainIndexMap.contains(chainIdentifier)) {
+            i.remove();
+            continue;
+        } 
         secStruc->chainIndex = chainIndexMap.value(chainIdentifier);
+
     }
 }
+
+void PDBFormat::PDBParser::createMolecule( char chainIdentifier, BioStruct3D &biostruct, int chainIndex )
+{
+    SharedMolecule newMol( new MoleculeData );
+    newMol->name = QString("chain %1").arg(chainIdentifier);
+    biostruct.moleculeMap.insert(chainIndex,newMol);
+    chainIndexMap.insert(chainIdentifier, chainIndex);
+}
+
+void PDBFormat::PDBParser::updateResidueIndexes( BioStruct3D& /*biostruc*/)
+{
+}
+
 char PDBFormat::getAcronymByName( const QByteArray& name )
 {   
     if (acronymNameMap.contains(name)) 
@@ -920,6 +954,7 @@ Document* PDBFormat::createDocumentFromBioStruct3D( BioStruct3D &bioStruct, Docu
         AnnotationTableObject* ao = i.key();
         ao->addObjectRelation(dnao, GObjectRelationRole::SEQUENCE);
         biostrucObj->addObjectRelation(dnao, GObjectRelationRole::SEQUENCE);
+        biostrucObj->addObjectRelation(ao, GObjectRelationRole::ANNOTATION_TABLE);
     }
 
     return doc;
