@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "SAMFormat.h"
 #include "DocumentFormatUtils.h"
@@ -24,6 +35,7 @@
 #include <U2Core/TextUtils.h>
 #include <U2Core/DNATranslation.h>
 #include <U2Core/AppContext.h>
+#include <U2Core/U2AssemblyUtils.h>
 
 #include <QtCore/QRegExp>
 
@@ -76,9 +88,13 @@ SAMFormat::SAMFormat( QObject* p ): DocumentFormat(p, DocumentFormatFlags_SW, QS
 {
     formatName = tr("SAM");
     supportedObjectTypes+=GObjectTypes::MULTIPLE_ALIGNMENT;
+    skipDetection = false;
 }
 
-FormatDetectionResult SAMFormat::checkRawData( const QByteArray& rawData ) const {
+RawDataCheckResult SAMFormat::checkRawData( const QByteArray& rawData, const GUrl&) const {
+    if (skipDetection) {
+        return FormatDetection_NotMatched;
+    }
     QRegExp rx("^@[A-Za-z][A-Za-z](\\t[A-Za-z][A-Za-z]:[ -~]+)");
     //try to find SAM header
     if(rx.indexIn(rawData) != 0) {
@@ -95,6 +111,54 @@ FormatDetectionResult SAMFormat::checkRawData( const QByteArray& rawData ) const
     return FormatDetection_VeryHighSimilarity;
 }
 
+static void prepareRead(const QByteArray& core, const QByteArray& quality, QByteArray& seq, QByteArray& qual, QByteArray& cigar) {
+    bool gap = true;
+    int lastCigarPos = 0;
+
+    QList<U2CigarToken> cigarTokens;
+
+    for(int i = 0, coreLen = core.length(); i < coreLen; i++) {
+        char c = core[i];
+        if(c == MAlignment_GapChar) {
+            if(!gap) {
+                if(i != lastCigarPos) {
+                    cigarTokens.append(U2CigarToken(U2CigarOp_M, i - lastCigarPos));
+                }
+                gap = true;
+                lastCigarPos = i;
+            }
+        } else {
+            seq.push_back(c);
+            if(!quality.isEmpty()) {
+                qual.push_back(DNAQuality::encode(quality[i], DNAQualityType_Sanger));
+            }
+            if(gap) {
+                if(i != lastCigarPos) {
+                    cigarTokens.append(U2CigarToken(U2CigarOp_N, i - lastCigarPos));
+                }
+                gap = false;
+                lastCigarPos = i;
+            }
+        }
+    }
+    if(lastCigarPos != core.length() - 1) {
+        cigarTokens.append(U2CigarToken(gap ? U2CigarOp_N : U2CigarOp_M, core.length() - 1 - lastCigarPos));
+    }
+    if(cigarTokens.isEmpty()) {
+        cigar = QByteArray("*");
+    } else {
+        foreach(U2CigarToken token, cigarTokens) {
+            assert(token.count != 0);
+            cigar.append(QString::number(token.count));
+            switch(token.op) {
+                case U2CigarOp_M: cigar.append("M"); break;
+                case U2CigarOp_N: cigar.append("N"); break;
+                default:;
+            }
+        }
+    }
+}
+
 Document* SAMFormat::loadDocument( IOAdapter* io, TaskStateInfo& ti, const QVariantMap& _fs, DocumentLoadMode mode /*= DocumentLoadMode_Whole*/ )
 {
     Q_UNUSED(mode);
@@ -280,7 +344,7 @@ Document* SAMFormat::loadDocument( IOAdapter* io, TaskStateInfo& ti, const QVari
         objects.append(new MAlignmentObject(defaultMA));
     }
 
-    if (ti.hasErrors() || ti.cancelFlag) {
+    if (ti.hasError() || ti.cancelFlag) {
         qDeleteAll(objects);
         return NULL;
     }
@@ -336,18 +400,26 @@ void SAMFormat::storeDocument( Document* d, TaskStateInfo& ts, IOAdapter* io )
         QByteArray rname(ma.getName().replace(QRegExp("\\s|\\t"), "_").toAscii());
         foreach(MAlignmentRow row, ma.getRows()) {
             block.clear();
+            //const QByteArray &core = row.getCore();
             QByteArray qname = QString(row.getName()).replace(QRegExp("\\s|\\t"), "_").toAscii();
             QByteArray flag("0"); // can contains strand, mapped/unmapped, etc.
             QByteArray pos = QByteArray::number(row.getCoreStart()+1);
             QByteArray mapq("255"); //255 indicating the mapping quality is not available
-            QByteArray cigar("*");
             QByteArray mrnm("*");
             QByteArray mpos("0");
             QByteArray isize("0");
-            QByteArray seq(row.getCore());
-            QByteArray qual(row.getCoreQuality().qualCodes);
-            if(qual.isEmpty()) qual.fill('I', row.getCoreLength()); //I - 50 Phred quality score (99.999%)
+            QByteArray seq;
+            QByteArray qual;
+            QByteArray cigar;
 
+            prepareRead(row.getCore(), row.getCoreQuality().qualCodes, seq, qual, cigar);
+            if (row.hasQuality()) {
+                row.getCoreQuality().qualCodes;
+            } else {
+                qual.reserve(seq.length());
+                qual.fill('I', seq.length());
+            }
+            
             block = qname + tab + flag + tab+ rname + tab + pos + tab + mapq + tab + cigar + tab + mrnm
                 + tab + mpos + tab + isize + tab + seq + tab + qual + "\n";
             if (io->writeBlock( block ) != block.length()) {
@@ -365,24 +437,47 @@ bool SAMFormat::getSectionTags( QByteArray &line, const QByteArray &sectionName,
     return true;
 }
 
-bool SAMFormat::storeAlignedRead( int offset, const DNASequence& read, IOAdapter* io, const QString& refName, int refLength, bool first )
-{
-   
+bool SAMFormat::storeHeader(IOAdapter* io, const QVector<QByteArray> &names, const QVector<int> &lengths) {
+    assert(names.size() > 0);
+    assert(names.size() == lengths.size());
     static const QByteArray TAB = "\t";
-    
-    if( NULL == io || !io->isOpen() ) {
-        //ts.setError(L10N::badArgument("IO adapter"));
+    QByteArray block;
+    block.append(SECTION_HEADER).append(TAB).append("VN:").append(VERSION).append("\n");   
+    for (int i=0; i<names.size(); i++) {
+        block.append(SECTION_SEQUENCE).append(TAB).append(TAG_SEQUENCE_NAME).append(":");
+        block.append(names[i]).append(TAB);
+        block.append(TAG_SEQUENCE_LENGTH).append(":").append(QByteArray::number(lengths[i])).append("\n");
+    }
+    if (io->writeBlock( block ) != block.length()) {
         return false;
     }
+    block.clear();
 
-    QByteArray block;
-    QByteArray rname = QString(refName).replace(QRegExp("\\s|\\t"), "_").toAscii();
+    return true;
+}
 
+bool SAMFormat::storeAlignedRead(int offset, const DNASequence& read, IOAdapter* io, const QByteArray& refName, int refLength, bool first, bool useCigar, const QByteArray &cigar)
+{
+    static const QByteArray TAB = "\t";
+    static const QByteArray flag("0"); // can contains strand, mapped/unmapped, etc.
+    static const QByteArray mapq("255"); //255 indicating the mapping quality is not available
+    static const QByteArray mrnm("*");
+    static const QByteArray mpos("0");
+    static const QByteArray isize("0");
+    static const QString rowDataNotCigar = "%1" + TAB + flag + TAB + "%2" + TAB + "%3" + TAB + mapq + TAB + "%4M" + TAB + mrnm
+        + TAB + mpos + TAB + isize + TAB + "%5" + TAB + "%6" + "\n";
+    static const QString rowDataCigar = "%1" + TAB + flag + TAB + "%2" + TAB + "%3" + TAB + mapq + TAB + "%4" + TAB + mrnm
+        + TAB + mpos + TAB + isize + TAB + "%5" + TAB + "%6" + "\n";
+    
+    if( NULL == io || !io->isOpen() ) {
+        return false;
+    }
     
     if (first) {
+        QByteArray block;
         block.append(SECTION_HEADER).append(TAB).append("VN:").append(VERSION).append("\n");   
         block.append(SECTION_SEQUENCE).append(TAB).append(TAG_SEQUENCE_NAME).append(":");
-        block.append(rname).append(TAB);
+        block.append(refName).append(TAB);
         block.append(TAG_SEQUENCE_LENGTH).append(":").append(QByteArray::number(refLength)).append("\n");
         if (io->writeBlock( block ) != block.length()) {
             return false;
@@ -394,29 +489,35 @@ bool SAMFormat::storeAlignedRead( int offset, const DNASequence& read, IOAdapter
     if (qname.isEmpty()) {
         qname = "contig";
     }
-    QByteArray flag("0"); // can contains strand, mapped/unmapped, etc.
-    QByteArray pos = QByteArray::number(offset+1);
-    QByteArray mapq("255"); //255 indicating the mapping quality is not available
-    QByteArray cigar("*");
-    QByteArray mrnm("*");
-    QByteArray mpos("0");
-    QByteArray isize("0");
-    QByteArray seq(read.seq);
-    QByteArray qual(read.quality.qualCodes);
-    if(qual.isEmpty()) {
-        qual.fill('I', read.length()); //I - 50 Phred quality score (99.999%)
+
+    QByteArray qual;
+    if (read.hasQualityScores()) {
+        qual = read.quality.qualCodes;
+    } else {
+        qual.fill('I', read.seq.length());
+    }
+    QString row;
+    if (useCigar) {
+        row = rowDataCigar.arg(qname.constData())
+            .arg(refName.constData())
+            .arg(offset+1)
+            .arg(cigar.constData())
+            .arg(read.seq.constData())
+            .arg(qual.constData());
+    } else {
+        row = rowDataNotCigar.arg(qname.constData())
+            .arg(refName.constData())
+            .arg(offset+1)
+            .arg(read.seq.length())
+            .arg(read.seq.constData())
+            .arg(qual.constData());
     }
 
-    block = qname + TAB + flag + TAB + rname + TAB + pos + TAB + mapq + TAB + cigar + TAB + mrnm
-        + TAB + mpos + TAB + isize + TAB + seq + TAB + qual + "\n";
-    if (io->writeBlock( block ) != block.length()) {
+    if (io->writeBlock(row.toAscii()) != row.length()) {
         return false;
     }
 
     return true;
-
-
-    
 }
 
 }// namespace
