@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "SCFFormat.h"
 #include "IOLibUtils.h"
@@ -22,8 +33,9 @@
 #include <U2Core/GObjectTypes.h>
 #include <U2Core/GObjectRelationRoles.h>
 #include <U2Core/DNAChromatogramObject.h>
-
+#include <U2Core/U2OpStatus.h>
 #include <U2Core/TextUtils.h>
+#include <U2Core/U2SafePoints.h>
 
 /* TRANSLATOR U2::SCFFormat */    
 
@@ -35,7 +47,7 @@ SCFFormat::SCFFormat(QObject* p) : DocumentFormat(p,DocumentFormatFlags(0), QStr
     supportedObjectTypes+=GObjectTypes::CHROMATOGRAM;
 }
 
-FormatDetectionResult SCFFormat::checkRawData(const QByteArray& rawData) const {
+RawDataCheckResult SCFFormat::checkRawData(const QByteArray& rawData, const GUrl&) const {
     const char* data = rawData.constData();
     int size = rawData.size();
     if (size <= 4 || data[0]!='.' || data[1]!='s' || data[2]!='c' || data[3]!='f') {
@@ -59,7 +71,7 @@ Document* SCFFormat::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVaria
         }
     }
 
-    if (ti.hasErrors()) {
+    if (ti.hasError()) {
         return NULL;
     }
 
@@ -67,9 +79,11 @@ Document* SCFFormat::loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVaria
     sf.head = readBuff.constData();
     sf.pos = 0;
     sf.size = readBuff.size();
-    Document* doc = parseSCF(&sf, io->getFactory(), url, fs);
-    if (doc == NULL && !ti.hasErrors()) {
-        ti.setError(tr("Not a valid SCF file: %1").arg(url.getURLString()));
+    Document* doc = parseSCF(&sf, io->getFactory(), url, fs, ti);
+    if (doc == NULL && !ti.hasError()) {
+        if (!ti.hasError()) {
+            ti.setError(tr("Failed to parse SCF file: %1").arg(url.getURLString()));
+        }
     }
     return doc;
 }
@@ -505,7 +519,7 @@ int read_scf_bases3(SeekableBuf *fp, Bases *b, size_t num_bases)
     return 0;
 }
 
-Document* SCFFormat::parseSCF(SeekableBuf* fp, IOAdapterFactory* iof, const GUrl& url, const QVariantMap& fs) {    
+Document* SCFFormat::parseSCF(SeekableBuf* fp, IOAdapterFactory* iof, const GUrl& url, const QVariantMap& fs, U2OpStatus& os) {    
     Header h;
     float scf_version;
     int sections = READ_ALL;
@@ -644,7 +658,11 @@ Document* SCFFormat::parseSCF(SeekableBuf* fp, IOAdapterFactory* iof, const GUrl
     dna.info.insert(DNAInfo::COMMENT, vals);
 
     QList<GObject*> objects;
-    DNASequenceObject* seqObj = DocumentFormatUtils::addSequenceObject(objects, sampleName + " sequence", dna);
+    DNASequenceObject* seqObj = DocumentFormatUtils::addSequenceObject(objects, sampleName + " sequence", dna, fs, os);
+    if (os.hasError()) {
+        return NULL;
+    }
+    SAFE_POINT(seqObj != NULL, "DocumentFormatUtils::addSequenceObject returned NULL but didn't set error", NULL);
     DNAChromatogramObject* chromObj = new DNAChromatogramObject(cd, sampleName + " chromatogram");
     objects.append(chromObj);
     Document* doc = new Document(this, iof, url, objects, fs);
