@@ -1,31 +1,41 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ProjectTreeController.h"
 #include "UnloadDocumentTask.h"
 
 #include <U2Core/ProjectModel.h>
 #include <U2Core/GObject.h>
-#include <U2Gui/ProjectView.h>
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/ResourceTracker.h>
-#include <U2Gui/ObjectViewModel.h>
 #include <U2Core/Log.h>
-#include <U2Gui/MainWindow.h>
-
 #include <U2Core/RemoveDocumentTask.h>
 #include <U2Core/LoadDocumentTask.h>
 #include <U2Core/SaveDocumentTask.h>
-#include <U2Core/GObjectTypes.h>
-#include <U2Core/DNASequenceObject.h>
 #include <U2Core/UnloadedObject.h>
+#include <U2Core/U2SafePoints.h>
+
+#include <U2Gui/MainWindow.h>
+#include <U2Gui/ProjectView.h>
+#include <U2Gui/ObjectViewModel.h>
 
 #include <QtCore/QMimeData>
 #include <QtCore/QMap>
@@ -58,15 +68,18 @@ bool PTCObjectRelationFilter::filter(GObject* o) const {
     return !o->hasObjectRelation(rel);
 }
 
+
 ProjectTreeController::ProjectTreeController(QObject* parent, QTreeWidget* _tree, const ProjectTreeControllerModeSettings& m) 
 : QObject(parent), mode(m) {
 
     markActiveView = NULL;
+    setObjectName("ProjectTreeController");
 
     tree = _tree;
     tree->setSelectionMode(mode.allowMultipleSelection ? QAbstractItemView::ExtendedSelection : QAbstractItemView::SingleSelection);
 	tree->headerItem()->setHidden(true);
 	tree->setContextMenuPolicy(Qt::CustomContextMenu);
+    connect(tree->itemDelegate(), SIGNAL(closeEditor(QWidget*,QAbstractItemDelegate::EndEditHint)), SLOT(sl_onCloseEditor(QWidget*,QAbstractItemDelegate::EndEditHint)));
     
     documentIcon.addFile(":/core/images/document.png");
     roDocumentIcon.addFile(":/core/images/ro_document.png");
@@ -92,6 +105,9 @@ ProjectTreeController::ProjectTreeController(QObject* parent, QTreeWidget* _tree
     unloadSelectedDocumentsAction = new QAction(QIcon(":core/images/unload_document.png"), tr("Unload selected document"), this);
     connect(unloadSelectedDocumentsAction, SIGNAL(triggered()), SLOT(sl_onUnloadSelectedDocuments()));
 
+    renameAction = new QAction(tr("Rename..."), this);
+    connect(renameAction, SIGNAL(triggered()), SLOT(sl_onRename()));
+
     groupByDocumentAction = new QAction(tr("Group by document"), this);
     groupByDocumentAction->setObjectName("Group_by_document_action");
     groupByDocumentAction->setCheckable(true);
@@ -118,7 +134,6 @@ ProjectTreeController::ProjectTreeController(QObject* parent, QTreeWidget* _tree
 	connect(tree, SIGNAL(itemSelectionChanged()), SLOT(sl_onTreeSelectionChanged()));
 	connect(tree, SIGNAL(customContextMenuRequested(const QPoint &)), SLOT(sl_onContextMenuRequested(const QPoint &)));
 	connect(tree, SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)), SLOT(sl_onItemDoubleClicked(QTreeWidgetItem*, int )));
-    connect(tree, SIGNAL(itemChanged(QTreeWidgetItem *, int)), SLOT(sl_onItemChanged(QTreeWidgetItem *, int)));
     tree->installEventFilter(this);
 
 	Project* pr = AppContext::getProject();
@@ -170,7 +185,7 @@ void ProjectTreeController::connectDocument(Document* d) {
 	connect(d, SIGNAL(si_loadedStateChanged()), SLOT(sl_onDocumentLoadedStateChanged()));
 	connect(d, SIGNAL(si_objectAdded(GObject*)), SLOT(sl_onObjectAdded(GObject*)));
 	connect(d, SIGNAL(si_objectRemoved(GObject*)), SLOT(sl_onObjectRemoved(GObject*)));
-    connect(d, SIGNAL(si_lockedStateChanged()), SLOT(sl_lockedStateChanged()));
+    connect(d, SIGNAL(si_lockedStateChanged()), SLOT(sl_onLockedStateChanged()));
     connect(d, SIGNAL(si_urlChanged()), SLOT(sl_onDocumentURLorNameChanged()));
     connect(d, SIGNAL(si_nameChanged()), SLOT(sl_onDocumentURLorNameChanged()));
 	
@@ -195,6 +210,7 @@ void ProjectTreeController::disconnectDocument(Document* d) {
 
 void ProjectTreeController::connectGObject(GObject* o) {
 	connect(o, SIGNAL(si_modifiedStateChanged()), SLOT(sl_onObjectModifiedStateChanged()));
+    connect(o, SIGNAL(si_nameChanged(const QString&)), SLOT(sl_onObjectNameChanged(const QString&)));
 }
 
 void ProjectTreeController::buildTree() {
@@ -218,7 +234,12 @@ GObjectType ProjectTreeController::getLoadedObjectType(GObject* obj) const {
 }
 
 
-#define MAX_OBJECTS_TO_AUTOEXPAND 50
+// if objects number in document < MAX_OBJECTS_TO_AUTOEXPAND - document content will be automatically expanded on loading
+#define MAX_OBJECTS_TO_AUTOEXPAND 20
+// if documents number in project < MAX_DOCUMENTS_TO_AUTOEXPAND - document content will be automatically expanded on loading
+#define MAX_DOCUMENTS_TO_AUTOEXPAND 20
+
+
 
 void ProjectTreeController::buildDocumentTree(Document* d) {
     TreeUpdateHelper h(itemsToUpdate);
@@ -239,9 +260,6 @@ void ProjectTreeController::buildDocumentTree(Document* d) {
             ProjViewObjectItem* oItem = findGObjectItem(topItem, obj);
             if (oItem == NULL) {
                 oItem = new ProjViewObjectItem(obj, this);
-                if(obj->getGObjectType() == GObjectTypes::SEQUENCE && !obj->isStateLocked()) {
-                    oItem->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsEditable);
-                }
                 if (mode.groupMode != ProjectTreeGroupMode_ByDocument || topItem == NULL) {
                     insertTreeItemSorted(topItem, oItem);
                 } else { //keep natural mode, as in file
@@ -359,48 +377,36 @@ void ProjectTreeController::sl_onTreeSelectionChanged() {
 bool ProjectTreeController::eventFilter(QObject* o, QEvent* e) {
     if (e->type() == QEvent::KeyPress) {
         QKeyEvent *kEvent = (QKeyEvent*)e;
-        if(kEvent->key() == Qt::Key_F2) {
+        int key = kEvent->key();
+        bool hasSelection = !((QTreeWidget *)o)->selectedItems().isEmpty();
+        if (key == Qt::Key_F2 && hasSelection) {
+            sl_onRename();
+            return true;
+        } else if ( (key == Qt::Key_Return || key == Qt::Key_Enter) && hasSelection) {
             ProjViewItem *item = static_cast<ProjViewItem *>(((QTreeWidget *)o)->selectedItems().last());
-            if(item->isObjectItem()) {
+            if (item->isObjectItem() && !item->flags().testFlag(Qt::ItemIsEditable)) {
                 ProjViewObjectItem *objItem = static_cast<ProjViewObjectItem*>(item);
-                if(objItem->obj->getGObjectType() == GObjectTypes::SEQUENCE && !objItem->obj->getDocument()->isStateLocked()) {
-                    QString text = item->text(0);
-                    text = text.split("[s] ").last();
-                    item->setText(0,text);
-                    editing = true;
-                    tree->editItem(item);
-                    return true;
-                }
+                emit si_returnPressed(objItem->obj);
             }
+
         }
-    } 
+    }
     return false;
 }
 
-void ProjectTreeController::sl_onItemChanged(QTreeWidgetItem * item, int column) {
-    ProjViewTypeItem *pItem = static_cast<ProjViewTypeItem*>(item);
-    if(pItem->isObjectItem()) {
-        ProjViewObjectItem *objItem = static_cast<ProjViewObjectItem*>(item);
-        if(objItem->obj->getGObjectType() == GObjectTypes::SEQUENCE) {           
-            DNASequenceObject *obj = qobject_cast<DNASequenceObject*>(objItem->obj);
-            QString prevName  = obj->getGObjectName();
-            QString itemText = item->text(column).split("[s] ").last();
-            
-            if(itemText != prevName && editing) {
-                editing = false;
-                if(itemText.isEmpty()) {
-                    item->setText(column, prevName.prepend("[s] "));
-                    return;
-                }
-
-                obj->setGObjectName(itemText);
-                obj->getDocument()->setModified(true); 
-                emit si_nameChanged(obj);
-                
-            } 
-        }
+void ProjectTreeController::sl_onCloseEditor(QWidget*,QAbstractItemDelegate::EndEditHint) {
+    QTreeWidgetItem* item = tree->currentItem();
+    SAFE_POINT(item != NULL, "Unexpected current item on edit!",);
+    ProjViewItem* pvi = static_cast<ProjViewItem*>(item);
+    SAFE_POINT(pvi->isObjectItem(), "Not an object type item on edit!",);
+    ProjViewObjectItem* objItem = static_cast<ProjViewObjectItem*>(pvi);
+    if (!AppContext::getProject()->isStateLocked()) {
+        QString newName = item->text(0);
+        coreLog.trace(QString("Renaming object %1 to %2").arg(objItem->obj->getGObjectName()).arg(newName));
+        objItem->obj->setGObjectName(newName);
     }
-    editing = false;
+    objItem->setFlags(objItem->flags() & ~Qt::ItemIsEditable);
+    objItem->updateVisual();
 }
 
 void ProjectTreeController::updateSelection() {
@@ -427,9 +433,8 @@ void ProjectTreeController::updateSelection() {
 }
 
 
-void ProjectTreeController::sl_onItemDoubleClicked(QTreeWidgetItem * item, int column) {
-    Q_UNUSED(column);
-	ProjViewItem* pvi = static_cast<ProjViewItem*>(item);
+void ProjectTreeController::sl_onItemDoubleClicked(QTreeWidgetItem * item, int) {
+    ProjViewItem* pvi = static_cast<ProjViewItem*>(item);
 	if (pvi->isObjectItem()) {
 		emit si_doubleClicked((static_cast<ProjViewObjectItem*>(pvi))->obj);
 	} else if (pvi->isDocumentItem()) {
@@ -460,18 +465,17 @@ void ProjectTreeController::sl_onContextMenuRequested(const QPoint&) {
     }
 
     ProjectView* pv = AppContext::getProjectView();
-	if (pv!=NULL) {
-        //change original text, these actions removed when menu deleted
-        //QAction* addNewDocumentAction = new QAction(pv->getAddNewDocumentAction()->icon(), tr("new_document"), &m);
-        //connect(addNewDocumentAction, SIGNAL(triggered()), pv->getAddNewDocumentAction(), SLOT(trigger()));
-
+	if (pv != NULL) {
         QAction* addExistingDocumentAction = new QAction(pv->getAddExistingDocumentAction()->icon(), tr("Existing document"), &m);
         connect(addExistingDocumentAction, SIGNAL(triggered()), pv->getAddExistingDocumentAction(), SLOT(trigger()));
 
         QMenu* addMenu = m.addMenu(tr("Add"));
         addMenu->menuAction()->setObjectName( ACTION_PROJECT__ADD_MENU);
         addMenu->addAction(addExistingDocumentAction);
-        //addMenu->addAction(addNewDocumentAction);
+
+        QMenu* editMenu = m.addMenu(tr("Edit"));
+        editMenu->menuAction()->setObjectName( ACTION_PROJECT__EDIT_MENU);
+        editMenu->addAction(renameAction);
 	}
 
     QMenu* removeMenu = m.addMenu(tr("Remove"));
@@ -514,7 +518,7 @@ void ProjectTreeController::updateActions() {
     unloadSelectedDocumentsAction->setEnabled(hasLoadedDocumentInSelection);
 
     addReadonlyFlagAction->setEnabled(docsInSelection.size() == 1 && !docsInSelection.toList().first()->hasUserModLock() && !docsInSelection.toList().first()->isStateLocked());
-    removeReadonlyFlagAction->setEnabled(docsInSelection.size() == 1 && docsInSelection.toList().first()->hasUserModLock());
+    removeReadonlyFlagAction->setEnabled(docsInSelection.size() == 1 && docsInSelection.toList().first()->isLoaded() && docsInSelection.toList().first()->hasUserModLock());
 
     if (!docsItemsInSelection.isEmpty()) {
         loadSelectedDocumentsAction->setText(tr("Load selected documents"));
@@ -524,6 +528,15 @@ void ProjectTreeController::updateActions() {
         unloadSelectedDocumentsAction->setText(tr("Unload selected objects"));
     }
 
+    QList<QTreeWidgetItem*> selItems = tree->selectedItems();
+    bool renameIsOk = false;
+    if (selItems.size() == 1) {
+        ProjViewItem *item = static_cast<ProjViewItem *>(selItems.last());
+        if (item != NULL && item->isObjectItem() && !AppContext::getProject()->isStateLocked()) {
+            renameIsOk = true;
+        }
+    } 
+    renameAction->setEnabled(renameIsOk);
 }
 
 void ProjectTreeController::sl_onRemoveSelectedDocuments() {
@@ -536,11 +549,13 @@ void ProjectTreeController::sl_onRemoveSelectedDocuments() {
 
 void ProjectTreeController::sl_onLoadSelectedDocuments() {
     QSet<Document*> docsInSelection = getDocsInSelection(true);//mode.groupMode != ProjectTreeGroupMode_ByDocument);
+    QList<Document*> docsToLoad;
     foreach(Document* d, docsInSelection) {
         if (!d->isLoaded() && LoadUnloadedDocumentTask::findActiveLoadingTask(d)==NULL) {
-            runLoadDocumentTask(d);
+            docsToLoad.append(d);
         }
     }
+    runLoadDocumentTasks(docsToLoad);
 }
 
 void ProjectTreeController::sl_onUnloadSelectedDocuments() {
@@ -555,14 +570,19 @@ void ProjectTreeController::sl_onUnloadSelectedDocuments() {
 }
 
 
-void ProjectTreeController::runLoadDocumentTask(Document* d) {
-    Task* t = NULL;
+void ProjectTreeController::runLoadDocumentTasks(const QList<Document*>& docs) {
+    QList<Task*> tasks;
     if (mode.loadTaskProvider!=NULL) {
-        t = mode.loadTaskProvider->createLoadDocumentTask(d);
+        tasks = mode.loadTaskProvider->createLoadDocumentTasks(docs);
     } else {
-        t = new LoadUnloadedDocumentTask(d);
+        foreach(Document* d, docs) {
+            tasks << new LoadUnloadedDocumentTask(d);
+        }
     }
-    AppContext::getTaskScheduler()->registerTopLevelTask(t);
+    foreach(Task* t, tasks) {
+        AppContext::getTaskScheduler()->registerTopLevelTask(t);
+    }
+
 }
 
 void ProjectTreeController::sl_onDocumentAddedToProject(Document* d) {
@@ -614,18 +634,13 @@ void ProjectTreeController::sl_onToggleReadonly() {
     }
 }
 
-void ProjectTreeController::sl_lockedStateChanged() {
-    Document* doc = qobject_cast<Document*>(sender());
+void ProjectTreeController::sl_onLockedStateChanged() {
+    QObject * who = sender();
+    Document* doc = qobject_cast<Document*>(who);
     assert(doc!=NULL);
 
     ProjViewDocumentItem* di = findDocumentItem(doc);
-    foreach(GObject* obj, doc->getObjects()) {
-        ProjViewObjectItem* oi = findGObjectItem(di, obj);
-        if(oi->obj->getGObjectType() == GObjectTypes::SEQUENCE) {
-            oi->setFlags(oi->flags() ^ Qt::ItemIsEditable);
-        }
-    }
-
+    
     if (mode.readOnlyFilter == TriState_Unknown) {
         if (di!=NULL) {
             di->updateVisual(false);
@@ -657,6 +672,20 @@ void ProjectTreeController::sl_lockedStateChanged() {
     updateActions();
 }
 
+void ProjectTreeController::sl_onRename() {
+    QList<QTreeWidgetItem*> selItems = tree->selectedItems();
+    if (selItems.size() != 1) {
+        return;
+    }
+    ProjViewItem *item = static_cast<ProjViewItem *>(selItems.last());
+    if (item != NULL && item->isObjectItem() && !AppContext::getProject()->isStateLocked()) {
+        ProjViewObjectItem *objItem = static_cast<ProjViewObjectItem*>(item);
+        QString oldName = objItem->obj->getGObjectName();
+        objItem->setFlags(objItem->flags() | Qt::ItemIsEditable);
+        objItem->setText(0, objItem->obj->getGObjectName());
+        tree->editItem(objItem);
+    }
+}
 
 void ProjectTreeController::flattenDocumentItem(ProjViewDocumentItem* docItem) {
     assert(mode.groupMode == ProjectTreeGroupMode_Flat);
@@ -687,7 +716,7 @@ void ProjectTreeController::sl_onDocumentLoadedStateChanged() {
             docItem = NULL;
         }
     }
-    if (docItem!=NULL && d->getObjects().size() < MAX_OBJECTS_TO_AUTOEXPAND) {
+    if (docItem != NULL && d->getObjects().size() < MAX_OBJECTS_TO_AUTOEXPAND && AppContext::getProject()->getDocuments().size() < MAX_DOCUMENTS_TO_AUTOEXPAND) {
         docItem->setExpanded(d->isLoaded());
     }
 	updateActions();
@@ -707,18 +736,25 @@ void ProjectTreeController::sl_onDocumentModifiedStateChanged() {
     }
 }
 
-void ProjectTreeController::sl_onObjectModifiedStateChanged() {
-    updateActions();
-	GObject* obj = qobject_cast<GObject*>(sender());
-    assert(obj!=NULL);
+void ProjectTreeController::updateObjectVisual(GObject* obj) {
+    SAFE_POINT(obj != NULL, "Object is NULL in updateObjectVisual()", );
     if (!mode.isObjectShown(obj)) {
         return;
     }
-	ProjViewObjectItem* item = findGObjectItem(obj->getDocument(), obj);
-	assert(item);
-	item->updateVisual();
+    ProjViewObjectItem* item = findGObjectItem(obj->getDocument(), obj);
+    SAFE_POINT(item != NULL, QString("item not found for object %1").arg(obj->getGObjectName()), );
+    item->updateVisual();
 }
 
+void ProjectTreeController::sl_onObjectModifiedStateChanged() {
+    updateActions();
+    updateObjectVisual(qobject_cast<GObject*>(sender()));
+}
+
+void ProjectTreeController::sl_onObjectNameChanged(const QString&) {
+    updateActions();
+    updateObjectVisual(qobject_cast<GObject*>(sender()));
+}
 
 void ProjectTreeController::sl_onObjectAdded(GObject* obj) {
     if (!mode.isObjectShown(obj)) {
@@ -739,16 +775,13 @@ void ProjectTreeController::sl_onObjectAdded(GObject* obj) {
     }
     connectGObject(obj);
 	ProjViewObjectItem* objItem = new ProjViewObjectItem(obj, this);
-    if(obj->getGObjectType() == GObjectTypes::SEQUENCE && !obj->isStateLocked()) {
-        objItem->setFlags(objItem->flags() | Qt::ItemIsEditable);
-    }
-
+    
     if (mode.groupMode != ProjectTreeGroupMode_ByDocument || topItem == NULL) {
         insertTreeItemSorted(topItem, objItem);
     } else { //keep natural mode, as in file
         topItem->addChild(objItem);
     }
-    if (topItem!=NULL) {
+    if (topItem != NULL) {
         topItem->updateVisual();
     }
 	updateActions();
@@ -961,8 +994,9 @@ void ProjectTreeController::sl_onDocumentURLorNameChanged() {
 void ProjectTreeController::highlightItem(Document *doc){
     assert(doc);
     ProjViewDocumentItem *item = findDocumentItem(doc);
-    assert( item );
-    item->setSelected(true);
+    if (item) { //item can be NULL here if custom filter is used
+        item->setSelected(true);
+    }
 }
 
 void ProjectTreeController::sl_windowActivated(MWMDIWindow* w) {
@@ -993,7 +1027,7 @@ void ProjectTreeController::sl_windowActivated(MWMDIWindow* w) {
     }
     GObjectViewWindow* ow = qobject_cast<GObjectViewWindow*>(w); 
     if (ow != NULL) {
-        uiLog.trace(QString("Project view now listens object events in '%1' view").arg(ow->getWindowName()));
+        uiLog.trace(QString("Project view now listens object events in '%1' view").arg(ow->windowTitle()));
         markActiveView = ow->getObjectView();
         connect(markActiveView, SIGNAL(si_objectAdded(GObjectView*, GObject*)), SLOT(sl_objectAddedToActiveView(GObjectView*, GObject*)));
         connect(markActiveView, SIGNAL(si_objectRemoved(GObjectView*, GObject*)), SLOT(sl_objectRemovedFromActiveView(GObjectView*, GObject*)));
@@ -1145,9 +1179,8 @@ bool ProjViewObjectItem::operator< ( const QTreeWidgetItem & other ) const {
     }
 }
 
-void ProjViewObjectItem::updateVisual(bool recursive) {
-    Q_UNUSED(recursive);
-	QString text;
+void ProjViewObjectItem::updateVisual(bool ) {
+    QString text;
     GObjectType t = obj->getGObjectType();
     bool unloaded = t == GObjectTypes::UNLOADED;
     if (unloaded) {
@@ -1155,7 +1188,7 @@ void ProjViewObjectItem::updateVisual(bool recursive) {
         t = qobject_cast<UnloadedObject*>(obj)->getLoadedObjectType();
     }
     const GObjectTypeInfo& ti = GObjectTypes::getTypeInfo(t);
-    text+="["+ti.treeSign+"] ";
+    text+="[" + ti.treeSign + "] ";
     
     if (unloaded && obj->getDocument()->getObjects().size() < MAX_OBJS_TO_SHOW_LOAD_PROGRESS) {
         LoadUnloadedDocumentTask* t = LoadUnloadedDocumentTask::findActiveLoadingTask(obj->getDocument());
@@ -1207,17 +1240,6 @@ bool ProjViewObjectItem::isActive() const {
     return w->getObjectView()->containsObject(obj);
 }
 
-void ProjViewObjectItem::setData(int column, int role, const QVariant & value) {
-    QVariant newValue = value;
-    if(role == Qt::EditRole) {
-        if(value.toString().split(" ").first() != "[s]") {
-            QString prefix = "[s] ";
-            newValue = QVariant::fromValue(prefix + value.toString());
-        }
-    }
-    QTreeWidgetItem::setData(column, role, newValue);
-}
-
 ProjViewTypeItem::ProjViewTypeItem(const GObjectType& t, ProjectTreeController* c) 
 : ProjViewItem(c), otype(t)
 {
