@@ -542,7 +542,7 @@
     <name>ProjectTreeItemSelectorDialogBase</name>
     <message>
         <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="13"/>
-        <source>Select item</source>
+        <source>Select Item</source>
         <translation></translation>
     </message>
     <message>
@@ -552,7 +552,7 @@
     </message>
     <message>
         <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="43"/>
-        <source>Ok</source>
+        <source>OK</source>
         <translation></translation>
     </message>
     <message>
