@@ -112,7 +112,7 @@
     <message>
         <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="41"/>
         <source>Highlight</source>
-        <translation>Подсветка</translation>
+        <translation>Маркировка</translation>
     </message>
     <message>
         <location filename="../src/util_gui/ui/AnnotationSettingsDialog.ui" line="69"/>
@@ -562,7 +562,7 @@
     <name>ProjectTreeItemSelectorDialogBase</name>
     <message>
         <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="13"/>
-        <source>Select item</source>
+        <source>Select Item</source>
         <translation>Выбор элемента</translation>
     </message>
     <message>
@@ -572,7 +572,7 @@
     </message>
     <message>
         <location filename="../src/util_gui/ui/ProjectTreeItemSelectorDialogBase.ui" line="43"/>
-        <source>Ok</source>
+        <source>OK</source>
         <translation>Готово</translation>
     </message>
     <message>
@@ -1259,10 +1259,6 @@ Do you wish to create this directory?</source>
         <source>Open &apos;%1&apos;</source>
         <translation>Открытие окна &apos;%1&apos;</translation>
     </message>
-    <message>
-        <source>No sequence info found!</source>
-        <translation type="obsolete">Информация о последовательности не найдена!</translation>
-    </message>
 </context>
 <context>
     <name>U2::ObjectViewTreeController</name>
