@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "QDScheme.h"
 #include "QDConstraint.h"
@@ -27,7 +38,7 @@ void QDParameters::setParameter(const QString& name, const QVariant& val) {
 //////////////////////////////////////////////////////////////////////////
 const int QDActor::DEFAULT_MAX_RESULT_LENGTH(10000);
 
-QDActor::QDActor(QDActorPrototype const* _proto) : scheme(NULL), proto(_proto), direction(Any) {
+QDActor::QDActor(QDActorPrototype const* _proto) : scheme(NULL), proto(_proto), strand(QDStrand_Both), simmetric(false) {
     cfg = new QDActorParameters;
     foreach(Attribute* a, proto->getParameters()) {
         cfg->addParameter(a->getId(), new Attribute(*a));
@@ -59,8 +70,8 @@ void QDActor::reset() {
     }
 }
 
-bool contains(const QDResultUnit& res, const QList<LRegion>& location) {
-    foreach(const LRegion& r, location) {
+bool contains(const QDResultUnit& res, const QVector<U2Region>& location) {
+    foreach(const U2Region& r, location) {
         if (r.contains(res->region)) {
             return true;
         }
@@ -68,7 +79,7 @@ bool contains(const QDResultUnit& res, const QList<LRegion>& location) {
     return false;
 }
 
-void QDActor::filterResults(const QList<LRegion>& location) {
+void QDActor::filterResults(const QVector<U2Region>& ) {
     /*QList<QDResultGroup*> res = results;
     foreach(QDResultGroup* grp, res) {
         foreach(const QDResultUnit& ru, grp->getResultsList()) {
@@ -91,7 +102,11 @@ static const QString KEY_ATTR = "key";
 QList< QPair<QString,QString> > QDActor::saveConfiguration() const {
     QList< QPair<QString,QString> > res;
     QMapIterator<QString, Attribute*> it(cfg->getParameters());
-    res.append(qMakePair(KEY_ATTR, cfg->getAnnotationKey()));
+    QString annKey = cfg->getAnnotationKey();
+    if (annKey.contains(' ')) {
+        annKey = "\"" + annKey + "\"";
+    }
+    res.append(qMakePair(KEY_ATTR, annKey));
     while (it.hasNext()) {
         it.next();
         Attribute* a = it.value();
@@ -124,6 +139,46 @@ void QDActor::loadConfiguration(const QList< QPair<QString, QString> >& strMap)
     }
 }
 
+QDStrandOption QDActor::getStrandToRun() const {
+    QDStrandOption schemaStrand = scheme->getStrand();
+    QDStrandOption strand2run = QDStrand_Both;
+    if (schemaStrand!=QDStrand_Both) {
+        if (schemaStrand==QDStrand_DirectOnly) {
+            strand2run = strand;
+        }
+        if (schemaStrand==QDStrand_ComplementOnly) {
+            if (strand==QDStrand_DirectOnly) {
+                strand2run = QDStrand_ComplementOnly;
+            }
+            if (strand==QDStrand_ComplementOnly) {
+                strand2run = QDStrand_DirectOnly;
+            }
+        }
+    }
+    return strand2run;
+}
+
+QDStrandOption QDActor::getStrand() const {
+    if (hasStrand()) {
+        return strand;
+    }
+    //return QDStrand_DirectOnly;
+    return QDStrand_Both;
+}
+
+void QDActor::setStrand( QDStrandOption stOp ) {
+    strand = stOp;
+    emit si_strandChanged(strand);
+}
+
+QList<QDConstraint*> QDActor::getConstraints() const {
+    QList<QDConstraint*> res;
+    foreach(QDSchemeUnit* su, units) {
+        res << su->getConstraints();
+    }
+    return res;
+}
+
 //QDSchemeUnit
 //////////////////////////////////////////////////////////////////////////
 QString QDSchemeUnit::getPersonalName() const {
@@ -714,6 +769,7 @@ bool QDScheme::validateGroupName( const QString& name ) const {
 void QDScheme::setRequiredNum(const QString& group, int num) {
     assert(actorGroups.keys().contains(group));
     const QList<QDActor*>& grpMembrs = actorGroups.value(group);
+    Q_UNUSED(grpMembrs);
     assert(num<=grpMembrs.size());
     actorGroupReqNum[group] = num;
     emit si_schemeChanged();
@@ -757,6 +813,13 @@ void QDResultGroup::add(const QList<QDResultUnit>& res) {
     }
 }
 
+void QDResultGroup::buildGroupFromSingleResult(const QDResultUnit& ru, QList<QDResultGroup*>& results) {
+    QDStrandOption groupStrand = ru->strand == U2Strand::Direct ? QDStrand_DirectOnly : QDStrand_ComplementOnly;
+    QDResultGroup* g = new QDResultGroup(groupStrand);
+    g->add(ru);
+    results.append(g);
+}
+
 //AttributeValueMapper
 //////////////////////////////////////////////////////////////////////////
 
