@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QTextStream>
 
@@ -16,8 +27,11 @@
 #include <U2Lang/WorkflowEnv.h>
 #include <U2Lang/ActorPrototypeRegistry.h>
 #include <U2Lang/CoreLibConstants.h>
-#include <U2Lang/CoreDataTypes.h>
 #include <U2Lang/SchemaSerializer.h>
+#include <U2Lang/BaseTypes.h>
+#include <U2Lang/BaseAttributes.h>
+#include <U2Lang/WorkflowUtils.h>
+#include <U2Lang/ExternalToolCfg.h>
 
 #include "HRSchemaSerializer.h"
 
@@ -34,7 +48,8 @@ const QString HRSchemaSerializer::HEADER_LINE           = "#!UGENE_WORKFLOW";
 const QString HRSchemaSerializer::OLD_XML_HEADER        = "<!DOCTYPE GB2WORKFLOW>";
 const QString HRSchemaSerializer::BODY_START            = "workflow";
 const QString HRSchemaSerializer::META_START            = ".meta";
-const QString HRSchemaSerializer::ITERATION_START       = ".iteration";
+const QString HRSchemaSerializer::DOT_ITERATION_START   = ".iteration";
+const QString HRSchemaSerializer::ITERATION_START       = "iteration";
 const QString HRSchemaSerializer::DATAFLOW_SIGN         = "->";
 const QString HRSchemaSerializer::EQUALS_SIGN           = ":";
 const QString HRSchemaSerializer::UNDEFINED_CONSTRUCT   = HRSchemaSerializer::tr("Undefined construct at '%1 %2'");
@@ -46,12 +61,23 @@ const QString HRSchemaSerializer::DOT                   = ".";
 const QString HRSchemaSerializer::DASH                  = "-";
 const QString HRSchemaSerializer::ITERATION_ID          = "id";
 const QString HRSchemaSerializer::ALIASES_START         = "aliases";
+const QString HRSchemaSerializer::ALIASES_HELP_START    = "help";
 const QString HRSchemaSerializer::VISUAL_START          = "visual";
 const QString HRSchemaSerializer::UNDEFINED_META_BLOCK  = HRSchemaSerializer::tr("Undefined block in .meta: '%1'");
 const QString HRSchemaSerializer::TAB                   = "    ";
 const QString HRSchemaSerializer::NO_NAME               = "";
 const QString HRSchemaSerializer::COLON                 = ":";
 const QString HRSchemaSerializer::SEMICOLON             = ";";
+const QString HRSchemaSerializer::INPUT_START           = ".inputs";
+const QString HRSchemaSerializer::OUTPUT_START          = ".outputs";
+const QString HRSchemaSerializer::ATTRIBUTES_START      = ".attributes";
+const QString HRSchemaSerializer::TYPE_PORT             = "type";
+const QString HRSchemaSerializer::FORMAT_PORT           = "format";
+const QString HRSchemaSerializer::CMDLINE               = "cmdline";
+const QString HRSchemaSerializer::DESCRIPTION           = "description";
+const QString HRSchemaSerializer::PROMPTER              = "templatedescription";
+const QString HRSchemaSerializer::FUNCTION_START        = "@";
+const QString HRSchemaSerializer::ACTOR_BINDINGS        = ".actor-bindings";
 
 template <class T>
 static void setIfNotNull(const T & what, T * to) {
@@ -64,9 +90,9 @@ static Attribute* getAttribute(Actor * proc, const QString & attrId) {
     assert(proc != NULL);
     if( proc->hasParameter(attrId) ) {
         return proc->getParameter(attrId);
-    } else if( proc->hasParameter(CoreLibConstants::URL_IN_ATTR().getId()) && attrId == CoreLibConstants::URL_LOCATION_ATTR().getId() ) {
-        Attribute * attr = new Attribute(CoreLibConstants::URL_LOCATION_ATTR(), CoreDataTypes::BOOL_TYPE(), false, true);
-        proc->addParameter( CoreLibConstants::URL_LOCATION_ATTR().getId(), attr);
+    } else if( proc->hasParameter(BaseAttributes::URL_IN_ATTRIBUTE().getId()) && attrId == BaseAttributes::URL_LOCATION_ATTRIBUTE().getId() ) {
+        Attribute * attr = new Attribute(BaseAttributes::URL_LOCATION_ATTRIBUTE(), BaseTypes::BOOL_TYPE(), false, true);
+        proc->addParameter( BaseAttributes::URL_LOCATION_ATTRIBUTE().getId(), attr);
         return attr;
     }
     return NULL;
@@ -76,7 +102,7 @@ static QVariant getAttrValue(Actor * proc, const QString & attrId, const QString
     Attribute * attr = getAttribute(proc, attrId);
     if(attr == NULL) {
         throw HRSchemaSerializer::ReadFailed(HRSchemaSerializer::tr("Parameter '%1' undefined for element '%2'").
-            arg(attrId).arg(proc->getId()));
+            arg(attrId).arg(proc->getLabel()));
     }
     DataTypeValueFactory * valueFactory = WorkflowEnv::getDataTypeValueFactoryRegistry()->getById(attr->getAttributeType()->getId());
     if( valueFactory == NULL ) {
@@ -106,7 +132,9 @@ static QString quotedString(const QString & str) {
 static QString valueString(const QString & s) {
     QString str = s;
     str.replace("\"", "'");
-    if( str.contains(QRegExp("\\s") ) || str.contains(HRSchemaSerializer::SEMICOLON)) {
+    if( str.contains(QRegExp("\\s") ) || str.contains(HRSchemaSerializer::SEMICOLON) || 
+        str.contains(HRSchemaSerializer::EQUALS_SIGN) || str.contains(HRSchemaSerializer::DATAFLOW_SIGN) || 
+        str.contains(HRSchemaSerializer::BLOCK_START) || str.contains(HRSchemaSerializer::BLOCK_END)) {
         return quotedString(str);
     } else {
         return str;
@@ -127,8 +155,8 @@ QString HRSchemaSerializer::Tokenizer::look() const {
     return tokens.first();
 }
 
-void HRSchemaSerializer::Tokenizer::appendToken(const QString & t) {
-    if(t.isEmpty()) {
+void HRSchemaSerializer::Tokenizer::appendToken(const QString & t, bool skipEmpty) {
+    if(t.isEmpty() && skipEmpty) {
         return;
     }
     if(t == BLOCK_START) {
@@ -232,7 +260,8 @@ void HRSchemaSerializer::Tokenizer::tokenize(const QString & d) {
             continue;
         }
         if(depth == 1) {
-            isElemDef = !line.startsWith(META_START) && !line.startsWith(ITERATION_START) && !line.contains(DATAFLOW_SIGN);
+            isElemDef = !line.startsWith(META_START) && !line.startsWith(DOT_ITERATION_START) && !line.contains(DATAFLOW_SIGN) 
+                && !line.startsWith(INPUT_START) && !line.startsWith(OUTPUT_START) && !line.startsWith(ATTRIBUTES_START);
             elemDefHeader = true;
         } else {
             elemDefHeader = false;
@@ -279,7 +308,7 @@ void HRSchemaSerializer::Tokenizer::tokenizeBlock(const QString & line, QTextStr
         }
         if(ch == BLOCK_END.at(0)) {
             if(level-- == 0) {
-                appendToken(blockTok.trimmed());
+                appendToken(blockTok.trimmed(), false);
                 appendToken(BLOCK_END);
                 skipDelimiters(stream);
                 if(!stream.atEnd()) {
@@ -317,13 +346,23 @@ void HRSchemaSerializer::Tokenizer::tokenizeLine(const QString & l, QTextStream
             }
         } else if(ch == QUOTE.at(0)) {
             if( finishAtQuote ) {
-                addToken(curToken);
+                appendToken(curToken);
                 curToken.clear();
                 finishAtQuote = false;
             } else {
+                addToken(curToken);
+                curToken.clear();
                 finishAtQuote = true;
             }
             continue;
+        } else if (ch == FUNCTION_START.at(0)) {
+            if (finishAtQuote) {
+                curToken.append(ch);
+            } else {
+                addToken(curToken);
+                curToken.clear();
+                addToken(ch);
+            }
         } else {
             curToken.append(ch);
         }
@@ -446,7 +485,7 @@ void HRSchemaSerializer::parseHeader(Tokenizer & tokenizer, Metadata * meta) {
     }
     QString desc;
     while(tokenizer.look().startsWith(SERVICE_SYM)) {
-        desc += tokenizer.take().mid(SERVICE_SYM.size());
+        desc += tokenizer.take().mid(SERVICE_SYM.size()) + HRSchemaSerializer::NEW_LINE;
     }
     setIfNotNull<QString>(desc, meta == NULL ? NULL : &meta->comment);
 }
@@ -499,10 +538,7 @@ Actor* HRSchemaSerializer::parseElementsDefinition(Tokenizer & tokenizer, const
     proc->setLabel(procName);
     
     ActorId oldId = str2aid(pairs.equalPairs.take(ELEM_ID_ATTR));
-    if(idMap != NULL) {
-        if(oldId.isEmpty()) {
-            throw ReadFailed(tr("Internal error: element runtime id not set in copying schema for element %1").arg(actorName));
-        }
+    if(idMap != NULL && !oldId.isEmpty()) {
         idMap->insert(oldId, proc->getId());
     }
     
@@ -513,6 +549,7 @@ Actor* HRSchemaSerializer::parseElementsDefinition(Tokenizer & tokenizer, const
     foreach( const QString & key, pairs.equalPairs.keys() ) {
         proc->getParameter(key)->setAttributeValue(getAttrValue(proc, key, pairs.equalPairs.value(key)));
     }
+
     return proc;
 }
 
@@ -530,6 +567,10 @@ static QString parseAfter(const QString & dottedStr, int ind) {
     return res.mid(0, res.size() - HRSchemaSerializer::DOT.size());
 }
 
+void HRSchemaSerializer::backwardIncapability() {
+    throw ReadFailed(tr("It is a workflow file which is not supported in this version of UGENE. Please, try to install UGENE 1.10 or later"));
+}
+
 static void skipBlock(HRSchemaSerializer::Tokenizer & tokenizer) {
     while(tokenizer.look() != HRSchemaSerializer::BLOCK_END) {
         QString tok = tokenizer.take();
@@ -583,7 +624,7 @@ Iteration HRSchemaSerializer::parseIteration(Tokenizer & tokenizer, const QStrin
 void HRSchemaSerializer::parseAliases(Tokenizer & tokenizer, const QMap<QString, Actor*> & actorMap) {
     ParsedPairs pairs(tokenizer);
     if( !pairs.blockPairs.isEmpty() ) {
-        throw ReadFailed(tr("No other blocks allowed in .aliases block"));
+        throw ReadFailed(tr("No other blocks allowed in aliases block"));
     }
     
     foreach(const QString & key, pairs.equalPairs.keys()) {
@@ -600,6 +641,24 @@ void HRSchemaSerializer::parseAliases(Tokenizer & tokenizer, const QMap<QString,
     }
 }
 
+void HRSchemaSerializer::parseAliasesHelp(Tokenizer & tokenizer, const QList<Actor*> & procs) {
+    ParsedPairs pairs(tokenizer);
+    if(!pairs.blockPairs.isEmpty()) {
+        throw ReadFailed(tr("No other blocks allowed in help block"));
+    }
+    
+    foreach(const QString & key, pairs.equalPairs.keys()) {
+        QString paramName;
+        Actor * actor = WorkflowUtils::findActorByParamAlias(procs, key, paramName, false);
+        if(actor == NULL) {
+            throw ReadFailed(tr("Undefined parameter alias used in help block: '%1'").arg(key));
+        }
+        QString help = pairs.equalPairs.value(key);
+        assert(!help.isEmpty());
+        actor->getAliasHelp()[key] = help;
+    }
+}
+
 QPair<Port*, Port*> HRSchemaSerializer::parseDataflow(Tokenizer & tokenizer, const QString & srcTok, const QMap<QString, Actor*> & actorMap) {
     QString srcActorName = parseAt(srcTok, 0);
     QString srcSlotId = parseAfter(srcTok, 0);
@@ -700,6 +759,10 @@ static void parseMeta(WorkflowSchemaReaderData & data) {
             data.tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
             parseVisual(data);
             data.tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
+        } else if(tok == HRSchemaSerializer::ALIASES_HELP_START) {
+            data.tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
+            HRSchemaSerializer::parseAliasesHelp(data.tokenizer, data.actorMap.values());
+            data.tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
         } else {
             throw HRSchemaSerializer::ReadFailed(HRSchemaSerializer::UNDEFINED_META_BLOCK.arg(tok));
         }
@@ -715,11 +778,15 @@ static void parseBody(WorkflowSchemaReaderData & data) {
             tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
             parseMeta(data);
             tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
-        } else if(tok == HRSchemaSerializer::ITERATION_START) {
+        } else if(tok == HRSchemaSerializer::DOT_ITERATION_START) {
             QString itName = tokenizer.look() == HRSchemaSerializer::BLOCK_START ? "" : tokenizer.take();
             tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
             data.schema->getIterations() << HRSchemaSerializer::parseIteration(tokenizer, itName, data.actorMap);
             tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
+        } else if (tok == HRSchemaSerializer::ACTOR_BINDINGS) {
+            HRSchemaSerializer::backwardIncapability();
+        } else if (tok == HRSchemaSerializer::FUNCTION_START) {
+            HRSchemaSerializer::backwardIncapability();
         } else if(next == HRSchemaSerializer::DATAFLOW_SIGN) {
             data.dataflowLinks << HRSchemaSerializer::parseDataflow(tokenizer, tok, data.actorMap);
         } else if(next == HRSchemaSerializer::BLOCK_START) {
@@ -799,6 +866,85 @@ QString HRSchemaSerializer::string2Schema(const QString & bytes, Schema * schema
     return NO_ERROR;
 }
 
+void HRSchemaSerializer::parsePorts(Tokenizer & tokenizer, QList<DataConfig>& ports) {
+    while(tokenizer.look() != BLOCK_END) {
+        DataConfig cfg;
+        cfg.attrName = tokenizer.take();
+        tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
+        ParsedPairs pairs(tokenizer);
+        cfg.type = pairs.equalPairs.take(TYPE_PORT);
+        cfg.format = pairs.equalPairs.take(FORMAT_PORT);
+        cfg.description = pairs.equalPairs.take(DESCRIPTION);
+        tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
+        ports << cfg;
+    }
+}
+
+void HRSchemaSerializer::parseAttributes(Tokenizer & tokenizer, QList<AttributeConfig>& attrs) {
+    while(tokenizer.look() != BLOCK_END) {
+        AttributeConfig cfg;
+        cfg.attrName = tokenizer.take();
+        tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
+        ParsedPairs pairs(tokenizer);
+        cfg.type = pairs.equalPairs.take(TYPE_PORT);
+        cfg.description = pairs.equalPairs.take(DESCRIPTION);
+        tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
+        attrs << cfg;
+    }
+}
+
+ExternalProcessConfig*  HRSchemaSerializer::parseActorBody(Tokenizer & tokenizer) {
+    ExternalProcessConfig *cfg = new ExternalProcessConfig();
+    cfg->name = tokenizer.take();
+    while(tokenizer.notEmpty() && tokenizer.look() != HRSchemaSerializer::BLOCK_END) {
+        QString tok = tokenizer.take();
+        QString next = tokenizer.look();
+        if(tok == HRSchemaSerializer::INPUT_START) {
+            tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
+            HRSchemaSerializer::parsePorts(tokenizer, cfg->inputs);
+            tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
+        } else if(tok == HRSchemaSerializer::OUTPUT_START) {
+            tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
+            HRSchemaSerializer::parsePorts(tokenizer, cfg->outputs);
+            tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
+        } else if(tok == HRSchemaSerializer::ATTRIBUTES_START) {
+            tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
+            HRSchemaSerializer::parseAttributes(tokenizer, cfg->attrs);
+            tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
+        } else if(tok == HRSchemaSerializer::BLOCK_START) {
+            //tokenizer.take();
+            /*Actor * proc = HRSchemaSerializer::parseElementsDefinition(tokenizer, tok, data.actorMap, data.idMap);
+            data.schema->addProcess(proc);
+            tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);*/
+        } else if(tok == HRSchemaSerializer::CMDLINE) {
+            tokenizer.assertToken(COLON);
+            cfg->cmdLine = tokenizer.take();
+        } else if(tok == HRSchemaSerializer::DESCRIPTION)  {
+            tokenizer.assertToken(COLON);
+            cfg->description = tokenizer.take();
+        }else if(tok == HRSchemaSerializer::PROMPTER) {
+            tokenizer.assertToken(COLON);
+            cfg->templateDescription = tokenizer.take();
+        } else {
+            throw HRSchemaSerializer::ReadFailed(HRSchemaSerializer::UNDEFINED_CONSTRUCT.arg(tok).arg(next));
+        }
+    }
+    return cfg;
+}
+
+ExternalProcessConfig* HRSchemaSerializer::string2Actor(const QString & bytes) {
+    ExternalProcessConfig *cfg = NULL;
+    try {
+        WorkflowSchemaReaderData data(bytes, NULL, NULL, NULL);
+        parseHeader(data.tokenizer, data.meta);
+        cfg = parseActorBody(data.tokenizer);
+    } catch (...) {
+        return NULL;
+    }
+    return cfg;
+}
+
+
 void HRSchemaSerializer::addPart( QString & to, const QString & w) {
     QString what = w;
     if( !what.endsWith(NEW_LINE) ) {
@@ -861,7 +1007,7 @@ static QString elementsDefinitionBlock(Actor * actor, bool copyMode) {
         res += HRSchemaSerializer::makeEqualsPair(HRSchemaSerializer::ELEM_ID_ATTR, actor->getId());
     }
     AttributeScript * actorScript = actor->getScript();
-    if(actorScript != NULL) {
+    if(actorScript != NULL && !actorScript->getScriptText().trimmed().isEmpty()) {
         res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::SCRIPT_ATTR, HRSchemaSerializer::NO_NAME, 
             actorScript->getScriptText() + HRSchemaSerializer::NEW_LINE, 2, false, true);
     }
@@ -965,7 +1111,7 @@ QString HRSchemaSerializer::iterationsDefinition(const QList<Iteration> & iterat
     
     QString res;
     foreach( const Iteration & iteration, iterations ) {
-        res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::ITERATION_START, iteration.name, iterationData(iteration, nmap));
+        res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::DOT_ITERATION_START, iteration.name, iterationData(iteration, nmap));
     }
     return res;
 }
@@ -987,6 +1133,10 @@ static QString metaData(const Schema & schema, const HRSchemaSerializer::NamesMa
         res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::ALIASES_START, HRSchemaSerializer::NO_NAME, 
                                              HRSchemaSerializer::schemaAliases(schema.getProcesses(), nmap), 2);
     }
+    if(schema.hasAliasHelp()) {
+        res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::ALIASES_HELP_START, HRSchemaSerializer::NO_NAME, 
+                                             HRSchemaSerializer::aliasesHelp(schema.getProcesses()), 2);
+    }
     res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::VISUAL_START, HRSchemaSerializer::NO_NAME, visualData(schema, nmap), 2);
     return res;
 }
@@ -1002,6 +1152,18 @@ QString HRSchemaSerializer::schemaAliases(const QList<Actor*> & procs, const Nam
     return res;
 }
 
+QString HRSchemaSerializer::aliasesHelp(const QList<Actor*> & procs) {
+    QString res;
+    foreach(Actor * a, procs) {
+        const QMap<QString, QString> & aliasesHelp = a->getAliasHelp();
+        foreach(const QString & alias, aliasesHelp.keys()) {
+            assert(a->getParamAliases().values().contains(alias));
+            res += HRSchemaSerializer::makeEqualsPair(alias, aliasesHelp.value(alias), 3);
+        }
+    }
+    return res;
+}
+
 static QString generateElementName(Actor * proc, const QList<QString>& existing) {
     QString candidate = proc->getProto()->getId().replace(HRSchemaSerializer::DOT, HRSchemaSerializer::DASH).
                                                   replace(QRegExp("\\s+"), HRSchemaSerializer::DASH);
@@ -1035,7 +1197,7 @@ static QString bodyItself(const Schema & schema, bool copyMode) {
     return res;
 }
 
-QString HRSchemaSerializer::schema2String(const Schema & schema, Metadata * meta, bool copyMode) {
+QString HRSchemaSerializer::schema2String(const Schema & schema, const Metadata * meta, bool copyMode) {
     QString res;
     addPart(res, header2String(meta));
     addPart(res, makeBlock(BODY_START, meta ? meta->name : "", bodyItself(schema, copyMode), 0, true));
@@ -1056,4 +1218,66 @@ QMap<ActorId, ActorId> HRSchemaSerializer::deepCopy(const Schema& from, Schema*
     return idMap;
 }
 
-} // U2
+static QString inputsDefenition(const QList<DataConfig> &inputs) {
+    QString res = HRSchemaSerializer::TAB + HRSchemaSerializer::INPUT_START + " {\n";
+    foreach(const DataConfig cfg, inputs) {
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + cfg.attrName + " {\n";
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "type:" + cfg.type + ";\n";
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "format:" + cfg.format + ";\n";
+        if(!cfg.description.isEmpty()) {
+            res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "description:\"" + cfg.description + "\";\n";
+        }
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "}\n";
+    }
+    res += HRSchemaSerializer::TAB + "}\n";
+    return res;
+}
+
+static QString outputsDefenition(const QList<DataConfig> &inputs) {
+    QString res = HRSchemaSerializer::TAB + HRSchemaSerializer::OUTPUT_START + " {\n";
+    foreach(const DataConfig cfg, inputs) {
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + cfg.attrName + " {\n";
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "type:" + cfg.type + ";\n";
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "format:" + cfg.format + ";\n";
+        if(!cfg.description.isEmpty()) {
+            res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "description:\"" + cfg.description + "\";\n";
+        }
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "}\n";
+    }
+    res += HRSchemaSerializer::TAB + "}\n";
+    return res;
+}
+
+static QString attributesDefinition(const QList<AttributeConfig> &attrs) {
+    QString res = HRSchemaSerializer::TAB + HRSchemaSerializer::ATTRIBUTES_START + " {\n";
+    foreach(const AttributeConfig &cfg, attrs) {
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + cfg.attrName + " {\n";
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "type:" + cfg.type + ";\n";
+        if(!cfg.description.isEmpty()) {
+            res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "description:\"" + cfg.description + "\";\n";
+        }
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::TAB + "}\n";
+    }
+    res += HRSchemaSerializer::TAB + "}\n";
+    return res;
+}
+
+QString HRSchemaSerializer::actor2String(ExternalProcessConfig *cfg ) {
+    QString res = HRSchemaSerializer::HEADER_LINE + "\n";
+    res += "\"" + cfg->name + "\" {\n";
+    res += inputsDefenition(cfg->inputs);
+    res += outputsDefenition(cfg->outputs);
+    res += attributesDefinition(cfg->attrs);
+    res += HRSchemaSerializer::TAB + HRSchemaSerializer::CMDLINE + ":\"" + cfg->cmdLine + "\";\n";
+    if(!cfg->description.isEmpty()) {
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::DESCRIPTION + ":\"" + cfg->description + "\";\n";
+    }
+    if(!cfg->templateDescription.isEmpty()) {
+        res += HRSchemaSerializer::TAB + HRSchemaSerializer::PROMPTER + ":\"" + cfg->templateDescription + "\";\n";
+    }
+    res += "}";
+    return res;
+}
+
+
+} // U2
\ No newline at end of file
