@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtXml/qdom.h>
 
@@ -25,10 +36,7 @@
 namespace U2 {
 namespace Workflow {
 
-const QMap<QString, QString> SchemaSerializer::ATTRIBUTE_ID_MAP = SchemaSerializer::initAttributesMap();
 const QMap<QString, QString> SchemaSerializer::ELEM_TYPES_MAP = SchemaSerializer::initElemTypesMap();
-const QMap<QString, QMap<QString, QString> > SchemaSerializer::ELEM_PORT_ID_MAP = SchemaSerializer::initElemPortIdMap();
-const QMap<QString, QMap<QString, QString> > SchemaSerializer::PORT_SLOT_ID_MAP = SchemaSerializer::initPortSlotIdMap();
 
 const QString SchemaSerializer::WORKFLOW_DOC = "GB2WORKFLOW";
 
@@ -70,73 +78,6 @@ static void saveParamAliases(const QMap<QString, QString> & aliases, QDomElement
     owner.appendChild( el );
 }
 
-QMap<QString, QString> SchemaSerializer::initAttributesMap() {
-    QMap<QString, QString> map;
-    map["URL_IN"] = "url-in";
-    map["URL_OUT"] = "url-out";
-    return map;
-}
-
-//QMap<QString, QString> SchemaSerializer::initSlotMap() {
-//    QMap<QString, QString> map;
-//    map["URL_SLOT"] = CoreLibConstants::URL_SLOT_ID;
-//    return map;
-//}
-
-QMap<QString, QMap<QString, QString> > SchemaSerializer::initPortSlotIdMap() {
-    QMap<QString, QMap<QString, QString> > map;
-    map[QString("read-msa")+QString("out-msa")].insert("url_slot", "url");
-    map[QString("read-msa")+QString("out-msa")].insert("malignment", "msa");
-    map[QString("fetch-sequence")+QString("out-sequence")].insert("seq", "sequence");
-    map[QString("fetch-sequence")+QString("out-sequence")].insert("ann_table", "annotations");
-    map[QString("read-sequence")+QString("out-sequence")].insert("url_slot", "url");
-    map[QString("read-sequence")+QString("out-sequence")].insert("seq", "sequence");
-    map[QString("read-sequence")+QString("out-sequence")].insert("ann_table", "annotations");
-    map[QString("read-text")+QString("out-text")].insert("url_slot", "url");
-    map[QString("read-text")+QString("out-text")].insert("string", "text");
-    map[QString("write-msa")+QString("in-msa")].insert("url_slot", "url");
-    map[QString("write-msa")+QString("in-msa")].insert("malignment", "msa");
-    map[QString("write-clustalw")+QString("in-msa")].insert("url_slot", "url");
-    map[QString("write-clustalw")+QString("in-msa")].insert("malignment", "msa");
-    map[QString("write-fasta")+QString("in-sequence")].insert("url_slot", "url");
-    map[QString("write-fasta")+QString("in-sequence")].insert("seq", "sequence");
-    map[QString("write-fasta")+QString("in-sequence")].insert("fasta.header", "fasta-header");
-    map[QString("write-fastq")+QString("in-sequence")].insert("url_slot", "url");
-    map[QString("write-fastq")+QString("in-sequence")].insert("seq", "sequence");
-    map[QString("write-genbank")+QString("in-sequence")].insert("url_slot", "url");
-    map[QString("write-genbank")+QString("in-sequence")].insert("seq", "sequence");
-    map[QString("write-genbank")+QString("in-sequence")].insert("ann_table", "annotations");
-    map[QString("write-text")+QString("in-text")].insert("url_slot", "url");
-    map[QString("write-text")+QString("in-text")].insert("string", "text");
-    map[QString("write-sequence")+QString("in-sequence")].insert("url_slot", "url");
-    map[QString("write-sequence")+QString("in-sequence")].insert("seq", "sequence");
-    map[QString("write-sequence")+QString("in-sequence")].insert("ann_table", "annotations");
-    map[QString("write-stockholm")+QString("in-msa")].insert("url_slot", "url");
-    map[QString("write-stockholm")+QString("in-msa")].insert("malignment", "msa");
-    map[QString("collocated-annotation-search")+QString("in-sequence")].insert("seq", "sequence");
-    map[QString("collocated-annotation-search")+QString("in-sequence")].insert("ann_table", "annotations");
-    map[QString("collocated-annotation-search")+QString("out-annotations")].insert("ann_table", "annotations");
-    map[QString("extract-annotated-sequence")+QString("in-sequence")].insert("ann_table", "annotations");
-    map[QString("extract-annotated-sequence")+QString("in-sequence")].insert("seq", "sequence");
-    map[QString("extract-annotated-sequence")+QString("out-sequence")].insert("ann_table", "annotations");
-    map[QString("extract-annotated-sequence")+QString("out-sequence")].insert("seq", "sequence");
-    map[QString("repeats-search")+QString("in-sequence")].insert("seq", "sequence");
-    map[QString("repeats-search")+QString("out-annotations")].insert("ann_table", "annotations");
-    return map;
-}
-
-QString SchemaSerializer::getElemPortSlot(const QString& elemId, const QString portId, const QString& slot) {
-    QString key = elemId + portId;
-    if(!PORT_SLOT_ID_MAP.contains(key)) {
-        return slot;
-    }
-    QMap<QString, QString> map = PORT_SLOT_ID_MAP.value(key);
-    if(map.contains(slot)) {
-        return map.value(slot);
-    }
-    return slot;
-}
-
 QMap<QString, QString> SchemaSerializer::initElemTypesMap() {
     QMap<QString, QString> map;
     map["read.malignment"] = "read-msa";
@@ -195,96 +136,6 @@ QString SchemaSerializer::getElemType(const QString & t) {
     return t;
 }
 
-QMap<QString, QMap<QString, QString> > SchemaSerializer::initElemPortIdMap() {
-    QMap<QString, QMap<QString, QString> > map;
-    map["read-msa"].insert("data", "out-msa");
-    map["read-sequence"].insert("data", "out-sequence");
-    map["fetch-sequence"].insert("out", "out-sequence");
-    map["read-text"].insert("string", "out-text");
-    map["write-msa"].insert("data", "in-msa");
-    map["write-clustalw"].insert("data", "in-msa");
-    map["write-fasta"].insert("data", "in-sequence");
-    map["write-fastq"].insert("data", "in-sequence");
-    map["write-genbank"].insert("data", "in-sequence");
-    map["write-text"].insert("data", "in-text");
-    map["write-sequence"].insert("data", "in-sequence");
-    map["write-stockholm"].insert("data", "in-msa");
-    map["collocated-annotation-search"].insert("in", "in-sequence");
-    map["collocated-annotation-search"].insert("out", "out-annotations");
-    map["extract-annotated-sequence"].insert("in", "in-sequence");
-    map["extract-annotated-sequence"].insert("out", "out-sequence");
-    map["repeats-search"].insert("in", "in-sequence");
-    map["repeats-search"].insert("out", "out-annotations");
-    map["search"].insert("in", "in-sequence");
-    map["search"].insert("out", "out-annotations");
-    map["import-phred-qualities"].insert("in", "in-sequence");
-    map["import-phred-qualities"].insert("out", "out-sequence");
-    map["blast"].insert("in", "in-sequence");
-    map["blast"].insert("out", "out-annotations");
-    map["blast-plus"].insert("in", "in-sequence");
-    map["blast-plus"].insert("out", "out-annotations");
-    map["orf-search"].insert("in", "in-sequence");
-    map["orf-search"].insert("out", "out-annotations");
-    map["blast-ncbi"].insert("in", "in-sequence");
-    map["blast-ncbi"].insert("out", "out-annotations");
-    map["ssearch"].insert("in", "in-sequence");
-    map["ssearch"].insert("out", "out-annotations");
-    map["bowtie"].insert("out", "out-msa");
-    map["bowtie"].insert("reads", "in-sequence");
-    map["bowtie"].insert("ebwt", "in-ebwt");
-    map["bowtie-build-index"].insert("out", "out-ebwt");
-    map["bowtie-read-index"].insert("out", "out-ebwt");
-    map["hmm2-build"].insert("in", "in-msa");
-    map["hmm2-build"].insert("out", "out-hmm2");
-    map["hmm2-search"].insert("hmm", "in-hmm2");
-    map["hmm2-search"].insert("seq", "in-sequence");
-    map["hmm2-search"].insert("out", "out-annotations");
-    map["hmm2-read-profile"].insert("out", "out-hmm2");
-    map["hmm2-write-profile"].insert("in", "in-hmm2");
-    map["clustalw"].insert("in", "in-msa");
-    map["clustalw"].insert("out", "out-msa");
-    map["kalign"].insert("in", "in-msa");
-    map["kalign"].insert("out", "out-msa");
-    map["mafft"].insert("in", "in-msa");
-    map["mafft"].insert("out", "out-msa");
-    map["muscle"].insert("in", "in-msa");
-    map["muscle"].insert("out", "out-msa");
-    map["tcoffee"].insert("in", "in-msa");
-    map["tcoffee"].insert("out", "out-msa");
-    map["fmatrix-build"].insert("in", "in-msa");
-    map["fmatrix-build"].insert("out", "out-fmatrix"); 
-    map["sitecon-build"].insert("in", "in-msa");
-    map["sitecon-build"].insert("out", "out-sitecon");
-    map["wmatrix-build"].insert("in", "in-msa");
-    map["wmatrix-build"].insert("out", "out-wmatrix"); 
-    map["fmatrix-to-wmatrix"].insert("in", "in-fmatrix");
-    map["fmatrix-to-wmatrix"].insert("out", "out-wmatrix");
-    map["fmatrix-read"].insert("out", "out-fmatrix");
-    map["sitecon-read"].insert("out", "out-sitecon");
-    map["wmatrix-read"].insert("out", "out-wmatrix");    
-    map["sitecon-search"].insert("out", "out-annotations");
-    map["sitecon-search"].insert("seq", "in-sequence");
-    map["sitecon-search"].insert("model", "in-sitecon");
-    map["wmatrix-search"].insert("out", "out-annotations");
-    map["wmatrix-search"].insert("seq", "in-sequence");
-    map["wmatrix-search"].insert("model", "in-wmatrix");
-    map["fmatrix-write"].insert("in", "in-fmatrix");
-    map["sitecon-write"].insert("in", "in-sitecon");
-    map["wmatrix-write"].insert("in", "in-wmatrix");
-    return map;
-}
-
-QString SchemaSerializer::getElemPort(const QString & elemId, const QString & portId) {
-    if(!ELEM_PORT_ID_MAP.contains(elemId)){
-        return portId;
-    }
-    QMap<QString, QString> map = ELEM_PORT_ID_MAP.value(elemId);
-    if(map.contains(portId)) {
-        return map.value(portId);
-    }
-    return portId;
-}
-
 QDomElement SchemaSerializer::saveActor(const Actor* proc, QDomElement& proj) {
     QDomElement docElement = proj.ownerDocument().createElement(PROCESS_EL);
     
@@ -300,21 +151,21 @@ QDomElement SchemaSerializer::saveActor(const Actor* proc, QDomElement& proj) {
     return docElement;
 }
 
-static Actor* readActor(const QDomElement& procElement) {
-    const QString name = procElement.attribute(TYPE_ATTR);
-    ActorPrototype* proto = WorkflowEnv::getProtoRegistry()->getProto(name);
-    if (!proto) {
-        return NULL;
-    }
+//static Actor* readActor(const QDomElement& procElement) {
+//    const QString name = procElement.attribute(TYPE_ATTR);
+//    ActorPrototype* proto = WorkflowEnv::getProtoRegistry()->getProto(name);
+//    if (!proto) {
+//        return NULL;
+//    }
 
-    Actor* proc = proto->createInstance();
-    if (proc) {
-        SchemaSerializer::readConfiguration(proc, procElement);
-        proc->setLabel(procElement.attribute(NAME_ATTR));
-        SchemaSerializer::readParamAliases( proc->getParamAliases(), procElement );
-    }
-    return proc;
-}
+//    Actor* proc = proto->createInstance();
+//    if (proc) {
+//        SchemaSerializer::readConfiguration(proc, procElement);
+//        proc->setLabel(procElement.attribute(NAME_ATTR));
+//        SchemaSerializer::readParamAliases( proc->getParamAliases(), procElement );
+//    }
+//    return proc;
+//}
 
 QDomElement SchemaSerializer::saveLink(const Link* link, QDomElement& proj) {
     QDomElement docElement = proj.ownerDocument().createElement(DATAFLOW_EL);
@@ -374,14 +225,6 @@ void SchemaSerializer::readIterations(QList<Iteration>& lst, const QDomElement&
         QVariant var = QVariantUtils::String2Var(el.text());
         if (qVariantCanConvert<CfgMap>(var)) {
             it.cfg = var.value<CfgMap>();
-            foreach(const QString & oldAttrId, ATTRIBUTE_ID_MAP.keys()) {
-                foreach(const ActorId& actorId, it.cfg.keys()) {
-                    if(it.cfg[actorId].contains(oldAttrId)) {
-                        it.cfg[actorId][ATTRIBUTE_ID_MAP.value(oldAttrId)] = it.cfg[actorId][oldAttrId];
-                        it.cfg[actorId].remove(oldAttrId);
-                    }
-                }
-            }
         }
         if (qVariantCanConvert<IterationCfg>(var)) {
             IterationCfg tmp = var.value<IterationCfg>();
@@ -405,22 +248,7 @@ void SchemaSerializer::readConfiguration(Configuration* cfg, const QDomElement&
         while (it.hasNext()) {
             it.next();
             QVariant val = it.value();
-            QString keyStr = ATTRIBUTE_ID_MAP.contains(it.key()) ? ATTRIBUTE_ID_MAP.value(it.key()) : it.key();
-            if(keyStr == IntegralBusPort::BUS_MAP_ATTR_ID) {
-                /*Port * p = dynamic_cast<Port*>(cfg);
-                assert(p != NULL);
-                QString elemId = p->owner()->getProto()->getId();
-                QString portId = p->getId();
-                QStrStrMap busMap = it.value().value<QStrStrMap>();
-                foreach(const QString & s, busMap.keys()) {
-                    QString slot = getElemPortSlot(elemId, portId, s);
-                    if(slot != s) {
-                        busMap[slot] = busMap.value(s);
-                        busMap.remove(s);
-                    }
-                }
-                val = qVariantFromValue<QStrStrMap>(busMap);*/
-            }
+            QString keyStr = it.key();
             if(cfg->hasParameter(keyStr)) {
                 cfg->getParameter(keyStr)->fromVariant(val);
             }
@@ -445,12 +273,12 @@ void SchemaSerializer::readParamAliases( QMap<QString, QString> & aliases, const
 
 static const QString META_EL = "info";
 
-static void saveMeta(const Workflow::Metadata* meta, QDomElement& proj){
-    QDomElement el = proj.ownerDocument().createElement(META_EL);
-    proj.appendChild(el);
-    el.setAttribute(NAME_ATTR, meta->name);
-    el.appendChild(proj.ownerDocument().createCDATASection(meta->comment));
-}
+//static void saveMeta(const Workflow::Metadata* meta, QDomElement& proj){
+//    QDomElement el = proj.ownerDocument().createElement(META_EL);
+//    proj.appendChild(el);
+//    el.setAttribute(NAME_ATTR, meta->name);
+//    el.appendChild(proj.ownerDocument().createCDATASection(meta->comment));
+//}
 
 QString SchemaSerializer::readMeta(Workflow::Metadata* meta, const QDomElement& proj) {
     QDomElement el = proj.elementsByTagName(META_EL).item(0).toElement();
@@ -553,7 +381,7 @@ QString SchemaSerializer::xml2schema(const QDomElement& projectElement, Schema*
         for(int j=0; j<nl.size(); j++) {
             QDomElement el = nl.item(j).toElement();
             if (el.isNull()) continue;
-            QString eid = getElemPort(name, el.attribute(ID_ATTR));
+            QString eid = el.attribute(ID_ATTR);
             Port* p = proc->getPort(eid);
             if (!p) {
                 if (stopIfError) {
