@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "TaskSchedulerImpl.h"
 
@@ -14,6 +25,8 @@
 #include <U2Core/AppResources.h>
 #include <U2Core/Timer.h>
 #include <U2Core/AppContext.h>
+#include <U2Core/U2SafePoints.h>
+#include <U2Core/L10n.h>
 
 #include <QtCore/QCoreApplication>
 
@@ -35,6 +48,11 @@ TaskSchedulerImpl::TaskSchedulerImpl(AppResourcePool* rp) {
 
     schedulerLog = new LogCache();
     schedulerLog->filter.filters.append(LogFilterItem(ULOG_CAT_TASKS, LogLevel_TRACE));
+    schedulerLog->filter.filters.append(LogFilterItem(ULOG_CAT_CORE_SERVICES, LogLevel_TRACE));
+    schedulerLog->filter.filters.append(LogFilterItem(ULOG_CAT_IO, LogLevel_TRACE));
+    schedulerLog->filter.filters.append(LogFilterItem(ULOG_CAT_USER_INTERFACE, LogLevel_ERROR));
+    schedulerLog->filter.filters.append(LogFilterItem(ULOG_CAT_ALGORITHM, LogLevel_TRACE));
+    schedulerLog->filter.filters.append(LogFilterItem(ULOG_CAT_CONSOLE, LogLevel_ERROR));
 }
 
 TaskSchedulerImpl::~TaskSchedulerImpl() {
@@ -65,14 +83,14 @@ void TaskSchedulerImpl::propagateStateToParent(Task* task) {
     if (parentTask == NULL) {
         return;
     }
-    if (parentTask->hasErrors() || parentTask->isCanceled()) {
+    if (parentTask->hasError() || parentTask->isCanceled()) {
         return;
     }
     if (task->isCanceled() && parentTask->getFlags().testFlag(TaskFlag_FailOnSubtaskCancel)) {
         TaskStateInfo& tsi = getTaskStateInfo(parentTask);
-        tsi.setError( tr("Subtask {%1} is canceled").arg(task->getTaskName()) );
+        tsi.setError( tr("Subtask {%1} is canceled %2").arg(task->getTaskName()).arg(task->getError()) );
         cancelTask(parentTask);
-    } else if (task->hasErrors() && parentTask->getFlags().testFlag(TaskFlag_FailOnSubtaskError)) {
+    } else if (task->hasError() && parentTask->getFlags().testFlag(TaskFlag_FailOnSubtaskError)) {
         TaskStateInfo& tsi = getTaskStateInfo(parentTask);
         if (parentTask->getFlags().testFlag(TaskFlag_MinimizeSubtaskErrorText)) {
             tsi.setError(task->getError());
@@ -90,10 +108,13 @@ bool TaskSchedulerImpl::processFinishedTasks() {
         Task::State state = ti->task->getState();
         assert(state != Task::State_Finished);
 
-        if (ti->task->getTimeOut()!=0){
+        if (ti->task->getTimeOut() > 0){
             int secsPassed = GTimer::secsBetween(ti->task->getTimeInfo().startTime, GTimer::currentTimeMicros());
-            if(ti->task->getTimeOut()<=secsPassed){
-                ti->task->setError( tr("TimeOut Error. TimeOut = %1 sec.").arg(ti->task->getTimeOut()));
+            if(ti->task->getTimeOut() < secsPassed){
+                QString msg = QString("Timeout error, running %1 sec expected %2 sec.").arg(secsPassed).arg(ti->task->getTimeOut());
+                taskLog.error(QString("Task {%1} %2 Cancelling task...").arg(ti->task->getTaskName()).arg(msg));
+
+                ti->task->setError(msg);
                 ti->task->cancel();
             }
 
@@ -138,6 +159,8 @@ bool TaskSchedulerImpl::processFinishedTasks() {
         // notify parent that subtask finished, check if there are new subtasks from parent
         if (pti != NULL) {
             Task* parentTask = pti->task;
+            SAFE_POINT(parentTask != NULL, "When notifying parentTask about finished task: parentTask is NULL", hasFinished);
+            SAFE_POINT(task != NULL, "When notifying parentTask about finished task: task is NULL", hasFinished);
             propagateStateToParent(task);
             QList<Task*> newSubTasks = onSubTaskFinished(parentTask, task);
             if (!newSubTasks.isEmpty() || !pti->newSubtasks.isEmpty()) {
@@ -146,8 +169,12 @@ bool TaskSchedulerImpl::processFinishedTasks() {
                 }
             }
             foreach(Task* newSub, newSubTasks) {
-                pti->newSubtasks.append(newSub);
-                addSubTask(parentTask, newSub);
+                if(newSub != NULL) {
+                    pti->newSubtasks.append(newSub);
+                    addSubTask(parentTask, newSub);
+                } else {
+                    taskLog.error(QString("Calling onSubTaskFinished from task {%1} with subtask {%2} returned list containing NULL, skipping").arg(parentTask->getTaskName()).arg(task->getTaskName()));
+                }
             }
         }
     }
@@ -169,12 +196,11 @@ void TaskSchedulerImpl::unregisterFinishedTopLevelTasks() {
 void TaskSchedulerImpl::processNewSubtasks() {
     for (int i=0, n = tasksWithNewSubtasks.size();i<n; i++) {
         TaskInfo* ti = tasksWithNewSubtasks[i];
-        TaskFlags flags =  ti->task->getFlags();
         assert(ti->newSubtasks.size() > 0);
 
         int nParallel = ti->task->getNumParallelSubtasks();
         int nNew = ti->newSubtasks.size();
-        int nToRun = qMin(nParallel, nNew) - ti->numActiveSubtasks();
+        int nToRun = qMin(nParallel - ti->numActiveSubtasks(), nNew);
         int nRun = 0;
         for (int j=0; j < nToRun; j++) {
             Task* newSub = ti->newSubtasks[j];
@@ -201,7 +227,7 @@ void TaskSchedulerImpl::runReady() {
         Task::State state = task->getState();
         //Note: task is running if any of its subtasks is running
         assert(state == Task::State_Prepared || state == Task::State_Running);
-        if (task->getFlags().testFlag(TaskFlag_NoRun) || task->isCanceled() || task->hasErrors()) {
+        if (task->getFlags().testFlag(TaskFlag_NoRun) || task->isCanceled() || task->hasError()) {
             if (state == Task::State_Prepared) {
                 promoteTask(ti, Task::State_Running);
             }
@@ -238,7 +264,7 @@ void TaskSchedulerImpl::runThread(TaskInfo* ti) {
     assert(!ti->task->getFlags().testFlag(TaskFlag_NoRun));
     assert(ti->task->hasFlags(TaskFlag_RunBeforeSubtasksFinished) || ti->numFinishedSubtasks == ti->task->getSubtasks().size());
     assert(!ti->task->isCanceled());
-    assert(!ti->task->hasErrors());
+    assert(!ti->task->hasError());
     assert(!ti->selfRunFinished);
 #endif
     ti->thread = new TaskThread(ti);
@@ -249,9 +275,9 @@ void TaskSchedulerImpl::runThread(TaskInfo* ti) {
 
 QString TaskSchedulerImpl::tryLockResources(Task* task, bool prepareStage, bool& hasLockedResourcesAfterCall) {
     if (prepareStage) { //task must be New
-        assert(task->getState() == Task::State_New);
+        SAFE_POINT(task->getState() == Task::State_New, "Attempt to lock prepare-stage resources for non-NEW task!", L10N::internalError());
     } else { //task must be Prepared or Running. Task can be 'Running' if it has subtasks
-        assert(task->getState() == Task::State_Running || task->getState() == Task::State_Prepared);
+        SAFE_POINT(task->getState() == Task::State_Running || task->getState() == Task::State_Prepared, QString("Attempt to lock run-stage for task in state: %1!").arg(task->getState()), L10N::internalError());
     }
     if (!prepareStage && !threadsResource->isAvailable()) {
         return tr("Waiting for resource '%1', count: %2").arg(threadsResource->name).arg(1);
@@ -296,7 +322,7 @@ QString TaskSchedulerImpl::tryLockResources(Task* task, bool prepareStage, bool&
 }
 
 void TaskSchedulerImpl::releaseResources(TaskInfo* ti, bool prepareStage) {
-    assert(ti->task->getState() == (prepareStage ? Task::State_Finished : Task::State_Running));
+    SAFE_POINT(ti->task->getState() == (prepareStage ? Task::State_Finished : Task::State_Running), "Releasing task resources in illegal state!",);
     if (!(prepareStage ? ti->hasLockedPrepareResources : ti->hasLockedRunResources)) {
         return;
     }
@@ -361,9 +387,11 @@ void TaskSchedulerImpl::prepareNewTasks() {
     QList<Task*> newCopy = newTasks;
     newTasks.clear();
     foreach(Task* task, newCopy) {
-        if (task->hasErrors() || task->isCanceled()) {//check if its canceled or has errors
+        if (task->hasError() || task->isCanceled()) {//check if its canceled or has errors
             propagateStateToParent(task);
             //forget about this task
+            TaskInfo ti(task, 0);
+            promoteTask(&ti, Task::State_Finished);
             if (task->isTopLevelTask()) {
                 unregisterTopLevelTask(task);
             }
@@ -377,6 +405,7 @@ void TaskSchedulerImpl::prepareNewTasks() {
 }
 
 void TaskSchedulerImpl::registerTopLevelTask(Task* task) {
+    SAFE_POINT(task, QString("Trying to register NULL task"),);
 
 #ifdef _DEBUG
     QThread* appThread = QCoreApplication::instance()->thread();
@@ -386,28 +415,28 @@ void TaskSchedulerImpl::registerTopLevelTask(Task* task) {
     assert(taskThread == thisThread);
 #endif
 
-    assert(task->getState() == Task::State_New);
-
+    SAFE_POINT(task->getState() == Task::State_New, QString("Trying to register task in not NEW state. State: %1").arg(task->getState()),);
+    SAFE_POINT(!topLevelTasks.contains(task), QString("Task is already registered: %1").arg(task->getTaskName()),);    
+    
     taskLog.details(tr("Registering new task: %1").arg(task->getTaskName()));
-    assert(!topLevelTasks.contains(task));
     topLevelTasks.append(task);
     emit si_topLevelTaskRegistered(task);
     newTasks.append(task);
 }
 
 bool TaskSchedulerImpl::addToPriorityQueue(Task* task, TaskInfo* pti) {
-    if (pti!=NULL && (pti->task->isCanceled() || pti->task->hasErrors())) { //canceled tasks are not processed
+    if (pti!=NULL && (pti->task->isCanceled() || pti->task->hasError())) { //canceled tasks are not processed
         task->cancel();
     }
 
     //check if there are enough resources;
-    bool runPrepare = !task->isCanceled() && !task->hasErrors();
+    bool runPrepare = !task->isCanceled() && !task->hasError();
     bool lr = false;
     if (runPrepare) {
         QString noResMessage = tryLockResources(task, true, lr);
         if (!noResMessage.isEmpty()) {
             setTaskStateDesc(task, noResMessage);
-            if (!task->hasErrors()) {
+            if (!task->hasError()) {
                 return false; //call again
             } else {
                 runPrepare = false; // resource lock error
@@ -419,7 +448,9 @@ bool TaskSchedulerImpl::addToPriorityQueue(Task* task, TaskInfo* pti) {
     ti->hasLockedPrepareResources = lr;
     priorityQueue.append(ti);
     if (runPrepare) {
+        setTaskInsidePrepare(task, true);
         task->prepare();
+        setTaskInsidePrepare(task, false);
         ti->wasPrepared = true;
     }
     promoteTask(ti, Task::State_Prepared);
@@ -429,7 +460,7 @@ bool TaskSchedulerImpl::addToPriorityQueue(Task* task, TaskInfo* pti) {
     for (int i = 0, n = subtasks.size(); i < n; i++) {
         Task* sub = subtasks[i];
         bool ok = i < nParallel && addToPriorityQueue(sub, ti);
-        if (!ok && !sub->hasErrors()) { //if task got err on resource allocation -> its not new now, but failed
+        if (!ok && !sub->hasError()) { //if task got err on resource allocation -> its not new now, but failed
             ti->newSubtasks.append(sub);
             if( !tasksWithNewSubtasks.contains(ti) ){
                 tasksWithNewSubtasks.append(ti);
@@ -440,8 +471,10 @@ bool TaskSchedulerImpl::addToPriorityQueue(Task* task, TaskInfo* pti) {
 }
 
 void TaskSchedulerImpl::unregisterTopLevelTask(Task* task) {
-    assert(topLevelTasks.contains(task));
-    taskLog.trace(tr("Uregistering task: %1").arg(task->getTaskName()));
+    SAFE_POINT(task != NULL, "Trying to unregister NULL task",);
+    SAFE_POINT(topLevelTasks.contains(task), QString("Trying to unregister task that is not top-level"),);
+
+    taskLog.trace(tr("Unregistering task: %1").arg(task->getTaskName()));
     stopTask(task);
     topLevelTasks.removeOne(task);
 
@@ -499,10 +532,8 @@ QString TaskSchedulerImpl::getStateName(Task* t) const {
 
 
 QDateTime TaskSchedulerImpl::estimatedFinishTime(Task* task) const {
-    if (task->getState()!=Task::State_Running) {
-        assert(0);
-        return QDateTime();
-    }
+    SAFE_POINT(task->getState() == Task::State_Running, "Method is valid for running tasks only", QDateTime());
+
     const TaskTimeInfo& tti = task->getTimeInfo();
     int secsPassed = GTimer::secsBetween(tti.startTime, GTimer::currentTimeMicros());
     float percentInSecs = task->getProgress() / (float)secsPassed;
@@ -586,7 +617,7 @@ void TaskSchedulerImpl::promoteTask(TaskInfo* ti, Task::State newState) {
     TaskTimeInfo& tti = getTaskTimeInfo(task);
     TaskInfo* pti = ti->parentTaskInfo;
 
-    if (!tsi.hasErrors()) {
+    if (!tsi.hasError()) {
         taskLog.trace(tr("promoting task {%1} to '%2'").arg(task->getTaskName()).arg(state2String(newState)));
     } else {
         taskLog.trace(tr("promoting task {%1} to '%2', error '%3'").arg(task->getTaskName()).arg(state2String(newState)).arg(tsi.getError()));
@@ -616,7 +647,7 @@ void TaskSchedulerImpl::promoteTask(TaskInfo* ti, Task::State newState) {
         case Task::State_Finished:
             checkFinishedState(ti);
             tti.finishTime = GTimer::currentTimeMicros();
-            tsi.setStateDesc(QString());
+            tsi.setDescription(QString());
             if (pti != NULL) {
                 pti->numRunningSubtasks--;
                 assert(pti->numRunningSubtasks>=0);
@@ -624,7 +655,7 @@ void TaskSchedulerImpl::promoteTask(TaskInfo* ti, Task::State newState) {
                 assert(pti->numFinishedSubtasks <= pti->task->getSubtasks().size());
             }
             if (ti->task->isTopLevelTask()) {
-                if (tsi.hasErrors() && !tsi.cancelFlag) {
+                if (tsi.hasError() && !tsi.cancelFlag) {
                     taskLog.error(tr("Task {%1} finished with error: %2").arg(task->getTaskName()).arg(tsi.getError()));
                 } else if (tsi.cancelFlag) {
                     taskLog.info(tr("Task {%1} canceled").arg(ti->task->getTaskName()));
@@ -678,10 +709,10 @@ void TaskSchedulerImpl::updateTaskProgressAndDesc(TaskInfo* ti) {
         const QList<Task*>& subs = task->getSubtasks();
         if (!subs.isEmpty()) {
             Task* sub = subs.last();
-            tsi.setStateDesc(sub->getStateInfo().getStateDesc());
+            tsi.setDescription(sub->getStateInfo().getDescription());
         }
     }
-    QString currentDesc = tsi.getStateDesc();
+    QString currentDesc = tsi.getDescription();
     if (currentDesc!= ti->prevDesc) {
         ti->prevDesc = currentDesc;
         emit_taskDescriptionChanged(task);
@@ -711,7 +742,11 @@ void TaskSchedulerImpl::updateTaskProgressAndDesc(TaskInfo* ti) {
                 sum += sub->getProgress() * w;
                 maxSum += w;
             }
-            newProgress = qRound(sum / maxSum);
+            if (maxSum > 1.0f) {
+                newProgress = qRound(sum / maxSum);
+            } else {
+                newProgress = qRound(sum);
+            }
         }
         updateProgress = tsi.progress != newProgress;
     }
@@ -723,6 +758,7 @@ void TaskSchedulerImpl::updateTaskProgressAndDesc(TaskInfo* ti) {
 }
 
 void TaskSchedulerImpl::deleteTask(Task* task) {
+    SAFE_POINT(task != NULL, "Trying to delete NULL task",);
     foreach(Task* sub, task->getSubtasks()) {
         //todo: check subtask autodelete ??
         deleteTask(sub);
