@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "RemoteMachineScanDialogImpl.h"
 #include "RemoteMachineSettingsDialog.h"
@@ -90,8 +101,8 @@ rmm(monitor), getPublicMachinesTask( NULL ) {
         okPushButton->setText( OK_BUTTON_RUN );
     }
     
-    updateState();
     initMachineActionsMenu();
+    updateState();
 }
 
 void RemoteMachineMonitorDialogImpl::initMachineActionsMenu() {
@@ -299,7 +310,7 @@ void RemoteMachineMonitorDialogImpl::sl_retrieveInfoTaskStateChanged() {
     RemoteMachineItemInfo & itemInfo = machinesItemsByOrder[row];
     
     bool pingOk = retrieveInfoTask->isPingOk();
-    bool authOk = !retrieveInfoTask->hasErrors();
+    bool authOk = !retrieveInfoTask->hasError();
 
     treeItem->setIcon( 2, pingOk ? PING_YES : PING_NO);
     treeItem->setIcon( 3, authOk ? PING_YES : PING_NO);
@@ -375,7 +386,7 @@ void RemoteMachineMonitorDialogImpl::sl_getPublicMachinesTaskStateChanged() {
         
     QList< RemoteMachineSettings* > newMachines = getPublicMachinesTask->takePublicMachines();
 
-    if( getPublicMachinesTask->hasErrors()) {
+    if( getPublicMachinesTask->hasError()) {
         QMessageBox::critical(this, tr("Info"), tr("Error during remote machines request: %1").arg(getPublicMachinesTask->getError()));
     } else if ( newMachines.isEmpty() ) {
         QMessageBox::information(this, tr("Info"), tr("No public machines found"));
@@ -432,7 +443,10 @@ void RemoteMachineMonitorDialogImpl::updateState()
     removePushButton->setEnabled(available );
     modifyPushButton->setEnabled(available );
     showTasksButton->setEnabled(available);
-
+    
+    foreach (QAction* action, machineActionsMenu->actions()) {
+        action->setEnabled(available);
+    }
 }
 
 RemoteMachineSettings* RemoteMachineMonitorDialogImpl::getSelectedMachine() const {
