@@ -1,13 +1,3 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #ifndef _CREATEPHYTREEDIALOGCONTROLLER_H_
 #define _CREATEPHYTREEDIALOGCONTROLLER_H_
 
@@ -31,11 +21,13 @@ public:
     CreatePhyTreeDialogController(QWidget* parent, const MAlignmentObject* mobj, CreatePhyTreeSettings& settings);
     ~CreatePhyTreeDialogController();
 
-    void insertWidget(int pos, CreatePhyTreeWidget* widget);
+    void insertContrWidget(int pos, CreatePhyTreeWidget* widget);
 
 private slots:
     void sl_okClicked();
     void sl_browseClicked();
+    void sl_onStoreSettings();
+    void sl_onRestoreDefault();
     
 private:
     int rightMargin;
@@ -43,6 +35,9 @@ private:
     CreatePhyTreeSettings& settings;
     QList<CreatePhyTreeWidget*> childWidgets;
     Ui_CreatePhyTree* ui;
+
+    bool estimateResources(qint64* memoryRequiredMB); 
+    bool checkSeed(int seed);
 };
 
 }
