@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "FindDialog.h"
 
@@ -75,7 +86,7 @@ FindDialog::FindDialog(ADVSequenceObjectContext* context): QDialog(context->getA
     prevMatch = 100;
     task = NULL;
     
-    QList<LRegion> selection = ctx->getSequenceSelection()->getSelectedRegions();
+    QVector<U2Region> selection = ctx->getSequenceSelection()->getSelectedRegions();
     if(!selection.isEmpty()) {
         initialSelection = selection.first();
     }
@@ -104,6 +115,9 @@ FindDialog::FindDialog(ADVSequenceObjectContext* context): QDialog(context->getA
     leFind->setFocus();
     lbResult->setSortingEnabled(true);
 
+    DNAAlphabet* al = ctx->getSequenceObject()->getAlphabet();
+    useAmbiguousBasesBox->setEnabled(al->isNucleic());
+
     timer = new QTimer(this);
 
     connect(AppContext::getTaskScheduler(), SIGNAL(si_stateChanged(Task*)), SLOT(sl_onTaskFinished(Task*)));
@@ -152,7 +166,7 @@ void FindDialog::connectGUI() {
 
 
 void FindDialog::updateState() {
-    bool hasInitialSelection = initialSelection.len > 0;
+    bool hasInitialSelection = initialSelection.length > 0;
     bool hasActiveTask = task!=NULL;
     bool hasAmino = ctx->getAminoTT()!=NULL;
     bool hasCompl = ctx->getComplementTT()!=NULL;
@@ -333,7 +347,7 @@ void FindDialog::tunePercentBox() {
 
 //line ed
 void FindDialog::sl_onSearchPatternChanged(const QString&) {
-    if (leFind->text().length() > getCompleteSearchRegion().len) {
+    if (leFind->text().length() > getCompleteSearchRegion().length) {
         sl_onRangeToSequence();
     }
     tunePercentBox();
@@ -367,7 +381,7 @@ bool FindDialog::checkState(bool forSingleShot) {
     int maxErr = getMaxErr();
     int minMatch = pattern.length() - maxErr;
     assert(minMatch > 0);
-    if (minMatch > getCompleteSearchRegion().len) {
+    if (minMatch > getCompleteSearchRegion().length) {
         QMessageBox::critical(this, tr("Error!"), tr("Pattern length is greater than search range"));
         return false;
     }
@@ -388,7 +402,7 @@ bool FindDialog::checkState(bool forSingleShot) {
         assert(t!=NULL);
         al = t->getDstAlphabet();
     }
-    bool alphabetIsOk = TextUtils::fits(al->getMap(), pattern.toLocal8Bit().data(), pattern.size());
+    bool alphabetIsOk = TextUtils::fits(al->getMap(), pattern.toLocal8Bit().data(), pattern.size()) || useAmbiguousBasesBox->isChecked();
     if (!alphabetIsOk) {
         int res = QMessageBox::warning(this, tr("Warning!"), tr("Search pattern contains symbols that are out of the active alphabet range. Continue anyway?"), QMessageBox::Yes, QMessageBox::No);
         if (res == QMessageBox::No) {
@@ -449,8 +463,8 @@ int FindDialog::getMaxErr() const {
     return int((float)(1 - float(sbMatch->value()) / 100) * leFind->text().length());
 }
 
-LRegion FindDialog::getCompleteSearchRegion() const {
-    return LRegion(sbRangeStart->value()-1, sbRangeEnd->value() - sbRangeStart->value() + 1);
+U2Region FindDialog::getCompleteSearchRegion() const {
+    return U2Region(sbRangeStart->value()-1, sbRangeEnd->value() - sbRangeStart->value() + 1);
 }
 
 void FindDialog::runTask(bool singleShot) {
@@ -471,13 +485,14 @@ void FindDialog::runTask(bool singleShot) {
     s.maxErr = getMaxErr();
     
     s.insDelAlg = rbInsDelAlg->isChecked();
+    s.useAmbiguousBases = useAmbiguousBasesBox->isChecked();
 
     //setup search region
     s.searchRegion = getCompleteSearchRegion();
 
     if (singleShot) { //TODO: loosing complementary strand here!
         int newStartPos = sbCurrentPos->value() - 1; //visual val is +1 to the last used current
-        s.searchRegion.len-=(newStartPos - s.searchRegion.startPos);
+        s.searchRegion.length-=(newStartPos - s.searchRegion.startPos);
         s.searchRegion.startPos = newStartPos;
     }
     
@@ -543,7 +558,7 @@ void FindDialog::sl_onResultActivated(QListWidgetItem* i, bool setCurPos) {
     }
     ADVSingleSequenceWidget* sw = qobject_cast<ADVSingleSequenceWidget*>(ctx->getAnnotatedDNAView()->getSequenceWidgetInFocus());
     if (sw!=NULL && sw->getSequenceContext() == ctx)  {
-        if (item->res.complement) {
+        if (item->res.strand == U2Strand::Complementary) {
             sw->centerPosition(item->res.region.endPos());
         } else {
             sw->centerPosition(item->res.region.startPos);
@@ -562,7 +577,7 @@ void FindDialog::sl_currentResultChanged(QListWidgetItem* current, QListWidgetIt
 }
 
 void FindDialog::sl_onRangeToSelection() {
-    assert(initialSelection.len!=0);
+    assert(initialSelection.length!=0);
     sbRangeStart->setValue(initialSelection.startPos + 1);
     sbCurrentPos->setValue(sbRangeStart->value());
     sbRangeEnd->setValue(initialSelection.endPos());
@@ -585,22 +600,22 @@ void FindDialog::sl_onRemoveOverlaps() {
             FRListItem* rj = static_cast<FRListItem*>(lbResult->item(j));
             assert(rj->res.region.startPos >= ri->res.region.startPos);
 
-            if (rj->res.complement != ri->res.complement) {
+            if (rj->res.strand != ri->res.strand) {
                 continue;
             }
             if (rj->res.translation != ri->res.translation) {
                 continue;
             }
             if (rj->res.translation) {
-                bool complement =rj->res.complement ;
-                int framej = complement ? rj->res.region.endPos() % 3 : rj->res.region.startPos % 3;
-                int framei = complement ? ri->res.region.endPos() % 3 : ri->res.region.startPos % 3;
+                U2Strand strand  = rj->res.strand ;
+                int framej = strand == U2Strand::Complementary ? rj->res.region.endPos() % 3 : rj->res.region.startPos % 3;
+                int framei = strand == U2Strand::Complementary ? ri->res.region.endPos() % 3 : ri->res.region.startPos % 3;
                 if (framei != framej) {
                     continue;
                 }
             }
-            LRegion r = rj->res.region.intersect(ri->res.region);
-            if (r.len > 0 && r.len >= MAX_OVERLAP_K * ri->res.region.len) {
+            U2Region r = rj->res.region.intersect(ri->res.region);
+            if (r.length > 0 && r.length >= MAX_OVERLAP_K * ri->res.region.length) {
                 if (ri->res.err > ri->res.err) {
                     delete ri;
                     i--;
@@ -634,7 +649,7 @@ FRListItem::FRListItem(const FindAlgorithmResult& r) : res(r)
         .arg(res.region.startPos+1) //user sees sequence from [1, end]
         .arg(res.region.endPos())
         .arg(res.translation ? yes : no)
-        .arg(res.complement ? yes : no));
+        .arg(res.strand == U2Strand::Complementary ? yes : no));
 }
 
 bool FRListItem::operator< ( const QListWidgetItem & other ) const {
