@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ADVGraphModel.h"
 #include "GSequenceGraphView.h"
@@ -117,9 +128,9 @@ void GSequenceGraphUtils::fitToScreen(const QVector<float>& data, int dataStartB
     }
 }
 
-int GSequenceGraphUtils::getNumSteps(const LRegion& range, int w, int s) { 
-    assert(range.len >= w);
-    int steps = (range.len  - w) / s + 1;
+int GSequenceGraphUtils::getNumSteps(const U2Region& range, int w, int s) { 
+    assert(range.length >= w);
+    int steps = (range.length  - w) / s + 1;
     return steps;
 }
 
@@ -368,7 +379,7 @@ static void align(int start, int end, int win, int step, int seqLen, int& aligne
 
 
 void GSequenceGraphDrawer::calculatePoints(GSequenceGraphData* d, PairVector& points, float& min, float& max, int numPoints) {
-    const LRegion& vr = view->getVisibleRange();
+    const U2Region& vr = view->getVisibleRange();
 
     int step = wdata.step;
     int win = wdata.window;
@@ -380,7 +391,7 @@ void GSequenceGraphDrawer::calculatePoints(GSequenceGraphData* d, PairVector& po
     points.secondPoints.fill(UNKNOWN_VAL);
     min = UNKNOWN_VAL;
     max = UNKNOWN_VAL;
-    if (vr.len < win) {
+    if (vr.length < win) {
         return;
     }
     int alignedFirst = 0; //start point for the first window
@@ -391,7 +402,7 @@ void GSequenceGraphDrawer::calculatePoints(GSequenceGraphData* d, PairVector& po
     bool winStepNotChanged = win == d->cachedW && step == d->cachedS ;
     bool numPointsNotChanged = numPoints == d->cachedData.firstPoints.size();
 
-    bool useCached = vr.len == d->cachedLen && vr.startPos == d->cachedFrom 
+    bool useCached = vr.length == d->cachedLen && vr.startPos == d->cachedFrom 
         && winStepNotChanged && numPointsNotChanged;
     
     if (useCached) {
@@ -405,7 +416,7 @@ void GSequenceGraphDrawer::calculatePoints(GSequenceGraphData* d, PairVector& po
         bool offsetIsTooSmall = qAbs((d->alignedLC - d->alignedFC) - (alignedLast - alignedFirst)) <= step
                         && (qAbs(alignedFirst - d->alignedFC) < basesPerPoint);
 
-        if (offsetIsTooSmall && winStepNotChanged && numPointsNotChanged && vr.len == d->cachedLen ) {
+        if (offsetIsTooSmall && winStepNotChanged && numPointsNotChanged && vr.length == d->cachedLen ) {
             useCached = true;
             points = d->cachedData;
         } else {
@@ -449,7 +460,7 @@ void GSequenceGraphDrawer::calculatePoints(GSequenceGraphData* d, PairVector& po
     // cache this result
     d->cachedData = points;
     d->cachedFrom = vr.startPos;
-    d->cachedLen = vr.len;
+    d->cachedLen = vr.length;
     d->cachedW = win;
     d->cachedS = step;
     d->alignedFC = alignedFirst;
@@ -469,7 +480,7 @@ void GSequenceGraphDrawer::calculateWithFit(GSequenceGraphData* d, PairVector& p
     for (int i = 0; i < nPoints; i++) {
         pointData.clear();
         int startPos = alignedFirst + int(i * basesPerPoint);
-        LRegion r(startPos, len);
+        U2Region r(startPos, len);
 #ifdef DEBUG
         assert(r.endPos() <= lastBase);
 #endif
@@ -488,11 +499,11 @@ void GSequenceGraphDrawer::calculateWithExpand(GSequenceGraphData* d, PairVector
     int step = wdata.step;
     assert((alignedLast - alignedFirst) % step == 0);
 
-    LRegion r(alignedFirst, alignedLast - alignedFirst + win);
+    U2Region r(alignedFirst, alignedLast - alignedFirst + win);
     DNASequenceObject* o = view->getSequenceObject();
     QVector<float> res;
     d->ga->calculate(res, o, r, &wdata);
-    const LRegion& vr = view->getVisibleRange();
+    const U2Region& vr = view->getVisibleRange();
 
     assert(alignedFirst + win2 + step >= vr.startPos); //0 or 1 step is before the visible range
     assert(alignedLast + win2 - step <= vr.endPos()); //0 or 1 step is after the the visible range
@@ -511,7 +522,7 @@ void GSequenceGraphDrawer::calculateWithExpand(GSequenceGraphData* d, PairVector
     assert(hasBeforeStep ? (firstBaseOffset < step && firstBaseOffset!=0): firstBaseOffset <= win2);
     assert(hasAfterStep ? (lastBaseOffset <= step && lastBaseOffset !=0) : lastBaseOffset < win2 + step);
 
-    float base2point = points.firstPoints.size() / (float)vr.len;
+    float base2point = points.firstPoints.size() / (float)vr.length;
 
     int ri = hasBeforeStep ? 1 : 0;
     int rn = hasAfterStep ? res.size()-1 : res.size();
@@ -540,7 +551,7 @@ void GSequenceGraphDrawer::calculateWithExpand(GSequenceGraphData* d, PairVector
 
 
 void GSequenceGraphDrawer::showSettingsDialog() {
-    WindowStepSelectorDialog d(view, LRegion(1, view->getSequenceLen()-1),
+    WindowStepSelectorDialog d(view, U2Region(1, view->getSequenceLen()-1),
                                wdata.window, wdata.step, commdata.min, commdata.max, commdata.enableCuttoff);
     int res = d.exec();
     if (res == QDialog::Accepted) {
