@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ADVSingleSequenceWidget.h"
 #include "ADVSequenceObjectContext.h"
@@ -23,13 +34,14 @@
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/AnnotationTableObject.h>
 #include <U2Core/GObjectRelationRoles.h>
-
 #include <U2Core/DNASequenceSelection.h>
 #include <U2Core/AnnotationSelection.h>
+#include <U2Core/GHints.h>
 
 #include <U2Misc/RangeSelector.h>
 #include <U2Misc/PositionSelector.h>
 #include <U2Gui/GUIUtils.h>
+#include <U2Gui/ExportImageDialog.h>
 #include <U2Misc/DialogUtils.h>
 #include <U2Misc/HBar.h>
 
@@ -92,7 +104,6 @@ ADVSingleSequenceWidget::ADVSingleSequenceWidget(ADVSequenceObjectContext* seqCt
     headerWidget->installEventFilter(this);
     linesLayout->addWidget(headerWidget);
 
-
     init();
 }
 
@@ -155,6 +166,7 @@ void ADVSingleSequenceWidget::init() {
     //hBar->addAction(panView->getZoomToSelectionAction());
     hBar->addAction(zoomToRangeAction);
     hBar->addAction(panView->getZoomToSequenceAction());
+    hBar->addWidget(panView->getPanViewActions());
 
     updateSelectionActions();
 
@@ -264,16 +276,16 @@ void ADVSingleSequenceWidget::removeSequenceView(GSequenceLineView* v, bool dele
     updateMinMaxHeight();
 }
 
-LRegion ADVSingleSequenceWidget::getVisibleRange() const {
+U2Region ADVSingleSequenceWidget::getVisibleRange() const {
     return panView->getVisibleRange();
 }
 
-void ADVSingleSequenceWidget::setVisibleRange(const LRegion& r) {
+void ADVSingleSequenceWidget::setVisibleRange(const U2Region& r) {
     return panView->setVisibleRange(r);
 }
 
 int ADVSingleSequenceWidget::getNumBasesVisible() const {
-    return panView->getVisibleRange().len;
+    return panView->getVisibleRange().length;
 }
 
 void ADVSingleSequenceWidget::setNumBasesVisible(int n) {
@@ -484,24 +496,31 @@ void ADVSingleSequenceWidget::sl_onSelectRange() {
     dlg.setModal(true);
     dlg.setWindowTitle(tr("Select range"));
     ADVSequenceObjectContext* ctx = getSequenceContext();
-    RangeSelector rs(&dlg, 1, ctx->getSequenceLen(), ctx->getSequenceLen(), true);
+    DNASequenceSelection* selection=ctx->getSequenceSelection();
+    RangeSelector* rs;
+    if(selection->isEmpty()){
+        rs=new RangeSelector(&dlg, 1, ctx->getSequenceLen(), ctx->getSequenceLen(), true);
+    }else{
+        rs=new RangeSelector(&dlg, selection->getSelectedRegions().first().startPos + 1, selection->getSelectedRegions().first().endPos(), ctx->getSequenceLen(), true);
+    }
     int rc = dlg.exec();
     if (rc == QDialog::Accepted) {
-        LRegion r(rs.getStart() - 1, rs.getEnd() - rs.getStart() + 1);
+        U2Region r(rs->getStart() - 1, rs->getEnd() - rs->getStart() + 1);
         ctx->getSequenceSelection()->clear();
         getSequenceSelection()->addRegion(r);
         if (!detView->getVisibleRange().intersects(r)) {
             detView->setCenterPos(r.startPos);
         }
     }
+    delete rs;
 }
 
-QList<LRegion> ADVSingleSequenceWidget::getSelectedAnnotationRegions(int max) {
+QVector<U2Region> ADVSingleSequenceWidget::getSelectedAnnotationRegions(int max) {
     ADVSequenceObjectContext* seqCtx = getSequenceContext();
     const QList<AnnotationSelectionData> selection = seqCtx->getAnnotatedDNAView()->getAnnotationsSelection()->getSelection();
-    const QSet<AnnotationTableObject*> myAnns = seqCtx->getAnnotationObjects();
+    const QSet<AnnotationTableObject*> myAnns = seqCtx->getAnnotationObjects(true);
 
-    QList<LRegion> res;
+    QVector<U2Region> res;
     foreach(const AnnotationSelectionData& sd, selection) {
         AnnotationTableObject* aObj = sd.annotation->getGObject();
         if (myAnns.contains(aObj)) {
@@ -515,25 +534,25 @@ QList<LRegion> ADVSingleSequenceWidget::getSelectedAnnotationRegions(int max) {
 }
 
 void ADVSingleSequenceWidget::sl_onSelectInRange() {
-    QList<LRegion> selRegs = getSelectedAnnotationRegions(3);
+    QVector<U2Region> selRegs = getSelectedAnnotationRegions(3);
     assert(selRegs.size() == 2);
     
-    const LRegion& r1 = selRegs.at(0);
-    const LRegion& r2 = selRegs.at(1);
+    const U2Region& r1 = selRegs.at(0);
+    const U2Region& r2 = selRegs.at(1);
     assert(!r1.intersects(r2));
     
-    LRegion r;
+    U2Region r;
     r.startPos = qMin(r1.endPos(), r2.endPos());
-    r.len = qMax(r1.startPos, r2.startPos) - r.startPos;
+    r.length = qMax(r1.startPos, r2.startPos) - r.startPos;
     
     getSequenceContext()->getSequenceSelection()->clear();
     getSequenceContext()->getSequenceSelection()->addRegion(r);
 }
 
 void ADVSingleSequenceWidget::sl_onSelectOutRange() {
-    QList<LRegion> selRegs = getSelectedAnnotationRegions(0);
+    QVector<U2Region> selRegs = getSelectedAnnotationRegions(0);
     assert(!selRegs.isEmpty());
-    LRegion r = LRegion::containingRegion(selRegs);
+    U2Region r = U2Region::containingRegion(selRegs);
 
     getSequenceContext()->getSequenceSelection()->clear();
     getSequenceContext()->getSequenceSelection()->addRegion(r);
@@ -546,7 +565,7 @@ void ADVSingleSequenceWidget::sl_zoomToRange() {
     DNASequenceSelection* sel = getSequenceSelection();
     int start=getVisibleRange().startPos + 1, end=getVisibleRange().endPos();
     if (!sel->isEmpty()) {
-        const QList<LRegion>& regions = sel->getSelectedRegions();
+        const QVector<U2Region>& regions = sel->getSelectedRegions();
         start=regions.first().startPos+1;
         end=regions.first().endPos();
     }
@@ -555,7 +574,7 @@ void ADVSingleSequenceWidget::sl_zoomToRange() {
 
     int rc = dlg.exec();
     if (rc == QDialog::Accepted) {
-        LRegion r(rs->getStart() - 1, rs->getEnd() - rs->getStart() + 1);
+        U2Region r(rs->getStart() - 1, rs->getEnd() - rs->getStart() + 1);
         panView->setVisibleRange(r);
         detView->setStartPos(r.startPos);
     }
@@ -576,11 +595,12 @@ void ADVSingleSequenceWidget::sl_zoomToRange() {
 
 void ADVSingleSequenceWidget::updateState(const QVariantMap& m) {
     QVariantMap map = m.value(SPLITTER_STATE_MAP_NAME).toMap();
-    QVariantMap myData = map.value(getActiveSequenceContext()->getSequenceObject()->getGObjectName()).toMap();
-    LRegion panReg = myData.value(PAN_REG_NAME).value<LRegion>();
+    QString sequenceInProjectId = getActiveSequenceContext()->getSequenceObject()->getGHints()->get(GObjectHint_InProjectId).toString();
+    QVariantMap myData = map.value(sequenceInProjectId).toMap();
+    U2Region panReg = myData.value(PAN_REG_NAME).value<U2Region>();
     int detPos = myData.value(DET_POS_NAME).toInt();
     
-    LRegion seqRange(0, getActiveSequenceContext()->getSequenceLen());
+    U2Region seqRange(0, getActiveSequenceContext()->getSequenceLen());
     if (seqRange.contains(detPos)) {
         detView->setStartPos(detPos);
     }
@@ -621,7 +641,7 @@ void ADVSingleSequenceWidget::saveState(QVariantMap& m) {
     QVariantMap map = m.value(SPLITTER_STATE_MAP_NAME).toMap();
     
     QVariantMap myData;
-    myData[PAN_REG_NAME] = QVariant::fromValue<LRegion>(panView->getVisibleRange());
+    myData[PAN_REG_NAME] = QVariant::fromValue<U2Region>(panView->getVisibleRange());
     myData[DET_POS_NAME] = QVariant::fromValue<int>(detView->getVisibleRange().startPos);
     myData[OVERVIEW_VISIBLE] = !isOverviewCollapsed();
     myData[PAN_VISIBLE] = !isPanViewCollapsed();
@@ -641,7 +661,8 @@ void ADVSingleSequenceWidget::saveState(QVariantMap& m) {
     myData[CUSTOM_R_OFFSETS] = roffsets;
     myData[CUSTOM_R_COLORS] = rcolors;
     
-    map[getActiveSequenceContext()->getSequenceObject()->getGObjectName()] = myData;
+    QString sequenceInProjectId = getActiveSequenceContext()->getSequenceObject()->getGHints()->get(GObjectHint_InProjectId).toString();
+    map[sequenceInProjectId] = myData;
     m[SPLITTER_STATE_MAP_NAME] = map;
 }
 
@@ -652,52 +673,13 @@ void ADVSingleSequenceWidget::sl_closeView()
 }
 void ADVSingleSequenceWidget::sl_saveScreenshot()
 {
-    LastOpenDirHelper lod(IMAGE_DIR);
-    QRect* screenRect = new QRect(linesLayout->itemAt(1)->geometry().topLeft().x(),
+    QRect screenRect = QRect(linesLayout->itemAt(1)->geometry().topLeft().x(),
                                   linesLayout->itemAt(1)->geometry().topLeft().y(),
                                   this->geometry().bottomRight().x(),
                                   this->geometry().bottomRight().y());
-    QPixmap curPixMap = QPixmap::grabWidget(this, *screenRect);
-    QMap<QString, QString> filters;
-    filters[ "PNG - Portable Network Graphics (*.png)" ] = "png";
-    filters[ "JPG/JPEG format (*.jpg)" ] = "jpg";
-    filters[ "TIF - Tagged Image File format (*.tiff)" ] = "tiff";
+    ExportImageDialog dialog(this, screenRect);
+    dialog.exec();
 
-    QString initialPath = lod.dir + "/untitled";
-    QString selectedFormat;
-    QString fileName = QFileDialog::getSaveFileName(this, tr("Save As"),
-        initialPath, QStringList(filters.keys()).join(";;"), &selectedFormat);
-    lod.url = fileName;
-    
-    if (!fileName.isEmpty()) {
-        bool formatAppend = true;
-        foreach( const QString & format, filters.values() ) {
-            if( fileName.endsWith("." + format) ){
-                formatAppend = false;
-                break;
-            }
-        }
-        if( formatAppend ) {
-            assert( filters.contains(selectedFormat) );
-            fileName.append( "." + filters[selectedFormat] );
-            
-            if( QFile::exists(fileName) ) {
-                QMessageBox::StandardButtons b = 
-                        QMessageBox::warning( 
-                                0, tr("Replace file"), 
-                                tr("%1 already exists.\nDo you want to replace it?").arg(fileName),
-                                QMessageBox::Yes|QMessageBox::No);
-                if( QMessageBox::Yes != b ) {
-                    return;
-                }
-            }
-        }
-        bool result = curPixMap.save(fileName);
-        if (!result) {
-            QMessageBox::critical(this, L10N::errorTitle(), L10N::errorImageSave(fileName, selectedFormat));
-            return;
-        }
-    }
 }
 
 void ADVSingleSequenceWidget::closeView() {
@@ -725,7 +707,7 @@ void ADVSingleSequenceWidget::sl_createCustomRuler() {
         }
         
         // find minimum of start positions of selected annotations
-        foreach( const LRegion & region, selectionData.getSelectedRegions() ) {
+        foreach( const U2Region & region, selectionData.getSelectedRegions() ) {
             annOffset = annOffset > region.startPos ? region.startPos : annOffset;
         }
     }
@@ -733,7 +715,7 @@ void ADVSingleSequenceWidget::sl_createCustomRuler() {
         offset = annOffset;
     }
     
-    QList<LRegion> selection = getSequenceSelection()->getSelectedRegions();
+    QVector<U2Region> selection = getSequenceSelection()->getSelectedRegions();
     if(!selection.isEmpty()) {
         offset = selection.first().startPos;
     }
@@ -754,16 +736,16 @@ void ADVSingleSequenceWidget::sl_removeCustomRuler() {
 
 void ADVSingleSequenceWidget::sl_onAnnotationSelectionChanged(AnnotationSelection* s, const QList<Annotation*>&, const QList<Annotation*>&) {
     // make sequence selection to match external annotation bounds
-    QList<LRegion> annotatedRegions = s->getSelectedLocations(getSequenceContext()->getAnnotationObjects());
+    QVector<U2Region> annotatedRegions = s->getSelectedLocations(getSequenceContext()->getAnnotationObjects(true));
     if (!annotatedRegions.isEmpty()) {
-        QList<LRegion> joinedRegions = LRegion::join(annotatedRegions);
+        QVector<U2Region> joinedRegions = U2Region::join(annotatedRegions);
         getSequenceContext()->getSequenceSelection()->setSelectedRegions(joinedRegions);
     }
     updateSelectionActions();
 }
 
 void ADVSingleSequenceWidget::updateSelectionActions() {
-    QList<LRegion> selRegs = getSelectedAnnotationRegions(3);
+    QVector<U2Region> selRegs = getSelectedAnnotationRegions(3);
 
     selectInAnnotationRangeAction->setEnabled(selRegs.size() == 2 && !selRegs[0].intersects(selRegs[1]));
     selectOutAnnotationRangeAction->setEnabled(!selRegs.isEmpty());
@@ -789,8 +771,8 @@ void ADVSingleSequenceWidget::sl_togglePanView(){
     setPanViewCollapsed(!isPanViewCollapsed());
 }
 
-void ADVSingleSequenceWidget::setTitle(const QString& title) {
-    headerWidget->setTitle(title);
+void ADVSingleSequenceWidget::onSequenceObjectRenamed(const QString&) {
+    headerWidget->updateTitle();
 }
 
 
@@ -831,15 +813,15 @@ ADVSingleSequenceHeaderWidget::ADVSingleSequenceHeaderWidget(ADVSingleSequenceWi
     
     int labelWidth = 50;
     QFontMetrics fm(f);
-    QString nameText = objName + " [" + getShortAlphabetName(seqObj->getAlphabet()) +"]";
-    nameLabel = new QLabel(nameText, this);
+    nameLabel = new QLabel("", this);
+    updateTitle();
     nameLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
     nameLabel->setMinimumWidth(labelWidth);
-    nameLabel->setMaximumWidth(fm.width(nameText));
+    nameLabel->setMaximumWidth(fm.width(nameLabel->text()));
     nameLabel->setFont(f);
     nameLabel->setToolTip(objInfoTip);
     nameLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
-
+    
     toolBar = new HBar(this);
     toolBar->layout()->setSpacing(0);
     toolBar->layout()->setMargin(0);
@@ -867,6 +849,12 @@ ADVSingleSequenceHeaderWidget::ADVSingleSequenceHeaderWidget(ADVSingleSequenceWi
 
 }
 
+void ADVSingleSequenceHeaderWidget::updateTitle() {
+    DNASequenceObject* seqObj = ctx->getSequenceObject();
+    QString newTitle = seqObj->getGObjectName() + " [" + getShortAlphabetName(seqObj->getAlphabet()) +"]";
+    setTitle(newTitle);
+}
+
 void ADVSingleSequenceHeaderWidget::populateToolBars() {
     // close bar
     widgetStateMenuButton = new QToolButton(this);
@@ -964,16 +952,14 @@ QString ADVSingleSequenceHeaderWidget::getShortAlphabetName(DNAAlphabet* al) {
     if (id == BaseDNAAlphabetIds::NUCL_DNA_DEFAULT()) {
         return tr("dna");
     } else if (id == BaseDNAAlphabetIds::NUCL_DNA_EXTENDED()) {
-        return tr("dna ext.");
+        return tr("dna ext");
     } else if (id == BaseDNAAlphabetIds::NUCL_RNA_DEFAULT()) {
         return tr("rna");
     } else if (id == BaseDNAAlphabetIds::NUCL_RNA_EXTENDED()) {
-        return tr("rna ext.");
+        return tr("rna ext");
     }
     return "?";
 }
 
-
-
 }//namespace
 
