@@ -1,17 +1,29 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ADVSyncViewManager.h"
 #include "AnnotatedDNAView.h"
 #include "ADVSingleSequenceWidget.h"
 #include "ADVSequenceObjectContext.h"
+#include "AutoAnnotationUtils.h"
 #include "PanView.h"
 
 #include <U2Core/DNASequenceSelection.h>
@@ -76,6 +88,19 @@ ADVSyncViewManager::ADVSyncViewManager(AnnotatedDNAView* v) : QObject(v), adv(v)
     lockButtonTBAction = NULL;
     syncButtonTBAction = NULL;
     
+    // auto-annotations highlighting ops
+        
+    toggleAutoAnnotationsMenu = new QMenu("Global automatic annotation highlighting");
+    toggleAutoAnnotationsMenu->setIcon(QIcon(":core/images/predefined_annotation_groups.png"));
+    connect( toggleAutoAnnotationsMenu, SIGNAL(aboutToShow()), SLOT(sl_updateAutoAnnotationsMenu()) );
+     
+    toggleAutoAnnotationsButton = new QToolButton();
+    toggleAutoAnnotationsButton->setDefaultAction(toggleAutoAnnotationsMenu->menuAction());
+    toggleAutoAnnotationsButton->setPopupMode(QToolButton::InstantPopup);
+    
+    toggleAutoAnnotationsAction = NULL;
+    
+    
     // visual mode ops
     toggleAllAction = new QAction("Toggle All sequence views", this);
     connect(toggleAllAction, SIGNAL(triggered()), SLOT(sl_toggleVisualMode()));
@@ -97,7 +122,7 @@ ADVSyncViewManager::ADVSyncViewManager(AnnotatedDNAView* v) : QObject(v), adv(v)
     toggleViewButtonMenu->addAction(toggleOveAction);
     toggleViewButtonMenu->addAction(togglePanAction);
     toggleViewButtonMenu->addAction(toggleDetAction);
-    connect(toggleViewButtonMenu, SIGNAL(aboutToShow()), SLOT(updateVisualMode()));
+    connect(toggleViewButtonMenu, SIGNAL(aboutToShow()), SLOT(sl_updateVisualMode()));
     
     toggleViewButton = new QToolButton();
     toggleViewButton->setDefaultAction(toggleViewButtonMenu->menuAction());
@@ -115,6 +140,9 @@ ADVSyncViewManager::~ADVSyncViewManager() {
     delete syncMenu;
     delete lockMenu;
     
+    delete toggleAutoAnnotationsButton;
+    delete toggleAutoAnnotationsMenu;
+
     delete toggleViewButton;
     delete toggleViewButtonMenu;
 }
@@ -130,6 +158,14 @@ void ADVSyncViewManager::updateToolbar1(QToolBar* tb) {
 }
 
 void ADVSyncViewManager::updateToolbar2(QToolBar* tb) {
+
+    if (toggleAutoAnnotationsAction == NULL ) {
+        updateAutoAnnotationActions();
+        toggleAutoAnnotationsAction = tb->addWidget(toggleAutoAnnotationsButton);
+    } else {
+        tb->addAction(toggleAutoAnnotationsAction);
+    }
+
     if (toggleViewButtonAction == NULL) {
         toggleViewButtonAction = tb->addWidget(toggleViewButton);
     } else {
@@ -149,6 +185,9 @@ void ADVSyncViewManager::sl_sequenceWidgetAdded(ADVSequenceWidget* w) {
         return;
     }
     unlock();
+    if (toggleAutoAnnotationsAction != NULL) {
+        updateAutoAnnotationActions();
+    }
 }
 
 void ADVSyncViewManager::sl_sequenceWidgetRemoved(ADVSequenceWidget* w) {
@@ -157,6 +196,7 @@ void ADVSyncViewManager::sl_sequenceWidgetRemoved(ADVSequenceWidget* w) {
         return;
     }
     unlock();
+    updateAutoAnnotationActions();
 }
 
 void ADVSyncViewManager::unlock() {
@@ -186,7 +226,7 @@ void ADVSyncViewManager::sl_rangeChanged() {
     recursion = true;
 
     PanView* activePan = qobject_cast<PanView*>(sender());
-    const LRegion& activeRange = activePan->getVisibleRange();
+    const U2Region& activeRange = activePan->getVisibleRange();
     int activeOffset = activePan->getSyncOffset();
     foreach(ADVSingleSequenceWidget* sw, views) {
         PanView* pan = sw->getPanView();
@@ -195,14 +235,14 @@ void ADVSyncViewManager::sl_rangeChanged() {
         }
         int panOffset = pan->getSyncOffset();
         int resultOffset = panOffset - activeOffset;
-        int seqLen = pan->getSeqLen();
-        int newStart = qBound(0, activeRange.startPos + resultOffset, seqLen);
-        int nVisible = qMin(activeRange.len, seqLen);
+        qint64 seqLen = pan->getSeqLen();
+        qint64 newStart = qBound(qint64(0), activeRange.startPos + resultOffset, seqLen);
+        qint64 nVisible = qMin(activeRange.length, seqLen);
         if (newStart + nVisible > seqLen) {
             newStart = seqLen - nVisible;
         }
         assert(newStart >= 0 && newStart + nVisible <= seqLen);
-        pan->setVisibleRange(LRegion(newStart, nVisible));
+        pan->setVisibleRange(U2Region(newStart, nVisible));
     }
     
     recursion = false;
@@ -266,7 +306,7 @@ void ADVSyncViewManager::sync(bool lock, SyncMode m) {
     
     //offset here ==> new panview start pos
     //dOffset is used to keep focused sequence unchanged
-    LRegion focusedRange;
+    U2Region focusedRange;
     int dOffset = 0; 
     for (int i=0; i< seqs.size(); i++ ){
         int offset = 0;
@@ -288,14 +328,14 @@ void ADVSyncViewManager::sync(bool lock, SyncMode m) {
         int offset = offsets[i] - dOffset;
         PanView* pan = seqW->getPanView();
         if (seqW != focusedW) {
-            pan->setNumBasesVisible(focusedRange.len);
+            pan->setNumBasesVisible(focusedRange.length);
             pan->setStartPos(offset);
         }
         if (lock) {
             DNASequenceSelection* selection = seqW->getSequenceContext()->getSequenceSelection();
             connect(selection, 
-                SIGNAL(si_selectionChanged(LRegionsSelection*, const QList<LRegion>&, const QList<LRegion>& )),
-                SLOT(sl_onSelectionChanged(LRegionsSelection*, const QList<LRegion>&, const QList<LRegion>& )) );
+                SIGNAL(si_selectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>& )),
+                SLOT(sl_onSelectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>& )) );
             pan->setSyncOffset(offset);
             connect(pan, SIGNAL(si_visibleRangeChanged()), SLOT(sl_rangeChanged()));
             views.append(seqW);
@@ -321,11 +361,11 @@ int ADVSyncViewManager::offsetByAnnSel(ADVSingleSequenceWidget* w) const {
 
 int ADVSyncViewManager::findSelectedAnnotationPos(ADVSingleSequenceWidget* w) const {
     AnnotationSelection* as = w->getSequenceContext()->getAnnotationsSelection();
-    const QSet<AnnotationTableObject*>& objs = w->getSequenceContext()->getAnnotationObjects();
+    const QSet<AnnotationTableObject*>& objs = w->getSequenceContext()->getAnnotationObjects(true);
     foreach(const AnnotationSelectionData& d , as->getSelection()) {
         AnnotationTableObject* obj = d.annotation->getGObject();
         if (objs.contains(obj)) {
-            return d.annotation->isOnComplementStrand() ? d.getSelectedRegions().last().endPos() : d.getSelectedRegions().first().startPos;
+            return d.annotation->getStrand().isCompementary() ? d.getSelectedRegions().last().endPos() : d.getSelectedRegions().first().startPos;
         }
     }
     return -1;
@@ -359,7 +399,7 @@ ADVSyncViewManager::SyncMode ADVSyncViewManager::detectSyncMode() const {
 
 }
 
-void ADVSyncViewManager::updateVisualMode() {
+void ADVSyncViewManager::sl_updateVisualMode() {
     //if have at least 1 visible -> hide all
     bool haveVisiblePan = false;    
     bool haveVisibleDet = false;
@@ -406,7 +446,7 @@ void ADVSyncViewManager::sl_toggleVisualMode() {
     }
 }
 
-void ADVSyncViewManager::sl_onSelectionChanged( LRegionsSelection* sel, const QList<LRegion>& added, const QList<LRegion>& )
+void ADVSyncViewManager::sl_onSelectionChanged( LRegionsSelection* sel, const QVector<U2Region>& added, const QVector<U2Region>& )
 {
     Q_UNUSED(sel);
     if (selectionRecursion) {
@@ -426,21 +466,22 @@ void ADVSyncViewManager::sl_onSelectionChanged( LRegionsSelection* sel, const QL
         }
 
         int offset = focusedW->getVisibleRange().startPos - w->getVisibleRange().startPos;
-        if (offset < 0) {
-            offset = -offset;
-        }
-
+        
         DNASequenceSelection* selection = w->getSequenceSelection();
         selection->clear();
-        foreach(LRegion r, added) {
+        foreach(U2Region r, added) {
             r.startPos -= offset;
+
             if (r.startPos < 0) {
                 r.startPos = 0;
             }
+
             if (r.endPos() > w->getSequenceLen()) {
-                r.len = w->getSequenceLen() - r.startPos;
+                r.length = w->getSequenceLen() - r.startPos;
+            }
+            if(r.length > 0) {
+                selection->addRegion(r);
             }
-            selection->addRegion(r);
         }
 
     } 
@@ -461,4 +502,82 @@ void ADVSyncViewManager::toggleCheckedAction( SyncMode mode )
             lockByStartPosAction->toggle();
     }
 }
+
+void ADVSyncViewManager::updateAutoAnnotationActions()
+{
+    aaActionMap.clear();
+    toggleAutoAnnotationsMenu->clear();
+
+    foreach (ADVSequenceWidget* w, adv->getSequenceWidgets()) {
+        QList<ADVSequenceWidgetAction*> actions = w->getADVSequenceWidgetActions();
+        foreach (ADVSequenceWidgetAction* action, actions) {
+            AutoAnnotationsADVAction* aaAction = qobject_cast<AutoAnnotationsADVAction*>(action);
+            if (aaAction != NULL) {
+                QList<QAction*> aaToggleActions = aaAction->getToggleActions();
+                foreach( QAction* toggleAction, aaToggleActions) {
+                    if (toggleAction->isEnabled()) {
+                        aaActionMap.insertMulti(toggleAction->text(), toggleAction);
+                    }
+                }
+            }
+        }
+    }
+    
+    toggleAutoAnnotationsButton->setEnabled(!aaActionMap.isEmpty());
+    
+    QSet<QString> actionNames = aaActionMap.keys().toSet();
+
+    foreach (const QString& aName, actionNames) {
+        QAction* action = new QAction(toggleAutoAnnotationsMenu);
+        action->setObjectName(aName);
+        connect(action, SIGNAL(triggered()), SLOT(sl_toggleAutoAnnotaionsHighlighting()));
+        toggleAutoAnnotationsMenu->addAction(action);
+    }
+}
+
+#define HAVE_ENABLED_AUTOANNOTATIONS "have_enabled_autoannotations"
+
+void ADVSyncViewManager::sl_toggleAutoAnnotaionsHighlighting()
+{
+    QAction* menuAction = qobject_cast<QAction*>( sender() );
+    if (menuAction == NULL) {
+        return;
+    }
+    QVariant val = menuAction->property(HAVE_ENABLED_AUTOANNOTATIONS);
+    assert(val.isValid());
+    bool haveEnabledAutoAnnotations = val.toBool();
+    QList<QAction*> aaActions = aaActionMap.values(menuAction->objectName());
+    foreach (QAction* aaAction, aaActions ) 
+    {
+        aaAction->setChecked(!haveEnabledAutoAnnotations);
+    }
+
+}
+
+void ADVSyncViewManager::sl_updateAutoAnnotationsMenu()
+{
+    QList<QAction*> menuActions = toggleAutoAnnotationsMenu->actions();
+    
+    foreach (QAction* menuAction, menuActions) {
+        QString aName = menuAction->objectName(); 
+        bool haveEnabledAutoAnnotations = false;   
+        //if have at least 1 checked  -> uncheck all
+        QList<QAction*> aaActions = aaActionMap.values(aName);
+        foreach(QAction* aaAction, aaActions ) {
+            if (aaAction->isChecked()) {
+                haveEnabledAutoAnnotations = true;
+                break;
+            }
+        }
+        
+        if (haveEnabledAutoAnnotations) {
+            menuAction->setText(tr("Hide %1").arg(aName));
+        } else {
+            menuAction->setText(tr("Show %1").arg(aName));
+        }
+        menuAction->setProperty(HAVE_ENABLED_AUTOANNOTATIONS,haveEnabledAutoAnnotations);
+    }
+
+}
+
 }//namespace
