@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "AnnotationsTreeView.h"
 
@@ -21,20 +32,25 @@
 #include <U2Core/Settings.h>
 #include <U2Core/Timer.h>
 #include <U2Core/DBXRefRegistry.h>
+#include <U2Core/U2SafePoints.h>
 
-#include <U2Formats/GenbankLocationParser.h>
 #include <U2Core/AnnotationSettings.h>
 #include <U2Core/AnnotationTableObject.h>
 #include <U2Core/GObjectTypes.h>
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/AnnotationSelection.h>
+#include <U2Core/AutoAnnotationsSupport.h>
+
+#include <U2Formats/GenbankLocationParser.h>
+
 #include <U2Gui/ProjectTreeController.h>
 #include <U2Gui/ProjectTreeItemSelectorDialog.h>
 #include <U2Gui/GUIUtils.h>
 #include <U2Gui/EditQualifierDialog.h>
-#include <U2Misc/TreeWidgetUtils.h>
 #include <U2Gui/OpenViewTask.h>
 
+#include <U2Misc/TreeWidgetUtils.h>
+
 #include <QtCore/QFileInfo>
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QPainter>
@@ -70,7 +86,7 @@ AnnotationsTreeView::AnnotationsTreeView(AnnotatedDNAView* _ctx) : ctx(_ctx){
     lastClickedColumn = 0;
 
     tree = new QTreeWidget(this);
-    tree->setObjectName("tree_widget");
+    tree->setObjectName("annotations_tree_widget");
 
     tree->setSortingEnabled(true);
     tree->sortItems(0, Qt::AscendingOrder);
@@ -83,6 +99,7 @@ AnnotationsTreeView::AnnotationsTreeView(AnnotatedDNAView* _ctx) : ctx(_ctx){
     tree->setSelectionMode(QAbstractItemView::ExtendedSelection);
     tree->viewport()->installEventFilter(this);
     tree->setMouseTracking(true);
+    tree->setAutoScroll(false);
 
     connect(tree, SIGNAL(itemEntered(QTreeWidgetItem*, int)), SLOT(sl_itemEntered(QTreeWidgetItem*, int)));
     connect(tree, SIGNAL(itemClicked(QTreeWidgetItem*, int)), SLOT(sl_itemClicked(QTreeWidgetItem*, int)));
@@ -100,7 +117,8 @@ AnnotationsTreeView::AnnotationsTreeView(AnnotatedDNAView* _ctx) : ctx(_ctx){
     connect(ctx, SIGNAL(si_buildPopupMenu(GObjectView*, QMenu*)), SLOT(sl_onBuildPopupMenu(GObjectView*, QMenu*)));
     connect(ctx, SIGNAL(si_annotationObjectAdded(AnnotationTableObject*)), SLOT(sl_onAnnotationObjectAdded(AnnotationTableObject*)));
     connect(ctx, SIGNAL(si_annotationObjectRemoved(AnnotationTableObject*)), SLOT(sl_onAnnotationObjectRemoved(AnnotationTableObject*)));
-    foreach(AnnotationTableObject* obj, ctx->getAnnotationObjects()) {
+    QList<AnnotationTableObject*> aObjs = ctx->getAnnotationObjects(true);
+    foreach(AnnotationTableObject* obj, aObjs) {
         sl_onAnnotationObjectAdded(obj);
     }
     connectAnnotationSelection();
@@ -281,7 +299,7 @@ AVAnnotationItem* AnnotationsTreeView::findAnnotationItem(const AnnotationGroup*
 /** This method is optimized to use annotation groups. 
 So can only be used for annotations that belongs to some object */
 QList<AVAnnotationItem*> AnnotationsTreeView::findAnnotationItems(const Annotation* a) const {
-    assert(a->getGObject() != NULL && ctx->getAnnotationObjects().contains(a->getGObject()));
+    assert(a->getGObject() != NULL && ctx->getAnnotationObjects(true).contains(a->getGObject()));
 
     QList<AVAnnotationItem*> res;
     foreach(AnnotationGroup* g, a->getGroups()) {
@@ -339,6 +357,9 @@ void AnnotationsTreeView::sl_onAnnotationSelectionChanged(AnnotationSelection*,
     foreach(Annotation* a, removed) {
         foreach(AnnotationGroup* g, a->getGroups()) {
             AVAnnotationItem* item = findAnnotationItem(g, a);
+            if (item == NULL) {
+                continue;
+            }
             if (item->isSelected()) {
                 item->setSelected(false);
             }
@@ -349,6 +370,9 @@ void AnnotationsTreeView::sl_onAnnotationSelectionChanged(AnnotationSelection*,
     foreach(Annotation* a, added) {
         foreach(AnnotationGroup* g, a->getGroups()) {
             AVAnnotationItem* item = findAnnotationItem(g, a);
+            if (item == NULL) {
+                continue;
+            }
             if (!item->isSelected()) {
                 item->setSelected(true);
                 selectedItems.append(item);
@@ -408,10 +432,14 @@ void AnnotationsTreeView::sl_onAnnotationObjectAdded(AnnotationTableObject* obj)
     TreeSorter ts(this);
     
     assert(findGroupItem(obj->getRootGroup()) == NULL);
+    
     AVGroupItem* groupItem = buildGroupTree(NULL, obj->getRootGroup());
+    SAFE_POINT(groupItem != NULL, "creating AVGroupItem failed",);
     tree->addTopLevelItem(groupItem);
     connect(obj, SIGNAL(si_onAnnotationsAdded(const QList<Annotation*>&)), SLOT(sl_onAnnotationsAdded(const QList<Annotation*>&)));
     connect(obj, SIGNAL(si_onAnnotationsRemoved(const QList<Annotation*>&)), SLOT(sl_onAnnotationsRemoved(const QList<Annotation*>&)));
+    connect(obj, SIGNAL(si_onAnnotationsInGroupRemoved(const QList<Annotation*>&, AnnotationGroup*)), 
+                        SLOT(sl_onAnnotationsInGroupRemoved(const QList<Annotation*>&, AnnotationGroup*)));
     connect(obj, SIGNAL(si_onAnnotationModified(const AnnotationModification&)), SLOT(sl_onAnnotationModified(const AnnotationModification&)));
 
     connect(obj, SIGNAL(si_onGroupCreated(AnnotationGroup*)), SLOT(sl_onGroupCreated(AnnotationGroup*)));
@@ -419,18 +447,26 @@ void AnnotationsTreeView::sl_onAnnotationObjectAdded(AnnotationTableObject* obj)
     connect(obj, SIGNAL(si_onGroupRenamed(AnnotationGroup*, const QString& )), SLOT(sl_onGroupRenamed(AnnotationGroup*, const QString& )));
 
     connect(obj, SIGNAL(si_modifiedStateChanged()), SLOT(sl_annotationObjectModifiedStateChanged()));
+    connect(obj, SIGNAL(si_nameChanged(const QString&)), SLOT(sl_onAnnotationObjectRenamed(const QString&)));
 }
 
 void AnnotationsTreeView::sl_onAnnotationObjectRemoved(AnnotationTableObject* obj) {
     TreeSorter ts(this);
 
     AVGroupItem* groupItem = findGroupItem(obj->getRootGroup());
-    assert(groupItem!=NULL);
+    
+    // it's safe to delete NULL pointer
     delete groupItem;
     
     obj->disconnect(this);
 }
 
+void AnnotationsTreeView::sl_onAnnotationObjectRenamed(const QString&) {
+    AnnotationTableObject* ao = qobject_cast<AnnotationTableObject*>(sender());
+    AVGroupItem* gi = findGroupItem(ao->getRootGroup());
+    SAFE_POINT(gi!=NULL, "Failed to find annotations object on rename!",);
+    gi->updateVisual();
+}
 
 void AnnotationsTreeView::sl_onAnnotationsAdded(const QList<Annotation*>& as) {
     GTIMER(c1,t1,"AnnotationsTreeView::sl_onAnnotationsAdded");
@@ -454,7 +490,7 @@ void AnnotationsTreeView::sl_onAnnotationsAdded(const QList<Annotation*>& as) {
                     }
                     childGroup = childGroup->getParentGroup();
                 }
-                assert(gi!=NULL && childGroup!=NULL);
+                SAFE_POINT(gi!=NULL && childGroup!=NULL, "AnnotationsTreeView::sl_onAnnotationsAdded: childGroup not found",);
                 buildGroupTree(gi, childGroup);
             }
             assert(gi!=NULL);
@@ -502,6 +538,60 @@ void AnnotationsTreeView::sl_onAnnotationsRemoved(const QList<Annotation*>& as)
     sl_onItemSelectionChanged();
 }
 
+void AnnotationsTreeView::sl_onAnnotationsInGroupRemoved(const QList<Annotation*>& as, AnnotationGroup* group) {
+    AnnotationTableObject* aObj = qobject_cast<AnnotationTableObject*>(sender());
+    RemoveItemsTask *task = new RemoveItemsTask(this, aObj, as, group);
+    AppContext::getTaskScheduler()->registerTopLevelTask(task);
+}
+
+void RemoveItemsTask::prepare() {
+    TreeSorter ts(treeView);
+
+    treeView->tree->disconnect(treeView, SLOT(sl_onItemSelectionChanged()));
+    parentGroupItem = treeView->findGroupItem(parentGroup); 
+    parentGroupItem->setExpanded(false);
+    parentGroupItem->setDisabled(true);
+    parentGroupItem->setFlags(parentGroupItem->flags() ^ (Qt::ItemIsSelectable | Qt::ItemIsEditable));
+    //flags = parentGroupItem->flags();
+    //parentGroupItem->setFlags(0);
+
+    //AnnotationTableObject* aObj = qobject_cast<AnnotationTableObject*>(sender());
+    assert(aObj != NULL);
+    
+}
+
+void RemoveItemsTask::run() {
+    //AVGroupItem* groupItem = treeView->findGroupItem(aObj->getRootGroup());
+    qDeleteAll(parentGroupItem->takeChildren());
+    //delete parentGroupItem;
+    /*foreach(Annotation* a, as) {
+        assert(a->getGObject() == NULL);
+        QList<AVAnnotationItem*> aItems;
+        groupItem->findAnnotationItems(aItems, a);
+        assert(!aItems.isEmpty());
+        itemsToDelete.append(aItems);
+    }*/
+}
+
+Task::ReportResult RemoveItemsTask::report() {
+    //parentGroupItem->setFlags(flags);
+    /*foreach(AVAnnotationItem * aItem, itemsToDelete) {
+        (static_cast<AVGroupItem*>(aItem->parent()))->updateVisual();
+        delete aItem;
+    }*/
+   /* foreach(AVGroupItem* g, groupsToUpdate) {
+        g->updateVisual();
+    }*/
+    AVGroupItem* groupItem = treeView->findGroupItem(aObj->getRootGroup()); 
+    groupItem->updateVisual();
+
+    connect(treeView->tree, SIGNAL(itemSelectionChanged()), treeView, SLOT(sl_onItemSelectionChanged ()));
+
+    treeView->sl_onItemSelectionChanged();
+    aObj->releaseLocker();
+    return ReportResult_Finished;
+}
+
 void AnnotationsTreeView::sl_onAnnotationModified(const AnnotationModification& md) {
     switch(md.type) {
         case AnnotationModification_NameChanged: 
@@ -569,11 +659,17 @@ void AnnotationsTreeView::sl_onGroupCreated(AnnotationGroup* g) {
 
 void AnnotationsTreeView::sl_onGroupRemoved(AnnotationGroup* parent, AnnotationGroup* g) {
     AVGroupItem* pg  = findGroupItem(parent);
+    if(pg == NULL) {
+        return;
+    }
     assert(parent!=NULL && pg!=NULL);
     
     for(int i = 0, n = pg->childCount(); i < n; i++) {
         AVItem* item = static_cast<AVItem*>(pg->child(i));
         if (item->type == AVItemType_Group && (static_cast<AVGroupItem*>(item))->group == g) {
+            if (item->parent() != NULL) {
+                item->parent()->removeChild(item);
+            }
             delete item;
             break;
         }
@@ -589,6 +685,7 @@ void AnnotationsTreeView::sl_onGroupRenamed(AnnotationGroup* g, const QString& o
 }
 
 AVGroupItem* AnnotationsTreeView::buildGroupTree(AVGroupItem* parentGroupItem, AnnotationGroup* g) {
+    SAFE_POINT(g != NULL, "in AnnotationsTreeView::buildGroupTree: AnnotationGroup argument is NULL", NULL);
     AVGroupItem* groupItem = new AVGroupItem(this, parentGroupItem, g);
     const QList<AnnotationGroup*>& subgroups = g->getSubgroups();
     foreach(AnnotationGroup* subgroup, subgroups) {
@@ -604,7 +701,7 @@ AVGroupItem* AnnotationsTreeView::buildGroupTree(AVGroupItem* parentGroupItem, A
 
 AVAnnotationItem* AnnotationsTreeView::buildAnnotationTree(AVGroupItem* parentGroup, Annotation* a) {
     AVAnnotationItem* annotationItem = new AVAnnotationItem(parentGroup, a);
-    const QVector<Qualifier>& qualifiers = a->getQualifiers();
+    const QVector<U2Qualifier>& qualifiers = a->getQualifiers();
     if (!qualifiers.isEmpty()) {
         annotationItem->setChildIndicatorPolicy(QTreeWidgetItem::ShowIndicator);
     }
@@ -614,8 +711,8 @@ AVAnnotationItem* AnnotationsTreeView::buildAnnotationTree(AVGroupItem* parentGr
 void AnnotationsTreeView::populateAnnotationQualifiers(AVAnnotationItem* ai){
     assert(ai->childIndicatorPolicy() == QTreeWidgetItem::ShowIndicator);
     assert(ai->childCount() == 0);
-    const QVector<Qualifier>& qualifiers = ai->annotation->getQualifiers();
-    foreach(const Qualifier& q, qualifiers) {
+    const QVector<U2Qualifier>& qualifiers = ai->annotation->getQualifiers();
+    foreach(const U2Qualifier& q, qualifiers) {
         AVQualifierItem* curQualifierItem = new AVQualifierItem(ai, q);
         Q_UNUSED(curQualifierItem);
     }
@@ -768,6 +865,16 @@ void AnnotationsTreeView::adjustMenu(QMenu* m) const {
     assert(removeMenu!=NULL);
     removeMenu->addAction(removeObjectsFromViewAction);
     removeMenu->addAction(removeAnnsAndQsAction);
+
+    bool enabled = false;
+    foreach (QAction* action, removeMenu->actions()) {
+        if (action->isEnabled()) {
+            enabled = true;
+            break;
+        }
+    }
+    removeMenu->setEnabled(enabled);
+
 }
 
 void AnnotationsTreeView::sl_onAddAnnotationObjectToView() {
@@ -852,8 +959,12 @@ void AnnotationsTreeView::sl_removeObjectFromView() {
     foreach(AVGroupItem* gItem, topLevelGroups) {
         objects.append(gItem->group->getGObject());
     }
+
     foreach(GObject* obj, objects) {
         assert(obj->getGObjectType() == GObjectTypes::ANNOTATION_TABLE);
+        if (AutoAnnotationsSupport::isAutoAnnotation(obj)) {
+            continue;
+        }
         ctx->removeObject(obj);
     }
 }
@@ -867,21 +978,21 @@ static bool groupDepthInverseComparator(const AVGroupItem* i1, const AVGroupItem
 void AnnotationsTreeView::sl_removeAnnsAndQs() {
     //remove selected qualifiers first (cache them, since different qualifier items with equal name/val are not distinguished)
     QList<AVQualifierItem*> qualifierItemsToRemove = selectQualifierItems(tree->selectedItems(), TriState_No);
-    QVector<Qualifier>  qualsToRemove(qualifierItemsToRemove.size());
+    QVector<U2Qualifier>  qualsToRemove(qualifierItemsToRemove.size());
     QVector<Annotation*>  qualAnnotations(qualifierItemsToRemove.size());
+    
     for(int i=0, n = qualifierItemsToRemove.size(); i<n ; i++) {
         AVQualifierItem* qi = qualifierItemsToRemove[i];
         AVAnnotationItem* ai = static_cast<AVAnnotationItem*>(qi->parent());
         qualAnnotations[i] = ai->annotation;
-        qualsToRemove[i] = Qualifier(qi->qName, qi->qValue);
+        qualsToRemove[i] = U2Qualifier(qi->qName, qi->qValue);
     }
     for(int i=0, n = qualifierItemsToRemove.size(); i<n ; i++) {
         Annotation* a = qualAnnotations.at(i);
-        const Qualifier& q = qualsToRemove.at(i);
+        const U2Qualifier& q = qualsToRemove.at(i);
         a->removeQualifier(q);
     }
     
-
     //remove selected annotations now
     QList<AVAnnotationItem*> annotationItemsToRemove = selectAnnotationItems(tree->selectedItems(), TriState_No);
     QMultiMap<AnnotationGroup*, Annotation*> annotationsByGroup;
@@ -913,8 +1024,18 @@ void AnnotationsTreeView::updateState() {
     QList<QTreeWidgetItem*> items = tree->selectedItems();
     
     QList<AVGroupItem*> topLevelGroups = selectGroupItems(items, TriState_Unknown, TriState_Yes);
-    removeObjectsFromViewAction->setEnabled(!topLevelGroups.isEmpty());
+   
+    bool hasAutoAnnotationObjects = false;
+    foreach (AVGroupItem* item, topLevelGroups) {
+        AnnotationTableObject* aObj = item->getAnnotationTableObject();
+        if (AutoAnnotationsSupport::isAutoAnnotation(aObj)) {
+            hasAutoAnnotationObjects = true;
+            break;
+        }
+    }
     
+    removeObjectsFromViewAction->setEnabled(!topLevelGroups.isEmpty() && !hasAutoAnnotationObjects);
+
     QList<AVGroupItem*> nonRootModGroups = selectGroupItems(items, TriState_No, TriState_No);
     QList<AVAnnotationItem*> modAnnotations = selectAnnotationItems(items, TriState_No);
     QList<AVQualifierItem*>  modQualifiers = selectQualifierItems(items, TriState_No);
@@ -1132,7 +1253,7 @@ bool AnnotationsTreeView::eventFilter(QObject* o, QEvent* e) {
 }
 
 
-bool AnnotationsTreeView::initiateDragAndDrop(QMouseEvent* me) {
+bool AnnotationsTreeView::initiateDragAndDrop(QMouseEvent* ) {
     uiLog.trace("Starting drag & drop in annotations view");
 
     resetDragAndDropData();
@@ -1473,14 +1594,14 @@ void AnnotationsTreeView::editItem(AVItem* item) {
     if (item->type == AVItemType_Qualifier) {
         AVQualifierItem* qi  = static_cast<AVQualifierItem*>(item);
         AVAnnotationItem* ai = static_cast<AVAnnotationItem*>(qi->parent());
-        Qualifier q;
+        U2Qualifier q;
         bool ro = qi->isReadonly();
         bool ok = editQualifierDialogHelper(qi, ro, q);
-        if (!ro && ok && (q.getQualifierName()!=qi->qName || q.getQualifierValue()!=qi->qValue)) {
+        if (!ro && ok && (q.name !=qi->qName || q.value != qi->qValue)) {
             Annotation* a = (static_cast<AVAnnotationItem*>(qi->parent()))->annotation;
             a->removeQualifier(qi->qName, qi->qValue);
             a->addQualifier(q);
-            AVQualifierItem* qi = ai->findQualifierItem(q.getQualifierName(), q.getQualifierValue());
+            AVQualifierItem* qi = ai->findQualifierItem(q.name, q.value);
             tree->setCurrentItem(qi);
             tree->scrollToItem(qi);
         }  
@@ -1529,8 +1650,8 @@ QString AnnotationsTreeView::renameDialogHelper(AVItem* i, const QString& defTex
     return edit->text();
 }
 
-bool AnnotationsTreeView::editQualifierDialogHelper(AVQualifierItem* i, bool ro, Qualifier& q) {
-    EditQualifierDialog d(this, Qualifier(i == NULL ? "new_qualifier" : i->qName , i == NULL ? "" : i->qValue), ro, i != NULL);
+bool AnnotationsTreeView::editQualifierDialogHelper(AVQualifierItem* i, bool ro, U2Qualifier& q) {
+    EditQualifierDialog d(this, U2Qualifier(i == NULL ? "new_qualifier" : i->qName , i == NULL ? "" : i->qValue), ro, i != NULL);
     moveDialogToItem(i == NULL ? tree->currentItem() : i, d);
     int rc = d.exec();
     q = d.getModifiedQualifier();
@@ -1550,18 +1671,16 @@ void AnnotationsTreeView::renameItem(AVItem* item) {
             && gi->group->getParentGroup()->getSubgroup(newName, false) == NULL) 
         {
             gi->group->setGroupName(newName);
+            gi->group->getGObject()->setModified(true);
             gi->updateVisual();
         }
     } else if (item->type == AVItemType_Annotation) {
         AVAnnotationItem* ai = static_cast<AVAnnotationItem*>(item);
-        QList<LRegion> l = ai->annotation->getLocation();
-        QString annName = ai->annotation->getAnnotationName();
-        bool isCompl = ai->annotation->isOnComplementStrand();
-        bool isOrder = ai->annotation->isOrder();
+        QVector<U2Region> l = ai->annotation->getRegions();
         QList<ADVSequenceObjectContext*> soList = ctx->findRelatedSequenceContexts(ai->annotation->getGObject());
         assert(soList.size() == 1);
         ADVSequenceObjectContext* so = soList.first();
-        LRegion seqRange = so->getSequenceObject()->getSequenceRange();
+        U2Region seqRange = so->getSequenceObject()->getSequenceRange();
         EditAnnotationDialogController dialog(ai->annotation, seqRange, this);
         moveDialogToItem(ai, dialog);
         int result = dialog.exec();
@@ -1575,12 +1694,13 @@ void AnnotationsTreeView::renameItem(AVItem* item) {
                     a->updateVisual(ATVAnnUpdateFlag_BaseColumns);
                 }
             }
-            QList<LRegion> newRegions = dialog.getRegionList();
-            if( !newRegions.isEmpty() && l != newRegions){
-                ai->annotation->replaceLocationRegions(newRegions);
+            U2Location location = dialog.getLocation();
+            if( !location->regions.isEmpty() && l != location->regions){
+                ai->annotation->replaceRegions(location->regions);
             }
-            ai->annotation->setOnComplementStrand(dialog.isComplement());                
-            ai->annotation->setOrder(dialog.isOrder());
+            ai->annotation->setLocationOperator(location->op);
+            ai->annotation->setStrand(location->strand);
+            ai->annotation->getGObject()->setModified(true);
         }
     } else {
         assert(item->type == AVItemType_Qualifier);
@@ -1592,6 +1712,7 @@ void AnnotationsTreeView::renameItem(AVItem* item) {
             QString val = qi->qValue;
             a->removeQualifier(qi->qName, val);
             a->addQualifier(newName, val);
+            a->getGObject()->setModified(true);
             AVQualifierItem* qi = ai->findQualifierItem(newName, val);
             tree->setCurrentItem(qi);
             tree->scrollToItem(qi);
@@ -1604,15 +1725,15 @@ void AnnotationsTreeView::sl_addQualifier() {
     if (item->isReadonly() || item->type == AVItemType_Group) {
         return;
     }
-    Qualifier q;
+    U2Qualifier q;
     bool ok = editQualifierDialogHelper(NULL, false, q);
     if (ok) {
-        assert(!q.getQualifierName().isEmpty());
+        assert(!q.name.isEmpty());
         AVAnnotationItem* ai = item->type == AVItemType_Annotation ? static_cast<AVAnnotationItem*>(item) : static_cast<AVAnnotationItem*>(item->parent());
         Annotation* a = ai->annotation;
         a->addQualifier(q);
         ai->setExpanded(true);
-        AVQualifierItem* qi = ai->findQualifierItem(q.getQualifierName(), q.getQualifierValue());
+        AVQualifierItem* qi = ai->findQualifierItem(q.name, q.value);
         tree->setCurrentItem(qi);
         tree->scrollToItem(qi);
     }
@@ -1746,16 +1867,22 @@ const QIcon& AVGroupItem::getDocumentIcon() {
 }
 
 void AVGroupItem::updateVisual() {
+    SAFE_POINT(group != NULL, "AVGroupItem created with NULL AnnotationGroup argument",);
     if (parent() == NULL) { // document item
         AnnotationTableObject* aobj  = group->getGObject();
-        QString docShortName = aobj->getDocument()->getName();
-        assert(!docShortName.isEmpty());
-        QString text = group->getGObject()->getGObjectName() + " ["+docShortName+"]";
-        if (aobj->isTreeItemModified()) { 
-            text+=" *";
+        Document* doc = aobj->getDocument();
+        QString text = aobj->getGObjectName();
+        if (doc != NULL ) {
+            QString docShortName = aobj->getDocument()->getName();
+            assert(!docShortName.isEmpty());
+            text = group->getGObject()->getGObjectName() + " ["+docShortName+"]";
+            if (aobj->isTreeItemModified()) { 
+                text+=" *";
+            }
         }
         setText(0, text);
         setIcon(0, getDocumentIcon());
+        GUIUtils::setMutedLnF(this, aobj->getAnnotations().count() == 0, false);
     } else { // usual groups with annotations
         int na = group->getAnnotations().size();
         int ng = group->getSubgroups().size();
@@ -1797,7 +1924,9 @@ void AVGroupItem::updateAnnotations(const QString& nameFilter, ATVAnnUpdateFlags
 
 bool AVGroupItem::isReadonly() const {
     //documents names are not editable
-    return group->getParentGroup() == NULL ? true: group->getGObject()->isStateLocked();
+    GObject* obj = group->getGObject();
+    bool readOnly = obj->isStateLocked() || AutoAnnotationsSupport::isAutoAnnotation(obj);
+    return group->getParentGroup() == NULL ? true : readOnly;
 }
 
 void AVGroupItem::findAnnotationItems(QList<AVAnnotationItem*>& result, Annotation* a) const {
@@ -1914,7 +2043,7 @@ bool AVAnnotationItem::operator<(const QTreeWidgetItem & other) const {
         if (name1 == name2) { 
             // for annotations with equal names we compare locations
             // this allows to avoid resorting on lazy qualifier loading
-            return annotation->getLocation().first() < ai.annotation->getLocation().first();
+            return annotation->getLocation()->regions[0] < ai.annotation->getLocation()->regions[0];
         }
         return name1 < name2;
     }
@@ -1941,7 +2070,7 @@ bool AVAnnotationItem::isColumnNumeric(int col) const {
 
 double AVAnnotationItem::getNumericVal(int col) const {
     if (col == 1) {
-        LRegion r = annotation->getLocation().first();
+        const U2Region& r = annotation->getLocation()->regions[0];
         return r.startPos;
     }
     bool ok  = false;
@@ -1950,10 +2079,10 @@ double AVAnnotationItem::getNumericVal(int col) const {
     return d;
 }
 
-void AVAnnotationItem::removeQualifier(const Qualifier& q) {
+void AVAnnotationItem::removeQualifier(const U2Qualifier& q) {
     for(int i=0, n = childCount(); i < n; i++) {
         AVQualifierItem* qi = static_cast<AVQualifierItem*>(child(i));
-        if (qi->qName == q.getQualifierName() && qi->qValue == q.getQualifierValue()) {
+        if (qi->qName == q.name && qi->qValue == q.value) {
             delete qi;
             break;
         }
@@ -1961,7 +2090,7 @@ void AVAnnotationItem::removeQualifier(const Qualifier& q) {
     updateVisual(ATVAnnUpdateFlag_QualColumns);
 }
 
-void AVAnnotationItem::addQualifier(const Qualifier& q) {
+void AVAnnotationItem::addQualifier(const U2Qualifier& q) {
     AVQualifierItem* qi = new AVQualifierItem(this, q); Q_UNUSED(qi);
     updateVisual(ATVAnnUpdateFlag_QualColumns);
 }
@@ -1977,8 +2106,8 @@ AVQualifierItem* AVAnnotationItem::findQualifierItem(const QString& name, const
     return NULL;
 }
 
-AVQualifierItem::AVQualifierItem(AVAnnotationItem* parent, const Qualifier& q) 
-: AVItem(parent, AVItemType_Qualifier), qName(q.getQualifierName()), qValue(q.getQualifierValue())
+AVQualifierItem::AVQualifierItem(AVAnnotationItem* parent, const U2Qualifier& q) 
+: AVItem(parent, AVItemType_Qualifier), qName(q.name), qValue(q.value)
 {
     setText(0, qName);
     setText(1, qValue);
