@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "DetView.h"
 #include "ADVSequenceObjectContext.h"
@@ -14,13 +25,14 @@
 #include <U2Core/DNAAlphabet.h>
 #include <U2Core/DNATranslation.h>
 #include <U2Core/AppContext.h>
+#include <U2Core/U2Annotation.h>
 
 #include <U2Core/DNATranslationImpl.h>
 
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/AnnotationTableObject.h>
 #include <U2Core/AnnotationSettings.h>
-#include <U2Core/AnnotationUtils.h>
+#include <U2Core/U2AnnotationUtils.h>
 
 #include <U2Core/DNASequenceSelection.h>
 #include <U2Misc/GraphUtils.h>
@@ -32,6 +44,8 @@
 #include <QtGui/QFontMetrics>
 #include <QtGui/QMenu>
 #include <QtGui/QApplication>
+#include <QtGui/QLayout>
+#include <QtGui/QMessageBox>
 
 
 namespace U2 {
@@ -63,6 +77,7 @@ DetView::DetView(QWidget* p, ADVSequenceObjectContext* ctx)
     renderArea->setObjectName("render_area");
 
     connect(ctx, SIGNAL(si_aminoTranslationChanged()), SLOT(sl_onAminoTTChanged()));
+    connect(ctx, SIGNAL(si_translationRowsChanged()), SLOT(sl_translationRowsChanged()));
 
     connect(ctx->getSequenceGObject(), SIGNAL(si_sequenceChanged()), this, SLOT(sl_sequenceChanged()));
 
@@ -74,7 +89,7 @@ DetView::DetView(QWidget* p, ADVSequenceObjectContext* ctx)
 void DetView::updateSize() {
     DetViewRenderArea* detArea = (static_cast<DetViewRenderArea*>(renderArea));
     detArea->updateSize();
-    setFixedHeight(detArea->height() + scrollBar->height());
+    setFixedHeight(layout()->minimumSize().height());
 }
 
 void DetView::resizeEvent(QResizeEvent *e) { 
@@ -84,9 +99,9 @@ void DetView::resizeEvent(QResizeEvent *e) {
     
     if (visibleSymbolsCount > seqLen) {
         visibleRange.startPos = 0;
-        visibleRange.len = seqLen;
+        visibleRange.length = seqLen;
     } else {
-        visibleRange.len = visibleSymbolsCount;
+        visibleRange.length = visibleSymbolsCount;
         if (visibleRange.endPos() > seqLen) {
             visibleRange.startPos = seqLen - visibleSymbolsCount;
         }
@@ -144,6 +159,9 @@ void DetView::setShowComplement(bool t) {
 void DetView::setShowTranslation(bool t) {
     showTranslationAction->disconnect(this);
     showTranslationAction->setChecked(t);
+    if(!t){
+        getSequenceContext()->setTranslationsVisible(t);
+    }
     connect(showTranslationAction, SIGNAL(triggered(bool)), SLOT(sl_showTranslationToggle(bool)));
 
     updateSize();
@@ -159,7 +177,7 @@ void DetView::mouseReleaseEvent(QMouseEvent* me) {
         if ((static_cast<DetViewRenderArea*>(renderArea))->isOnTranslationsLine(areaPoint.y())) {
             int pos = renderArea->coordToPos(areaPoint.x());
             if (pos == lastPressPos) {
-                LRegion rgn(pos-1, 3);
+                U2Region rgn(pos-1, 3);
                 if (rgn.startPos >=0 && rgn.endPos() <= seqLen) {
                     setSelection(rgn);
                     lastPressPos=-1;
@@ -176,21 +194,47 @@ void DetView::sl_sequenceChanged(){
     int charWidth = renderArea->getCharWidth();
     int visibleSymbolsCount = w / charWidth;
     if(seqLen > visibleSymbolsCount){
-        if((visibleRange.len != visibleSymbolsCount) || (visibleRange.endPos() > seqLen)){
-            visibleRange.len = visibleSymbolsCount;
+        if((visibleRange.length != visibleSymbolsCount) || (visibleRange.endPos() > seqLen)){
+            visibleRange.length = visibleSymbolsCount;
             if(visibleRange.endPos() > visibleSymbolsCount){
                 visibleRange.startPos = seqLen - visibleSymbolsCount;
             }
             onVisibleRangeChanged(true);
         }
     }else{
-        visibleRange.len = seqLen;
+        visibleRange.length = seqLen;
         onVisibleRangeChanged(true);
     }
     GSequenceLineView::sl_sequenceChanged();
 }
 
+void DetView::sl_translationRowsChanged(){
+    QVector<bool> visibleRows = getSequenceContext()->getTranslationRowsVisibleStatus();
+    bool anyFrame = false;
+    foreach(bool b, visibleRows){
+        anyFrame = anyFrame || b;
+    }
+    if(!anyFrame){
+        if(showTranslationAction->isChecked()){
+            sl_showTranslationToggle(false);
+        }
+        return;
+    }
+    if(!showTranslationAction->isChecked()){
+        sl_showTranslationToggle(true);
+    }
 
+    updateScrollBar();
+    updateSize();
+    completeUpdate();
+}
+
+void DetView::sl_showTranslationToggle( bool v ){
+    showTranslationAction->setChecked(v);
+    getSequenceContext()->setTranslationsVisible(v);
+    updateSize();
+    //setShowTranslation(v);
+}
 //////////////////////////////////////////////////////////////////////////
 /// render
 DetViewRenderArea::DetViewRenderArea(DetView* v) : GSequenceLineViewAnnotatedRenderArea(v, true) {
@@ -210,21 +254,21 @@ void DetViewRenderArea::updateLines() {
         baseLine = 0;
         rulerLine = 1;
         numLines = 2;
-    } else if (detView->hasComplementStrand() && detView->hasTranslations()) {
+    } else if (detView->hasComplementaryStrand() && detView->hasTranslations()) {
         firstDirectTransLine = 0;
         baseLine = 3;
         rulerLine = 4;
         complementLine = 5;
         firstComplTransLine = 6;
         numLines = 9;
-    } else if (detView->hasComplementStrand()) {
+    } else if (detView->hasComplementaryStrand()) {
         assert(!detView->hasTranslations());
         baseLine = 0;
         rulerLine = 1;
         complementLine = 2;
         numLines = 3;
     } else {
-        assert(!detView->hasComplementStrand() && detView->hasTranslations());
+        assert(!detView->hasComplementaryStrand() && detView->hasTranslations());
         firstDirectTransLine = 0;
         baseLine = 3;
         rulerLine = 4;
@@ -233,14 +277,14 @@ void DetViewRenderArea::updateLines() {
     assert(numLines > 0);
 }
 
-LRegion DetViewRenderArea::getAnnotationYRange(Annotation* a, int region, const AnnotationSettings* as) const {
-    bool complement = a->isOnComplementStrand() && getDetView()->hasComplementStrand();
-    TriState aminoState = a->getAminoFrame();
+U2Region DetViewRenderArea::getAnnotationYRange(Annotation* a, int region, const AnnotationSettings* as) const {
+    bool complement = a->getStrand().isCompementary() && getDetView()->hasComplementaryStrand();
+    TriState aminoState = TriState_Unknown; //a->getAminoFrame();
     if (aminoState == TriState_Unknown) {
         aminoState = as->amino ? TriState_Yes : TriState_No;
     }
     bool transl = getDetView()->hasTranslations() && aminoState == TriState_Yes;
-    int frame = AnnotationUtils::getRegionFrame(view->getSequenceLen(), complement, a->isOrder(), region, a->getLocation());
+    int frame = U2AnnotationUtils::getRegionFrame(view->getSequenceLen(), a->getStrand(), a->isOrder(), region, a->getRegions());
     int line = -1;
     if (complement) {
         if (transl) {
@@ -257,18 +301,18 @@ LRegion DetViewRenderArea::getAnnotationYRange(Annotation* a, int region, const
     }
     assert(line!=-1);
     int y = getLineY(line);
-    return LRegion(y, lineHeight);
+    return U2Region(y, lineHeight);
 }
 
 bool DetViewRenderArea::isOnTranslationsLine(int y) const {
     if (firstDirectTransLine != -1) {
-        LRegion dtr(getLineY(firstDirectTransLine), 3*lineHeight);
+        U2Region dtr(getLineY(firstDirectTransLine), 3*lineHeight);
         if (dtr.contains(y)) {
             return true;
         }
     }
     if (firstComplTransLine !=-1) {
-        LRegion ctr(getLineY(firstComplTransLine), 3*lineHeight);
+        U2Region ctr(getLineY(firstComplTransLine), 3*lineHeight);
         if (ctr.contains(y)) {
             return true;
         }
@@ -321,15 +365,15 @@ void DetViewRenderArea::drawDirect(QPainter& p) {
     p.setFont(sequenceFont);
     p.setPen(Qt::black);
 
-    const LRegion visibleRange = view->getVisibleRange();
-    assert(visibleRange.len * charWidth <= width());
+    const U2Region visibleRange = view->getVisibleRange();
+    assert(visibleRange.length * charWidth <= width());
 
     const QByteArray& sequence = view->getSequenceContext()->getSequenceData();
     const char* seq = sequence.data() + visibleRange.startPos;
 
     /// draw base line;
     int y = getTextY(baseLine);
-    for(int i=0;i < visibleRange.len; i++) {
+    for(int i = 0; i < visibleRange.length; i++) {
         char nucl = seq[i];
         p.drawText(i*charWidth + xCharOffset, y, QString(nucl));
     }
@@ -341,7 +385,7 @@ void DetViewRenderArea::drawComplement(QPainter& p) {
 
     DetView* detView = getDetView();
     if (complementLine > 0) {
-        const LRegion visibleRange = detView->getVisibleRange();
+        const U2Region visibleRange = detView->getVisibleRange();
 
         const QByteArray& sequence = detView->getSequenceContext()->getSequenceData();
         const char* seq = sequence.data() + detView->getVisibleRange().startPos;
@@ -349,7 +393,7 @@ void DetViewRenderArea::drawComplement(QPainter& p) {
         DNATranslation* complTrans = detView->getComplementTT();
         QByteArray map = complTrans->getOne2OneMapper();
         int y = getTextY(complementLine);
-        for(int i=0;i< visibleRange.len; i++) {
+        for(int i=0;i< visibleRange.length; i++) {
             char nucl = seq[i];
             char complNucl = map.at(nucl);
             p.drawText(i*charWidth + xCharOffset, y, QString(complNucl));
@@ -376,10 +420,10 @@ void DetViewRenderArea::drawTranslations(QPainter& p) {
     assert(aminoTable!=NULL && aminoTable->isThree2One());
 
     const QByteArray& sequence = detView->getSequenceContext()->getSequenceData();
-    const LRegion& visibleRange  = detView->getVisibleRange();
+    const U2Region& visibleRange  = detView->getVisibleRange();
 
-    int maxUsablePos = qMin(visibleRange.endPos() + 1, sequence.length());
-    int minUsablePos = qMax(visibleRange.startPos - 1, 0);
+    qint64 maxUsablePos = qMin(visibleRange.endPos() + 1, qint64(sequence.length()));
+    qint64 minUsablePos = qMax(visibleRange.startPos - 1, qint64(0));
 
     QColor startC(0,0x99,0);
     QColor stopC(0x99,0,0);
@@ -417,11 +461,11 @@ void DetViewRenderArea::drawTranslations(QPainter& p) {
             for(int j = 0, n = amino.length(); j < n ; j++, dnaSeq += 3) {
                 char amin = amino[j];
                 int xpos = 3 * j + 1 + dx;
-                assert(xpos >= 0 && xpos < visibleRange.len);
+                assert(xpos >= 0 && xpos < visibleRange.length);
                 int x =  xpos * charWidth + xCharOffset;
 
                 QColor charColor;
-                bool inAnnotation = deriveTranslationCharColor(dnaSeq - seqStart, false, annotationsInRange, charColor);
+                bool inAnnotation = deriveTranslationCharColor(dnaSeq - seqStart, U2Strand::Direct, annotationsInRange, charColor);
 
                 if (aminoTable->isStartCodon(dnaSeq)) {
                     p.setPen(inAnnotation ? charColor : startC);
@@ -440,7 +484,7 @@ void DetViewRenderArea::drawTranslations(QPainter& p) {
             }
         }
     }
-    if (detView->hasComplementStrand()) {//reverse translations
+    if (detView->hasComplementaryStrand()) {//reverse translations
         DNATranslation* complTable = detView->getComplementTT();
         assert(complTable!=NULL);
         int seqLen = sequence.length();
@@ -465,13 +509,13 @@ void DetViewRenderArea::drawTranslations(QPainter& p) {
             int dx = visibleRange.endPos() - revComplStartPos;
             for(int j = 0, n = amino.length(); j < n ; j++, dnaSeq +=3) {
                 char amin = amino[j];
-                int xpos = visibleRange.len - (3 * j + 2 + dx);
-                assert(xpos >= 0 && xpos < visibleRange.len);
+                int xpos = visibleRange.length - (3 * j + 2 + dx);
+                assert(xpos >= 0 && xpos < visibleRange.length);
                 int x =  xpos * charWidth + xCharOffset;
 
                 QColor charColor;
                 bool inAnnotation = deriveTranslationCharColor(maxUsablePos - (dnaSeq - revComplDna.constData()), 
-                    true, annotationsInRange, charColor);
+                    U2Strand::Complementary, annotationsInRange, charColor);
 
                 if (aminoTable->isStartCodon(dnaSeq)) {
                     p.setPen(inAnnotation ? charColor : startC);
@@ -494,7 +538,7 @@ void DetViewRenderArea::drawTranslations(QPainter& p) {
     p.setFont(sequenceFont);
 }
 
-bool DetViewRenderArea::deriveTranslationCharColor(int pos, bool complement, QList<Annotation*> annotationsInRange, QColor& result) {
+bool DetViewRenderArea::deriveTranslationCharColor(int pos, U2Strand strand, QList<Annotation*> annotationsInRange, QColor& result) {
     // logic:
     // no annotations found -> grey
     // found annotation that is on translation -> black
@@ -502,25 +546,24 @@ bool DetViewRenderArea::deriveTranslationCharColor(int pos, bool complement, QLi
     // 2+ annotations found on nucleic -> black
 
     int nAnnotations = 0;
-    Annotation* annotation;
-    LRegion tripletRange = complement ? LRegion(pos - 2, 2) : LRegion(pos, 2);
+    U2Region tripletRange = strand == U2Strand::Complementary ? U2Region(pos - 2, 2) : U2Region(pos, 2);
     AnnotationSettings* as = NULL;
     int sequenceLen = view->getSequenceLen();
     foreach (Annotation* a, annotationsInRange) {
-        if (a->isOnComplementStrand() != complement) {
+        if (a->getStrand() != strand) {
             continue;            
         }
         bool annotationOk = false;
         AnnotationSettings *tas = NULL;
         bool order = a->isOrder();
-        const QList<LRegion>& location = a->getLocation();
-        for (int i = 0, n = location.length(); i < n; i++) {
-            const LRegion& r = location.at(i);
+        const QVector<U2Region>& location = a->getRegions();
+        for (int i = 0, n = location.size(); i < n; i++) {
+            const U2Region& r = location.at(i);
             if (!r.contains(tripletRange)) {
                 continue;
             }
-            int regionFrame = AnnotationUtils::getRegionFrame(sequenceLen, complement, order, i, location);
-            int posFrame = complement ? (sequenceLen - pos) % 3 : (pos % 3);
+            int regionFrame = U2AnnotationUtils::getRegionFrame(sequenceLen, strand, order, i, location);
+            int posFrame = strand == U2Strand::Complementary ? (sequenceLen - pos) % 3 : (pos % 3);
             if (regionFrame ==  posFrame) {
                 tas = AppContext::getAnnotationsSettingsRegistry()->getAnnotationSettings(a);
                 if (tas->visible){
@@ -531,7 +574,6 @@ bool DetViewRenderArea::deriveTranslationCharColor(int pos, bool complement, QLi
         }
         if (annotationOk) {
             nAnnotations++;
-            annotation = a;
             as = tas;
             if (nAnnotations > 1) {
                 break;
@@ -548,7 +590,7 @@ bool DetViewRenderArea::deriveTranslationCharColor(int pos, bool complement, QLi
         result == Qt::black;
         return true;
     }
-    TriState aminoState = annotation->getAminoFrame();
+    TriState aminoState = TriState_Unknown; //annotation->getAminoFrame();
     if (aminoState == TriState_Unknown) {
         aminoState = as->amino ? TriState_Yes : TriState_No;
     }
@@ -571,15 +613,15 @@ void DetViewRenderArea::drawSequenceSelection(QPainter& p) {
     QPen pen1(Qt::black, 1, Qt::DashLine);
     p.setPen(pen1);
 
-    foreach(const LRegion& r, sel->getSelectedRegions()) {
+    foreach(const U2Region& r, sel->getSelectedRegions()) {
         highlight(p, r, baseLine);
-        if (detView->hasComplementStrand()) {
+        if (detView->hasComplementaryStrand()) {
             highlight(p, r, complementLine);
         }
         if (detView->hasTranslations()) {
             int translLine = posToDirectTransLine(r.startPos);
             highlight(p, r, translLine);
-            if (detView->hasComplementStrand()) {
+            if (detView->hasComplementaryStrand()) {
                 int complTransLine = posToComplTransLine(r.endPos());
                 highlight(p, r, complTransLine);
             }
@@ -589,7 +631,7 @@ void DetViewRenderArea::drawSequenceSelection(QPainter& p) {
 
 void DetViewRenderArea::drawRuler(QPainter& p) {
     int y = getLineY(rulerLine) + 2;
-    const LRegion& visibleRange = view->getVisibleRange();
+    const U2Region& visibleRange = view->getVisibleRange();
     int firstCharStart = posToCoord(visibleRange.startPos);
     int lastCharStart = posToCoord(visibleRange.endPos()-1);
     int firstCharCenter = firstCharStart + charWidth / 2;
@@ -610,12 +652,12 @@ int DetViewRenderArea::posToComplTransLine(int p) const {
 }
 
 
-void DetViewRenderArea::highlight(QPainter& p, const LRegion& r, int line) {
-    const LRegion& visibleRange = view->getVisibleRange();
+void DetViewRenderArea::highlight(QPainter& p, const U2Region& r, int line) {
+    const U2Region& visibleRange = view->getVisibleRange();
     if (!visibleRange.intersects(r)) {
         return;
     }
-    LRegion visibleRegion = visibleRange.intersect(r);
+    U2Region visibleRegion = visibleRange.intersect(r);
     int x = posToCoord(visibleRegion.startPos);
     int width = posToCoord(visibleRegion.endPos()) - x;
 
@@ -626,7 +668,7 @@ void DetViewRenderArea::highlight(QPainter& p, const LRegion& r, int line) {
 }
 
 int DetViewRenderArea::coordToPos(int x) const {
-    LRegion visibleRange = view->getVisibleRange();
+    U2Region visibleRange = view->getVisibleRange();
         int pos = visibleRange.startPos + int(x / (float)charWidth + 0.5f);
     if (pos > visibleRange.endPos()) {
         pos = visibleRange.endPos();
@@ -635,7 +677,7 @@ int DetViewRenderArea::coordToPos(int x) const {
 }
 
 float DetViewRenderArea::posToCoordF(int x, bool useVirtualSpace) const {
-    const LRegion& visible = view->getVisibleRange();
+    const U2Region& visible = view->getVisibleRange();
     if (!useVirtualSpace && !visible.contains(x) && visible.endPos()!=x) {
         return -1;
     }
