@@ -1,22 +1,35 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "GSequenceLineView.h"
 
 #include "ADVSequenceObjectContext.h"
 
-#include <U2Gui/ObjectViewModel.h>
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/DNASequenceSelection.h>
+#include <U2Core/U2SafePoints.h>
+
 #include <U2Misc/GScrollBar.h>
 
+#include <U2Gui/ObjectViewModel.h>
 #include <QtGui/QTextEdit>
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QApplication>
@@ -33,11 +46,10 @@ frameView(NULL), coherentRangeView(NULL), ignoreMouseSelectionEvents(false)
     setFocusPolicy(Qt::WheelFocus);
 
     scrollBar = new GScrollBar(Qt::Horizontal, this);
-    scrollBar->setFixedHeight(18);
-
+    
     connect(ctx->getSequenceSelection(),
-        SIGNAL(si_selectionChanged(LRegionsSelection*, const QList<LRegion>&, const QList<LRegion>&)),
-        SLOT(sl_onDNASelectionChanged(LRegionsSelection*, const QList<LRegion>& , const QList<LRegion>&)));
+        SIGNAL(si_selectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)),
+        SLOT(sl_onDNASelectionChanged(LRegionsSelection*, const QVector<U2Region>& , const QVector<U2Region>&)));
 }
 
 void GSequenceLineView::pack() {
@@ -49,7 +61,7 @@ void GSequenceLineView::pack() {
     layout->addWidget(scrollBar);
     setLayout(layout);
 
-    setFixedHeight(renderArea->height() + scrollBar->height());
+    setFixedHeight(layout->minimumSize().height());
 }
 
 void GSequenceLineView::resizeEvent(QResizeEvent *e) { 
@@ -62,7 +74,7 @@ void GSequenceLineView::updateScrollBar() {
     scrollBar->disconnect(this);
 
     scrollBar->setMinimum(0);
-    scrollBar->setMaximum(seqLen - visibleRange.len);
+    scrollBar->setMaximum(seqLen - visibleRange.length);
     scrollBar->setSliderPosition(visibleRange.startPos);
 
     //todo:
@@ -72,7 +84,7 @@ void GSequenceLineView::updateScrollBar() {
     scrollBar->setSingleStep(singleStep);
     scrollBar->setPageStep(pageStep);
 
-    scrollBar->setDisabled(visibleRange.len == seqLen);
+    scrollBar->setDisabled(visibleRange.length == seqLen);
 
     connect(scrollBar, SIGNAL(valueChanged(int)), SLOT(sl_onScrollBarMoved(int)));
 }
@@ -88,7 +100,7 @@ int GSequenceLineView::getPageStep() const {
     if (coherentRangeView !=NULL) {
         return coherentRangeView->getPageStep();
     }
-    return visibleRange.len;
+    return visibleRange.length;
 }
 
 void GSequenceLineView::sl_onScrollBarMoved(int pos) {
@@ -103,33 +115,33 @@ void GSequenceLineView::sl_onScrollBarMoved(int pos) {
         if (aAction == QAbstractSlider::SliderSingleStepAdd) {
             int selStart = qMin(lastPressPos, visibleRange.endPos());
             int selEnd = qMax(lastPressPos, visibleRange.endPos());
-            setSelection(LRegion(selStart, selEnd - selStart));
+            setSelection(U2Region(selStart, selEnd - selStart));
         } else if (aAction == QAbstractSlider::SliderSingleStepSub) {
             int selStart = qMin(lastPressPos, visibleRange.startPos);
             int selEnd = qMax(lastPressPos, visibleRange.startPos);
-            setSelection(LRegion(selStart, selEnd - selStart));
+            setSelection(U2Region(selStart, selEnd - selStart));
         }
     }
 }
 
-void GSequenceLineView::setSelection(const LRegion& r) {
-    assert(r.startPos >=0 && r.endPos() <= seqLen);
+void GSequenceLineView::setSelection(const U2Region& r) {
+    SAFE_POINT(r.startPos >=0 && r.endPos() <= seqLen, QString("Selection is out of range! [%2, len: %3]").arg(r.startPos).arg(r.length),);
     ctx->getSequenceSelection()->clear();
-    if (r.len!=0) {
+    if (r.length!=0) {
         ctx->getSequenceSelection()->addRegion(r);
     }
 }
 
-void GSequenceLineView::addSelection(const LRegion& r) {
-    assert(r.startPos >=0 && r.endPos() <= seqLen);
-    if (r.len!=0) {
+void GSequenceLineView::addSelection(const U2Region& r) {
+    SAFE_POINT(r.startPos >=0 && r.endPos() <= seqLen, QString("Selection is out of range! [%2, len: %3]").arg(r.startPos).arg(r.length),);
+    if (r.length!=0) {
         ctx->getSequenceSelection()->addRegion(r);
     }
 }
 
-void GSequenceLineView::removeSelection(const LRegion& r) {
-    assert(r.startPos >=0 && r.endPos() <= seqLen);
-    if (r.len!=0) {
+void GSequenceLineView::removeSelection(const U2Region& r) {
+    SAFE_POINT(r.startPos >=0 && r.endPos() <= seqLen, QString("Selection is out of range! [%2, len: %3]").arg(r.startPos).arg(r.length),);
+    if (r.length!=0) {
         ctx->getSequenceSelection()->removeRegion(r);
     }
 }
@@ -152,7 +164,8 @@ void GSequenceLineView::mousePressEvent(QMouseEvent* me) {
     }
 
     lastPressPos = renderArea->coordToPos(renderAreaPos.x());
-    assert(lastPressPos >= visibleRange.startPos && lastPressPos <= visibleRange.endPos());
+
+    SAFE_POINT(lastPressPos >= visibleRange.startPos && lastPressPos <= visibleRange.endPos(), "Last mouse press position is out of visible range!",);
 
     if (!ignoreMouseSelectionEvents) {
         ctx->getSequenceSelection()->clear();
@@ -173,7 +186,7 @@ void GSequenceLineView::mouseReleaseEvent(QMouseEvent* me) {
             QPoint areaPoint = toRenderAreaPoint(me->pos());
             int pos = renderArea->coordToPos(areaPoint.x());
             if (pos == lastPressPos) {
-                LRegion rgn(pos, 1);
+                U2Region rgn(pos, 1);
                 if (rgn.startPos >=0 && rgn.endPos() <= seqLen) {
                     setSelection(rgn);
                 }
@@ -204,16 +217,16 @@ void GSequenceLineView::mouseMoveEvent(QMouseEvent* me) {
         }
         
         // compute selection
-        int pos = renderArea->coordToPos(areaPoint.x());
-        int selStart = qMin(lastPressPos, pos);
-        int selLen = qAbs(pos - lastPressPos);
+        qint64 pos = renderArea->coordToPos(areaPoint.x());
+        qint64 selStart = qMin(lastPressPos, pos);
+        qint64 selLen = qAbs(pos - lastPressPos);
         if (selStart<0) {
             selLen+=selStart;
             selStart=0;
         } else if (selStart + selLen > seqLen) {
             selLen = seqLen - selStart;
         }
-        setSelection(LRegion(selStart, selLen));
+        setSelection(U2Region(selStart, selLen));
 
     }
     QWidget::mouseMoveEvent(me);
@@ -235,7 +248,7 @@ void GSequenceLineView::keyPressEvent(QKeyEvent *e) {
     switch(key) {
         case Qt::Key_Left:
         case Qt::Key_Up:
-            view->setStartPos(qMax(0, visibleRange.startPos - 1));
+            view->setStartPos(qMax(qint64(0), visibleRange.startPos - 1));
             accepted = true;
             break;
         case Qt::Key_Right:
@@ -268,15 +281,16 @@ void GSequenceLineView::keyPressEvent(QKeyEvent *e) {
 }
 
 void GSequenceLineView::setCenterPos(int centerPos) {
-    assert(centerPos <= seqLen && centerPos >= 0);
-    int newPos = qMax(0, centerPos - visibleRange.len/2);
+    SAFE_POINT(centerPos <= seqLen && centerPos >= 0, QString("Center pos is out of sequence range! value: %1").arg(centerPos),);
+
+    int newPos = qMax(qint64(0), centerPos - visibleRange.length/2);
     setStartPos(newPos);
 }
 
 
 void GSequenceLineView::setStartPos(int newPos) {
-    if (newPos + visibleRange.len > seqLen) {
-        newPos = seqLen - visibleRange.len;
+    if (newPos + visibleRange.length > seqLen) {
+        newPos = seqLen - visibleRange.length;
     }
     if (newPos < 0) {
         newPos = 0;
@@ -327,10 +341,8 @@ void GSequenceLineView::wheelEvent(QWheelEvent *we) {
     } 
 }
 
-void GSequenceLineView::sl_onDNASelectionChanged(LRegionsSelection* s, const QList<LRegion>& added, const QList<LRegion>& removed) {
-    Q_UNUSED(s);
-
-    if (visibleRange.intersectsWithAny(added) || visibleRange.intersectsWithAny(removed)) {
+void GSequenceLineView::sl_onDNASelectionChanged(LRegionsSelection*, const QVector<U2Region>& added, const QVector<U2Region>& removed) {
+    if (visibleRange.intersects(added) || visibleRange.intersects(removed)) {
         addUpdateFlags(GSLV_UF_SelectionChanged);
         update();
     }
@@ -349,7 +361,7 @@ void GSequenceLineView::focusOutEvent(QFocusEvent* fe) {
 bool GSequenceLineView::eventFilter(QObject *object, QEvent *event) {
     if (object == frameView) {
         // show-hide frame on frameView show/hide event
-        if (isVisible() && event->type() == QEvent::Show || event->type() == QEvent::Hide) {
+        if ((isVisible() && event->type() == QEvent::Show) || event->type() == QEvent::Hide) {
             if (visibleRange.contains(frameView->getVisibleRange())) {
                 addUpdateFlags(GSLV_UF_FrameChanged);
                 update();
@@ -361,7 +373,8 @@ bool GSequenceLineView::eventFilter(QObject *object, QEvent *event) {
 
 
 void GSequenceLineView::setFrameView(GSequenceLineView* _frameView) {
-    assert((frameView == NULL) != (_frameView==NULL));
+    SAFE_POINT((frameView == NULL) != (_frameView==NULL), "Failed to set frame view!",);
+
     if (_frameView == NULL) {
         frameView->disconnect(this);
         frameView->removeEventFilter(this);
@@ -373,8 +386,8 @@ void GSequenceLineView::setFrameView(GSequenceLineView* _frameView) {
     connect(frameView, SIGNAL(si_visibleRangeChanged()), SLOT(sl_onFrameRangeChanged()));
 }
 
-void GSequenceLineView::setConherentRangeView(GSequenceLineView* _rangeView) {
-    assert((coherentRangeView == NULL) != (_rangeView==NULL));
+void GSequenceLineView::setCoherentRangeView(GSequenceLineView* _rangeView) {
+    SAFE_POINT((coherentRangeView == NULL) != (_rangeView==NULL), "Failed to set coherent view!",);
     if (_rangeView == NULL) {
         coherentRangeView->disconnect(this);
         coherentRangeView = NULL;
@@ -389,25 +402,25 @@ void GSequenceLineView::setConherentRangeView(GSequenceLineView* _rangeView) {
 void GSequenceLineView::sl_onFrameRangeChanged() {
     //todo: optimize and do not redraw frame if visual coords of the frame are not changed!
 #ifdef _DEBUG
-    const LRegion& newRange = frameView->getVisibleRange();
-    assert(newRange.startPos >= 0 && newRange.endPos() <= ctx->getSequenceObject()->getSequenceLen() && newRange.len >= 0);
+    const U2Region& newRange = frameView->getVisibleRange();
+    assert(newRange.startPos >= 0 && newRange.endPos() <= ctx->getSequenceObject()->getSequenceLen() && newRange.length >= 0);
 #endif
     addUpdateFlags(GSLV_UF_FrameChanged);
     update();
 }
 
 void GSequenceLineView::sl_onCoherentRangeViewRangeChanged() {
-    const LRegion& newRange = coherentRangeView->getVisibleRange();
+    const U2Region& newRange = coherentRangeView->getVisibleRange();
     if (newRange == visibleRange) {
         return;
     }
     setVisibleRange(newRange);
 }
 
-void GSequenceLineView::setVisibleRange(const LRegion& newRange, bool signal) {
-    assert(newRange.startPos >=0 && newRange.endPos()<=seqLen);
+void GSequenceLineView::setVisibleRange(const U2Region& newRange, bool signal) {
+    SAFE_POINT(newRange.startPos >=0 && newRange.endPos() <= seqLen, "Failed to update visible range. Range is out of the sequence range!",);
     
-    if (newRange==visibleRange) {
+    if (newRange == visibleRange) {
         return;
     }
     if (featureFlags.testFlag(GSLV_FF_SupportsCustomRange)) {
@@ -432,6 +445,11 @@ void GSequenceLineView::sl_sequenceChanged(){
     completeUpdate();
 }
 
+const U2Region& GSequenceLineView::getSequenceRange() const
+{
+    return ctx->getSequenceObject()->getSequenceRange();
+}
+
 //////////////////////////////////////////////////////////////////////////
 /// GSequenceLineViewRenderArea
 
@@ -477,18 +495,18 @@ void GSequenceLineViewRenderArea::drawFrame(QPainter& p) {
     if (frameView == NULL || !frameView->isVisible()) {
         return;
     }
-    const LRegion& frameRange = frameView->getVisibleRange();
-    if (frameRange.len == 0) {
+    const U2Region& frameRange = frameView->getVisibleRange();
+    if (frameRange.length == 0) {
         return;
     }
-    const LRegion& visibleRange = view->getVisibleRange();
-    LRegion visibleFrameRange = visibleRange.intersect(frameRange);
+    const U2Region& visibleRange = view->getVisibleRange();
+    U2Region visibleFrameRange = visibleRange.intersect(frameRange);
     if (visibleFrameRange.isEmpty()) {
         return;
     }
     float scale = getCurrentScale();
     int xStart = (int) ( scale * (visibleFrameRange.startPos - visibleRange.startPos) );
-    int xLen = qMax((int)(scale * visibleFrameRange.len), 4);
+    int xLen = qMax((int)(scale * visibleFrameRange.length), 4);
     QPen pen(Qt::lightGray, 2, Qt::DashLine);
     p.setPen(pen);
     p.drawRect(xStart, 0, xLen, height());
@@ -513,13 +531,13 @@ void GSequenceLineViewRenderArea::paintEvent(QPaintEvent *e) {
 }
 
 float GSequenceLineViewRenderArea::getCurrentScale() const {
-    return float(width()) / view->getVisibleRange().len;
+    return float(width()) / view->getVisibleRange().length;
 }
 
 
 int GSequenceLineViewRenderArea::coordToPos(int _x) const {
     int x = qBound(0, _x, width());
-    const LRegion& vr = view->getVisibleRange();
+    const U2Region& vr = view->getVisibleRange();
     float scale = getCurrentScale();
     int pos = vr.startPos + int(x/scale+0.5f);
     assert(pos >= vr.startPos && pos <= vr.endPos());
@@ -527,7 +545,7 @@ int GSequenceLineViewRenderArea::coordToPos(int _x) const {
 }
 
 float GSequenceLineViewRenderArea::posToCoordF(int p, bool useVirtualSpace) const {
-    const LRegion& visibleRange = view->getVisibleRange();
+    const U2Region& visibleRange = view->getVisibleRange();
     if (!useVirtualSpace && !visibleRange.contains(p) && p!=visibleRange.endPos()) {
         return -1;
     }
