@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "GSequenceLineViewAnnotated.h"
 #include "ADVSequenceObjectContext.h"
@@ -15,10 +26,12 @@
 #include <U2Core/Timer.h>
 #include <U2Core/AnnotationTableObject.h>
 #include <U2Core/AnnotationSettings.h>
+#include <U2Core/U2AnnotationUtils.h>
 #include <U2Core/DNASequenceSelection.h>
 #include <U2Gui/GUIUtils.h>
 #include <U2Core/AnnotationData.h>
 #include <U2Formats/GenbankFeatures.h>
+#include <U2Formats/GenbankLocationParser.h>
 
 #include <QtGui/QMenu>
 #include <QtGui/QToolTip>
@@ -35,7 +48,8 @@ namespace U2 {
 GSequenceLineViewAnnotated::GSequenceLineViewAnnotated(QWidget* p, ADVSequenceObjectContext* ctx) 
 : GSequenceLineView(p, ctx)
 {
-    foreach(AnnotationTableObject* ao, ctx->getAnnotationObjects()) {
+    const QSet<AnnotationTableObject*> aObjs = ctx->getAnnotationObjects(true);
+    foreach(AnnotationTableObject* ao, aObjs) {
         connectAnnotationObject(ao);
     }
     connect(ctx->getAnnotationsSelection(),
@@ -54,6 +68,8 @@ GSequenceLineViewAnnotated::GSequenceLineViewAnnotated(QWidget* p, ADVSequenceOb
 void GSequenceLineViewAnnotated::connectAnnotationObject(AnnotationTableObject* ao) {
     connect(ao, SIGNAL(si_onAnnotationsAdded(const QList<Annotation*>&)), SLOT(sl_onAnnotationsAdded(const QList<Annotation*>&)));
     connect(ao, SIGNAL(si_onAnnotationsRemoved(const QList<Annotation*>&)), SLOT(sl_onAnnotationsRemoved(const QList<Annotation*>&)));
+    connect(ao, SIGNAL(si_onAnnotationsInGroupRemoved(const QList<Annotation*>&, AnnotationGroup*)), 
+        SLOT(sl_onAnnotationsInGroupRemoved(const QList<Annotation*>&, AnnotationGroup*)));
     connect(ao, SIGNAL(si_onAnnotationModified(const AnnotationModification&)), SLOT(sl_onAnnotationsModified(const AnnotationModification&)));
 }
 
@@ -86,8 +102,29 @@ void GSequenceLineViewAnnotated::sl_onAnnotationsRemoved(const QList<Annotation*
     update();
 }
 
+void GSequenceLineViewAnnotated::sl_onAnnotationsInGroupRemoved(const QList<Annotation*>& l, AnnotationGroup*) {
+    /*unregisterAnnotations(l);
+    addUpdateFlags(GSLV_UF_AnnotationsChanged);
+    update();*/
+    AnnotationTableObject *aobj = static_cast<AnnotationTableObject*>(sender());
+   // aobj->releaseLocker();
+    ClearAnnotationsTask *task = new ClearAnnotationsTask(l, aobj, this);
+    AppContext::getTaskScheduler()->registerTopLevelTask(task);
+}
+
+void ClearAnnotationsTask::run() {
+    view->unregisterAnnotations(l);
+}
+
+Task::ReportResult ClearAnnotationsTask::report() {
+    view->addUpdateFlags(GSLV_UF_AnnotationsChanged);
+    view->update();
+    aobj->releaseLocker();
+    return ReportResult_Finished;
+}
+
 void GSequenceLineViewAnnotated::sl_onAnnotationSelectionChanged(AnnotationSelection* as, const QList<Annotation*>& _added, const QList<Annotation*>& _removed) {
-    const QSet<AnnotationTableObject*>& aos = ctx->getAnnotationObjects();
+    const QSet<AnnotationTableObject*> aos = ctx->getAnnotationObjects(true);
 
     bool changed = false;
     QList<Annotation*> added = ctx->selectRelatedAnnotations(_added);
@@ -126,7 +163,7 @@ void GSequenceLineViewAnnotated::sl_onAnnotationSelectionChanged(AnnotationSelec
 }
 
 bool GSequenceLineViewAnnotated::isAnnotationVisible(Annotation* a) const  {
-    foreach(const LRegion& r, a->getLocation()) {
+    foreach(const U2Region& r, a->getRegions()) {
         if (visibleRange.intersects(r)) {
             return true;
         }
@@ -140,17 +177,18 @@ QList<AnnotationSelectionData> GSequenceLineViewAnnotated::selectAnnotationByCoo
     AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
     int pos = ra->coordToPos(p.x());
     int dPos = 0;
-    if (visibleRange.len > renderArea->width()) {
+    if (visibleRange.length > renderArea->width()) {
         float scale = renderArea->getCurrentScale();
         dPos = (int) ( 1 / (scale) );
         assert(dPos < seqLen);
     }
-    LRegion reg(pos-dPos, 1 + 2*dPos);
-    foreach(AnnotationTableObject* ao, ctx->getAnnotationObjects()) {
+    U2Region reg(pos-dPos, 1 + 2*dPos);
+    const QSet<AnnotationTableObject*> aObjs = ctx->getAnnotationObjects(true);
+    foreach(AnnotationTableObject* ao, aObjs ) {
         foreach(Annotation* a, ao->getAnnotations()) {
-            const QList<LRegion>& location = a->getLocation();
+            QVector<U2Region> location = a->getRegions();
             for (int i = 0, n = location.size(); i < n; i++) {
-                const LRegion& l = location[i];
+                const U2Region& l = location[i];
                 if (l.intersects(reg) || l.endPos() == reg.startPos) {
                     bool ok = true;
                     if (l.endPos() == pos || pos == l.startPos) {//now check pixel precise coords for boundaries
@@ -161,7 +199,7 @@ QList<AnnotationSelectionData> GSequenceLineViewAnnotated::selectAnnotationByCoo
                     if (ok) {
                         AnnotationSettings* as = asr->getAnnotationSettings(a);
                         if (as->visible) {
-                            LRegion ry = ra->getAnnotationYRange(a, i, as);
+                            U2Region ry = ra->getAnnotationYRange(a, i, as);
                             if (ry.contains(p.y())) {
                                 res.append(AnnotationSelectionData(a, i));
                             }
@@ -193,8 +231,8 @@ void GSequenceLineViewAnnotated::mousePressEvent(QMouseEvent * me) {
                 AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
                 QMenu popup;
                 foreach(const AnnotationSelectionData& as, selected) {
-                    const QList<LRegion>& location = as.annotation->getLocation();
-                    const LRegion& r = location[qMax(0, as.locationIdx)];
+                    QVector<U2Region> location = as.annotation->getRegions();
+                    const U2Region& r = location[qMax(0, as.locationIdx)];
                     QString text = as.annotation->getAnnotationName()
                                    + QString(" [%1, %2]").arg(QString::number(r.startPos+1)).arg(QString::number(r.endPos()));
                     AnnotationSettings* asettings = asr->getAnnotationSettings(as.annotation->getAnnotationName());
@@ -219,19 +257,20 @@ void GSequenceLineViewAnnotated::mousePressEvent(QMouseEvent * me) {
                 //select region
                 if (expandAnnotationSelectionToSequence) {
                     ctx->getSequenceSelection()->clear();
-                    LRegion regionToSelect;
+                    U2Region regionToSelect;
                     foreach(const AnnotationSelectionData& asd, asel->getSelection()) {
                         AnnotationTableObject* aobj = asd.annotation->getGObject();
-                        if (!ctx->getAnnotationObjects().contains(aobj)) {
+                        const QSet<AnnotationTableObject*> aObjs = ctx->getAnnotationObjects(true);
+                        if (!aObjs.contains(aobj)) {
                             continue;
                         }
-                        LRegion aregion;
+                        U2Region aregion;
                         if (asd.locationIdx == -1) {
-                            aregion = LRegion::containingRegion(asd.annotation->getLocation());
+                            aregion = U2Region::containingRegion(asd.annotation->getRegions());
                         } else {
-                            aregion = asd.annotation->getLocation().at(asd.locationIdx);
+                            aregion = asd.annotation->getRegions().at(asd.locationIdx);
                         }
-                        regionToSelect = regionToSelect.len == 0 ? aregion : LRegion::containingRegion(regionToSelect, aregion);
+                        regionToSelect = regionToSelect.length == 0 ? aregion : U2Region::containingRegion(regionToSelect, aregion);
                     }
                     ctx->getSequenceSelection()->addRegion(regionToSelect);
                 }
@@ -249,23 +288,24 @@ QString GSequenceLineViewAnnotated::prepareAnnotationText(const Annotation* a, c
     if (as->nameQuals.isEmpty()) {
         return a->getAnnotationName();
     }
-    QVector<Qualifier> qs;
+    QVector<U2Qualifier> qs;
     foreach(const QString& qn, as->nameQuals) {
         qs.clear();
         a->findQualifiers(qn, qs);
         if (!qs.isEmpty()) {
-            QString res = qs[0].getQualifierValue();
+            QString res = qs[0].value;
             return res;
         }
     }
     return a->getAnnotationName();
 }
 
-QList<Annotation*> GSequenceLineViewAnnotated::findAnnotationsInRange(const LRegion& range) {
+QList<Annotation*> GSequenceLineViewAnnotated::findAnnotationsInRange(const U2Region& range) {
     QList<Annotation*> result;
-    foreach(AnnotationTableObject* ao, ctx->getAnnotationObjects()) {
+    const QSet<AnnotationTableObject*> aObjs = ctx->getAnnotationObjects(true);
+    foreach(AnnotationTableObject* ao, aObjs) {
         foreach (Annotation* a, ao->getAnnotations()) {
-            if (LRegion::intersectsWithAny(range, a->getLocation()) != -1) {
+            if (range.intersects(a->getRegions())) {
                 result.append(a);
             }
         }
@@ -311,7 +351,7 @@ void GSequenceLineViewAnnotatedRenderArea::drawAnnotations(QPainter& p) {
     QPen pen1(Qt::SolidLine);
     pen1.setWidth(1);
 
-    foreach(AnnotationTableObject* ao, ctx->getAnnotationObjects()) {
+    foreach(AnnotationTableObject* ao, ctx->getAnnotationObjects(true)) {
         foreach(Annotation* a, ao->getAnnotations()) {
             AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
             AnnotationSettings* as = asr->getAnnotationSettings(a->getAnnotationName());
@@ -372,7 +412,7 @@ void static addTrimPath(QPainterPath& path, const QRect& rect, bool leftTrim) {
 
 
 void GSequenceLineViewAnnotatedRenderArea::drawAnnotation(QPainter& p, DrawAnnotationPass pass, Annotation* a, const QPen& borderPen, bool selected, 
-                                                          const AnnotationSettings* as, LRegion predefinedy) {
+                                                          const AnnotationSettings* as, U2Region predefinedy) {
     if (as == NULL) {
         AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
         as = asr->getAnnotationSettings(a->getAnnotationName());
@@ -381,17 +421,17 @@ void GSequenceLineViewAnnotatedRenderArea::drawAnnotation(QPainter& p, DrawAnnot
         return;
     }
     const GSequenceLineViewAnnotated::DrawSettings& drawSettings = getGSequenceLineViewAnnotated()->getDrawSettings();
-    const LRegion& vr = view->getVisibleRange();
+    const U2Region& vr = view->getVisibleRange();
 
-    const QList<LRegion>& location = a->getLocation();
+    QVector<U2Region> location = a->getRegions();
     bool simple = location.size() == 1;
     for (int ri = 0, ln = location.size(); ri < ln; ri++) {
-        const LRegion& r = location.at(ri);
+        const U2Region& r = location.at(ri);
         if (!r.intersects(vr) || predefinedy.startPos < 0) {
             continue;
         }
-        LRegion visibleLocation = r.intersect(vr);
-        LRegion y = predefinedy.isEmpty() ? getAnnotationYRange(a, ri, as) : predefinedy;
+        U2Region visibleLocation = r.intersect(vr);
+        U2Region y = predefinedy.isEmpty() ? getAnnotationYRange(a, ri, as) : predefinedy;
         if (y.startPos <  0){
             continue;
         }
@@ -402,13 +442,14 @@ void GSequenceLineViewAnnotatedRenderArea::drawAnnotation(QPainter& p, DrawAnnot
         int rw = qMax(selected ? MIN_SELECTED_ANNOTATION_WIDTH : MIN_ANNOTATION_WIDTH, qRound(x2f - x1f));
         int x1 = qRound(x1f);
         
-        QRect annotationRect(x1, y.startPos, rw, y.len);
+        QRect annotationRect(x1, y.startPos, rw, y.length);
         QPainterPath rectPath;
-        rectPath.addRect(x1, y.startPos, rw, y.len);
+        rectPath.addRect(x1, y.startPos, rw, y.length);
         bool leftTrim  = visibleLocation.startPos != r.startPos;
         bool rightTrim = visibleLocation.endPos()!= r.endPos();
-        if (drawSettings.drawAnnotationArrows && (!leftTrim && !rightTrim)) {
-            addArrowPath(rectPath, annotationRect, a->isOnComplementStrand());
+        bool drawArrow = a->getStrand().isCompementary() ? !leftTrim : !rightTrim;
+        if (drawSettings.drawAnnotationArrows && drawArrow ) {
+            addArrowPath(rectPath, annotationRect, a->getStrand().isCompementary());
         } /* else  {
             if (leftTrim) {
                 addTrimPath(rectPath, annotationRect, true);
@@ -471,7 +512,7 @@ void GSequenceLineViewAnnotatedRenderArea::drawAnnotationsSelection(QPainter& p)
 
     foreach(const AnnotationSelectionData& asd, ctx->getAnnotationsSelection()->getSelection()) {
         AnnotationTableObject* o = asd.annotation->getGObject();
-        if (ctx->getAnnotationObjects().contains(o)) {
+        if (ctx->getAnnotationObjects(true).contains(o)) {
             if (annotationsCanOverlap) {
                 drawAnnotation(p, DrawAnnotationPass_DrawFill,   asd.annotation, pen1, true);
             }
@@ -531,43 +572,49 @@ void GSequenceLineViewAnnotatedRenderArea::drawCutSite(QPainter& p, const QRect&
 #define MAX_VIRTUAL_RANGE 10000
 
 void GSequenceLineViewAnnotatedRenderArea::drawAnnotationConnections(QPainter& p, Annotation* a, const AnnotationSettings* as) {
-    if (a->getLocation().size() < 2) {
+    if (a->getLocation()->isSingleRegion()) {
         return;
     }
+    
+    
+    if (U2AnnotationUtils::isSplitted(a->getLocation(), getGSequenceLineViewAnnotated()->getSequenceRange())) {
+        return;
+    }
+
     const GSequenceLineViewAnnotated::DrawSettings& drawSettings = getGSequenceLineViewAnnotated()->getDrawSettings();
-    const LRegion& visibleRange = view->getVisibleRange();
+    const U2Region& visibleRange = view->getVisibleRange();
     int dx1 = 0;
     int dx2 = 0;
     if (drawSettings.drawAnnotationArrows) {
-        if (a->isOnComplementStrand()) {
+        if (a->getStrand().isCompementary()) {
             dx2 = - FEATURE_ARROW_HLEN;
         } else {
             dx1 = FEATURE_ARROW_HLEN;
         }
     }
-    const QList<LRegion>& location = a->getLocation();
+    QVector<U2Region> location = a->getRegions();
     for (int ri = 0, ln = location.size(); ri < ln; ri++) {
-        const LRegion& r = location.at(ri);
-        LRegion y = getAnnotationYRange(a, ri, as);
+        const U2Region& r = location.at(ri);
+        //U2Region y = getAnnotationYRange(a, ri, as);
         if (ri > 0) {
-            LRegion prev = location.at(ri - 1);
+            U2Region prev = location.at(ri - 1);
             int prevPos = prev.endPos();
             int pos = r.startPos;
             int min = qMin(prevPos, pos);
             int max = qMax(prevPos, pos);
-            if (visibleRange.intersects(LRegion(min, max-min))) {
+            if (visibleRange.intersects(U2Region(min, max-min))) {
                 int x1 = posToCoord(prevPos, true) + dx1;
                 int x2 = posToCoord(pos, true) + dx2;
                 if (qAbs(x2-x1) > 1) {
                     x1 = qBound(-MAX_VIRTUAL_RANGE, x1, MAX_VIRTUAL_RANGE); //qt4.4 crashes in line clipping alg for extremely large X values
                     x2 = qBound(-MAX_VIRTUAL_RANGE, x2, MAX_VIRTUAL_RANGE);
                     int midX = (x1 + x2) / 2;
-                    LRegion pyr = getAnnotationYRange(a, ri - 1, as);
-                    LRegion yr = getAnnotationYRange(a, ri, as);
+                    U2Region pyr = getAnnotationYRange(a, ri - 1, as);
+                    U2Region yr = getAnnotationYRange(a, ri, as);
                     int y1 = pyr.startPos;
-                    int dy1 = pyr.len/2;
+                    int dy1 = pyr.length/2;
                     int y2 = yr.startPos;
-                    int dy2 = yr.len/2;
+                    int dy2 = yr.length/2;
                     int midY = qMin(y1, y2);
                     p.drawLine(x1, y1+dy1, midX, midY);
                     p.drawLine(midX, midY, x2, y2+dy2);
@@ -578,19 +625,19 @@ void GSequenceLineViewAnnotatedRenderArea::drawAnnotationConnections(QPainter& p
 }
 
 void GSequenceLineViewAnnotated::ensureVisible(Annotation* a, int locationIdx) {
-    const QList<LRegion>& location = a->getLocation();
+    QVector<U2Region> location = a->getRegions();
     assert(locationIdx < location.size());
     if (locationIdx == -1) {
-        foreach(const LRegion& r, location) {
+        foreach(const U2Region& r, location) {
             if (visibleRange.intersects(r)) {
                 return;
             }
         }
     }
-    const LRegion& region = location[qMax(0, locationIdx)];
+    const U2Region& region = location[qMax(0, locationIdx)];
     if (!visibleRange.intersects(region)) {
-        int pos = a->isOnComplementStrand() ? region.endPos() : region.startPos;
-        setCenterPos(qBound(0, pos, seqLen-1));
+        qint64 pos = a->getStrand().isCompementary() ? region.endPos() : region.startPos;
+        setCenterPos(qBound(qint64(0), pos, seqLen-1));
     }
 }
 
@@ -630,6 +677,7 @@ QString GSequenceLineViewAnnotated::createToolTip(QHelpEvent* e) {
                 tip += "<tr><td/><td>...</td>";
                 rows++;
             } else {
+                tip += "<tr><td></td><td><b>Location</b> = " + Genbank::LocationParser::buildLocationString(ad.annotation->data()) + "</td></tr>";
                 tip += "<tr><td/><td>";
                 tip += ad.annotation->getQualifiersTip(ROWS_LIMIT - rows, getSequenceObject(), ctx->getComplementTT(), ctx->getAminoTT());
                 tip += "</td></tr>";
@@ -652,7 +700,7 @@ void GSequenceLineViewAnnotated::sl_onAnnotationsModified( const AnnotationModif
     }
 }
 bool GSequenceLineViewAnnotatedRenderArea::isAnnotationSelectionInVisibleRange() const {
-    const QSet<AnnotationTableObject*>& aos = view->getSequenceContext()->getAnnotationObjects();
+    const QSet<AnnotationTableObject*> aos = view->getSequenceContext()->getAnnotationObjects(true);
     AnnotationSelection* as = view->getSequenceContext()->getAnnotationsSelection();
     foreach(const AnnotationSelectionData& asd, as->getSelection()) {
         if (!aos.contains(asd.annotation->getGObject())) {
