@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "Overview.h"
 
@@ -31,7 +42,7 @@ namespace U2 {
 
 Overview::Overview(QWidget *p, ADVSequenceObjectContext *ctx) : GSequenceLineView(p, ctx) {
     renderArea = new OverviewRenderArea(this);
-    visibleRange = LRegion(0, ctx->getSequenceLen());
+    visibleRange = U2Region(0, ctx->getSequenceLen());
     renderArea->setMouseTracking(true);
 
     ADVSingleSequenceWidget* ssw = qobject_cast<ADVSingleSequenceWidget*>(p);
@@ -52,11 +63,13 @@ Overview::Overview(QWidget *p, ADVSequenceObjectContext *ctx) : GSequenceLineVie
         SLOT(sl_annotationObjectAdded(AnnotationTableObject*)));
     connect(ctx, SIGNAL(si_annotationObjectRemoved(AnnotationTableObject*)),
         SLOT(sl_annotationObjectRemoved(AnnotationTableObject*)));
-    foreach(AnnotationTableObject* at, ctx->getAnnotationObjects()) {
+    foreach(AnnotationTableObject* at, ctx->getAnnotationObjects(true)) {
         connect(at, SIGNAL(si_onAnnotationsAdded(const QList<Annotation*>&)),
             SLOT(sl_annotationsAdded(const QList<Annotation*>&)));
         connect(at, SIGNAL(si_onAnnotationsRemoved(const QList<Annotation*>&)),
             SLOT(sl_annotationsRemoved(const QList<Annotation*>&)));
+        connect(at, SIGNAL(si_onAnnotationsInGroupRemoved(const QList<Annotation*>&, AnnotationGroup*)), 
+            SLOT(sl_onAnnotationsInGroupRemoved(const QList<Annotation*>&, AnnotationGroup*)));
         connect(at, SIGNAL(si_onAnnotationModified(const AnnotationModification&)),
             SLOT(sl_annotationModified(const AnnotationModification&)));
         connect(AppContext::getAnnotationsSettingsRegistry(),
@@ -101,6 +114,13 @@ void Overview::sl_annotationsRemoved(const QList<Annotation*>& a) {
     update();
 }
 
+void Overview::sl_onAnnotationsInGroupRemoved(const QList<Annotation*>&, AnnotationGroup*) {
+    addUpdateFlags(GSLV_UF_AnnotationsChanged);
+    update();
+    AnnotationTableObject *aobj = static_cast<AnnotationTableObject*>(sender());
+    aobj->releaseLocker();
+}
+
 void Overview::sl_annotationModified(const AnnotationModification& md) {
     if (md.type==AnnotationModification_LocationChanged) {
         addUpdateFlags(GSLV_UF_AnnotationsChanged);
@@ -187,16 +207,16 @@ void Overview::mousePressEvent(QMouseEvent *me) {
         }
         else {
             int seqLen = ctx->getSequenceLen();
-            int panVisLen = panView->getVisibleRange().len;
-            int detVisLen = detView->getVisibleRange().len;
+            int panVisLen = panView->getVisibleRange().length;
+            int detVisLen = detView->getVisibleRange().length;
 
             int panPos = renderArea->coordToPos(renderAreaPos.x() - panSlider.width()/2);
             panPos = qBound(0, panPos, seqLen-panVisLen);
-            panView->setVisibleRange(LRegion(panPos, panVisLen));
+            panView->setVisibleRange(U2Region(panPos, panVisLen));
 
             int detPos = renderArea->coordToPos(renderAreaPos.x());
             detPos = qBound(0, detPos, seqLen-detVisLen);
-            detView->setVisibleRange(LRegion(detPos, detVisLen));
+            detView->setVisibleRange(U2Region(detPos, detVisLen));
         }
     }
     QWidget::mousePressEvent(me);
@@ -225,16 +245,16 @@ void Overview::mouseMoveEvent(QMouseEvent *me) {
     if (me->buttons() & Qt::LeftButton) {
         int pos = renderArea->coordToPos(renderAreaPos.x() - mousePosToSlider.x());
         if(lastPressPos!=-1) {//make selection
-            LRegion selection;
+            U2Region selection;
             int mousePos = renderArea->coordToPos(renderAreaPos.x());
             int selLen = mousePos-lastPressPos;
             if(selLen>0) {
                 selection.startPos=lastPressPos;
-                selection.len=selLen;
+                selection.length=selLen;
             }
             else {
                 selection.startPos=mousePos;
-                selection.len=-selLen;
+                selection.length=-selLen;
             }
             setSelection(selection);
             QWidget::mouseMoveEvent(me);
@@ -252,10 +272,10 @@ void Overview::mouseMoveEvent(QMouseEvent *me) {
                     panVisLen *= -1;
                 }
 
-                panVisLen = panView->getVisibleRange().len + panVisLen;
+                panVisLen = panView->getVisibleRange().length + panVisLen;
                 pos = renderArea->coordToPos(panSlider.left()) ;
                 if(panVisLen > 0 && panView->getSeqLen() >= (panVisLen + pos)) {
-                    panView->setVisibleRange(LRegion(pos, panVisLen));
+                    panView->setVisibleRange(U2Region(pos, panVisLen));
                 }
             } else if(panSliderMovedLeft) {
                 OverviewRenderArea* ra = static_cast<OverviewRenderArea*>(renderArea);
@@ -267,21 +287,21 @@ void Overview::mouseMoveEvent(QMouseEvent *me) {
                     panVisLen *= -1;
                 }
 
-                panVisLen = panView->getVisibleRange().len + panVisLen + offset;
+                panVisLen = panView->getVisibleRange().length + panVisLen + offset;
                 pos = panView->getVisibleRange().endPos() - panVisLen;
                 if(panVisLen > 0 && pos > 0 && (panVisLen + pos) <= ctx->getSequenceLen()) {
-                    panView->setVisibleRange(LRegion(pos, panVisLen));
+                    panView->setVisibleRange(U2Region(pos, panVisLen));
                 }
             } else if(panSliderClicked) {
-                int panVisLen = panView->getVisibleRange().len;
+                int panVisLen = panView->getVisibleRange().length;
                 pos = qBound(0, pos, ctx->getSequenceLen() - panVisLen);
-                panView->setVisibleRange(LRegion(pos, panVisLen));
+                panView->setVisibleRange(U2Region(pos, panVisLen));
             }
         }
         if (detSliderClicked) {
-            int detVisLen = detView->getVisibleRange().len;
+            int detVisLen = detView->getVisibleRange().length;
             pos = qBound(0, pos, ctx->getSequenceLen() - detVisLen);
-            detView->setVisibleRange(LRegion(pos, detVisLen));
+            detView->setVisibleRange(U2Region(pos, detVisLen));
         }
     }
     QWidget::mouseMoveEvent(me);
@@ -292,21 +312,21 @@ void Overview::mouseDoubleClickEvent(QMouseEvent* me) {
         OverviewRenderArea* ra = static_cast<OverviewRenderArea*>(renderArea);
 
         QRectF panSlider(ra->getPanSlider());
-        int panVisLen = panView->getVisibleRange().len;
+        int panVisLen = panView->getVisibleRange().length;
         QPoint renderAreaPos = toRenderAreaPoint(me->pos());
         int panPos = ra->coordToPos(renderAreaPos.x() - panSlider.width()/2);
         panPos = qBound(0, panPos, ctx->getSequenceLen() - panVisLen);
-        panView->setVisibleRange(LRegion(panPos, panVisLen));
+        panView->setVisibleRange(U2Region(panPos, panVisLen));
         
         //don't process detSlider when details view is collapsed
         ADVSingleSequenceWidget* parent = qobject_cast<ADVSingleSequenceWidget*>(parentWidget());
         assert(parent);
         if(!parent->isDetViewCollapsed()) {
             QRectF detSlider(ra->getDetSlider());
-            int detVisLen = detView->getVisibleRange().len;
+            int detVisLen = detView->getVisibleRange().length;
             int detPos = ra->coordToPos(renderAreaPos.x());
             detPos = qBound(0, detPos, ctx->getSequenceLen() - detVisLen);
-            detView->setVisibleRange(LRegion(detPos, detVisLen));
+            detView->setVisibleRange(U2Region(detPos, detVisLen));
         }
 
         panSliderClicked=false;
@@ -404,14 +424,15 @@ void OverviewRenderArea::setAnnotationsOnPos() {
     ADVSequenceObjectContext* ctx = view->getSequenceContext();
     int len = ctx->getSequenceLen();
     annotationsOnPos.resize(len);
-    const LRegion& sequenceRange = ctx->getSequenceObject()->getSequenceRange();
+    const U2Region& sequenceRange = ctx->getSequenceObject()->getSequenceRange();
     AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
-    foreach(AnnotationTableObject* at, ctx->getAnnotationObjects()) {
+    QSet<AnnotationTableObject*> aObjs = ctx->getAnnotationObjects(true);
+    foreach(AnnotationTableObject* at, aObjs) {
         foreach(Annotation* a, at->getAnnotations()) {
             AnnotationSettings* as = asr->getAnnotationSettings(a->getAnnotationName());
             if(as->visible) {
-                foreach(const LRegion& r, a->getLocation()) {
-                    LRegion innerRegion = r.intersect(sequenceRange);
+                foreach(const U2Region& r, a->getRegions()) {
+                    U2Region innerRegion = r.intersect(sequenceRange);
                     for(int i = innerRegion.startPos;i < innerRegion.endPos(); i++) {
                         annotationsOnPos[i]++;
                     }
@@ -440,7 +461,7 @@ void OverviewRenderArea::drawAll(QPaintDevice *pd) {
     p.drawPixmap(0,0,*cachedView);
     Overview* gv = static_cast<Overview*>(view);
     int panX = posToCoord(gv->getPan()->getVisibleRange().startPos);
-    int panW = qMax(posToCoord(gv->getPan()->getVisibleRange().len), SLIDER_MIN_WIDTH);
+    int panW = qMax(posToCoord(gv->getPan()->getVisibleRange().length), SLIDER_MIN_WIDTH);
     int detX = posToCoord(gv->getDet()->getVisibleRange().startPos) - int(ARROW_WIDTH/2);
 
     int panSliderHeight = pd->height()-PEN_WIDTH;
@@ -499,7 +520,7 @@ void OverviewRenderArea::drawRuler(QPainter &p) {
     p.setPen(pen);
     Overview* gv = static_cast<Overview*>(view);
     int seqLen = gv->ctx->getSequenceLen();
-    LRegion visibleRange = gv->getVisibleRange();
+    U2Region visibleRange = gv->getVisibleRange();
 
     float halfChar = getCurrentScale() / 2;
     int firstCharCenter = qRound(posToCoordF(visibleRange.startPos) + halfChar);
@@ -524,7 +545,7 @@ void OverviewRenderArea::drawSelection(QPainter& p) {
     p.setPen(pen);
     Overview* gv = qobject_cast<Overview*>(view);
     DNASequenceSelection* sel = gv->ctx->getSequenceSelection();
-    foreach(const LRegion& r, sel->getSelectedRegions()) {
+    foreach(const U2Region& r, sel->getSelectedRegions()) {
         int x1 = posToCoord(r.startPos);
         int x2 = posToCoord(r.endPos());
         p.drawLine(x1, ANNOTATION_GRAPH_HEIGHT, x2, ANNOTATION_GRAPH_HEIGHT);
