@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "PanView.h"
 
@@ -38,6 +49,8 @@
 
 namespace U2 {
 
+#define RULER_NOTCH_SIZE 2
+
 PanView::ZoomUseObject::ZoomUseObject()
 : usingZoom(false), panView(NULL) {}
 
@@ -87,29 +100,63 @@ PanView::PanView(QWidget* p, ADVSequenceObjectContext* ctx) : GSequenceLineViewA
     rowsManager = new PVRowsManager();
     renderArea = new PanViewRenderArea(this);
 
-    visibleRange.len = seqLen;
-    minNuclsPerScreen = qMin(seqLen, 10); 
+    visibleRange.length = seqLen;
+    minNuclsPerScreen = qMin(seqLen, qint64(0)); 
 
     zoomUsing = 0;
 
-    zoomInAction = new QAction(QIcon(":/core/images/zoom_in.png"), tr("Zoom in"), this);
+    zoomInAction = new QAction(QIcon(":/core/images/zoom_in.png"), tr("Zoom In"), this);
     connect(zoomInAction, SIGNAL(triggered()), SLOT(sl_zoomInAction()));
 
-    zoomOutAction = new QAction(QIcon(":/core/images/zoom_out.png"), tr("Zoom out"), this);
+    zoomOutAction = new QAction(QIcon(":/core/images/zoom_out.png"), tr("Zoom Out"), this);
     connect(zoomOutAction, SIGNAL(triggered()), SLOT(sl_zoomOutAction()));
 
-    zoomToSelectionAction= new QAction(QIcon(":/core/images/zoom_sel.png"), tr("Zoom to selection"), this);
+    zoomToSelectionAction= new QAction(QIcon(":/core/images/zoom_sel.png"), tr("Zoom to Selection"), this);
     connect(zoomToSelectionAction, SIGNAL(triggered()), SLOT(sl_zoomToSelection()));
 
-    zoomToSequenceAction = new QAction(QIcon(":/core/images/zoom_whole.png"), tr("Zoom to whole sequence"), this);
+    zoomToSequenceAction = new QAction(QIcon(":/core/images/zoom_whole.png"), tr("Zoom to Whole Sequence"), this);
     connect(zoomToSequenceAction, SIGNAL(triggered()), SLOT(sl_zoomToSequence()));
 
-    toggleMainRulerAction = new QAction(tr("Show main ruler"), this);
+    panViewToolButton = new QToolButton();
+    
+    QMenu *menu = new QMenu();
+    showAllAnnotations = new QAction(tr("Show All Rows"), menu);
+    showAllAnnotations->setCheckable(true);
+    connect(showAllAnnotations, SIGNAL(triggered(bool)), renderArea, SLOT(sl_maxLines(bool)));
+
+    increasePanViewHeight = new QAction(tr("+1 Row"), menu);
+    connect(increasePanViewHeight, SIGNAL(triggered()), renderArea, SLOT(sl_increaseLines()));
+
+    decreasePanViewHeight = new QAction(tr("-1 Row"), menu);
+    connect(decreasePanViewHeight, SIGNAL(triggered()), renderArea, SLOT(sl_decreaseLines()));    
+
+    increase5PanViewHeight = new QAction(tr("+5 Rows"), menu);
+    connect(increase5PanViewHeight, SIGNAL(triggered()), renderArea, SLOT(sl_increase5Lines()));
+
+    decrease5PanViewHeight = new QAction(tr("-5 Rows"), menu);
+    connect(decrease5PanViewHeight, SIGNAL(triggered()), renderArea, SLOT(sl_decrease5Lines()));
+    
+    resetAnnotations = new QAction(tr("Reset Rows Number"), menu);
+    connect(resetAnnotations, SIGNAL(triggered()), renderArea, SLOT(sl_resetToDefault()));
+   
+    menu->addAction(showAllAnnotations);
+    menu->addAction(increase5PanViewHeight);
+    menu->addAction(increasePanViewHeight);
+    menu->addAction(decreasePanViewHeight);
+    menu->addAction(decrease5PanViewHeight);
+    menu->addAction(resetAnnotations);
+    
+    panViewToolButton->setPopupMode(QToolButton::InstantPopup);
+    panViewToolButton->setMenu(menu);
+    panViewToolButton->setIcon(QIcon(":/core/images/zoom_rows.png"));
+    panViewToolButton->setToolTip(tr("Manage Rows in Zoom View"));
+
+    toggleMainRulerAction = new QAction(tr("Show Main Ruler"), this);
     toggleMainRulerAction->setCheckable(true);
     toggleMainRulerAction->setChecked(getRenderArea()->showMainRuler);
     connect(toggleMainRulerAction, SIGNAL(triggered(bool)), SLOT(sl_toggleMainRulerVisibility(bool)));
 
-    toggleCustomRulersAction = new QAction(tr("Show custom rulers"), this);
+    toggleCustomRulersAction = new QAction(tr("Show Custom Rulers"), this);
     toggleCustomRulersAction->setCheckable(true);
     toggleCustomRulersAction->setChecked(getRenderArea()->showCustomRulers);
     toggleCustomRulersAction->setEnabled(!getRenderArea()->customRulers.isEmpty());
@@ -121,11 +168,12 @@ PanView::PanView(QWidget* p, ADVSequenceObjectContext* ctx) : GSequenceLineViewA
     syncOffset = 0;
 
     //can't move to the GSequenceLineViewAnnotated -> virtual calls does not work in  constructor
-    foreach(AnnotationTableObject* obj, ctx->getAnnotationObjects()) {
+    foreach(AnnotationTableObject* obj, ctx->getAnnotationObjects(true)) {
         registerAnnotations(obj->getAnnotations());
     }
 
     connect(ctx->getSequenceGObject(), SIGNAL(si_sequenceChanged()), this, SLOT(sl_sequenceChanged()));
+    connect(this, SIGNAL(si_updateRows()), SLOT(sl_updateRows()));
 
     updateActions();
     updateRowBar();
@@ -143,7 +191,7 @@ void PanView::pack() {
     layout->addWidget(scrollBar, 1, 0, 1, 1);
     setLayout(layout);
 
-    setFixedHeight(renderArea->height() + scrollBar->height());
+    setFixedHeight(layout->minimumSize().height());
 }
 
 PanView::~PanView() {
@@ -170,7 +218,8 @@ void PanView::unregisterAnnotations(const QList<Annotation*>& l) {
             rowsManager->removeAnnotation(a);
         }
     }
-    updateRows();
+    emit si_updateRows();
+    //updateRows();
 }
 
 void PanView::updateRows() {
@@ -180,6 +229,7 @@ void PanView::updateRows() {
     if (qAbs(rowBar->maximum() - rowBar->minimum())!=maxSteps) {
         updateRowBar();
     }
+    updateActions();
 }
 
 void PanView::updateRAHeight() {
@@ -187,7 +237,10 @@ void PanView::updateRAHeight() {
 
     bool heightChanged = ra->updateNumVisibleRows();
     if (heightChanged) {
-        setFixedHeight(renderArea->height() + scrollBar->height());
+        QLayout* lt = layout();
+        if (lt != NULL) {
+            setFixedHeight(lt->minimumSize().height());
+        }
     }
 }
 
@@ -241,7 +294,7 @@ void PanView::sl_onAnnotationSettingsChanged(const QStringList& changedSettings)
             continue;
         }
         QList<Annotation*> changed;
-        foreach(AnnotationTableObject* ao, ctx->getAnnotationObjects()) {
+        foreach(AnnotationTableObject* ao, ctx->getAnnotationObjects(true)) {
             ao->selectAnnotationsByName(name, changed);
         }
         if (changed.isEmpty()) {
@@ -261,9 +314,9 @@ void PanView::sl_onAnnotationSettingsChanged(const QStringList& changedSettings)
 
 
 
-void PanView::setSelection(const LRegion& r) {
+void PanView::setSelection(const U2Region& r) {
     ctx->getSequenceSelection()->clear();
-    if (r.len!=0) {
+    if (r.length!=0) {
         ctx->getSequenceSelection()->addRegion(r);
     }
 }
@@ -301,59 +354,68 @@ void PanView::updateActions() {
         return;
     }
 
-    zoomInAction->setEnabled(visibleRange.len > minNuclsPerScreen);
-    zoomOutAction->setEnabled(visibleRange.len < seqLen);
+    zoomInAction->setEnabled(visibleRange.length > minNuclsPerScreen);
+    zoomOutAction->setEnabled(visibleRange.length < seqLen);
 
-    const QList<LRegion>& sel = ctx->getSequenceSelection()->getSelectedRegions();
-    if (!sel.isEmpty() && sel.first().len >= minNuclsPerScreen) {
+    const QVector<U2Region>& sel = ctx->getSequenceSelection()->getSelectedRegions();
+    if (!sel.isEmpty() && sel.first().length >= minNuclsPerScreen) {
         zoomToSelectionAction->setEnabled(true);
     } else {
         zoomToSelectionAction->setEnabled(false);
     }
     zoomToSequenceAction->setEnabled(visibleRange.startPos != 0 || visibleRange.endPos() != seqLen);
+
+    increasePanViewHeight->setEnabled(((PanViewRenderArea*)renderArea)->canIncreaseLines());
+    decreasePanViewHeight->setEnabled(((PanViewRenderArea*)renderArea)->canDecreaseLines());
+    increase5PanViewHeight->setEnabled(((PanViewRenderArea*)renderArea)->canIncreaseLines());
+    decrease5PanViewHeight->setEnabled(((PanViewRenderArea*)renderArea)->canDecreaseLines());
+    resetAnnotations->setEnabled(!((PanViewRenderArea*)renderArea)->isDefaultSize());
+    //showAllAnnotations->setEnabled(!((PanViewRenderArea*)renderArea)->isAllLinesShown());
+    panViewToolButton->setEnabled(isVisible() && (increasePanViewHeight->isEnabled() || decreasePanViewHeight->isEnabled() || 
+        increase5PanViewHeight->isEnabled() || decrease5PanViewHeight->isEnabled() || resetAnnotations->isEnabled()));
 }
 
 void PanView::sl_zoomInAction() {
-    assert(visibleRange.len >= minNuclsPerScreen);
+    assert(visibleRange.length >= minNuclsPerScreen);
     DNASequenceSelection* sel = getSequenceContext()->getSequenceSelection();
     if (!sel->isEmpty()) {
-        const LRegion& selRange = sel->getSelectedRegions().first();
-        if (selRange.len >= minNuclsPerScreen && visibleRange.contains(selRange) && visibleRange != selRange) {
+        const U2Region& selRange = sel->getSelectedRegions().first();
+        if (selRange.length >= minNuclsPerScreen && visibleRange.contains(selRange) && visibleRange != selRange) {
             sl_zoomToSelection();
             return;
         }
     }
-    LRegion newVisibleRange = visibleRange;
-    newVisibleRange.len = qMax((visibleRange.len + 1) / 2, minNuclsPerScreen);
-    if (newVisibleRange.len!=visibleRange.len) {
-        newVisibleRange.startPos = visibleRange.startPos + (visibleRange.len - newVisibleRange.len)/2;
+    U2Region newVisibleRange = visibleRange;
+    newVisibleRange.length = qMax(int(visibleRange.length + 1) / 2, minNuclsPerScreen);
+    if (newVisibleRange.length!=visibleRange.length) {
+        newVisibleRange.startPos = visibleRange.startPos + (visibleRange.length - newVisibleRange.length)/2;
         setVisibleRange(newVisibleRange);
     }
 }
 
 void PanView::sl_zoomOutAction() {
-    assert(visibleRange.len <= seqLen);
-    LRegion newVisibleRange = visibleRange;
-    newVisibleRange.len = qMin(visibleRange.len * 2, seqLen);
-    if (newVisibleRange.len != visibleRange.len) {
-        newVisibleRange.startPos = qBound(0, visibleRange.startPos - (newVisibleRange.len - visibleRange.len)/2, seqLen-newVisibleRange.len);
+    assert(visibleRange.length <= seqLen);
+    U2Region newVisibleRange = visibleRange;
+    newVisibleRange.length = qMin(visibleRange.length * 2, seqLen);
+    if (newVisibleRange.length != visibleRange.length) {
+        newVisibleRange.startPos = qBound(qint64(0), visibleRange.startPos - (newVisibleRange.length - visibleRange.length)/2, seqLen-newVisibleRange.length);
         assert(newVisibleRange.startPos >=0 && newVisibleRange.endPos() <= seqLen); //todo: move to setVisibleRange
         setVisibleRange(newVisibleRange);
     }
 }
 
-void PanView::sl_onDNASelectionChanged(LRegionsSelection* s, const QList<LRegion>& added, const QList<LRegion>& removed) {
+void PanView::sl_onDNASelectionChanged(LRegionsSelection* s, const QVector<U2Region>& added, const QVector<U2Region>& removed) {
     GSequenceLineView::sl_onDNASelectionChanged(s, added, removed);
     updateActions();
 }
 
 void PanView::sl_zoomToSelection() {
-    const QList<LRegion>& sel = ctx->getSequenceSelection()->getSelectedRegions();
+    const QVector<U2Region>& sel = ctx->getSequenceSelection()->getSelectedRegions();
     if (sel.isEmpty()) {
         return;
     }
-    LRegion selRegion = sel.first();
-    if (selRegion.len < minNuclsPerScreen) {
+    U2Region selRegion = sel.first();
+    if (selRegion.length < minNuclsPerScreen) {
         return;
     }
     if (visibleRange==selRegion) {
@@ -365,17 +427,17 @@ void PanView::sl_zoomToSelection() {
 }
 
 void PanView::sl_zoomToSequence() {
-    LRegion wholeRange(0, seqLen);
+    U2Region wholeRange(0, seqLen);
     assert(visibleRange != wholeRange);
     visibleRange = wholeRange;
     onVisibleRangeChanged();
 }
 
-void PanView::setVisibleRange(const LRegion& newRange, bool signal) {
+void PanView::setVisibleRange(const U2Region& newRange, bool signal) {
     assert(newRange.startPos >=0 && newRange.endPos() <= seqLen);
 
-    if (newRange.len < minNuclsPerScreen) {
-        minNuclsPerScreen = newRange.len;
+    if (newRange.length < minNuclsPerScreen) {
+        minNuclsPerScreen = newRange.length;
     }
     GSequenceLineView::setVisibleRange(newRange, signal);
 }
@@ -409,15 +471,15 @@ void PanView::centerRow(int row) {
 
 void PanView::sl_onRangeChangeRequest(int start, int end) {
     uiLog.trace(tr("range change request: [%1, %2]").arg(start).arg(end));
-    setVisibleRange(LRegion(start-1, end));
+    setVisibleRange(U2Region(start-1, end));
 }
 
 void PanView::setNumBasesVisible(int n) {
-    int nBases = qBound(minNuclsPerScreen, n, seqLen);
-    int center = visibleRange.startPos + visibleRange.len / 2;
+    int nBases = qBound(minNuclsPerScreen, n, (int)seqLen);
+    int center = visibleRange.startPos + visibleRange.length / 2;
     int newStart = qMax(0, center - nBases / 2);
     assert(newStart + nBases <= seqLen);
-    setVisibleRange(LRegion(newStart, nBases));
+    setVisibleRange(U2Region(newStart, nBases));
 }
 
 PanViewRenderArea* PanView::getRenderArea() const {
@@ -496,11 +558,11 @@ void PanView::setSyncOffset(int o) {
 
 void PanView::sl_sequenceChanged(){
     seqLen = ctx->getSequenceLen();
-    LRegion curSource(0, ctx->getSequenceLen()), newRange(0,0);
+    U2Region curSource(0, ctx->getSequenceLen()), newRange(0,0);
     if(!curSource.contains(visibleRange)){
-        if (curSource.len > visibleRange.len){
+        if (curSource.length > visibleRange.length){
             newRange.startPos = visibleRange.startPos - (visibleRange.endPos() - curSource.endPos());
-            newRange.len = visibleRange.len;
+            newRange.length = visibleRange.length;
         }else{
             newRange = curSource;
         }
@@ -514,6 +576,7 @@ void PanView::hideEvent( QHideEvent *ev ){
     zoomOutAction->setDisabled(true);
     zoomToSelectionAction->setDisabled(true);
     zoomToSequenceAction->setDisabled(true);
+    panViewToolButton->setDisabled(true);
     QWidget::hideEvent(ev);
 }
 
@@ -522,11 +585,18 @@ void PanView::showEvent( QShowEvent *ev ){
     updateActions();
 }
 
+void PanView::sl_updateRows(){
+    updateRows();
+}
+
 //////////////////////////////////////////////////////////////////////////
 /// render
 PanViewRenderArea::PanViewRenderArea(PanView* d) : GSequenceLineViewAnnotatedRenderArea(d, false), panView(d) {
     showMainRuler = true;
     showCustomRulers = true;
+    fromActions = false;
+    showAllLines = false;
+    defaultRows = true;
     numLines = 0;
 
     rowLinesOffset = 0;
@@ -540,19 +610,38 @@ void PanViewRenderArea::drawAll(QPaintDevice* pd) {
     bool completeRedraw = uf.testFlag(GSLV_UF_NeedCompleteRedraw) || uf.testFlag(GSLV_UF_ViewResized) || 
                           uf.testFlag(GSLV_UF_VisibleRangeChanged) || uf.testFlag(GSLV_UF_AnnotationsChanged);
 
+    QPainter p(pd);
     if (completeRedraw) {
         QPainter pCached(cachedView);
         pCached.fillRect(0, 0, pd->width(), pd->height(), Qt::white);
         pCached.setPen(Qt::black);
 
-        drawRuler(pCached);
-        drawCustomRulers(pCached);
+        GraphUtils::RulerConfig c;
+        PanView* panview = qobject_cast<PanView*>(view);
+
+        const U2Region& visibleRange = view->getVisibleRange();
+        float halfChar = getCurrentScale() / 2;
+        int firstCharCenter = qRound(posToCoordF(visibleRange.startPos) + halfChar);
+        int lastCharCenter = qRound(posToCoordF(visibleRange.endPos()-1) + halfChar);
+        int firstLastWidth = lastCharCenter - firstCharCenter;
+        if (qRound(halfChar) == 0) {
+            int w = width();
+            assert(firstLastWidth == w); Q_UNUSED(w);
+            firstLastWidth--; // make the end of the ruler visible
+        }
+        c.notchSize = RULER_NOTCH_SIZE;
+        int chunk = GraphUtils::calculateChunk(visibleRange.startPos+1, visibleRange.endPos(), panView->width(), p);
+        foreach(const RulerInfo& ri, customRulers) {
+            chunk = qMax(chunk, GraphUtils::calculateChunk(visibleRange.startPos+1-ri.offset, visibleRange.endPos()-ri.offset, panView->width(), p));
+        }
+        c.predefinedChunk = chunk;
+        drawRuler(c, pCached, visibleRange, firstCharCenter, firstLastWidth);
+        drawCustomRulers(c, pCached, visibleRange, firstCharCenter);
 
         drawAnnotations(pCached);
 
         pCached.end();
     }
-    QPainter p(pd);
     p.drawPixmap(0, 0, *cachedView);
 
 
@@ -571,48 +660,28 @@ void PanViewRenderArea::drawAll(QPaintDevice* pd) {
         drawFocus(p);
     }
 }
-#define RULER_NOTCH_SIZE 2
-void PanViewRenderArea::drawRuler(QPainter& p) {
+void PanViewRenderArea::drawRuler(GraphUtils::RulerConfig c,  QPainter& p, const U2Region &visibleRange, int firstCharCenter, int firstLastWidth){
     if (!showMainRuler) {
         return;
     }
-    const LRegion& visibleRange = view->getVisibleRange();
-    float halfChar = getCurrentScale() / 2;
-    int firstCharCenter = qRound(posToCoordF(visibleRange.startPos) + halfChar);
-    int lastCharCenter = qRound(posToCoordF(visibleRange.endPos()-1) + halfChar);
-    int firstLastWidth = lastCharCenter - firstCharCenter;
-    if (qRound(halfChar) == 0) {
-        int w = width();
-        assert(firstLastWidth == w); Q_UNUSED(w);
-        firstLastWidth--; // make the end of the ruler visible
-    }
-    GraphUtils::RulerConfig c;
-    c.notchSize = RULER_NOTCH_SIZE;
     int y = getLineY(getRulerLine()) + c.notchSize;
     GraphUtils::drawRuler(p, QPoint(firstCharCenter, y), firstLastWidth, visibleRange.startPos+1, visibleRange.endPos(), rulerFont, c);
 }
 
 
 #define LINE_TEXT_OFFSET 10
-
-void PanViewRenderArea::drawCustomRulers(QPainter& p) {
+void PanViewRenderArea::drawCustomRulers(GraphUtils::RulerConfig c,  QPainter& p, const U2Region &visibleRange, int firstCharCenter) {
     if (!showCustomRulers || customRulers.isEmpty()) {
         return;
     }
-    const LRegion& visibleRange = view->getVisibleRange();
     float pixelsPerChar = getCurrentScale();
     float halfChar =  pixelsPerChar / 2;
-    int firstCharCenter = qRound(posToCoordF(visibleRange.startPos) + halfChar);
     int lastCharCenter = qRound(posToCoordF(visibleRange.endPos()-1) + halfChar);
-    
     QFont crf = rulerFont;
     crf.setBold(true);
-    
     QFontMetrics fm(crf);
     int w = width();
 
-    GraphUtils::RulerConfig c;
-    c.notchSize = RULER_NOTCH_SIZE;
     int maxRulerTextWidth = 0;
     foreach(const RulerInfo& ri, customRulers) {
         int w = fm.width(ri.name);
@@ -622,10 +691,8 @@ void PanViewRenderArea::drawCustomRulers(QPainter& p) {
         const RulerInfo& ri = customRulers[i];
         p.setPen(ri.color);
         p.setFont(crf);
-        
         int y = getLineY(getCustomRulerLine(i)) + c.notchSize;
         p.drawText(QRect(LINE_TEXT_OFFSET, y, maxRulerTextWidth, lineHeight), ri.name);
-    
         int rulerStartOffset = maxRulerTextWidth + LINE_TEXT_OFFSET;
         if (rulerStartOffset >= w)  {
             continue;
@@ -641,23 +708,28 @@ void PanViewRenderArea::drawCustomRulers(QPainter& p) {
             startPos+=nChars;
             x+=deltaPixels2;
         }
-        
         int rulerWidth = lastCharCenter - x;
         if (qRound(halfChar) == 0) {
             assert(firstCharCenter == 0 && lastCharCenter == w);
             rulerWidth--; // make the end of the ruler visible
         }
+        int offsetToFirstNotch = c.predefinedChunk - visibleRange.startPos%c.predefinedChunk;
+        int mainRuler = visibleRange.startPos + offsetToFirstNotch; 
+        int newStartPos = visibleRange.startPos - ri.offset + offsetToFirstNotch;
+        int lim = startPos + ri.offset;
+        for(; mainRuler < lim; mainRuler += c.predefinedChunk, newStartPos += c.predefinedChunk);
+        c.correction = newStartPos;
         GraphUtils::drawRuler(p, QPoint(x, y), rulerWidth, startPos, endPos, rulerFont, c);
     }
 }
 
-LRegion PanViewRenderArea::getAnnotationYRange(Annotation* a, int, const AnnotationSettings* as) const {
+U2Region PanViewRenderArea::getAnnotationYRange(Annotation* a, int, const AnnotationSettings* as) const {
     if (!as->visible) {
-        return LRegion(-1, 0);
+        return U2Region(-1, 0);
     }
     int row = getPanView()->getRowsManager()->getAnnotationRowIdx(a);
     int line = getRowLine(row);
-    return LRegion(getLineY(line) + 2, lineHeight - 4);
+    return U2Region(getLineY(line) + 2, lineHeight - 4);
 }
 
 void PanViewRenderArea::drawAnnotations(QPainter& p) {
@@ -693,7 +765,7 @@ void PanViewRenderArea::drawAnnotations(QPainter& p) {
             if (as->visible) {
                 QPen pen1(Qt::SolidLine);
                 pen1.setWidth(1);
-                LRegion yr(lineY + 2, lineHeight - 4);
+                U2Region yr(lineY + 2, lineHeight - 4);
                 foreach(Annotation* a, rData->annotations) {
                     drawAnnotation(p, DrawAnnotationPass_DrawFill, a, pen1, false, as, yr);
                     drawAnnotation(p, DrawAnnotationPass_DrawBorder, a, pen1, false, as, yr);
@@ -730,7 +802,7 @@ void PanViewRenderArea::drawSequence(QPainter& p) {
         halfCharByFont = smallCharWidth / 2.0f;
     }
     const QByteArray& seq = view->getSequenceContext()->getSequenceData();
-    const LRegion& visibleRange = view->getVisibleRange();
+    const U2Region& visibleRange = view->getVisibleRange();
     int y = getLineY(getSelectionLine()) + lineHeight - yCharOffset;
     for (int i = visibleRange.startPos; i < visibleRange.endPos(); i++) {
         char c = seq[i];
@@ -743,12 +815,12 @@ void PanViewRenderArea::drawSequence(QPainter& p) {
 #define ARROW_DY 5
 #define ARROW_DX 5
 void PanViewRenderArea::drawSequenceSelection(QPainter& p) {
-    const QList<LRegion>& selection = panView->getSequenceContext()->getSequenceSelection()->getSelectedRegions();
+    const QVector<U2Region>& selection = panView->getSequenceContext()->getSequenceSelection()->getSelectedRegions();
     bool showSequenceMode = isSequenceCharsVisible();
     if (selection.isEmpty()) {
         return;
     }
-    const LRegion& visibleRange = view->getVisibleRange();
+    const U2Region& visibleRange = view->getVisibleRange();
     QPen pen1(Qt::darkGray, 1, Qt::SolidLine);
     QPen pen2(QColor("#007DE3"), 2, Qt::SolidLine);
     p.setFont(rulerFont);
@@ -775,7 +847,7 @@ void PanViewRenderArea::drawSequenceSelection(QPainter& p) {
     }
 
     QString rangePattern = " "+tr("[%1 %2]")+" ";
-    foreach(const LRegion& r, selection) {
+    foreach(const U2Region& r, selection) {
         if (!visibleRange.intersects(r)) {
             continue;
         }
@@ -808,7 +880,7 @@ void PanViewRenderArea::drawSequenceSelection(QPainter& p) {
             QRect t2Rect = rfm.boundingRect(t2).translated(x2 + tOffs, rty);
 
             // define range text coords
-            QString rangeText = rangePattern.arg(r.len).arg(unitType);
+            QString rangeText = rangePattern.arg(r.length).arg(unitType);
             QRect rtRect = rfm.boundingRect(rangeText);
             int rulerWidth = x2 - x1;
             bool rangeTextInTheMiddle = rulerWidth - dArrow > rtRect.width();
@@ -876,7 +948,7 @@ int PanViewRenderArea::getRowLine(int i) const {
 
 #define MIN_VISIBLE_ROWS  1
 #define EXTRA_EMPTY_ROWS  0
-#define MAX_VISIBLE_ROWS 10
+#define MAX_VISIBLE_ROWS 20
 
 void PanViewRenderArea::setRowLinesOffset(int r) {
     int maxRows = getPanView()->getRowsManager()->getNumRows();
@@ -889,19 +961,115 @@ void PanViewRenderArea::setRowLinesOffset(int r) {
 }
 
 bool PanViewRenderArea::updateNumVisibleRows() {
-    int annotationRows = getPanView()->getRowsManager()->getNumRows();
-    int expectedRowsToShow = annotationRows + EXTRA_EMPTY_ROWS;
-    int actualAnnotationsRowsToShow = qBound(MIN_VISIBLE_ROWS, expectedRowsToShow, MAX_VISIBLE_ROWS);
-    int newNumLines = actualAnnotationsRowsToShow + 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
-    if (newNumLines == numLines) {
-        return false; //height was not changed
+    if(showAllLines) {
+        int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+        numLines =  getPanView()->getRowsManager()->getNumRows() + additionalLines;
+    } else if(defaultRows) {
+        int annotationRows = getPanView()->getRowsManager()->getNumRows();
+        int expectedRowsToShow = annotationRows + EXTRA_EMPTY_ROWS;
+        int actualAnnotationsRowsToShow = qBound(MIN_VISIBLE_ROWS, expectedRowsToShow, MAX_VISIBLE_ROWS);
+        int newNumLines = actualAnnotationsRowsToShow + 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+        if (newNumLines == numLines) {
+            return false; //height was not changed
+        }
+        numLines = newNumLines;
+    } else {
+        fromActions = false;
     }
-    numLines = newNumLines;
     setFixedHeight(numLines * lineHeight);
     view->addUpdateFlags(GSLV_UF_ViewResized);
     view->update();
     return true;
 }
 
+void PanViewRenderArea::sl_increaseLines(){
+    int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+    if(numLines < getPanView()->getRowsManager()->getNumRows() + additionalLines) {
+        numLines++;
+        fromActions = true;
+        defaultRows = false;
+        panView->updateRows();
+    }
+}
+
+void PanViewRenderArea::sl_decreaseLines(){
+    int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+    if(numLines > 1 + additionalLines) {
+        numLines--;
+        panView->showAllAnnotations->setChecked(false);
+        showAllLines = false;
+        fromActions = true;
+        defaultRows = false;
+        panView->updateRows();
+    }
+}
+
+void PanViewRenderArea::sl_increase5Lines(){
+    int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+    if(numLines < getPanView()->getRowsManager()->getNumRows() + additionalLines) {
+        numLines += qMin(5, getPanView()->getRowsManager()->getNumRows() + additionalLines - numLines);
+        fromActions = true;
+        defaultRows = false;
+        panView->updateRows();
+    }
+}
+
+void PanViewRenderArea::sl_decrease5Lines(){
+    int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+    if(numLines > 1 + additionalLines) {
+        numLines -= 5;
+        if(numLines < 1 + additionalLines) {
+            numLines = 1 + additionalLines;
+        }
+        panView->showAllAnnotations->setChecked(false);
+        showAllLines = false;
+        fromActions = true;
+        defaultRows = false;
+        panView->updateRows();
+    }
+}
+
+void PanViewRenderArea::sl_maxLines(bool checked){
+    if(checked) {
+        showAllLines = true;
+        int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+        numLines =  getPanView()->getRowsManager()->getNumRows() + additionalLines;
+        fromActions = true;
+        defaultRows = false;
+        panView->updateRows();
+    } else {
+        showAllLines = false;
+    }
+}
+
+void PanViewRenderArea::sl_resetToDefault() {
+    int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+    numLines = qMin(MAX_VISIBLE_ROWS + additionalLines, getPanView()->getRowsManager()->getNumRows() + additionalLines);
+    panView->showAllAnnotations->setChecked(false);
+    showAllLines = false;
+    fromActions = true;
+    defaultRows = false;
+    panView->updateRows();
+}
+
+bool PanViewRenderArea::canIncreaseLines() {
+    int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+    return numLines < (getPanView()->getRowsManager()->getNumRows() + additionalLines);
+}
+
+bool PanViewRenderArea::canDecreaseLines() {
+    int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+    return numLines > (1 +additionalLines);
+}
+
+bool PanViewRenderArea::isAllLinesShown() {
+    int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+    return numLines == (getPanView()->getRowsManager()->getNumRows() + additionalLines);
+}
+
+bool PanViewRenderArea::isDefaultSize() {
+    int additionalLines = 1 + (showMainRuler ? 1 : 0) + (showCustomRulers ? customRulers.size() : 0);
+    return numLines == (MAX_VISIBLE_ROWS + additionalLines);
+}
 }//namespace
 
