@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "MSAEditor.h"
 #include "MSAEditorTasks.h"
@@ -22,7 +33,9 @@
 #include <util_ov_phyltree/TreeViewerTasks.h>
 
 #include <U2Core/MAlignmentObject.h>
+#include <U2Core/DNASequenceObject.h>
 #include <U2Gui/GUIUtils.h>
+#include <U2Gui/ExportImageDialog.h>
 #include <U2Misc/DialogUtils.h>
 #include <U2Core/AppContext.h>
 
@@ -49,6 +62,7 @@
 #include <U2Core/GUrlUtils.h>
 #include <U2Core/DocumentUtils.h>
 
+#include <U2Core/SaveDocumentTask.h>
 #include <U2Core/PhyTreeObject.h>
 #include <U2Algorithm/PhyTreeGeneratorTask.h>
 #include <U2Algorithm/PhyTreeGeneratorRegistry.h>
@@ -79,6 +93,8 @@ MSAEditor::MSAEditor(const QString& viewName, GObject* obj)
 : GObjectView(MSAEditorFactory::ID, viewName), ui(NULL) {
     msaObject = qobject_cast<MAlignmentObject*>(obj);
     objects.append(msaObject);
+    onObjectAdded(msaObject);
+
     requiredObjects.append(msaObject);
     GCOUNTER(cvar,tvar,"MSAEditor");
 
@@ -100,9 +116,6 @@ MSAEditor::MSAEditor(const QString& viewName, GObject* obj)
     buildTreeAction = new QAction(QIcon(":/core/images/phylip.png"), tr("Build Tree"), this);
     connect(buildTreeAction, SIGNAL(triggered()), SLOT(sl_buildTree()));
 
-    saveScreenshotAction = new QAction(QIcon(":/core/images/cam2.png"), tr("Export as image"), this);
-    connect(saveScreenshotAction, SIGNAL(triggered()), SLOT(sl_saveScreenshot()));
-
     Settings* s = AppContext::getSettings();
     zoomFactor = DEFAULT_ZOOM_FACTOR;
     font.setFamily(s->getValue(SETTINGS_ROOT + SETTINGS_FONT_FAMILY, DEFAULT_FONT_FAMILY).toString());
@@ -236,7 +249,7 @@ void MSAEditor::sl_buildTree() {
 }
 
 void MSAEditor::sl_openTree() {
-    if (treeGeneratorTask->getState() != Task::State_Finished || treeGeneratorTask->hasErrors()) {
+    if (treeGeneratorTask->getState() != Task::State_Finished || treeGeneratorTask->hasError()) {
         return;
     }
 
@@ -258,11 +271,18 @@ void MSAEditor::sl_openTree() {
     Document *d = new Document(df, iof, treeFileName, QList<GObject*>()<<newObj);
     p->addDocument(d);
 
+    Task* saveTask = new SaveDocumentTask(d);
     Task* task = new OpenTreeViewerTask(newObj);
     TaskScheduler* scheduler = AppContext::getTaskScheduler();
+    scheduler->registerTopLevelTask(saveTask);
     scheduler->registerTopLevelTask(task);
 }
 
+void MSAEditor::onObjectRenamed(GObject*, const QString&) {
+    // update title
+    OpenMSAEditorTask::updateTitle(this);
+}
+
 static void saveFont(const QFont& f) {
     Settings* s = AppContext::getSettings();
     s->setValue(SETTINGS_ROOT + SETTINGS_FONT_FAMILY, f.family());
@@ -408,6 +428,9 @@ QWidget* MSAEditor::createWidget() {
     assert(ui == NULL);
     ui = new MSAEditorUI(this);
     connect(ui , SIGNAL(customContextMenuRequested(const QPoint &)), SLOT(sl_onContextMenuRequested(const QPoint &)));
+    saveScreenshotAction = new QAction(QIcon(":/core/images/cam2.png"), tr("Export as image"), this);
+    connect(saveScreenshotAction, SIGNAL(triggered()), ui, SLOT(sl_saveScreenshot()));
+    initDragAndDropSupport();
     return ui;
 }
 
@@ -441,8 +464,7 @@ void MSAEditor::sl_onContextMenuRequested(const QPoint & pos) {
     m.exec(QCursor::pos());
 }
 
-const QRect MSAEditor::getCurrentSelection() const
-{
+const QRect& MSAEditor::getCurrentSelection() const {
     return ui->seqArea->getSelection().getRect();
 }
 
@@ -459,20 +481,37 @@ void MSAEditor::calcFontPixelToPointSizeCoef() {
     
 }
 
-void MSAEditor::sl_saveScreenshot() {
-    QMap<QString, QString> filters;
-    filters[ "PNG - Portable Network Graphics (*.png)" ] = "png";
-    filters[ "JPG/JPEG format (*.jpg)" ] = "jpg";
-    filters[ "TIF - Tagged Image File format (*.tiff)" ] = "tiff";
-
-    LastOpenDirHelper lod("image");
-    QString selectedFilter;
-    lod.url = QFileDialog::getSaveFileName(ui, tr("Export alignment image"), lod.dir, QStringList(filters.keys()).join(";;"), &selectedFilter);
-    if (lod.url.isEmpty()) {
-        return;
+bool MSAEditor::eventFilter(QObject*, QEvent* e) {
+    if (e->type() == QEvent::DragEnter || e->type() == QEvent::Drop) {
+        QDropEvent* de = (QDropEvent*)e;
+        const QMimeData* md = de->mimeData();
+        const GObjectMimeData* gomd = qobject_cast<const GObjectMimeData*>(md);
+        if (gomd != NULL) {
+            if (msaObject->isStateLocked()) {
+                return false;
+            }
+            DNASequenceObject* dnaObj = qobject_cast<DNASequenceObject*> (gomd->objPtr.data());
+            if (dnaObj != NULL ) {
+                if (DNAAlphabet::deriveCommonAlphabet(dnaObj->getAlphabet(), msaObject->getAlphabet()) == NULL) {
+                    return false;
+                }
+                if (e->type() == QEvent::DragEnter) {
+                    de->acceptProposedAction();
+                } else {     
+                    msaObject->addRow(dnaObj->getDNASequence());
+                }    
+            }
+        }
     }
-    QString format = filters.value(selectedFilter);
-    ui->saveScreenshot(lod.url, format);
+
+    return false;    
+}
+
+void MSAEditor::initDragAndDropSupport()
+{
+    assert(ui!= NULL);
+    ui->setAcceptDrops(true);
+    ui->installEventFilter(this);
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -482,6 +521,8 @@ MSAEditorUI::MSAEditorUI(MSAEditor* _editor): editor(_editor), seqArea(NULL), of
     setContextMenuPolicy(Qt::CustomContextMenu);
     setMinimumSize(300, 200);
 
+    setWindowIcon(GObjectTypes::getTypeInfo(GObjectTypes::MULTIPLE_ALIGNMENT).icon);
+
     QWidget *seqAreaContainer, *nameAreaContainer, *label;
     GScrollBar* shBar = new GScrollBar(Qt::Horizontal);
     QScrollBar* nhBar = new QScrollBar(Qt::Horizontal);
@@ -566,11 +607,9 @@ QAction* MSAEditorUI::getRedoAction() const {
     return undoFWK->getRedoAction();
 }
 
-void MSAEditorUI::saveScreenshot(const QString& filename, const QString& format) {
-    QRect screenRect(0, 0, 0, 0);
-    screenRect.setBottomRight(seqArea->parentWidget()->geometry().bottomRight());
-    QPixmap curPixMap = QPixmap::grabWidget(this, screenRect);
-    curPixMap.save(filename, format.toAscii().constData());
+void MSAEditorUI::sl_saveScreenshot(){
+    ExportImageDialog dialog(this);
+    dialog.exec();
 }
 
 MSALabelWidget::MSALabelWidget(const MSAEditorUI* _ui, const QString & _t, Qt::Alignment _a) 
@@ -593,5 +632,11 @@ void MSALabelWidget::sl_fontChanged() {
     setMinimumHeight(ui->consArea->height());
 }
 
+void MSALabelWidget::mousePressEvent( QMouseEvent *e )
+{
+    ui->seqArea->cancelSelection();
+}
+
+
 }//namespace
 
