@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "MSAEditorConsensusArea.h"
 #include "MSAEditor.h"
@@ -175,9 +186,9 @@ void MSAEditorConsensusArea::drawConsensus(QPainter& p) {
 }
 
 void MSAEditorConsensusArea::drawConsensusChar(QPainter& p, int pos, bool selected) {
-    LRegion yRange = getYRange(MSAEditorConsElement_CONSENSUS_TEXT);
-    LRegion xRange= ui->seqArea->getBaseXRange(pos, false);
-    QRect cr(xRange.startPos, yRange.startPos, xRange.len + 1, yRange.len);
+    U2Region yRange = getYRange(MSAEditorConsElement_CONSENSUS_TEXT);
+    U2Region xRange= ui->seqArea->getBaseXRange(pos, false);
+    QRect cr(xRange.startPos, yRange.startPos, xRange.length + 1, yRange.length);
     int w = width(), h = height();
     assert(xRange.endPos() <= w && yRange.endPos() <= h); Q_UNUSED(w); Q_UNUSED(h);
     if (selected) {
@@ -202,25 +213,25 @@ void MSAEditorConsensusArea::drawRuler(QPainter& p) {
     int lastPos = ui->seqArea->getLastVisibleBase(true);
 
     QFontMetrics rfm(rulerFont);
-    LRegion rr = getYRange(MSAEditorConsElement_RULER);
-    LRegion rrP = getYRange(MSAEditorConsElement_CONSENSUS_TEXT);
+    U2Region rr = getYRange(MSAEditorConsElement_RULER);
+    U2Region rrP = getYRange(MSAEditorConsElement_CONSENSUS_TEXT);
     int dy = rr.startPos - rrP.endPos();
-    rr.len+=dy;
+    rr.length+=dy;
     rr.startPos-=dy;
-    LRegion firstBaseXReg = ui->seqArea->getBaseXRange(startPos, false);
-    LRegion lastBaseXReg = ui->seqArea->getBaseXRange(lastPos, false);
+    U2Region firstBaseXReg = ui->seqArea->getBaseXRange(startPos, false);
+    U2Region lastBaseXReg = ui->seqArea->getBaseXRange(lastPos, false);
     int firstLastLen = lastBaseXReg.startPos - firstBaseXReg.startPos;
-    int firstXCenter = firstBaseXReg.startPos + firstBaseXReg.len / 2;
+    int firstXCenter = firstBaseXReg.startPos + firstBaseXReg.length / 2;
     QPoint startPoint(firstXCenter, rr.startPos);
     
     GraphUtils::RulerConfig c;
     c.singleSideNotches = true;
     c.notchSize = RULER_NOTCH_SIZE;
-    c.textOffset = (rr.len - rfm.ascent()) /2;
+    c.textOffset = (rr.length - rfm.ascent()) /2;
     c.extraAxisLenBefore = startPoint.x();
     c.extraAxisLenAfter = w - (startPoint.x() + firstLastLen);
-    c.textBorderStart = -firstBaseXReg.len / 2;
-    c.textBorderEnd = -firstBaseXReg.len / 2;
+    c.textBorderStart = -firstBaseXReg.length / 2;
+    c.textBorderEnd = -firstBaseXReg.length / 2;
     GraphUtils::drawRuler(p, startPoint, firstLastLen, startPos + 1, lastPos + 1, rulerFont, c);
 
     startPoint.setY(rr.endPos());
@@ -232,33 +243,33 @@ void MSAEditorConsensusArea::drawRuler(QPainter& p) {
 void MSAEditorConsensusArea::drawHistogram(QPainter& p) {
     QColor c("#255060");
     p.setPen(c);
-    LRegion yr = getYRange(MSAEditorConsElement_HISTOGRAM);
-    yr.startPos++; yr.len-=2; //keep borders
+    U2Region yr = getYRange(MSAEditorConsElement_HISTOGRAM);
+    yr.startPos++; yr.length-=2; //keep borders
     QBrush brush(c, Qt::Dense4Pattern);
     QVector<int> counts(256, 0);
     for (int pos = ui->seqArea->getFirstVisibleBase(), lastPos = ui->seqArea->getLastVisibleBase(true); pos <= lastPos; pos++) {
-        LRegion xr = ui->seqArea->getBaseXRange(pos, true);
+        U2Region xr = ui->seqArea->getBaseXRange(pos, true);
         int percent = consensusCache->getConsensusCharPercent(pos);
         assert(percent >= 0 && percent <= 100);
-        int h = qRound(percent * yr.len / 100.0);
-        QRect hr(xr.startPos + 1, yr.endPos() - h, xr.len - 2, h);
+        int h = qRound(percent * yr.length / 100.0);
+        QRect hr(xr.startPos + 1, yr.endPos() - h, xr.length - 2, h);
         p.drawRect(hr);
         p.fillRect(hr, brush);
     }
 }
 
-LRegion MSAEditorConsensusArea::getYRange(MSAEditorConsElement e) const {
-    LRegion res;
+U2Region MSAEditorConsensusArea::getYRange(MSAEditorConsElement e) const {
+    U2Region res;
     switch(e) {
         case MSAEditorConsElement_HISTOGRAM: 
-                                res = LRegion(0, 50);
+                                res = U2Region(0, 50);
                                 break;
         case MSAEditorConsElement_CONSENSUS_TEXT: 
-                                res = LRegion(0, editor->getRowHeight());
+                                res = U2Region(0, editor->getRowHeight());
                                 res.startPos += getYRange(MSAEditorConsElement(e-1)).endPos();
                                 break;
         case MSAEditorConsElement_RULER: 
-                                res = LRegion(0, rulerFontHeight + 2 * RULER_NOTCH_SIZE + 4);
+                                res = U2Region(0, rulerFontHeight + 2 * RULER_NOTCH_SIZE + 4);
                                 res.startPos += getYRange(MSAEditorConsElement(e-1)).endPos();
                                 break;
     }
@@ -355,7 +366,7 @@ void MSAEditorConsensusArea::sl_configureConsensusAction() {
 void MSAEditorConsensusArea::updateThresholdInfoInConsensusDialog() {
     const MSAConsensusAlgorithm* algo = getConsensusAlgorithm();
     if (algo->supportsThreshold()) {
-        consensusDialog->enableThresholdSelector(algo->getThresholdRange(), algo->getThreshold(), algo->getThresholdSuffix());
+        consensusDialog->enableThresholdSelector(algo->getMinThreshold(), algo->getMaxThreshold(), algo->getThreshold(), algo->getThresholdSuffix());
     } else {
         consensusDialog->disableThresholdSelector();
     }
