@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "MSAEditorSequenceArea.h"
 #include "MSAEditor.h"
@@ -14,7 +25,6 @@
 #include "CreateSubalignimentDialogController.h"
 
 #include <U2Algorithm/CreateSubalignmentTask.h>
-#include <U2Gui/DelayedAddDocumentAndOpenViewTask.h>
 #include <U2Core/SaveDocumentTask.h>
 #include <U2Core/AddSequencesToAlignmentTask.h>
 #include <U2Core/DNAAlphabet.h>
@@ -92,7 +102,7 @@ MSAEditorSequenceArea::MSAEditorSequenceArea(MSAEditorUI* _ui, GScrollBar* hb, G
     addAction(insSymAction);
 
 
-    createSubaligniment = new QAction(tr("Extract selected as MSA..."), this);
+    createSubaligniment = new QAction(tr("Save subalignment"), this);
     createSubaligniment->setShortcutContext(Qt::WidgetShortcut);
     connect(createSubaligniment, SIGNAL(triggered()), SLOT(sl_createSubaligniment()));
 
@@ -107,9 +117,6 @@ MSAEditorSequenceArea::MSAEditorSequenceArea(MSAEditorUI* _ui, GScrollBar* hb, G
     gotoAction->setToolTip(QString("%1 (%2)").arg(gotoAction->text()).arg(gotoAction->shortcut().toString()));
     connect(gotoAction, SIGNAL(triggered()), SLOT(sl_goto()));
 
-    //removeGapColumnsAction = new QAction(QIcon(":core/images/msaed_remove_columns_with_gaps.png"), tr("Remove columns with gaps"), this);
-    //connect(removeGapColumnsAction, SIGNAL(triggered()), SLOT(sl_removeColumnsWithGaps()));
-    
     removeAllGapsAction = new QAction(QIcon(":core/images/msaed_remove_all_gaps.png"), tr("Remove all gaps"), this);
     connect(removeAllGapsAction, SIGNAL(triggered()), SLOT(sl_removeAllGaps()));
 
@@ -260,14 +267,14 @@ void MSAEditorSequenceArea::drawContent(QPainter& p) {
     int h = height();
     const MAlignment& msa = maObj->getMAlignment();
     for (int seq = firstVisibleSeq; seq <= lastVisibleSeq; seq++) {
-        LRegion baseYRange = getSequenceYRange(seq, true);
+        U2Region baseYRange = getSequenceYRange(seq, true);
 
         //draw horizontal grid
         //p.drawLine(0, r.startPos, width(), r.startPos); p.drawLine(0, r.endPos(), width(), r.endPos());
 
         for (int pos = startPos; pos <= lastPos; pos++) {
-            LRegion baseXRange = getBaseXRange(pos, true);
-            QRect cr(baseXRange.startPos, baseYRange.startPos, baseXRange.len+1, baseYRange.len);
+            U2Region baseXRange = getBaseXRange(pos, true);
+            QRect cr(baseXRange.startPos, baseYRange.startPos, baseXRange.length+1, baseYRange.length);
             assert(cr.left() < w && cr.top() < h); Q_UNUSED(w); Q_UNUSED(h);
             char c = msa.charAt(seq, pos);
             QColor color = colorScheme->getColor(seq, pos);
@@ -289,14 +296,14 @@ void MSAEditorSequenceArea::drawSelection( QPainter &p )
     int x = selection.x();
     int y = selection.y();
     
-    LRegion xRange = getBaseXRange(x, true);
-    LRegion yRange = getSequenceYRange(y, true);
+    U2Region xRange = getBaseXRange(x, true);
+    U2Region yRange = getSequenceYRange(y, true);
  
     QPen pen(highlightSelection || hasFocus()? Qt::black : Qt::gray);
     pen.setStyle(Qt::DashLine);
     pen.setWidth(highlightSelection ? 2 : 1);
     p.setPen(pen);
-    p.drawRect(xRange.startPos, yRange.startPos, xRange.len*selection.width(), yRange.len*selection.height());
+    p.drawRect(xRange.startPos, yRange.startPos, xRange.length*selection.width(), yRange.length*selection.height());
 
 }
 
@@ -304,14 +311,14 @@ void MSAEditorSequenceArea::drawCursor(QPainter& p) {
     if (!isVisible(cursorPos, true)) {
         return;
     }
-    LRegion xRange = getBaseXRange(cursorPos.x(), true);
-    LRegion yRange = getSequenceYRange(cursorPos.y(), true);
+    U2Region xRange = getBaseXRange(cursorPos.x(), true);
+    U2Region yRange = getSequenceYRange(cursorPos.y(), true);
 
     QPen pen(highlightSelection || hasFocus()? Qt::black : Qt::gray);
     pen.setStyle(Qt::DashLine);
     pen.setWidth(highlightSelection ? 2 : 1);
     p.setPen(pen);
-    p.drawRect(xRange.startPos, yRange.startPos, xRange.len, yRange.len);
+    p.drawRect(xRange.startPos, yRange.startPos, xRange.length, yRange.length);
 }
 
 void MSAEditorSequenceArea::drawFocus(QPainter& p) {
@@ -538,20 +545,20 @@ int MSAEditorSequenceArea::getSequenceNumByY(int y) const {
     return seq;
 }
 
-LRegion MSAEditorSequenceArea::getBaseXRange(int pos, bool useVirtualCoords) const {
-    LRegion res(editor->getColumnWidth() * (pos - startPos), editor->getColumnWidth());
+U2Region MSAEditorSequenceArea::getBaseXRange(int pos, bool useVirtualCoords) const {
+    U2Region res(editor->getColumnWidth() * (pos - startPos), editor->getColumnWidth());
     if (!useVirtualCoords) {
         int w = width();
-        res = res.intersect(LRegion(0, w));
+        res = res.intersect(U2Region(0, w));
     }
     return res;
 }
 
-LRegion MSAEditorSequenceArea::getSequenceYRange(int seq, bool useVirtualCoords) const {
-    LRegion res(editor->getRowHeight()* (seq - startSeq), editor->getRowHeight());
+U2Region MSAEditorSequenceArea::getSequenceYRange(int seq, bool useVirtualCoords) const {
+    U2Region res(editor->getRowHeight()* (seq - startSeq), editor->getRowHeight());
     if (!useVirtualCoords) {
         int h = height();
-        res = res.intersect(LRegion(0, h));
+        res = res.intersect(U2Region(0, h));
     }
     return res;
 }
@@ -842,7 +849,7 @@ QPoint MSAEditorSequenceArea::coordToPos(const QPoint& coord) const {
     QPoint res(-1, -1);
     //Y: row
     for (int i=getFirstVisibleSequence(), n = getLastVisibleSequence(true); i<=n; i++) {
-        LRegion r = getSequenceYRange(i, false);
+        U2Region r = getSequenceYRange(i, false);
         if (r.contains(coord.y())) {
             res.setY(i);
             break;
@@ -851,7 +858,7 @@ QPoint MSAEditorSequenceArea::coordToPos(const QPoint& coord) const {
     
     //X: position in sequence
     for (int i=getFirstVisibleBase(), n = getLastVisibleBase(true); i<=n; i++) {
-        LRegion r = getBaseXRange(i, false);
+        U2Region r = getBaseXRange(i, false);
         if (r.contains(coord.x())) {
             res.setX(i);
             break;
@@ -998,9 +1005,13 @@ void MSAEditorSequenceArea::buildMenu(QMenu* m) {
     QMenu* editMenu = GUIUtils::findSubMenu(m, MSAE_MENU_EDIT);
     assert(editMenu!=NULL);
     QList<QAction*> actions; 
-    actions << createSubaligniment << removeAllGapsAction;
+    actions << removeAllGapsAction;
     editMenu->insertActions(editMenu->isEmpty() ? NULL : editMenu->actions().first(), actions);
-
+    
+    QMenu * exportMenu = GUIUtils::findSubMenu(m, MSAE_MENU_EXPORT);
+    assert(exportMenu != NULL);
+    exportMenu->addAction(createSubaligniment);
+    
     QMenu* copyMenu = GUIUtils::findSubMenu(m, MSAE_MENU_COPY);
     copyMenu->addAction(copySelectionAction);
 
@@ -1026,13 +1037,14 @@ void MSAEditorSequenceArea::sl_delCol() {
     if(dlg.exec() == QDialog::Accepted) {
         DeleteMode deleteMode = dlg.getDeleteMode();
         int value = dlg.getValue();
-
+        MAlignmentObject* msaObj = editor->getMSAObject();
         switch(deleteMode) {
-            case DeleteByAbsoluteVal: editor->getMSAObject()->geleteGapsByAbsoluteVal(value);
+            case DeleteByAbsoluteVal: msaObj->deleteGapsByAbsoluteVal(value);
                 break;
-            case DeleteByRelativeVal: editor->getMSAObject()->geleteGapsByRelativeVal(value);
+            case DeleteByRelativeVal: 
+                msaObj->deleteGapsByAbsoluteVal( ( msaObj->getMAlignment().getNumRows()*value ) / 100 );
                 break;
-            case DeleteAll: editor->getMSAObject()->deleteAllGapColumn();
+            case DeleteAll: msaObj->deleteAllGapColumn();
                 break;
             default:
                 assert(0);
@@ -1141,17 +1153,13 @@ void MSAEditorSequenceArea::sl_createSubaligniment(){
     CreateSubalignimentDialogController dialog(editor->getMSAObject(), selection.getRect(), this);
     dialog.exec();
     if(dialog.result() == QDialog::Accepted){
-        LRegion window = dialog.getRegion();
-        bool isAdd = dialog.getAddToProjFlag();
+        U2Region window = dialog.getRegion();
+        bool addToProject = dialog.getAddToProjFlag();
         QString path = dialog.getSavePath();
         QStringList seqNames = dialog.getSelectedSeqNames();
-
-        CreateSubalignmentTask *csatask = new CreateSubalignmentTask(editor->getMSAObject(), window, seqNames, path, true);
-        if(isAdd) {
-            DelayedAddDocumentAndOpenViewTask *delayedTask = new DelayedAddDocumentAndOpenViewTask();
-            connect(csatask, SIGNAL(documentCreated(Document*)), delayedTask, SLOT(sl_onDocumentAvailable(Document*)));
-        }
-        AppContext::getTaskScheduler()->registerTopLevelTask(csatask);
+        Task* csTask = new CreateSubalignmentAndOpenViewTask(editor->getMSAObject(), 
+            CreateSubalignmentSettings(window, seqNames, path, true, addToProject) );
+        AppContext::getTaskScheduler()->registerTopLevelTask(csTask);
     }
 }
 
@@ -1262,6 +1270,12 @@ void MSAEditorSequenceArea::deleteCurrentSelection()
 
         maObj->removeRegion(selection.x(), selection.y(), selection.width(), selection.height(), true);
     }
+    if (selection.height() == 1 && selection.width() == 1) {
+        if (isInRange(selection.topLeft())) {
+            return;
+        }
+    }
+
     cancelSelection();
     
 }
@@ -1276,11 +1290,12 @@ void MSAEditorSequenceArea::sl_addSeqFromFile()
     QString filter = DialogUtils::prepareDocumentsFileFilterByObjType(GObjectTypes::SEQUENCE, true);
     
     LastOpenDirHelper lod;
-    lod.url = QFileDialog::getOpenFileName(this, tr("Open file with sequences"), lod.dir, filter);
+    QStringList urls = QFileDialog::getOpenFileNames(this, tr("Open file with sequences"), lod.dir, filter);
     
-    if (!lod.url.isEmpty()) {
+    if (!urls.isEmpty()) {
+        lod.url = urls.first();
         cancelSelection();
-        AddSequencesToAlignmentTask * task = new AddSequencesToAlignmentTask(msaObject, lod.url);    
+        AddSequencesToAlignmentTask * task = new AddSequencesToAlignmentTask(msaObject, urls);    
         AppContext::getTaskScheduler()->registerTopLevelTask(task);
     }
     
@@ -1345,9 +1360,11 @@ void MSAEditorSequenceArea::fillSelectionWithGaps( )
             return;
     }
     
-    LRegion sequences(selection.y(), selection.height());
+    U2Region sequences(selection.y(), selection.height());
     maObj->insertGap(sequences,  selection.x() , selection.width());
-    cancelSelection();
+    if (selection.height() > 1 && selection.width() > 1) {
+        cancelSelection();
+    }
     
 }
 
