@@ -1,13 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
+/**
+* UGENE - Integrated Bioinformatics Tools.
+* Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+* http://ugene.unipro.ru
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License
+* as published by the Free Software Foundation; either version 2
+* of the License, or (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+* MA 02110-1301, USA.
+*/
 #include "TreeViewer.h"
 #include "TreeViewerFactory.h"
 #include "GraphicsBranchItem.h"
@@ -31,6 +41,9 @@
 #include <U2Core/ProjectModel.h>
 #include <U2Core/L10n.h>
 
+#include <U2Gui/GUIUtils.h>
+#include <U2Gui/ExportImageDialog.h>
+
 #include <U2Misc/HBar.h>
 #include <U2Misc/DialogUtils.h>
 #include <U2View/CreatePhyTreeDialogController.h>
@@ -56,24 +69,22 @@ namespace U2 {
 
 TreeViewer::TreeViewer(const QString& viewName, GObject* obj, GraphicsRectangularBranchItem* _root, qreal s):
     GObjectView(TreeViewerFactory::ID, viewName),
-    printAction(NULL),
-    contAction(NULL),
-    nameLabelsAction(NULL),
-    distanceLabelsAction(NULL),
-    captureTreeAction(NULL),
-    exportAction(NULL),
+    treeSettingsAction(NULL),
+    layoutGroup(NULL),
     rectangularLayoutAction(NULL),
     circularLayoutAction(NULL),
     unrootedLayoutAction(NULL),
-    labelsMenu(NULL),
-    captureMenu(NULL),
-    layoutMenu(NULL),
-    textSettingsAction(NULL),
     branchesSettingsAction(NULL),
+    nameLabelsAction(NULL),
+    distanceLabelsAction(NULL),
+    textSettingsAction(NULL),
+    contAction(NULL),
     zoomToSelAction(NULL),
     zoomToAllAction(NULL),
     zoomOutAction(NULL),
-    buttonToolBar(NULL),
+    printAction(NULL),
+    captureTreeAction(NULL),
+    exportAction(NULL),
     ui(NULL),
     root(_root),
     scale(s)
@@ -81,10 +92,10 @@ TreeViewer::TreeViewer(const QString& viewName, GObject* obj, GraphicsRectangula
     phyObject = qobject_cast<PhyTreeObject*>(obj);
     objects.append(phyObject);
     requiredObjects.append(phyObject);
+    onObjectAdded(phyObject);
 }
 
 QTransform TreeViewer::getTransform() const {
-
     return ui->transform();
 }
 
@@ -124,110 +135,205 @@ Task* TreeViewer::updateViewTask(const QString& stateName, const QVariantMap& st
 }
 
 void TreeViewer::createActions() {
-    labelsMenu = new QMenu();
-    nameLabelsAction = labelsMenu->addAction(tr("Show sequence names"));
+    // Tree Settings
+    treeSettingsAction = new QAction(QIcon(":core/images/phylip.png"), tr("Tree Settings..."), ui);
+
+    // Layout
+    layoutGroup = new QActionGroup(ui);
+
+    rectangularLayoutAction = new QAction(tr("Rectangular"), layoutGroup);
+    rectangularLayoutAction->setCheckable(true);
+    rectangularLayoutAction->setChecked(true);
+
+    circularLayoutAction = new QAction(tr("Circular"), layoutGroup);
+    circularLayoutAction->setCheckable(true);
+
+    unrootedLayoutAction = new QAction(tr("Unrooted"), layoutGroup);
+    unrootedLayoutAction->setCheckable(true);
+
+    // Branch Settings
+    branchesSettingsAction = new QAction(QIcon(":core/images/color_wheel.png"), tr("Branch Settings..."), ui);
+
+    // Show Labels
+    nameLabelsAction = new QAction(tr("Show Names"), ui);
     nameLabelsAction->setCheckable(true);
     nameLabelsAction->setChecked(true);
-    distanceLabelsAction = labelsMenu->addAction(tr("Show distance labels"));
+
+    distanceLabelsAction = new QAction(tr("Show Distances"), ui);
     distanceLabelsAction->setCheckable(true);
     distanceLabelsAction->setChecked(true);
 
-    printAction = new QAction(QIcon(":/core/images/printer.png"), tr("Print tree"), ui);
+    // Formatting
+    textSettingsAction = new QAction(QIcon(":core/images/font.png"), tr("Formatting..."), ui);
 
-    captureMenu = new QMenu();
-    captureTreeAction = captureMenu->addAction(tr("Capture tree"));
-    exportAction = captureMenu->addAction(tr("Export tree in SVG"));
-
-    contAction = new QAction(QIcon(":core/images/align_tree_labels.png"), tr("Align name labels"), ui);
+    // Align Labels
+    // Note: the icon is truncated to 15 px height to look properly in the main menu when it is checked
+    contAction = new QAction(QIcon(":core/images/align_tree_labels.png"), tr("Align Labels"), ui);
     contAction->setCheckable(true);
 
-    layoutMenu = new QMenu();
-    rectangularLayoutAction = layoutMenu->addAction(tr("Rectangular layout"));
-    rectangularLayoutAction->setCheckable(true);
-    rectangularLayoutAction->setChecked(true);
-    circularLayoutAction = layoutMenu->addAction(tr("Circular layout"));
-    circularLayoutAction->setCheckable(true);
-    unrootedLayoutAction = layoutMenu->addAction(tr("Unrooted layout"));
-    unrootedLayoutAction->setCheckable(true);
+    // Zooming
+    zoomToSelAction = new QAction(QIcon(":core/images/zoom_in.png"), tr("Zoom In") , ui);
+    zoomOutAction = new QAction(QIcon(":core/images/zoom_out.png"), tr("Zoom Out"), ui);
+    zoomToAllAction = new QAction(QIcon(":core/images/zoom_whole.png"), tr("Reset Zooming"), ui);
 
-    branchesSettingsAction = new QAction(QIcon(":core/images/color_wheel.png"), tr("Branch settings"), ui);
-    textSettingsAction = new QAction(QIcon(":core/images/font.png"), tr("Text settings"), ui);
+    // Print Tree
+    printAction = new QAction(QIcon(":/core/images/printer.png"), tr("Print Tree..."), ui);
 
-    zoomToSelAction = new QAction(QIcon(":core/images/zoom_in.png"), tr("Zoom in") , ui);
-    zoomOutAction = new QAction(QIcon(":core/images/zoom_out.png"), tr("Zoom out"), ui);
-    zoomToAllAction = new QAction(QIcon(":core/images/zoom_whole.png"), tr("Reset zooming"), ui);
-
-    QActionGroup* layoutGroup = new QActionGroup(ui);
-    rectangularLayoutAction->setActionGroup(layoutGroup);
-    circularLayoutAction->setActionGroup(layoutGroup);
-    unrootedLayoutAction->setActionGroup(layoutGroup);
+    // Screen Capture
+    captureTreeAction = new QAction(tr("Screen Capture..."), ui);
+    exportAction = new QAction(tr("Whole Tree as SVG..."), ui);
 }
 
-void TreeViewer::buildStaticToolbar(QToolBar* tb) {
-    QToolButton* button = new QToolButton();
-    button->setPopupMode(QToolButton::InstantPopup);
-    QAction* defaultAction = new QAction(QIcon(":/core/images/text_ab.png"), "", button);
-    button->setDefaultAction(defaultAction);
-    button->setMenu(labelsMenu);
-    tb->addWidget(button);
+void TreeViewer::setupLayoutSettingsMenu(QMenu* m)
+{
+    m->addActions(layoutGroup->actions());
+}
 
-    tb->addAction(printAction);
+void TreeViewer::setupShowLabelsMenu(QMenu* m)
+{
+    m->addAction(nameLabelsAction);
+    m->addAction(distanceLabelsAction);
+}
 
-    button = new QToolButton();
-    button->setPopupMode(QToolButton::InstantPopup);
-    defaultAction = new QAction(QIcon(":/core/images/cam2.png"), "", button);
-    button->setDefaultAction(defaultAction);
-    button->setMenu(captureMenu);
-    tb->addWidget(button);
+void TreeViewer::setupCameraMenu(QMenu* m)
+{
+    m->addAction(captureTreeAction);
+    m->addAction(exportAction);
+}
 
+void TreeViewer::buildStaticToolbar(QToolBar* tb) 
+{
+    // Tree Settings
+    tb->addAction(treeSettingsAction);
+
+    // Layout
+    QToolButton* layoutButton = new QToolButton(tb);
+    QMenu* layoutMenu = new QMenu(tr("Layout"), ui);
+    setupLayoutSettingsMenu(layoutMenu);
+    layoutButton->setDefaultAction(layoutMenu->menuAction());
+    layoutButton->setPopupMode(QToolButton::InstantPopup);
+    layoutButton->setIcon(QIcon(":core/images/tree_layout.png"));
+    tb->addWidget(layoutButton);
+
+    // Branch Settings
+    tb->addAction(branchesSettingsAction);
+
+    // Labels and Text Settings
+    tb->addSeparator();
+    QToolButton* showLabelsButton = new QToolButton();
+    QMenu* showLabelsMenu = new QMenu(tr("Show Labels"), ui);
+    setupShowLabelsMenu(showLabelsMenu);
+    showLabelsButton->setDefaultAction(showLabelsMenu->menuAction());
+    showLabelsButton->setPopupMode(QToolButton::InstantPopup);
+    showLabelsButton->setIcon(QIcon(":/core/images/text_ab.png"));
+    tb->addWidget(showLabelsButton);
+
+    tb->addAction(textSettingsAction);
     tb->addAction(contAction);
-
-    button = new QToolButton();
-    button->setPopupMode(QToolButton::InstantPopup);
-    defaultAction = new QAction(tr("Layout"), button);
-    button->setDefaultAction(defaultAction);
-    button->setMenu(layoutMenu);
-    tb->addWidget(button);
-
+    // Zooming
+    tb->addSeparator();
     tb->addAction(zoomToSelAction);
     tb->addAction(zoomOutAction);
     tb->addAction(zoomToAllAction);
 
-    tb->addAction(branchesSettingsAction);
-    tb->addAction(textSettingsAction);
+    // Print and Capture
+    tb->addSeparator();
+    tb->addAction(printAction);
+
+    QToolButton* cameraButton = new QToolButton();
+    QMenu* cameraMenu = new QMenu(tr("Export Tree Image"), ui);
+    setupCameraMenu(cameraMenu);
+    cameraButton->setDefaultAction(cameraMenu->menuAction());
+    cameraButton->setPopupMode(QToolButton::InstantPopup);
+    cameraButton->setIcon(QIcon(":/core/images/cam2.png"));
+    tb->addWidget(cameraButton);
 }
 
+void TreeViewer::buildStaticMenu(QMenu* m)
+{
+    // Tree Settings
+    m->addAction(treeSettingsAction);
+
+    // Layout
+    QMenu* layoutMenu = new QMenu(tr("Layout"), ui);
+    setupLayoutSettingsMenu(layoutMenu);
+    layoutMenu->setIcon(QIcon(":core/images/tree_layout.png"));
+    m->addMenu(layoutMenu);
+
+    // Branch Settings
+    m->addAction(branchesSettingsAction);
+
+    // Labels and Text Settings
+    m->addSeparator();
+
+    QMenu* labelsMenu = new QMenu(tr("Show Labels"), ui);
+    setupShowLabelsMenu(labelsMenu);
+    labelsMenu->setIcon(QIcon(":/core/images/text_ab.png"));
+    m->addMenu(labelsMenu);
+
+    m->addAction(textSettingsAction);
+
+    m->addAction(contAction);
+    // Zooming
+    m->addSeparator();
+    m->addAction(zoomToSelAction);
+    m->addAction(zoomOutAction);
+    m->addAction(zoomToAllAction);
+
+    // Print and Capture
+    m->addSeparator();
+    m->addAction(printAction);
+
+    QMenu* cameraMenu = new QMenu(tr("Export Tree Image"), ui);
+    setupCameraMenu(cameraMenu);
+    cameraMenu->setIcon(QIcon(":/core/images/cam2.png"));
+    m->addMenu(cameraMenu);
+
+    m->addSeparator();
+
+    GObjectView::buildStaticMenu(m);
+    GUIUtils::disableEmptySubmenus(m);
+}
 
 QWidget* TreeViewer::createWidget() {
     assert(ui == NULL);
     ui = new TreeViewerUI(this);
 
-    connect(ui, SIGNAL( ui->si_zoomChanged(qreal) ), SLOT(sl_zoomChanged(qreal) ));
-
     return ui;
 }
 
+void TreeViewer::onObjectRenamed(GObject*, const QString&) {
+    // update title
+    OpenTreeViewerTask::updateTitle(this);
+}
+
 ////////////////////////////
 // TreeViewerUI
 
 const qreal TreeViewerUI::ZOOM_COEF = 1.2;
 const qreal TreeViewerUI::MINIMUM_ZOOM = 1.0;
-const qreal TreeViewerUI::MAXIMUM_ZOOM = 10.0; // TODO: make it depends on tree size
+const qreal TreeViewerUI::MAXIMUM_ZOOM = 10.0; 
 const int TreeViewerUI::MARGIN = 10;
+const qreal TreeViewerUI::SIZE_COEF = 0.1;
 
-TreeViewerUI::TreeViewerUI(TreeViewer* treeViewer): phyObject(treeViewer->getPhyObject()), root(treeViewer->getRoot()), rectRoot(treeViewer->getRoot()), layout(TreeLayout_Rectangular) {
+
+TreeViewerUI::TreeViewerUI(TreeViewer* treeViewer): phyObject(treeViewer->getPhyObject()), root(treeViewer->getRoot()), rectRoot(treeViewer->getRoot()), layout(TreeLayout_Rectangular), curTreeViewer(NULL) {
+    curTreeViewer = treeViewer;
     contEnabled = false;
     showDistanceLabels = true;
     showNameLabels = true;
     maxNameWidth = 0;
     zoom = 1.0;
 
+    setWindowIcon(GObjectTypes::getTypeInfo(GObjectTypes::PHYLOGENETIC_TREE).icon);
+
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     setFrameShape(QFrame::NoFrame);
     setTransformationAnchor(QGraphicsView::AnchorUnderMouse);
     setScene(new QGraphicsScene());
     scene()->addItem(root);
+    setScale(treeViewer->getScale());
     addLegend(treeViewer->getScale());
     updateRect();
 
@@ -242,6 +348,7 @@ TreeViewerUI::TreeViewerUI(TreeViewer* treeViewer): phyObject(treeViewer->getPhy
     connect(treeViewer->getCircularLayoutAction(), SIGNAL(triggered(bool)), SLOT(sl_circularLayoutTriggered()));
     connect(treeViewer->getUnrootedLayoutAction(), SIGNAL(triggered(bool)), SLOT(sl_unrootedLayoutTriggered()));
     connect(treeViewer->getTextSettingsAction(), SIGNAL(triggered()), SLOT(sl_textSettingsTriggered()));
+    connect(treeViewer->getTreeSettingsAction(), SIGNAL(triggered()), SLOT(sl_treeSettingsTriggered()));
     connect(treeViewer->getZoomToSelAction(), SIGNAL(triggered()), SLOT(sl_zoomToSel()));
     connect(treeViewer->getZoomOutAction(), SIGNAL(triggered()), SLOT(sl_zoomOut()));
     connect(treeViewer->getZoomToAllAction(), SIGNAL(triggered()), SLOT(sl_zoomToAll()));
@@ -251,11 +358,13 @@ TreeViewerUI::TreeViewerUI(TreeViewer* treeViewer): phyObject(treeViewer->getPhy
     zoomOutAction = treeViewer->getZoomOutAction();
     zoomToAllAction = treeViewer->getZoomToAllAction();
     setColorAction = treeViewer->getBranchesSettingsAction();
+    captureAction = treeViewer->getCaptureTreeAction();
+    exportAction = treeViewer->getExportAction();
     buttonPopup = new QMenu(this);
 
     //chrootAction->setEnabled(false); //not implemented yet
 
-    swapAction = buttonPopup->addAction(QObject::tr("Swap siblings"));
+    swapAction = buttonPopup->addAction(QObject::tr("Swap Siblings"));
     connect(swapAction, SIGNAL(triggered(bool)), SLOT(sl_swapTriggered()));
 
     buttonPopup->addAction(zoomToAction);
@@ -265,6 +374,12 @@ TreeViewerUI::TreeViewerUI(TreeViewer* treeViewer): phyObject(treeViewer->getPhy
 
     buttonPopup->addAction(setColorAction);
 
+    QMenu* cameraMenu = new QMenu(tr("Export Tree Image"), this);
+    cameraMenu->addAction(captureAction);
+    cameraMenu->addAction(exportAction);
+    cameraMenu->setIcon(QIcon(":/core/images/cam2.png"));
+    buttonPopup->addMenu(cameraMenu);
+
     updateActionsState();
 }
 
@@ -288,6 +403,11 @@ TextSettings TreeViewerUI::getTextSettings() const {
     return textSettings;
 }
 
+TreeSettings TreeViewerUI::getTreeSettings() const {
+
+    return treeSettings;
+}
+
 void TreeViewerUI::updateSettings(const BranchSettings &settings) {
 
     branchSettings = settings;
@@ -306,6 +426,16 @@ void TreeViewerUI::updateSettings(const TextSettings &settings) {
     updateTextSettings();
 }
 
+void TreeViewerUI::updateSettings(const TreeSettings &settings) {
+
+    treeSettings = settings;
+    if(layout!=TreeLayout_Rectangular){
+        updateLayout();
+    }else{
+        updateTreeSettings();
+    }
+
+}
 
 void TreeViewerUI::sl_setSettingsTriggered() {
 
@@ -324,6 +454,13 @@ void TreeViewerUI::updateSettings() {
     QList<QGraphicsItem*> updatingItems = this->scene()->selectedItems();
     if(updatingItems.isEmpty()){
         updatingItems = this->items();
+
+        QGraphicsLineItem* legendLine = dynamic_cast<QGraphicsLineItem*>(legend);
+        if(legendLine){
+            QPen legendPen;
+            legendPen.setColor(branchSettings.branchColor);
+            legendLine->setPen(legendPen);
+        }
     }
 
     foreach (QGraphicsItem *graphItem, updatingItems) {
@@ -331,6 +468,9 @@ void TreeViewerUI::updateSettings() {
         GraphicsBranchItem *branchItem = dynamic_cast<GraphicsBranchItem*>(graphItem);
         if (branchItem) {
             branchItem->updateSettings(branchSettings);
+            if(branchItem->getCorrespondingItem()){
+                branchItem->getCorrespondingItem()->updateSettings(branchSettings);
+            }
         }
 
         scene()->update();
@@ -341,18 +481,118 @@ void TreeViewerUI::updateTextSettings(){
     QList<QGraphicsItem*> updatingItems = this->scene()->selectedItems();
     if(updatingItems.isEmpty()){
         updatingItems = this->items();
+
+        QList<QGraphicsItem*> legendChildItems = legend->children();
+        if(!legendChildItems.isEmpty()){
+            QGraphicsSimpleTextItem* legendText = dynamic_cast<QGraphicsSimpleTextItem*>(legendChildItems.first());
+            if(legendText){
+                legendText->setBrush(textSettings.textColor);
+            }
+        }
     }
 
     foreach (QGraphicsItem *graphItem, updatingItems) {
 
         GraphicsBranchItem *branchItem = dynamic_cast<GraphicsBranchItem*>(graphItem);
         if (branchItem) {
-          branchItem->updateTextSettings(textSettings.textFont, textSettings.textColor);
+            branchItem->updateTextSettings(textSettings.textFont, textSettings.textColor);
+            if(branchItem->getCorrespondingItem()){
+                branchItem->getCorrespondingItem()->updateTextSettings(textSettings.textFont, textSettings.textColor);
+            }
         }
 
-        scene()->update();
+        //scene()->update();
     }    
+
+    updateLayout();
+    updateTreeSettings();
 }
+void TreeViewerUI::updateTreeSettings(){
+
+    qreal avgW = 0;
+    if(treeSettings.type == TreeSettings::CLADOGRAM){
+        avgW = avgWidth(); 
+        legend->setVisible(false);
+    }else{
+         legend->setVisible(true);
+    }
+    
+    QStack<GraphicsBranchItem*> stack;
+    stack.push(rectRoot);
+    while (!stack.empty()) {
+        GraphicsBranchItem *item = stack.pop();
+        if(item!=rectRoot){
+         
+            if(layout == TreeLayout_Rectangular){
+                GraphicsRectangularBranchItem *rectItem = dynamic_cast<GraphicsRectangularBranchItem*>(item);
+                if(rectItem){
+                    rectItem->setHeightCoef(treeSettings.height_coef);
+                }
+            }
+
+            qreal coef  = qMax(1.0, TreeViewerUI::SIZE_COEF*treeSettings.width_coef);
+
+            switch (treeSettings.type)
+            {
+            case TreeSettings::PHYLOGRAM:
+                if(item->getDistanceText() != NULL){
+                    if(item->getDistanceText()->text() == "0"){
+                        item->setDistanceText("");
+                    }
+                }
+                item->setWidth(qAbs(item->getDist()) * getScale()* coef);
+                break;
+            case TreeSettings::CLADOGRAM:
+                if(item->getDistanceText() != NULL){
+                    if(item->getDistanceText()->text() == ""){
+                        item->setDistanceText("0");
+                    }
+                }
+                item->setWidth(avgW * getScale()* coef);
+                break;
+            default:
+                assert(false && "Unexpected tree type value");
+                break;
+            }
+        }
+        foreach (QGraphicsItem* ci, item->childItems()) {
+            GraphicsBranchItem* gbi = dynamic_cast<GraphicsBranchItem*>(ci);
+            if (gbi != NULL) {
+                stack.push(gbi);
+            }
+        }
+    }
+    updateRect();
+    scene()->update();
+
+    if(contEnabled){
+        QStack<GraphicsBranchItem*> stack;
+        stack.push(root);
+        if (root != rectRoot) {
+            stack.push(rectRoot);
+        }
+        while (!stack.empty()) {
+            GraphicsBranchItem* item = stack.pop();
+            if (item->getNameText() == NULL) {
+                foreach (QGraphicsItem* citem, item->childItems()) {
+                    GraphicsBranchItem* gbi = dynamic_cast<GraphicsBranchItem*>(citem);
+                    if (gbi != NULL) {
+                        stack.push(gbi);
+                    }
+                }
+            } else {
+                item->setWidth(0);
+            }
+        }
+        updateRect();
+        contEnabled = false;
+        sl_contTriggered(true);
+    }
+
+    defaultZoom();
+    fitInView(scene()->sceneRect(), Qt::KeepAspectRatio);
+}
+
 
 #define BRANCH_COLOR        QString("branch_color")
 #define BRANCH_THICKNESS    QString("branch_thickness")
@@ -410,7 +650,8 @@ void TreeViewerUI::addLegend(qreal scale) {
     str.truncate(i + 1);
 
     legend = new QGraphicsLineItem(0, 0, WIDTH, 0);
-    QGraphicsItem* text = new QGraphicsSimpleTextItem(str, legend);
+    QGraphicsSimpleTextItem* text = new QGraphicsSimpleTextItem(str, legend);
+    text->setFont(TreeViewerUtils::getFont());
     QRectF rect = text->boundingRect();
     text->setPos(0.5 * (WIDTH - rect.width()), -rect.height());
     scene()->addItem(legend);
@@ -428,7 +669,7 @@ void TreeViewerUI::zooming(qreal newzoom){
     }
     newzoom = zoom * newzoom;
     newzoom = qMax(MINIMUM_ZOOM, newzoom);
-    newzoom = qMin(MAXIMUM_ZOOM, newzoom);
+    newzoom = qMin(MAXIMUM_ZOOM * qMax(treeSettings.width_coef*TreeViewerUI::SIZE_COEF, 1.0), newzoom);
     scale(newzoom / zoom, newzoom / zoom);
     zoom = newzoom;   
     updateActionsState();
@@ -477,7 +718,7 @@ void TreeViewerUI::resizeEvent(QResizeEvent *e) {
 
 // needed to export tree
 void TreeViewerUI::paint(QPainter &painter) {
-    painter.setBrush(QColor(0, 0, 0));
+    painter.setBrush(Qt::darkGray);
     painter.setFont(TreeViewerUtils::getFont());
     scene()->render(&painter);
 }
@@ -508,6 +749,8 @@ void TreeViewerUI::sl_swapTriggered() {
         }
     }
     redrawRectangularLayout(); 
+    updateLayout();
+    updateTreeSettings();
 }
 
 void TreeViewerUI::collapseSelected() {
@@ -538,20 +781,14 @@ void TreeViewerUI::sl_collapseTriggered() {
 }
 
 void TreeViewerUI::sl_captureTreeTriggered() {
-    QString format = QString(TreeViewerUtils::IMAGE_FILTERS).section(";;", 4, 4);
-    QString fileName = phyObject->getDocument()->getName();
-    TreeViewerUtils::saveImageDialog(TreeViewerUtils::IMAGE_FILTERS, fileName, format);
-    if (!fileName.isEmpty()) {
-        QImage image(scene()->sceneRect().toRect().size(), QImage::Format_RGB32);
-        image.fill(0xFFFFFFFF);
-        QPainter painter(&image);
-        paint(painter);
-        bool result = image.save(fileName, format.toAscii().constData());
-        if (!result) {
-            QMessageBox::critical(this, L10N::errorTitle(), L10N::errorImageSave(fileName, format));
-            return;
-        }
-    }
+    this->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    this->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+
+    ExportImageDialog dialog(this,this->rect(),false,true,phyObject->getDocument()->getURL().baseFileName());
+    dialog.exec();
+
+    this->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+    this->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
 }
 
 void TreeViewerUI::sl_exportTriggered() {
@@ -591,6 +828,7 @@ void TreeViewerUI::sl_contTriggered(bool on) {
                     }
                 }
             } else {
+                
                 qreal nWidth = 0;
                 if(on){
                     qreal scW = scene()->sceneRect().width();
@@ -602,6 +840,17 @@ void TreeViewerUI::sl_contTriggered(bool on) {
                         nWidth -= textBRW + GraphicsBranchItem::TextSpace;
                     }
                 }
+// 
+//                 //test
+//                 QGraphicsItem* pitem =  item->parentItem();
+//                 GraphicsBranchItem* grPItem = dynamic_cast<GraphicsBranchItem*>(pitem);
+//                 if(grPItem){
+//                     if(grPItem->getDistanceText()!= NULL && grPItem->getDistanceText()->text() == ""){
+//                         nWidth+=8;
+//                     }
+//                 }
+//                 //test
+
                 item->setWidth(nWidth);
             }
         }
@@ -612,6 +861,7 @@ void TreeViewerUI::sl_contTriggered(bool on) {
 void TreeViewerUI::sl_rectangularLayoutTriggered() {
     if (layout != TreeLayout_Rectangular) {
         swapAction->setEnabled(true);
+        root->setSelectedRecurs(false, true); // clear selection
 
         layout = TreeLayout_Rectangular;
         scene()->removeItem(root);
@@ -622,14 +872,18 @@ void TreeViewerUI::sl_rectangularLayoutTriggered() {
         scene()->addItem(root);
         defaultZoom();
         updateRect();
+        updateTreeSettings();
+        fitInView(scene()->sceneRect(), Qt::KeepAspectRatio);
     }
 }
 
 void TreeViewerUI::sl_circularLayoutTriggered() {
     if (layout != TreeLayout_Circular) {
-        swapAction->setEnabled(false);
+        //swapAction->setEnabled(false);
+        root->setSelectedRecurs(false, true); // clear selection
 
         layout = TreeLayout_Circular;
+        updateTreeSettings();
         layoutTask = new CreateCircularBranchesTask(rectRoot);
         connect(layoutTask, SIGNAL(si_stateChanged()), SLOT(sl_layoutRecomputed()));
         TaskScheduler* scheduler = AppContext::getTaskScheduler();
@@ -639,9 +893,11 @@ void TreeViewerUI::sl_circularLayoutTriggered() {
 
 void TreeViewerUI::sl_unrootedLayoutTriggered() {
     if (layout != TreeLayout_Unrooted) {
-        swapAction->setEnabled(false);
+       // swapAction->setEnabled(false);
+        root->setSelectedRecurs(false, true); // clear selection
 
         layout = TreeLayout_Unrooted;
+        updateTreeSettings();
         layoutTask = new CreateUnrootedBranchesTask(rectRoot);
         connect(layoutTask, SIGNAL(si_stateChanged()), SLOT(sl_layoutRecomputed()));
         TaskScheduler* scheduler = AppContext::getTaskScheduler();
@@ -650,7 +906,7 @@ void TreeViewerUI::sl_unrootedLayoutTriggered() {
 }
 
 void TreeViewerUI::sl_layoutRecomputed() {
-    if (layoutTask->getState() != Task::State_Finished || layoutTask->hasErrors()) {
+    if (layoutTask->getState() != Task::State_Finished || layoutTask->hasError()) {
         return;
     }
 
@@ -670,7 +926,8 @@ void TreeViewerUI::sl_layoutRecomputed() {
         }
         showLabels(lt);
     }
-    fitInView(root);
+    
+    fitInView(scene()->sceneRect(), Qt::KeepAspectRatio);
 }
 
 void TreeViewerUI::showLabels(LabelTypes labelTypes) {
@@ -707,24 +964,34 @@ void TreeViewerUI::sl_showNameLabelsTriggered(bool on) {
         scene()->setSceneRect(rect);
         showNameLabels = on;
         showLabels(LabelType_SequnceName);
-
-        if (contEnabled) {
-            QStack<GraphicsBranchItem*> stack;
-            stack.push(root);
-            if (root != rectRoot) {
-                stack.push(rectRoot);
+        if(curTreeViewer){
+            curTreeViewer->getContAction()->setDisabled(!showNameLabels);
+            if(!showNameLabels){
+                sl_contTriggered(false);
+            }else{
+                if(curTreeViewer->getContAction()->isChecked()){
+                    sl_contTriggered(true);
+                }
             }
-            while (!stack.empty()) {
-                GraphicsBranchItem* item = stack.pop();
-                if (item->getNameText() == NULL) {
-                    foreach (QGraphicsItem* citem, item->childItems()) {
-                        GraphicsBranchItem* gbi = dynamic_cast<GraphicsBranchItem*>(citem);
-                        if (gbi != NULL) {
-                            stack.push(gbi);
+        }else{
+            if (contEnabled) {
+                QStack<GraphicsBranchItem*> stack;
+                stack.push(root);
+                if (root != rectRoot) {
+                    stack.push(rectRoot);
+                }
+                while (!stack.empty()) {
+                    GraphicsBranchItem* item = stack.pop();
+                    if (item->getNameText() == NULL) {
+                        foreach (QGraphicsItem* citem, item->childItems()) {
+                            GraphicsBranchItem* gbi = dynamic_cast<GraphicsBranchItem*>(citem);
+                            if (gbi != NULL) {
+                                stack.push(gbi);
+                            }
                         }
+                    } else {
+                        item->setWidth(item->getWidth() + (on ? 1 : -1) * (maxNameWidth - item->getNameText()->boundingRect().width() - 2 * GraphicsBranchItem::TextSpace));
                     }
-                } else {
-                    item->setWidth(item->getWidth() + (on ? 1 : -1) * (maxNameWidth - item->getNameText()->boundingRect().width() - 2 * GraphicsBranchItem::TextSpace));
                 }
             }
         }
@@ -777,10 +1044,18 @@ void TreeViewerUI::sl_textSettingsTriggered(){
          }
     }
 }
+
+void TreeViewerUI::sl_treeSettingsTriggered(){
+    TreeSettingsDialog dialog(this, getTreeSettings(), layout == TreeLayout_Rectangular);
+    if(dialog.exec()){
+        updateSettings(dialog.getSettings());
+    }
+}
+
 void TreeViewerUI::sl_zoomToSel(){
     QList<QGraphicsItem*> selectedItems = this->scene()->selectedItems();
     if(selectedItems.isEmpty()){
-         zooming(2.0); 
+         zooming(ZOOM_COEF); 
     }else{
         GraphicsButtonItem *topButton = NULL;
         foreach (QGraphicsItem *graphItem, selectedItems) {
@@ -792,21 +1067,22 @@ void TreeViewerUI::sl_zoomToSel(){
             }
         }
         if(!topButton){
-            zooming(2.0);
+            zooming(ZOOM_COEF);
         }else{
+            defaultZoom();
             QGraphicsItem *topItem = topButton->parentItem();
             QRectF rect = topItem->mapRectToScene(topItem->childrenBoundingRect());
             QRectF rect1 = scene()->sceneRect();
             qreal zoom1 = qMin(rect1.width() / rect.width(), rect1.height() / rect.height());
             zooming(zoom1);
-            fitInView(rect, Qt::KeepAspectRatio);
+            centerOn(rect.center());
         }
 
     }
      
 }
 void TreeViewerUI::sl_zoomOut(){
-    zooming(0.5);
+    zooming(1.0/(float)ZOOM_COEF);
 }
 void TreeViewerUI::sl_zoomToAll(){
     defaultZoom();
@@ -818,7 +1094,7 @@ void TreeViewerUI::defaultZoom(){
 
 void TreeViewerUI::redrawRectangularLayout(){
  
-    if(layout == TreeLayout_Rectangular){
+    //if(layout == TreeLayout_Rectangular){
         int current = 0;
         qreal minDistance = -2, maxDistance = 0;
         GraphicsRectangularBranchItem* item = rectRoot;
@@ -826,36 +1102,46 @@ void TreeViewerUI::redrawRectangularLayout(){
         item->redrawBranches(current, minDistance, maxDistance, phyObject->getTree()->rootNode);
 
         item->setWidthW(0);
+        item->setDist(0);
         item->setHeightW(0);
 
+        if(minDistance == 0){
+            minDistance = GraphicsRectangularBranchItem::EPSILON;
+        }
+        if(maxDistance == 0){
+            maxDistance = GraphicsRectangularBranchItem::EPSILON;
+        }
+
         qreal minDistScale = GraphicsRectangularBranchItem::DEFAULT_WIDTH / (qreal)minDistance;
         qreal maxDistScale = GraphicsRectangularBranchItem::MAXIMUM_WIDTH / (qreal)maxDistance;
 
         qreal scale = qMin(minDistScale, maxDistScale);
-
-        QStack<GraphicsRectangularBranchItem*> stack;
-        stack.push(item);
-        while (!stack.empty()) {
-            GraphicsRectangularBranchItem *item = stack.pop();
-            item->setWidth(item->getWidth() * scale);
-            foreach (QGraphicsItem* ci, item->childItems()) {
-                GraphicsRectangularBranchItem* gbi = dynamic_cast<GraphicsRectangularBranchItem*>(ci);
-                if (gbi != NULL) {
-                    stack.push(gbi);
-                }
-            }
-        }
-        scene()->removeItem(legend);
-        addLegend(scale);
-        updateRect();
-        scene()->update();
-    }
+        setScale(scale);
+    //}
     
 }
 
+qreal TreeViewerUI::avgWidth(){
+    qreal sumW = 0;
+    int count = 0;
+
+    QList<QGraphicsItem*> updatingItems = scene()->items();
+
+    foreach (QGraphicsItem *graphItem, updatingItems) {
+
+        GraphicsBranchItem *branchItem = dynamic_cast<GraphicsBranchItem*>(graphItem);
+        if (branchItem) {
+            sumW += qAbs(branchItem->getDist());
+            count++;
+        }
+    }
+
+    return sumW/(qreal)count;
+}
+
 void TreeViewerUI::updateActionsState(){
 
-    zoomToAction->setEnabled(zoom < MAXIMUM_ZOOM);
+    zoomToAction->setEnabled(zoom < MAXIMUM_ZOOM* qMax(treeSettings.width_coef*TreeViewerUI::SIZE_COEF, 1.0));
     zoomOutAction->setEnabled(zoom > MINIMUM_ZOOM);
     
     if(isSelectedCollapsed()){
@@ -866,6 +1152,24 @@ void TreeViewerUI::updateActionsState(){
 
     QList<QGraphicsItem*> updatingItems = this->scene()->selectedItems();
     collapseAction->setEnabled(!updatingItems.isEmpty());
-    if(layout == TreeLayout_Rectangular) swapAction->setEnabled(!updatingItems.isEmpty());
+    swapAction->setEnabled(!updatingItems.isEmpty());
 }
+
+void TreeViewerUI::updateLayout()
+{
+    TreeLayout tmpL = layout;
+    layout = TreeLayout_Rectangular;
+    switch(tmpL){
+        case TreeLayout_Circular:
+            sl_circularLayoutTriggered();
+            break;
+        case TreeLayout_Unrooted:
+            sl_unrootedLayoutTriggered();
+            break;
+        case TreeLayout_Rectangular:
+            //here to please compiler
+            break;
+    }
+}
+
 }//namespace
