@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "CollocationsSearchAlgorithm.h"
 
@@ -19,13 +30,13 @@ void CollocationsAlgorithm::find(const QList<CollocationsAlgorithmItem>& items,
 }
 
 void CollocationsAlgorithm::findN(const QList<CollocationsAlgorithmItem>& items, TaskStateInfo& si, 
-                                 CollocationsAlgorithmListener* l, const LRegion& searchRegion, int distance) 
+                                 CollocationsAlgorithmListener* l, const U2Region& searchRegion, qint64 distance) 
 {
     //todo: progress
 
-    int i=searchRegion.endPos();
+    qint64 i = searchRegion.endPos();
     foreach(const CollocationsAlgorithmItem& item, items) {
-        foreach(const LRegion& r, item.regions) {
+        foreach(const U2Region& r, item.regions) {
             assert(searchRegion.contains(r));
             i = qMin(i, r.startPos);
         }
@@ -34,33 +45,33 @@ void CollocationsAlgorithm::findN(const QList<CollocationsAlgorithmItem>& items,
         return;
     }
 
-    LRegion prevResult;
+    U2Region prevResult;
     do {
-        LRegion res;
-        LRegion currentRegion(i, qMin(i+distance, searchRegion.endPos()) - i);
+        U2Region res;
+        U2Region currentRegion(i, qMin(i + distance, searchRegion.endPos()) - i);
         bool onResult = true;
-        int nextI = currentRegion.endPos();
+        qint64 nextI = currentRegion.endPos();
         foreach(const CollocationsAlgorithmItem& item, items) {
             bool foundItem = false;
-            int nextItemStart =  currentRegion.endPos();
-            foreach(const LRegion& r, item.regions) {
+            qint64 nextItemStart =  currentRegion.endPos();
+            foreach(const U2Region& r, item.regions) {
                 if (r.startPos > currentRegion.startPos) {
                       nextItemStart = qMin(nextItemStart, r.startPos);
                 }
                 if (onResult && currentRegion.contains(r)) {
                     foundItem = true;
-                    res = res.len == 0 ? r : LRegion::containingRegion(res, r);
+                    res = res.length == 0 ? r : U2Region::containingRegion(res, r);
                 }
             }
             nextI = qMin(nextI, nextItemStart);
             onResult = onResult && foundItem;
         }
         if (onResult && res.startPos == i) {
-            assert(res.len > 0);
+            assert(res.length > 0);
             if (prevResult.contains(res)) {
                 //nothing to do;
             } else {
-                assert(!res.contains(prevResult) || prevResult.len == 0);
+                assert(!res.contains(prevResult) || prevResult.length == 0);
                 assert(prevResult.endPos() < res.endPos());
                 l->onResult(res);
                 prevResult = res;
@@ -68,25 +79,25 @@ void CollocationsAlgorithm::findN(const QList<CollocationsAlgorithmItem>& items,
         } 
         assert(nextI > i);
         i = nextI;
-        si.progress = int(100*float(i - searchRegion.startPos)/searchRegion.len);
+        si.progress = int(100*float(i - searchRegion.startPos)/searchRegion.length);
     } while (i + distance < searchRegion.endPos());
 }
 
-void averagingRes(LRegion& res, const LRegion& min, const LRegion& max, int distance, const LRegion& searchRegion)
+void averagingRes(U2Region& res, const U2Region& min, const U2Region& max, int distance, const U2Region& searchRegion)
 {
     //?
     if (!min.intersects(max)) {
         res.startPos = min.endPos()-1;
-        res.len = max.startPos - min.endPos() + 2;
+        res.length = max.startPos - min.endPos() + 2;
     }
     else {
         res.startPos = max.startPos;
-        res.len = min.endPos() - max.startPos;
+        res.length = min.endPos() - max.startPos;
     }
-    int tmp = distance - res.len;
-    res.startPos -= tmp*min.len/(max.len+min.len);
+    int tmp = distance - res.length;
+    res.startPos -= tmp*min.length/(max.length+min.length);
     if (res.startPos<0) res.startPos = 0;
-    res.len = distance;
+    res.length = distance;
     if (res.endPos() > searchRegion.endPos()) {
         res.startPos -= (res.endPos()-searchRegion.endPos());
         //res.len = (searchRegion.endPos() - res.startPos);
@@ -99,13 +110,13 @@ void averagingRes(LRegion& res, const LRegion& min, const LRegion& max, int dist
 
 
 void CollocationsAlgorithm::findP(const QList<CollocationsAlgorithmItem>& items, TaskStateInfo& si, 
-                                 CollocationsAlgorithmListener* l, const LRegion& searchRegion, int distance) 
+                                 CollocationsAlgorithmListener* l, const U2Region& searchRegion, qint64 distance) 
 {
     //printf("partial_search!\n");
 
-    int i = searchRegion.endPos();
+    qint64 i = searchRegion.endPos();
     foreach(const CollocationsAlgorithmItem& item, items) {
-        foreach(const LRegion& r, item.regions) {
+        foreach(const U2Region& r, item.regions) {
             assert(searchRegion.contains(r));
             if (i > r.endPos()-1) {
                 i = r.endPos()-1;
@@ -115,20 +126,20 @@ void CollocationsAlgorithm::findP(const QList<CollocationsAlgorithmItem>& items,
     if (i == searchRegion.endPos()) {
         return;
     }
-    LRegion prevResult;
-    LRegion prevMax;
+    U2Region prevResult;
+    U2Region prevMax;
     do {
-        LRegion res;
-        LRegion currentRegion(i, qMin(i+distance, searchRegion.endPos()) - i);
-        LRegion min, max;
+        U2Region res;
+        U2Region currentRegion(i, qMin(i+distance, searchRegion.endPos()) - i);
+        U2Region min, max;
         min.startPos = searchRegion.endPos() - 1;
         max.startPos = 0;
         bool onResult = true;
-        int nextI = currentRegion.endPos();
+        qint64 nextI = currentRegion.endPos();
         foreach(const CollocationsAlgorithmItem& item, items) {
             bool foundItem = false;
-            int nextItemEnd =  searchRegion.endPos();
-            foreach(const LRegion& r, item.regions) {
+            qint64 nextItemEnd =  searchRegion.endPos();
+            foreach(const U2Region& r, item.regions) {
                 if (r.endPos() <= searchRegion.endPos() && r.endPos()-1 > currentRegion.startPos
                                                         && nextItemEnd > r.endPos()-1) {
                         nextItemEnd = r.endPos()-1;
@@ -137,7 +148,7 @@ void CollocationsAlgorithm::findP(const QList<CollocationsAlgorithmItem>& items,
                     foundItem = true;
                     if (r.endPos() < min.endPos()) min = r;
                     if (max < r) max = r;
-                    res = res.len == 0 ? r : LRegion::containingRegion(res, r);
+                    res = res.length == 0 ? r : U2Region::containingRegion(res, r);
                 }
             }
             nextI = qMin(nextI, nextItemEnd);
@@ -153,9 +164,9 @@ void CollocationsAlgorithm::findP(const QList<CollocationsAlgorithmItem>& items,
             prevMax = max;
 
 
-            if (res.len > distance) {
+            if (res.length > distance) {
                 //function res averaging
-                //void averagingRes(LRegion& res, const LRegion& min, const LRegion& max, int distance)
+                //void averagingRes(U2Region& res, const U2Region& min, const U2Region& max, int distance)
 /*                if (!min.intersects(max)) {
                     res.startPos = min.endPos()-1;
                     res.len = max.startPos - min.endPos() + 2;
@@ -180,12 +191,12 @@ void CollocationsAlgorithm::findP(const QList<CollocationsAlgorithmItem>& items,
                 averagingRes(res, min, max, distance, searchRegion);
             }
 
-            assert(res.len > 0);
+            assert(res.length > 0);
             l->onResult(res);
         } 
         assert(nextI > i);
         i = nextI;
-        si.progress = int(100*float(i - searchRegion.startPos)/searchRegion.len);
+        si.progress = int(100*float(i - searchRegion.startPos)/searchRegion.length);
     } while (i < searchRegion.endPos());
 }
 
