@@ -1,17 +1,30 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_GRAPHIC_UTILS_H_
 #define _U2_GRAPHIC_UTILS_H_
 
 #include <U2Core/Vector3D.h>
+#include <U2Core/Log.h>
+#include <QtOpenGL>
 
 class GLUquadric;
 
@@ -110,20 +123,6 @@ Vector3D projectPointOnAxis(const Vector3D& point, const Vector3D& axisUnitVecto
 //! Calculates average point
 Vector3D calcMiddlePoint(const QVector<Vector3D>& points);
 
-class DisplayLists {
-    static unsigned int bigDL;
-    static unsigned int vanDerWaalsDL;
-    static const int BIG_DL_INDEX = 1;
-    static const int VANDERWAALS_DL_INDEX = 2;
-
-    static void drawAtomsBonds(const Color4f &viewAtomColor, float renderDetailLevel, const Molecule3DModel &model, const BioStruct3DColorScheme* colorScheme);
-
-public:
-    static void createBigDisplayList(float renderDetailLevel, const BioStruct3D& bioStruct, const QList<int> &modelIndexList, const BioStruct3DColorScheme* colorScheme);
-    static int getBigDisplayList() { return bigDL; }
-};
-
-
 void accPerspective(double fovy, double aspect,
                     double near, double far, double pixdx, double pixdy,
                     double eyedx, double eyedy, double focus);
@@ -136,8 +135,17 @@ void accFrustum(double left, double right, double bottom,
 //! Calculates axis through points using least linear square method
 QPair<Vector3D,Vector3D> calcBestAxisThroughPoints(const QVector<Vector3D>& points);
 
+//! Checks for OpenGL errors and reports them to log
+#define CHECK_GL_ERROR do { checkGlError(__FILE__, __LINE__); } while (0);
 
-
+inline void checkGlError(const char *file, int line) {
+    GLenum error = glGetError();
+    if (error != GL_NO_ERROR) {
+        QString where = QString("%1:%2: ").arg(file).arg(line);
+        QString msg = QString("OpenGL error (%1): %2").arg(error).arg((char*)gluErrorString(error));
+        uiLog.trace(where + msg);
+    }
+}
 
 } //namespace
 
