@@ -1,19 +1,32 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_SETTINGSDIALOG_H_
 #define _U2_SETTINGSDIALOG_H_
 
 #include "BioStruct3DGLWidget.h"
-#include <QtGui/QColorDialog>
 #include "ui_SettingsDialog.h"
+#include "AnaglyphRenderer.h"
+
+#include <QtGui/QColorDialog>
 
 namespace U2 {
 
@@ -65,33 +78,31 @@ private slots:
 
 
 public:
+    // anaglyph related settings
+    AnaglyphStatus getAnaglyphStatus() const;
+    const AnaglyphSettings& getAnaglyphSettings() const;
+
+    void setAnaglyphStatus(AnaglyphStatus status);
+    void setAnaglyphSettings(const AnaglyphSettings &settings);
+
+    void setRightEyeColor(QColor rightEyecolor);
+    void setLeftEyeColor(QColor leftEyecolor);
+
     QColor getBackgroundColor()const;
     QColor getSelectionColor()const;
 
-    QColor getLeftEyeColor()const;
-    QColor getRightEyeColor()const;
-
-    int getRenderDetailLevel()const;
+    float getRenderDetailLevel()const;
     int getShadingLevel()const;
-    bool getAnaglyph()const;
-    int getEyesShift()const;
 
     void setBackgroundColor(QColor color);
     void setSelectionColor(QColor color);
 
-    void setLeftEyeColor(QColor leftEyecolor);
-    void setRightEyeColor(QColor rightEyecolor);
-
     void setGlassesColorScheme(QColor &leftEyeColor, QColor &rightEyeColor);
     void setGlassesColorScheme(int num);
 
-    void setRenderDetailLevel(int renderDetailLevel);
+    void setRenderDetailLevel(float renderDetailLevel);
     void setShadingLevel(int shading);
 
-    void setAnaglyph(bool anaglyph);
-    void setAnaglyphAvailability(bool anaglyph);
-    void setEyesShift(int eyesShift);
-
     void setWidget(BioStruct3DGLWidget *glWidget);
 
 private:
@@ -105,13 +116,12 @@ private:
     QColor backgroundColor;
     QColor selectionColor;
 
-    QColor leftEyeColor;
-    QColor rightEyeColor;
 
     int renderDetailLevel;
     int shadingLevel;
-    bool anaglyph;
-    int eyesShift;
+
+    AnaglyphStatus anaglyphStatus;
+    AnaglyphSettings anaglyphSettings;
 };
 
 } // namespace
