@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ChromatogramView.h"
 
@@ -67,7 +78,7 @@ ChromatogramView::ChromatogramView(QWidget* p, ADVSequenceObjectContext* v, GSeq
     ra = static_cast<ChromatogramViewRenderArea *>(renderArea);
     scaleBar->setValue(ra->height()-ra->getHeightAreaBC()+ra->addUpIfQVL);
 
-    setConherentRangeView(cv);
+    setCoherentRangeView(cv);
     
     mP = new QMenu(this);
 
@@ -156,7 +167,7 @@ void ChromatogramView::mousePressEvent(QMouseEvent* me)
     }
     QPoint renderAreaPos = toRenderAreaPoint(me->pos());
 
-    const LRegion& visibleRange = getVisibleRange();
+    const U2Region& visibleRange = getVisibleRange();
     QRectF rect;
     for (int i=visibleRange.startPos; i<visibleRange.endPos(); ++i) {
         rect = ra->posToRect(i);
@@ -193,7 +204,7 @@ void ChromatogramView::sl_onPopupMenuCkicked(QAction* a) {
     char newBase = a->text().at(0).toAscii();
     char curBase = currentBaseCalls.at(selIndex);
     if (newBase != curBase) {
-        DNASequence editSequence = editDNASeq->getSequence();
+        DNASequence editSequence = editDNASeq->getDNASequence();
         int editSeqIdx = getEditSeqIndex(selIndex);
         if (curBase==GAP_CHAR) {
             bool ok = gapIndexes.removeOne(selIndex);
@@ -403,7 +414,7 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
 
     ChromatogramView* chromaView = qobject_cast<ChromatogramView*>(view);
 
-    const LRegion& visible = view->getVisibleRange();
+    const U2Region& visible = view->getVisibleRange();
     assert(!visible.isEmpty());
 
     ADVSequenceObjectContext* seqCtx = view->getSequenceContext();
@@ -420,7 +431,7 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
         p.setFont(font);
         p.setPen(Qt::black);
         p.fillRect(0, 0, pd->width(), heightPD, Qt::white);
-        if (pd->width()/charWidth>visible.len/dividerBoolShowBaseCallsChars) {
+        if (pd->width()/charWidth>visible.length/dividerBoolShowBaseCallsChars) {
             //draw basecalls
             drawOriginalBaseCalls(0, heightAreaBC-charHeight-addUpIfQVL, width(), charHeight, p, visible, ba); 
 
@@ -440,7 +451,7 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
                 p.drawText(curCP+charWidth, heightAreaBC-charHeight, baseForIds[i]);
             }
         }
-        if (pd->width()/charWidth>visible.len/dividerTraceOrBaseCallsLines) {
+        if (pd->width()/charWidth>visible.length/dividerTraceOrBaseCallsLines) {
             drawChromatogramTrace(0, heightAreaBC - addUpIfQVL, pd->width(), height() - heightAreaBC + addUpIfQVL, p, visible);
         } else {
             drawChromatogramBaseCallsLines(0, heightAreaBC, pd->width(), height() - heightAreaBC, p, visible, ba);
@@ -457,7 +468,7 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
         hasSel = false;
     }
 
-    if (pd->width() / charWidth > visible.len /dividerBoolShowBaseCallsChars && chromaView->editDNASeq!=NULL) {
+    if (pd->width() / charWidth > visible.length /dividerBoolShowBaseCallsChars && chromaView->editDNASeq!=NULL) {
         drawOriginalBaseCalls(0, 0, width(), charHeight, p, visible, chromaView->currentBaseCalls, false);
     }
 
@@ -469,9 +480,9 @@ void ChromatogramViewRenderArea::drawAll(QPaintDevice* pd)
         QPen linePenSelection(Qt::darkGray, 1, Qt::SolidLine);
         p.setPen(linePenSelection);
         p.setRenderHint(QPainter::Antialiasing, false);
-        const QList<LRegion>& sel=seqCtx->getSequenceSelection()->getSelectedRegions();
+        const QVector<U2Region>& sel=seqCtx->getSequenceSelection()->getSelectedRegions();
         if (sel.size() >= 1) {
-            LRegion self=sel.first();
+            U2Region self=sel.first();
             int i1=self.startPos,i2=self.endPos()-1;
             if (i1!=0)  {
                 p.drawLine((k*chroma.baseCalls[i1]+b+k*chroma.baseCalls[i1-1]+b)/2,0,
@@ -495,8 +506,8 @@ void ChromatogramViewRenderArea::setAreaHeight(int newH) {
 }
 
 int ChromatogramViewRenderArea::coordToPos(int c) const {
-    const LRegion& visibleRange = view->getVisibleRange();
-    if (visibleRange.startPos+visibleRange.len==chroma.seqLength 
+    const U2Region& visibleRange = view->getVisibleRange();
+    if (visibleRange.startPos+visibleRange.length==chroma.seqLength 
         && c>k*chroma.baseCalls[chroma.seqLength-1]+b)
     {
         return chroma.seqLength;
@@ -511,7 +522,7 @@ int ChromatogramViewRenderArea::coordToPos(int c) const {
 }
 
 int ChromatogramViewRenderArea::posToCoord(int p, bool useVirtualSpace) const {
-    const LRegion& visibleRange = view->getVisibleRange();
+    const U2Region& visibleRange = view->getVisibleRange();
     if (!useVirtualSpace && !visibleRange.contains(p) && p!=visibleRange.endPos()) {
         return -1;
     }
@@ -531,7 +542,7 @@ QRectF ChromatogramViewRenderArea::posToRect(int i) const {
 
 //draw functions
 
-void ChromatogramViewRenderArea::drawChromatogramTrace(qreal x, qreal y, qreal w, qreal h, QPainter& p, const LRegion& visible)
+void ChromatogramViewRenderArea::drawChromatogramTrace(qreal x, qreal y, qreal w, qreal h, QPainter& p, const U2Region& visible)
 {
     if (chromaMax == 0) {
         //nothing to draw
@@ -591,7 +602,7 @@ void ChromatogramViewRenderArea::drawChromatogramTrace(qreal x, qreal y, qreal w
     p.resetTransform();
 }
 
-void ChromatogramViewRenderArea::drawOriginalBaseCalls(qreal x, qreal y, qreal w, qreal h, QPainter& p, const LRegion& visible, const QByteArray& ba, bool is)
+void ChromatogramViewRenderArea::drawOriginalBaseCalls(qreal x, qreal y, qreal w, qreal h, QPainter& p, const U2Region& visible, const QByteArray& ba, bool is)
 {
     QRectF rect;
 
@@ -647,7 +658,7 @@ void ChromatogramViewRenderArea::drawOriginalBaseCalls(qreal x, qreal y, qreal w
     p.resetTransform();
 }
 
-void ChromatogramViewRenderArea::drawQualityValues(qreal x, qreal y, qreal w, qreal h, QPainter& p, const LRegion& visible, const QByteArray& ba)
+void ChromatogramViewRenderArea::drawQualityValues(qreal x, qreal y, qreal w, qreal h, QPainter& p, const U2Region& visible, const QByteArray& ba)
 {
     QRectF rectangle;
 
@@ -705,7 +716,7 @@ void ChromatogramViewRenderArea::drawQualityValues(qreal x, qreal y, qreal w, qr
      p.resetTransform();
 }
 
-void ChromatogramViewRenderArea::drawChromatogramBaseCallsLines(qreal x, qreal y, qreal w, qreal h, QPainter& p, const LRegion& visible, const QByteArray& ba)
+void ChromatogramViewRenderArea::drawChromatogramBaseCallsLines(qreal x, qreal y, qreal w, qreal h, QPainter& p, const U2Region& visible, const QByteArray& ba)
 {
     static const QColor colorForIds[4] = {
         Qt::darkGreen, Qt::blue, Qt::black, Qt::red
@@ -730,7 +741,7 @@ void ChromatogramViewRenderArea::drawChromatogramBaseCallsLines(qreal x, qreal y
     kLinearTransformTrace = qreal (k1) / k2;
     bLinearTransformTrace = leftMargin - kLinearTransformTrace*a1;
     double yRes = 0;
-    for (int j = visible.startPos; j < visible.startPos+visible.len; j++) {
+    for (int j = visible.startPos; j < visible.startPos+visible.length; j++) {
         int temp = chroma.baseCalls[j];
         if (temp >= chroma.traceLength) {
             // damaged data - FIXME improve?
