@@ -2,15 +2,15 @@
 <!DOCTYPE TS>
 <TS version="2.0" language="en">
 <context>
-    <name>GB2::ChromaViewAction</name>
+    <name>U2::ChromaViewAction</name>
     <message>
-        <location filename="../src/ChromaViewPlugin.cpp" line="106"/>
+        <location filename="../src/ChromaViewPlugin.cpp" line="109"/>
         <source>show_chromatogram</source>
         <translation>Show chromatogram</translation>
     </message>
 </context>
 <context>
-    <name>GB2::ChromaViewPlugin</name>
+    <name>U2::ChromaViewPlugin</name>
     <message>
         <location filename="../src/ChromaViewPlugin.cpp" line="33"/>
         <source>chroma_view_plugin_desc</source>
@@ -23,7 +23,7 @@
     </message>
 </context>
 <context>
-    <name>GB2::ChromatogramView</name>
+    <name>U2::ChromatogramView</name>
     <message>
         <source>-</source>
         <translation type="obsolete">-</translation>
@@ -33,52 +33,52 @@
         <translation type="obsolete">+</translation>
     </message>
     <message>
-        <location filename="../src/ChromatogramView.cpp" line="68"/>
+        <location filename="../src/ChromatogramView.cpp" line="70"/>
         <source>add_new_seq</source>
         <translation>Edit new sequence</translation>
     </message>
     <message>
-        <location filename="../src/ChromatogramView.cpp" line="71"/>
+        <location filename="../src/ChromatogramView.cpp" line="73"/>
         <source>add_exist_seq</source>
         <translation>Edit existing sequence</translation>
     </message>
     <message>
-        <location filename="../src/ChromatogramView.cpp" line="74"/>
+        <location filename="../src/ChromatogramView.cpp" line="76"/>
         <source>remove_editable_sequence</source>
         <translation>Remove edited sequence</translation>
     </message>
     <message>
-        <location filename="../src/ChromatogramView.cpp" line="77"/>
+        <location filename="../src/ChromatogramView.cpp" line="79"/>
         <source>remove_changes</source>
         <translation>Undo changes</translation>
     </message>
     <message>
-        <location filename="../src/ChromatogramView.cpp" line="159"/>
-        <location filename="../src/ChromatogramView.cpp" line="267"/>
+        <location filename="../src/ChromatogramView.cpp" line="161"/>
+        <location filename="../src/ChromatogramView.cpp" line="274"/>
         <source>error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../src/ChromatogramView.cpp" line="159"/>
-        <location filename="../src/ChromatogramView.cpp" line="267"/>
+        <location filename="../src/ChromatogramView.cpp" line="161"/>
+        <location filename="../src/ChromatogramView.cpp" line="274"/>
         <source>sequence_object_was_locked</source>
         <translation>Sequence is  locked</translation>
     </message>
     <message>
-        <location filename="../src/ChromatogramView.cpp" line="40"/>
+        <location filename="../src/ChromatogramView.cpp" line="42"/>
         <source>Show quality bars</source>
         <translation></translation>
     </message>
 </context>
 <context>
-    <name>GB2::ChromatogramViewRenderArea</name>
+    <name>U2::ChromatogramViewRenderArea</name>
     <message>
-        <location filename="../src/ChromatogramView.cpp" line="382"/>
+        <location filename="../src/ChromatogramView.cpp" line="389"/>
         <source>selection_is_too_big</source>
         <translation>Chromatogram view (zoom in to see base calls)</translation>
     </message>
     <message>
-        <location filename="../src/ChromatogramView.cpp" line="589"/>
+        <location filename="../src/ChromatogramView.cpp" line="601"/>
         <source>original</source>
         <translation>original sequence</translation>
     </message>
