@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "CircularItems.h"
 #include "CircularView.h"
@@ -153,17 +164,17 @@ void CircurlarAnnotationRegionItem::setLabel( CircularAnnotationLabel* label ) {
 /************************************************************************/
 
 static bool labelLengthLessThan(CircularAnnotationLabel* l1, CircularAnnotationLabel* l2) {
-    int length1 =  l1->getAnnotation()->getLocation()[l1->getRegion()].len;
-    int length2 =  l2->getAnnotation()->getLocation()[l2->getRegion()].len;
+    int length1 =  l1->getAnnotation()->getRegions()[l1->getRegion()].length;
+    int length2 =  l2->getAnnotation()->getRegions()[l2->getRegion()].length;
     return length1 < length2;
 }
 
 CircularAnnotationLabel::CircularAnnotationLabel( Annotation* ann, int _region, int sequenceLength, const QFont& font, CircularViewRenderArea* renderArea ) : 
 annotation(ann), labelFont(font), region(_region), ra(renderArea), hasPosition(false), inner(false), seqLen(sequenceLength)
 {
-    const LRegion& r = annotation->getLocation()[region];
+    const U2Region& r = annotation->getRegions()[region];
     qreal startAngle = (float)r.startPos / (float)sequenceLength * 360;
-    qreal spanAngle = qMin((float)r.len / (float)sequenceLength * 360, float(360 - startAngle));
+    qreal spanAngle = qMin((float)r.length / (float)sequenceLength * 360, float(360 - startAngle));
     startAngle+=renderArea->rotationDegree;
     float middleAngle = 360 - (startAngle + spanAngle /2.0);
     annotationAngle = middleAngle;
