@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "CircularView.h"
 
@@ -18,6 +29,7 @@
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/AnnotationTableObject.h>
 #include <U2Core/AnnotationSettings.h>
+#include <U2Core/U2AnnotationUtils.h>
 #include <U2View/ADVSequenceWidget.h>
 
 #include <U2Core/DNASequenceSelection.h>
@@ -43,13 +55,13 @@ const int CircularView::MIN_OUTER_SIZE = 100;
 const int CircularView::graduation = 16;
 
 
-static Logger log("Circular view plugin");
 
 CircularView::CircularView(QWidget* p, ADVSequenceObjectContext* ctx)
 : GSequenceLineViewAnnotated(p, ctx), clockwise(true), holdSelection(false)
 {
     connect (ctx->getAnnotatedDNAView(), SIGNAL(si_sequenceWidgetRemoved(ADVSequenceWidget*)), SLOT(sl_sequenceWidgetRemoved(ADVSequenceWidget*)));
-    foreach(AnnotationTableObject* obj, ctx->getAnnotationObjects()) {
+    QSet<AnnotationTableObject*> anns = ctx->getAnnotationObjects(true);
+    foreach(AnnotationTableObject* obj, anns ) {
         registerAnnotations(obj->getAnnotations());
     }
 
@@ -58,6 +70,7 @@ CircularView::CircularView(QWidget* p, ADVSequenceObjectContext* ctx)
     setMouseTracking(true);
 
     connect(ctx->getSequenceGObject(), SIGNAL(si_sequenceChanged()), this, SLOT(sl_sequenceChanged()));
+    connect(ctx->getSequenceGObject(), SIGNAL(si_nameChanged(const QString&)), this, SLOT(sl_onSequenceObjectRenamed(const QString&)));
     pack();
     
     //mark sequence as circular
@@ -65,8 +78,7 @@ CircularView::CircularView(QWidget* p, ADVSequenceObjectContext* ctx)
 }
 
 void CircularView::pack() {
-    int minH = (ra->regionY.count() - 1)*ra->ellipseDelta + MIN_OUTER_SIZE;
-    setMinimumHeight(minH);
+    updateMinHeight();
     layout = new QVBoxLayout();
     layout->setContentsMargins(0,0,0,0);
     layout->addWidget(renderArea);
@@ -74,6 +86,11 @@ void CircularView::pack() {
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
 }
 
+void CircularView::updateMinHeight() {
+    int minH = (ra->regionY.count() - 1)*ra->ellipseDelta + MIN_OUTER_SIZE;
+    setMinimumHeight(minH);
+}
+
 void CircularView::sl_sequenceWidgetRemoved(ADVSequenceWidget* w) {
     foreach (ADVSequenceObjectContext *wctx, w->getSequenceContexts()) {
         if (ctx == wctx) {
@@ -193,11 +210,11 @@ void CircularView::mouseMoveEvent( QMouseEvent * e )
         lastMouseY = point.y();
 
         if (twoParts) {
-            setSelection(LRegion(selStart, seqLen-selStart));
-            addSelection(LRegion(0, selEnd));
+            setSelection(U2Region(selStart, seqLen-selStart));
+            addSelection(U2Region(0, selEnd));
         }
         else {
-            setSelection(LRegion(selStart, selLen));
+            setSelection(U2Region(selStart, selLen));
         }
     }
     renderArea->update();
@@ -215,39 +232,22 @@ void CircularView::setAngle(int angle) {
 }
 
 void CircularView::sl_onAnnotationSelectionChanged(AnnotationSelection* selection, const QList<Annotation*>& added, const QList<Annotation*>& removed) {
-    QList<Annotation*> toAdd;
+    
     foreach (Annotation* a, added) {
-        const QString splitStr = a->findFirstQualifierValue("SPLIT");
-        if (splitStr.isEmpty()) {
-            continue;
-        }
-        int curSplit = splitStr.toInt();
-        QList<Annotation*> another;
-        AnnotationTableObject* aObj = a->getGObject();
-        foreach (Annotation* target, aObj->getAnnotations()) {
-            if (target->getAnnotationName() == a->getAnnotationName()) {
-                if (target == a) {
-                    continue;
-                }
-                int newSplit = target->findFirstQualifierValue("SPLIT").toInt();
-                if ( qAbs(newSplit) == qAbs(curSplit)) {
-                    // found other split
-                    toAdd.append( target );
-                    break;
-                }
-            }
+        bool splitted =  U2AnnotationUtils::isSplitted(a->getLocation(), ctx->getSequenceObject()->getSequenceRange()); 
+        int locationIdx = selection->getAnnotationData(a)->locationIdx;
+        if (splitted && locationIdx != -1) {
+            // set locationIdx = -1 to make sure whole annotation region is selected
+            selection->addToSelection(a);
+            return;
         }
     }
     
-    foreach(Annotation* a, toAdd) {
-        selection->addToSelection(a);
-    }
-
     GSequenceLineViewAnnotated::sl_onAnnotationSelectionChanged(selection, added, removed);
     renderArea->update();
 }
 
-void CircularView::sl_onDNASelectionChanged( LRegionsSelection* thiz, const QList<LRegion>& added, const QList<LRegion>& removed )
+void CircularView::sl_onDNASelectionChanged( LRegionsSelection* thiz, const QVector<U2Region>& added, const QVector<U2Region>& removed )
 {
     GSequenceLineViewAnnotated::sl_onDNASelectionChanged(thiz, added, removed);
     renderArea->update();
@@ -336,6 +336,10 @@ void CircularView::sl_zoomOut() {
     updateZoomActions();
 }
 
+void CircularView::sl_onSequenceObjectRenamed(const QString&) {
+    update();
+}
+
 void CircularView::updateZoomActions() {
     if (ra->outerEllipseSize*ZOOM_SCALE / width() > 10) {
         emit si_zoomInDisabled(true);
@@ -359,6 +363,7 @@ void CircularView::adaptSizes() {
     ra->innerEllipseSize=ra->outerEllipseSize-CV_REGION_ITEM_WIDTH;
     ra->rulerEllipseSize=ra->outerEllipseSize-CV_REGION_ITEM_WIDTH;
     ra->middleEllipseSize = (ra->outerEllipseSize + ra->innerEllipseSize)/2;
+    updateMinHeight();
     addUpdateFlags(GSLV_UF_NeedCompleteRedraw);
     ra->update();
 }
@@ -380,6 +385,10 @@ qreal CircularView::coordToAngle(const QPoint point) {
     return arcsin;
 }
 
+void CircularView::paint( QPainter& p ) {
+    ra->paintContent(p);
+}
+
 /************************************************************************/
 /* CircularViewRenderArea                                               */
 /************************************************************************/
@@ -403,18 +412,16 @@ CircularViewRenderArea::CircularViewRenderArea(CircularView* d)
 : GSequenceLineViewAnnotatedRenderArea(d, true), outerEllipseSize(OUTER_ELLIPSE_SIZE),
 ellipseDelta(ELLIPSE_DELTA), innerEllipseSize(INNER_ELLIPSE_SIZE), rulerEllipseSize(RULER_ELLIPSE_SIZE),
 middleEllipseSize(MIDDLE_ELLIPSE_SIZE), arrowLength(ARROW_LENGTH),
-arrowHeightDelta(ARROW_HEIGHT_DELTA), maxDisplayingLabels(MAX_DISPLAYING_LABELS),
-circularView(d), rotationDegree(0), mouseAngle(0), fitsInView(true), oldYlevel(0) {
+arrowHeightDelta(ARROW_HEIGHT_DELTA), maxDisplayingLabels(MAX_DISPLAYING_LABELS), fitsInView(true),
+circularView(d), rotationDegree(0), mouseAngle(0), oldYlevel(0) {
     setMouseTracking(true);
 
     ADVSequenceObjectContext* ctx = view->getSequenceContext();
-
-    int len = ctx->getSequenceLen();
-    int start = 1;
-
+  
     //build annotation items to get number of region levels for proper resize
     AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
-    foreach(AnnotationTableObject* ao, ctx->getAnnotationObjects()) {
+    QSet<AnnotationTableObject*> anns = ctx->getAnnotationObjects(true);
+    foreach(AnnotationTableObject* ao, anns) {
         foreach(Annotation* a, ao->getAnnotations()) {
             AnnotationSettings* as = asr->getAnnotationSettings(a->getAnnotationName());
             buildAnnotationItem(DrawAnnotationPass_DrawFill, a, false, as);
@@ -431,6 +438,26 @@ void CircularViewRenderArea::adaptNumberOfLabels(int h) {
     maxDisplayingLabels = int(h/lblHeight);
 }
 
+void CircularViewRenderArea::paintContent( QPainter& p ) {
+    int viewSize = qMin(circularView->height(), circularView->width());
+    uiLog.details(tr("circular view size %1 %2").arg(circularView->width()).arg(circularView->height()));
+    verticalOffset = parentWidget()->height()/2;
+    if (outerEllipseSize + (regionY.count()-1)*ellipseDelta + VIEW_MARGIN > viewSize) {
+        verticalOffset += rulerEllipseSize/2;
+    }
+    
+    p.fillRect(0, 0, width(), height(), Qt::white);
+    p.save();
+    p.translate(parentWidget()->width()/2, verticalOffset);
+
+    drawRuler(p);
+    drawAnnotations(p);
+    drawSequenceName(p);
+    drawAnnotationsSelection(p);
+    drawSequenceSelection(p);
+    drawMarker(p);
+    p.restore();
+}
 
 void CircularViewRenderArea::drawAll(QPaintDevice* pd) {
     QPainter p(pd);
@@ -489,7 +516,7 @@ void CircularViewRenderArea::drawAnnotationsSelection(QPainter& p) {
     }
     foreach(const AnnotationSelectionData& asd, ctx->getAnnotationsSelection()->getSelection()) {
         AnnotationTableObject* o = asd.annotation->getGObject();
-        if (ctx->getAnnotationObjects().contains(o)) {
+        if (ctx->getAnnotationObjects(true).contains(o)) {
             if(circItems.contains(asd.annotation)) {
                 CircularAnnotationItem* item = circItems[asd.annotation];
                 item->setSelected(true);
@@ -554,11 +581,11 @@ void CircularViewRenderArea::drawSequenceName(QPainter& p) {
 void CircularViewRenderArea::drawSequenceSelection( QPainter& p ) {
     ADVSequenceObjectContext* ctx = view->getSequenceContext();
     int seqLen = ctx->getSequenceLen();
-    const QList<LRegion>& selection = view->getSequenceContext()->getSequenceSelection()->getSelectedRegions();
+    const QVector<U2Region>& selection = view->getSequenceContext()->getSequenceSelection()->getSelectedRegions();
 
     QList<QPainterPath*> paths;
 
-    foreach(const LRegion& r, selection) {
+    foreach(const U2Region& r, selection) {
         QPainterPath* path = new QPainterPath();
         int yLevel = regionY.count() - 1;
         QRect outerRect(-outerEllipseSize/2 - yLevel * ellipseDelta/2 - ARROW_HEIGHT_DELTA,
@@ -568,7 +595,7 @@ void CircularViewRenderArea::drawSequenceSelection( QPainter& p ) {
         QRectF innerRect(-rulerEllipseSize/2 + NOTCH_SIZE, -rulerEllipseSize/2 + NOTCH_SIZE,
             rulerEllipseSize - 2*NOTCH_SIZE, rulerEllipseSize-2*NOTCH_SIZE);
         float startAngle = r.startPos / (float)seqLen * 360 + rotationDegree;
-        float spanAngle = r.len / (float)seqLen * 360;
+        float spanAngle = r.length / (float)seqLen * 360;
         path->moveTo(outerRect.width()/2 * cos(-startAngle / 180.0 * PI),
             -outerRect.width()/2 * sin(-startAngle / 180.0 * PI));
         path->arcTo(outerRect, -startAngle, -spanAngle);
@@ -685,8 +712,8 @@ QPair<int,int> CircularViewRenderArea::getVisibleRange() const {
 void CircularViewRenderArea::drawRuler( QPainter& p ) {
     p.save();
     ADVSequenceObjectContext* ctx = view->getSequenceContext();
-    const LRegion& range = ctx->getSequenceObject()->getSequenceRange();
-    int seqLen = range.len;
+    const U2Region& range = ctx->getSequenceObject()->getSequenceRange();
+    int seqLen = range.length;
     normalizeAngle(rotationDegree);
 
     if (fitsInView) {
@@ -732,7 +759,8 @@ void CircularViewRenderArea::drawAnnotations(QPainter& p) {
     AnnotationSettingsRegistry* asr = AppContext::getAnnotationsSettingsRegistry();
     //for(QSet<AnnotationTableObject*>::const_iterator i = ctx->getAnnotationObjects().begin(); i != ctx->getAnnotationGObjects().constEnd(); i++) {
     //TODO: there need const order of annotation tables
-    foreach(AnnotationTableObject* ao, ctx->getAnnotationObjects()) {
+    QSet<AnnotationTableObject*> anns = ctx->getAnnotationObjects(true);   
+    foreach(AnnotationTableObject* ao, anns) {
         foreach(Annotation* a, ao->getAnnotations()) {
             AnnotationSettings* as = asr->getAnnotationSettings(a->getAnnotationName());
             buildAnnotationItem(DrawAnnotationPass_DrawFill, a, false, as);
@@ -762,29 +790,29 @@ void CircularViewRenderArea::buildAnnotationItem(DrawAnnotationPass pass, Annota
 
     int seqLen = ctx->getSequenceLen();
 
-    const QList<LRegion>& location = a->getLocation();
+    const QVector<U2Region>& location = a->getRegions();
 
-    LRegion generalLocation(location.first().startPos, location.last().startPos - location.first().startPos + location.last().len);
+    U2Region generalLocation(location.first().startPos, location.last().startPos - location.first().startPos + location.last().length);
 
     int yLevel = 0;
     bool yFind = false;
     for(;yLevel<regionY.count();yLevel++) {
         bool intersects = false;
-        foreach(const LRegion& r, regionY[yLevel]) {
+        foreach(const U2Region& r, regionY[yLevel]) {
             if(r.intersects(generalLocation)) {
                 intersects = true;
                 break;
             }
         }
         if(!intersects) {
-            QList<LRegion>& rY = regionY[yLevel];
+            QVector<U2Region>& rY = regionY[yLevel];
             rY.append(generalLocation);
             yFind = true;
             break;
         }
     }
     if(!yFind) { 
-        QList<LRegion> newLevel;
+        QVector<U2Region> newLevel;
         newLevel.append(generalLocation);
         regionY.append(newLevel);
     }
@@ -792,9 +820,27 @@ void CircularViewRenderArea::buildAnnotationItem(DrawAnnotationPass pass, Annota
 
     QList<CircurlarAnnotationRegionItem*> regions;
 
-    foreach(const LRegion& r, location) {
+    bool splitted = U2AnnotationUtils::isSplitted(a->getLocation(), ctx->getSequenceObject()->getSequenceRange());
+    bool splittedItemIsReady = false;
+
+    foreach(const U2Region& r, location) {
+        
+        int totalLen = 0;
+
+        if (splitted) {
+            if (!splittedItemIsReady) {
+                totalLen = r.length + location[1].length;
+                splittedItemIsReady = true;
+            } else {
+                break;
+            }
+        } else {
+            totalLen = r.length;
+        }
+
         float startAngle = (float)r.startPos / (float)seqLen * 360;
-        float spanAngle = (float)r.len / (float)seqLen * 360;
+        float spanAngle = (float)totalLen / (float)seqLen * 360;
+
 
         //cut annotation border if dna is linear
         if(!circularView->isCircularTopology()) {
@@ -802,21 +848,6 @@ void CircularViewRenderArea::buildAnnotationItem(DrawAnnotationPass pass, Annota
         }
         
         startAngle+=rotationDegree;
-
-        QVector<Qualifier> quals;
-        a->findQualifiers("SPLIT", quals);
-        if(!quals.isEmpty()) {
-            int totalLen = quals.at(0).getQualifierValue().toInt();
-            if(totalLen>=0) {
-                if(totalLen>seqLen) {
-                    totalLen = seqLen;
-                }
-                spanAngle = (float)totalLen / (float)seqLen * 360;
-            }
-            else {
-                return;
-            }
-        }
         
         QPainterPath path;
         QRect outerRect(-outerEllipseSize/2 - yLevel * ellipseDelta/2, -outerEllipseSize/2 - yLevel * ellipseDelta/2, outerEllipseSize + yLevel * ellipseDelta, outerEllipseSize + yLevel * ellipseDelta);
@@ -824,7 +855,7 @@ void CircularViewRenderArea::buildAnnotationItem(DrawAnnotationPass pass, Annota
         QRect middleRect(-middleEllipseSize/2 - yLevel * ellipseDelta/2, -middleEllipseSize/2 - yLevel * ellipseDelta/2, middleEllipseSize + yLevel * ellipseDelta, middleEllipseSize + yLevel * ellipseDelta);
         arrowLength = qMin(arrowLength, ARROW_LENGTH);
         float dAlpha = 360 * arrowLength / (float)PI / (outerEllipseSize + innerEllipseSize + yLevel*ellipseDelta);
-        bool isShort = r.len / (float)seqLen * 360 < dAlpha;
+        bool isShort = totalLen / (float)seqLen * 360 < dAlpha;
 
         float regionLen = spanAngle*PI/180 * outerRect.height()/2;
         if(regionLen < REGION_MIN_LEN) {
@@ -837,7 +868,7 @@ void CircularViewRenderArea::buildAnnotationItem(DrawAnnotationPass pass, Annota
             path.arcTo(innerRect, -startAngle-spanAngle, spanAngle);
             path.closeSubpath();
         } else {
-            if(a->isOnComplementStrand()) {
+            if(a->getStrand().isCompementary()) {
                 path.moveTo(outerRect.width()/2 * cos((startAngle + dAlpha) / 180.0 * PI),
                     outerRect.height()/2 * sin((startAngle + dAlpha) / 180.0 * PI));
                 path.lineTo((outerRect.width()/2 + arrowHeightDelta) * cos((startAngle + dAlpha) / 180.0 * PI),
@@ -878,10 +909,14 @@ void CircularViewRenderArea::buildAnnotationLabel(const QFont& font, Annotation*
     }
 
     ADVSequenceObjectContext* ctx = view->getSequenceContext();
+    bool splitted = U2AnnotationUtils::isSplitted(a->getLocation(), ctx->getSequenceObject()->getSequenceRange());
 
     int seqLen = ctx->getSequenceLen();
-    const QList<LRegion>& location = a->getLocation();
-    for(int r=0;r<location.count();r++) {
+    const QVector<U2Region>& location = a->getRegions();
+    for(int r = 0; r < location.count(); r++) {
+        if (splitted && r != 0) {
+            break;
+        }
         CircularAnnotationLabel* label = new CircularAnnotationLabel(a, r, seqLen, font, this);
         labelList.append(label);
         CircurlarAnnotationRegionItem* ri = circItems[a]->getRegions()[r];
@@ -889,8 +924,8 @@ void CircularViewRenderArea::buildAnnotationLabel(const QFont& font, Annotation*
     }
 }
 
-LRegion CircularViewRenderArea::getAnnotationYRange(Annotation*, int, const AnnotationSettings*) const{
-    return LRegion(0,0);
+U2Region CircularViewRenderArea::getAnnotationYRange(Annotation*, int, const AnnotationSettings*) const{
+    return U2Region(0,0);
 }
 
 void CircularViewRenderArea::resizeEvent( QResizeEvent *e ) {
@@ -988,4 +1023,8 @@ void CircularViewRenderArea::evaluateLabelPositions() {
     }
 }
 
+CircularViewRenderArea::~CircularViewRenderArea() {
+    qDeleteAll(circItems.values());
+}
+
 }//namespace
