@@ -1,16 +1,28 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "CircularViewPlugin.h"
 #include "CircularView.h"
 #include "CircularViewSplitter.h"
+#include "RestrictionMapWidget.h"
 
 #include <U2Core/GObject.h>
 #include <U2Core/DocumentModel.h>
@@ -108,7 +120,6 @@ CircularViewSplitter* CircularViewContext::getView(GObjectView* view, bool creat
     if (create) {
         AnnotatedDNAView* av = qobject_cast<AnnotatedDNAView*>(view);
         circularView = new CircularViewSplitter(av);
-        av->insertWidgetIntoSplitter(circularView);
         resources.append(circularView);
         viewResources.insert(view, resources);
 
@@ -166,14 +177,18 @@ void CircularViewContext::sl_showCircular() {
         assert(a->view == NULL);
         CircularViewSplitter* splitter = getView(sw->getAnnotatedDNAView(), true);
         a->view = new CircularView(sw, sw->getSequenceContext());
-        splitter->addView(a->view);
+        a->rmapWidget=new RestrctionMapWidget(sw->getSequenceContext(),splitter);
+        splitter->addView(a->view,a->rmapWidget);
+        sw->getAnnotatedDNAView()->insertWidgetIntoSplitter(splitter);
+        splitter->adaptSize();
     } else {
         a->setText(tr("Show circular view"));
         assert(a->view!=NULL);
         CircularViewSplitter* splitter = getView(sw->getAnnotatedDNAView(), false);
         if(splitter != NULL) {
-            splitter->removeView(a->view);
+            splitter->removeView(a->view,a->rmapWidget);
             delete a->view;
+            delete a->rmapWidget;
             if(splitter->isEmpty()) {
                 removeCircularView(sw->getAnnotatedDNAView());
             }
