@@ -1,15 +1,28 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "CircularViewSplitter.h"
 #include "CircularView.h"
+#include "RestrictionMapWidget.h"
+#include "ExportImageCircularViewDialog.h"
 
 #include <U2Core/L10n.h>
 #include <U2Core/GObject.h>
@@ -23,11 +36,11 @@
 #include <QtGui/QFileDialog>
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QHBoxLayout>
-#include <QtSvg/QSvgGenerator>
 #include <QtGui/QPrinter>
 #include <QtGui/QPixmap>
 #include <QtGui/QPainter>
 #include <QtGui/QMessageBox>
+#include <QtGui/QTreeWidget>
 
 #include <QtGui/QApplication>
 
@@ -55,6 +68,14 @@ CircularViewSplitter::CircularViewSplitter(AnnotatedDNAView* view) : ADVSplitWid
     tbExport->setToolTip(tr("Save circular view as image"));
     tbExport->setFixedSize(20,20);
 
+    tbToggleRestrictionMap = new QToolButton(this);
+    tbToggleRestrictionMap->setIcon(QIcon(":/circular_view/images/side_list.png"));
+    tbToggleRestrictionMap->setToolTip(tr("Show/hide restriction sites map"));
+    tbToggleRestrictionMap->setFixedSize(20,20);
+    tbToggleRestrictionMap->setCheckable(true);
+    tbToggleRestrictionMap->setChecked(true);
+    connect(tbToggleRestrictionMap, SIGNAL(toggled(bool)),SLOT(sl_toggleRestrictionMap(bool)));
+
     toolBar = new HBar(this);
     toolBar->setOrientation(Qt::Vertical);
 
@@ -62,6 +83,8 @@ CircularViewSplitter::CircularViewSplitter(AnnotatedDNAView* view) : ADVSplitWid
     toolBar->addWidget(tbZoomOut);
     toolBar->addWidget(tbFitInView);
     toolBar->addWidget(tbExport);
+    toolBar->addWidget(tbToggleRestrictionMap);
+
     connect(tbExport, SIGNAL(pressed()), SLOT(sl_export()));
 
     splitter = new QSplitter(Qt::Horizontal);
@@ -99,7 +122,7 @@ void CircularViewSplitter::saveState( QVariantMap& m ) {
     //TODO:
 }
 
-void CircularViewSplitter::addView(CircularView* view) {
+void CircularViewSplitter::addView(CircularView* view, RestrctionMapWidget* rmapWidget) {
     tbFitInView->setDisabled(true);
     tbZoomOut->setDisabled(true);
     connect(tbZoomIn, SIGNAL(pressed()), view, SLOT(sl_zoomIn()));
@@ -111,8 +134,14 @@ void CircularViewSplitter::addView(CircularView* view) {
     connect(view, SIGNAL(si_fitInViewDisabled(bool)), SLOT(sl_updateFitInViewAction(bool)));
 
     circularViewList.append(view);
-    splitter->insertWidget(0, view);
-    adaptSize();
+    restrictionMapWidgets.append(rmapWidget);
+
+    splitter->addWidget(view);
+    splitter->addWidget(rmapWidget);
+    
+    splitter->setStretchFactor(splitter->indexOf(view), 10);
+    splitter->setStretchFactor(splitter->indexOf(rmapWidget), 1);
+    
     connect(view, SIGNAL(si_wheelMoved(int)), SLOT(sl_moveSlider(int)));
 }
 
@@ -128,50 +157,36 @@ void CircularViewSplitter::sl_moveSlider(int delta) {
     horScroll->setSliderPosition(newPos);
 }
 
-void CircularViewSplitter::removeView(CircularView* view) {
+void CircularViewSplitter::removeView(CircularView* view, RestrctionMapWidget* rmapWidget) {
     circularViewList.removeAll(view);
+    restrictionMapWidgets.removeAll(rmapWidget);
 }
 
 bool CircularViewSplitter::isEmpty() {
     return circularViewList.isEmpty();
 }
 
-void CircularViewSplitter::sl_export() {
-    QString filter = tr("Raster image (*.png *.bmp *.jpg *.jpeg *.ppm *.xbm *.xpm)");
-    filter += "\n" + tr("Vector image (*.svg)");
-    filter += "\n"+ tr("Portable document (*.pdf *.ps)");
-    LastOpenDirHelper lod("image");
-    lod.url = QFileDialog::getSaveFileName(this, tr("Export circular view to image"), lod.dir, filter);
-    if (!lod.url.isEmpty()) {
-        bool result = false;
-        QRegion bounds(rect());
-        if (lod.url.endsWith(".svg", Qt::CaseInsensitive)) {
-            QSvgGenerator svg;
-            svg.setFileName(lod.url);
-            svg.setSize(rect().size());
-            QPainter painter(&svg);
-            painter.setRenderHint(QPainter::Antialiasing);
-            render(&painter, QPoint(), bounds);
-            result = painter.end();
-        } else if (lod.url.endsWith(".pdf", Qt::CaseInsensitive) || lod.url.endsWith(".ps", Qt::CaseInsensitive)) {
-            QPrinter printer;
-            printer.setOutputFileName(lod.url);
-            QPainter painter(&printer);
-            painter.setRenderHint(QPainter::Antialiasing);
-            render(&painter, QPoint(), bounds);
-            result = painter.end();
-        } else {
-            QPixmap pixmap(rect().size());
-            QPainter painter(&pixmap);
-            painter.fillRect(pixmap.rect(), Qt::white);
-            painter.setRenderHint(QPainter::Antialiasing);
-            render(&painter, QPoint(), bounds);
-            result = painter.end() & pixmap.save(lod.url);
-        }
-        if (!result) {
-            QMessageBox::critical(this, L10N::errorTitle(), tr("Unexpected error while exporting image!"));
-        }
+bool noValidExtension(const QString& url) {
+    QFileInfo fi(url);
+    if (fi.suffix().isEmpty()) {
+        return true;
     }
+
+    QStringList validExtensions;
+    validExtensions << "png" << "bmp" << "jpg" << "jpeg" << "ppm" <<
+        "xbm" << "xpm" << "svg" << "pdf" << "ps";
+
+    if (!validExtensions.contains(fi.suffix())) {
+        return true;
+    }
+
+    return false;
+}
+
+void CircularViewSplitter::sl_export() {
+    CircularView* cv = circularViewList.last();
+    ExportImageCVDialog dialog(cv);
+    dialog.exec();
     tbExport->setDown(false);
 }
 
@@ -184,6 +199,7 @@ void CircularViewSplitter::sl_horSliderMoved(int newVal) {
 void CircularViewSplitter::adaptSize() {
 
     QWidget* widget = parentWidget();
+    
     Q_ASSERT(widget != NULL);
     QSplitter* parentSplitter = qobject_cast<QSplitter* > (widget);
 
@@ -241,4 +257,11 @@ void CircularViewSplitter::sl_updateFitInViewAction( bool disabled) {
     tbFitInView->setDisabled(disabled);
 }
 
+void CircularViewSplitter::sl_toggleRestrictionMap( bool toggle)
+{
+    foreach (QWidget* w, restrictionMapWidgets) {
+        w->setVisible(toggle);
+    }
+}
+
 } //namespace U2
