@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_CIRCULAR_VIEW_SPLITTER_H_
 #define _U2_CIRCULAR_VIEW_SPLITTER_H_
@@ -27,6 +38,7 @@ namespace U2 {
 
 class CircularViewHeaderWidget;
 class HBar;
+class RestrctionMapWidget;
 
 class CircularViewSplitter : public ADVSplitWidget{
     Q_OBJECT
@@ -37,9 +49,9 @@ public:
     virtual bool acceptsGObject(GObject*) {return false;}
     virtual void updateState(const QVariantMap& m);
     virtual void saveState(QVariantMap& m);
-    void addView(CircularView* view);
+    void addView(CircularView* view, RestrctionMapWidget* rmapWidget);
     void adaptSize();
-    void removeView(CircularView* view);
+    void removeView(CircularView* view, RestrctionMapWidget* rmapWidget);
     bool isEmpty();
     const QList<CircularView*>& getViewList() const { return circularViewList; }
 protected slots:
@@ -50,6 +62,7 @@ protected slots:
     void sl_updateZoomInAction(bool);
     void sl_updateZoomOutAction(bool);
     void sl_updateFitInViewAction(bool);
+    void sl_toggleRestrictionMap(bool);
 private:
     QSplitter* splitter;
     HBar* toolBar;    
@@ -59,8 +72,10 @@ private:
     QToolButton* tbZoomOut;
     QToolButton* tbFitInView;
     QToolButton* tbExport;
+    QToolButton* tbToggleRestrictionMap;
 
     QList<CircularView*> circularViewList;
+    QList<RestrctionMapWidget*> restrictionMapWidgets;
 };
 
 } //namespace U2
