@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <U2Core/GObject.h>
 #include <U2Core/AppContext.h>
@@ -123,7 +134,7 @@ void GTest_ExportNucleicToAminoAlignmentTask::init(XMLTestFormat *tf, const QDom
         return;
     }
 
-    selectedRows = LRegion();
+    selectedRows = U2Region();
     buf = el.attribute(EXTRACT_ROWS_ATTR);
     if (!buf.isEmpty()) {
         QStringList sl = buf.split(",");
@@ -144,12 +155,12 @@ void GTest_ExportNucleicToAminoAlignmentTask::init(XMLTestFormat *tf, const QDom
             stateInfo.setError(GTest::tr("Invalid base : %1").arg(sl[1]));
             return;
         }
-        selectedRows = LRegion(base, len);
+        selectedRows = U2Region(base, len);
     }    
 }
 
 void GTest_ExportNucleicToAminoAlignmentTask::prepare() {
-    if (hasErrors()) {
+    if (hasError()) {
         return;
     }
     Document* doc = getContext<Document>(this, inputFile);
@@ -171,7 +182,7 @@ void GTest_ExportNucleicToAminoAlignmentTask::prepare() {
     trid.replace("0", QString("%1").arg(transTable));
     trans << AppContext::getDNATranslationRegistry()->lookupTranslation(trid);
 
-    exportTask = new ExportMSA2MSATask(srcAl, selectedRows.len ? selectedRows.startPos : 0, selectedRows.len ? selectedRows.len : srcAl.getNumRows(), outputFileName, 
+    exportTask = new ExportMSA2MSATask(srcAl, selectedRows.length ? selectedRows.startPos : 0, selectedRows.length ? selectedRows.length : srcAl.getNumRows(), outputFileName, 
          trans, BaseDocumentFormats::CLUSTAL_ALN);
     addSubTask(exportTask);
 }
@@ -179,7 +190,7 @@ void GTest_ExportNucleicToAminoAlignmentTask::prepare() {
 QList<Task*> GTest_ExportNucleicToAminoAlignmentTask::onSubTaskFinished(Task* subTask) {
     Q_UNUSED(subTask);
     QList<Task*> res;
-    if (hasErrors() || subTask->hasErrors() || isCanceled()) {
+    if (hasError() || subTask->hasError() || isCanceled()) {
         return res;
     }
 
@@ -208,7 +219,7 @@ QList<Task*> GTest_ExportNucleicToAminoAlignmentTask::onSubTaskFinished(Task* su
 
 Task::ReportResult GTest_ExportNucleicToAminoAlignmentTask::report() {
     propagateSubtaskError();
-    if (hasErrors()) {
+    if (hasError()) {
         return ReportResult_Finished;
     }
 
