@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ExportProjectViewItems.h"
 
@@ -16,7 +27,7 @@
 #include "ExportMSA2SequencesDialog.h"
 #include "ExportMSA2MSADialog.h"
 #include "ExportChromatogramDialog.h"
-#include "ExportAnnotations2CSVDialog.h"
+#include "ExportAnnotationsDialog.h"
 #include "ExportAnnotations2CSVTask.h"
 #include "ExportUtils.h"
 
@@ -24,8 +35,6 @@
 #include "ImportAnnotationsFromCSVTask.h"
 
 #include <U2Core/AppContext.h>
-#include <U2Gui/MainWindow.h>
-#include <U2Gui/ProjectView.h>
 #include <U2Core/SelectionModel.h>
 #include <U2Core/L10n.h>
 #include <U2Core/GUrlUtils.h>
@@ -42,11 +51,15 @@
 #include <U2Core/DocumentSelection.h>
 #include <U2Core/GObjectSelection.h>
 #include <U2Core/SelectionUtils.h>
-
+#include <U2Core/U2OpStatusUtils.h>
 #include <U2Core/MSAUtils.h>
-#include <U2Gui/GUIUtils.h>
+
 #include <U2Misc/DialogUtils.h>
 
+#include <U2Gui/GUIUtils.h>
+#include <U2Gui/MainWindow.h>
+#include <U2Gui/ProjectView.h>
+
 #include <QtGui/QMessageBox>
 #include <QtGui/QFileDialog>
 #include <QtGui/QMainWindow>
@@ -74,8 +87,8 @@ ExportProjectViewItemsContoller::ExportProjectViewItemsContoller(QObject* p) : Q
     exportDNAChromatogramAction = new QAction(tr("Export chromatogram to SCF"), this);
     connect(exportDNAChromatogramAction, SIGNAL(triggered()), SLOT(sl_exportChromatogramToSCF()));
 
-    exportAnnotations2CSV = new QAction(tr("Export annotations to CSV file"), this);
-    connect(exportAnnotations2CSV, SIGNAL(triggered()), SLOT(sl_exportAnnotationsToCSV()));
+    exportAnnotations2CSV = new QAction(tr("Export annotations"), this);
+    connect(exportAnnotations2CSV, SIGNAL(triggered()), SLOT(sl_exportAnnotations()));
 
     ProjectView* pv = AppContext::getProjectView();
     assert(pv!=NULL);
@@ -97,7 +110,7 @@ void ExportProjectViewItemsContoller::addExportMenu(QMenu& m) {
     QMenu* sub = NULL;
 
     MultiGSelection ms; ms.addSelection(pv->getGObjectSelection()); ms.addSelection(pv->getDocumentSelection());
-    QSet<GObject*> set = SelectionUtils::findObjects(GObjectTypes::SEQUENCE, &ms, UOF_LoadedOnly);
+    QList<GObject*> set = SelectionUtils::findObjects(GObjectTypes::SEQUENCE, &ms, UOF_LoadedOnly);
     if (!set.isEmpty()) {
         sub = new QMenu(tr("Export"));
         sub->addAction(exportSequencesToSequenceFormatAction);
@@ -107,7 +120,7 @@ void ExportProjectViewItemsContoller::addExportMenu(QMenu& m) {
         if (set.size() == 1) {
             sub = new QMenu(tr("Export"));
             sub->addAction(exportAlignmentAsSequencesAction);
-            GObject* obj = set.toList().first();
+            GObject* obj = set.first();
             MAlignment ma = qobject_cast<MAlignmentObject*>(obj)->getMAlignment();
             if (ma.getAlphabet()->isNucleic()) {
                 sub->addAction(exportNucleicAlignmentToAminoAction);
@@ -146,7 +159,7 @@ void ExportProjectViewItemsContoller::addImportMenu(QMenu& m) {
     m.insertMenu(beforeAction, importMenu);
 }
 
-static bool hasComplementForAll(const QSet<GObject*>& set) {
+static bool hasComplementForAll(const QList<GObject*>& set) {
     foreach(GObject* o, set) {
         DNASequenceObject* so = qobject_cast<DNASequenceObject*>(o);
         if (o == NULL || GObjectUtils::findComplementTT(so) == NULL) {
@@ -156,7 +169,7 @@ static bool hasComplementForAll(const QSet<GObject*>& set) {
     return true;
 }
 
-static bool hasAminoForAll(const QSet<GObject*>& set) {
+static bool hasAminoForAll(const QList<GObject*>& set) {
     foreach(GObject* o, set) {
         DNASequenceObject* so = qobject_cast<DNASequenceObject*>(o);
         if (o == NULL || GObjectUtils::findAminoTT(so, false, NULL) == NULL) {
@@ -166,7 +179,7 @@ static bool hasAminoForAll(const QSet<GObject*>& set) {
     return true;
 }
 
-static bool hasNucleicForAll(const QSet<GObject*>& set) {
+static bool hasNucleicForAll(const QList<GObject*>& set) {
     foreach(GObject* o, set) {
         DNASequenceObject* so = qobject_cast<DNASequenceObject*>(o);
         if (o == NULL || GObjectUtils::findBackTranslationTT(so) == NULL) {
@@ -182,7 +195,7 @@ void ExportProjectViewItemsContoller::sl_saveSequencesToSequenceFormat() {
     assert(pv!=NULL);
 
     MultiGSelection ms; ms.addSelection(pv->getGObjectSelection()); ms.addSelection(pv->getDocumentSelection());
-    QSet<GObject*> set = SelectionUtils::findObjects(GObjectTypes::SEQUENCE, &ms, UOF_LoadedOnly);
+    QList<GObject*> set = SelectionUtils::findObjects(GObjectTypes::SEQUENCE, &ms, UOF_LoadedOnly);
     if (set.isEmpty()) {
         QMessageBox::critical(NULL, L10N::errorTitle(), tr("No sequence objects selected!"));
         return;
@@ -249,10 +262,10 @@ void ExportProjectViewItemsContoller::sl_saveSequencesAsAlignment() {
         return;
     }
 
-    QString err;
-    MAlignment ma = MSAUtils::seq2ma(sequenceObjects, err);
-    if (!err.isEmpty()) {
-        QMessageBox::critical(NULL, L10N::errorTitle(), err);
+    U2OpStatusImpl os;
+    MAlignment ma = MSAUtils::seq2ma(sequenceObjects, os);
+    if (os.hasError()) {
+        QMessageBox::critical(NULL, L10N::errorTitle(), os.getError());
         return;
     }
     
@@ -266,6 +279,8 @@ void ExportProjectViewItemsContoller::sl_saveSequencesAsAlignment() {
     if (rc != QDialog::Accepted) {
         return;
     }
+    QString objName = GUrl(d.url).baseFileName();
+    ma.setName(objName);
     Task* t = ExportUtils::wrapExportTask(new ExportAlignmentTask(ma, d.url, d.format), d.addToProjectFlag);
     AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
@@ -275,12 +290,12 @@ void ExportProjectViewItemsContoller::sl_saveAlignmentAsSequences() {
     assert(pv!=NULL);
 
     MultiGSelection ms; ms.addSelection(pv->getGObjectSelection()); ms.addSelection(pv->getDocumentSelection());
-    QSet<GObject*> set = SelectionUtils::findObjects(GObjectTypes::MULTIPLE_ALIGNMENT, &ms, UOF_LoadedOnly);
+    QList<GObject*> set = SelectionUtils::findObjects(GObjectTypes::MULTIPLE_ALIGNMENT, &ms, UOF_LoadedOnly);
     if (set.size()!=1) {
         QMessageBox::critical(NULL, L10N::errorTitle(), tr("Select one alignment object to export"));
         return;
     }
-    GObject* obj = set.toList().first();
+    GObject* obj = set.first();
     MAlignmentObject* maObject = qobject_cast<MAlignmentObject*>(obj);
     const MAlignment& ma = maObject->getMAlignment();
     ExportMSA2SequencesDialog d(AppContext::getMainWindow()->getQMainWindow());
@@ -298,17 +313,16 @@ void ExportProjectViewItemsContoller::sl_exportNucleicAlignmentToAmino() {
     assert(pv!=NULL);
 
     MultiGSelection ms; ms.addSelection(pv->getGObjectSelection()); ms.addSelection(pv->getDocumentSelection());
-    QSet<GObject*> set = SelectionUtils::findObjects(GObjectTypes::MULTIPLE_ALIGNMENT, &ms, UOF_LoadedOnly);
+    QList<GObject*> set = SelectionUtils::findObjects(GObjectTypes::MULTIPLE_ALIGNMENT, &ms, UOF_LoadedOnly);
     if (set.size()!=1) {
         QMessageBox::critical(NULL, L10N::errorTitle(), tr("Select one alignment object to export"));
         return;
     }    
 
-    GObject* obj = set.toList().first();
-    MAlignmentObject* mobj = qobject_cast<MAlignmentObject*>(obj);
+    GObject* obj = set.first();
     MAlignment ma = qobject_cast<MAlignmentObject*>(obj)->getMAlignment();
 
-    GObject* firstObject = set.toList().first();
+    GObject* firstObject = set.first();
     Document* doc = firstObject->getDocument();
 
     QString fileExt = AppContext::getDocumentFormatRegistry()->getFormatById(BaseDocumentFormats::CLUSTAL_ALN)->getSupportedDocumentFileExtensions().first();
@@ -347,12 +361,12 @@ void ExportProjectViewItemsContoller::sl_exportChromatogramToSCF() {
     assert(pv!=NULL);
 
     MultiGSelection ms; ms.addSelection(pv->getGObjectSelection()); ms.addSelection(pv->getDocumentSelection());
-    QSet<GObject*> set = SelectionUtils::findObjects(GObjectTypes::CHROMATOGRAM, &ms, UOF_LoadedOnly);
+    QList<GObject*> set = SelectionUtils::findObjects(GObjectTypes::CHROMATOGRAM, &ms, UOF_LoadedOnly);
     if (set.size() != 1 ) {
         QMessageBox::warning(NULL, L10N::errorTitle(), tr("Select one chromatogram object to export"));
         return;
     }
-    GObject* obj = set.toList().first();
+    GObject* obj = set.first();
     DNAChromatogramObject* chromaObj = qobject_cast<DNAChromatogramObject*>(obj);
     assert(chromaObj != NULL);
     
@@ -374,19 +388,22 @@ void ExportProjectViewItemsContoller::sl_exportChromatogramToSCF() {
     AppContext::getTaskScheduler()->registerTopLevelTask(task);
 }
 
-void ExportProjectViewItemsContoller::sl_exportAnnotationsToCSV()
-{
+void ExportProjectViewItemsContoller::sl_exportAnnotations() {
+    // find annotations: whole annotation file
     ProjectView* pv = AppContext::getProjectView();
     assert(pv!=NULL);
-
-    MultiGSelection ms; ms.addSelection(pv->getGObjectSelection()); ms.addSelection(pv->getDocumentSelection());
-    QSet<GObject*> set = SelectionUtils::findObjects(GObjectTypes::ANNOTATION_TABLE, &ms, UOF_LoadedOnly);
+    
+    MultiGSelection ms; 
+    ms.addSelection(pv->getGObjectSelection()); 
+    ms.addSelection(pv->getDocumentSelection());
+    
+    QList<GObject*> set = SelectionUtils::findObjects(GObjectTypes::ANNOTATION_TABLE, &ms, UOF_LoadedOnly);
     if (set.size() != 1 ) {
         QMessageBox::warning(QApplication::activeWindow(), exportAnnotations2CSV->text(), tr("Select one annotation object to export"));
         return;
     }
-
-    GObject* obj = set.toList().first();
+    
+    GObject* obj = set.first();
     AnnotationTableObject* aObj = qobject_cast<AnnotationTableObject*>(obj);
     assert(aObj != NULL);
     QList<Annotation*> annotations = aObj->getAnnotations();
@@ -395,25 +412,31 @@ void ExportProjectViewItemsContoller::sl_exportAnnotationsToCSV()
         return;
     }
     
-    ExportAnnotations2CSVDialog d(QApplication::activeWindow());
-    d.setWindowTitle(exportAnnotations2CSV->text());
     Annotation* first = annotations.first();
     const GUrl& url = first->getGObject()->getDocument()->getURL();
-    QString fileName = GUrlUtils::rollFileName(url.dirPath() + "/" + url.baseFileName() + "_annotations.csv", DocumentUtils::getNewDocFileNameExcludesHint());
-    d.setFileName(fileName);
-    d.setExportSequenceEnabled(false);    
-
+    QString fileName = GUrlUtils::rollFileName(url.dirPath() + "/" + url.baseFileName() + "_annotations.csv", 
+        DocumentUtils::getNewDocFileNameExcludesHint());
+    
+    ExportAnnotationsDialog d(fileName, QApplication::activeWindow());
+    d.setWindowTitle(exportAnnotations2CSV->text());
+    d.setExportSequenceVisible(false);    
+    
     if (QDialog::Accepted != d.exec()) {
         return;
     }
-
+    
     // TODO: lock documents or use shared-data objects
-    // TODO: sort?
-    // qStableSort(annotations.begin(), annotations.end(), annotationLessThan);
-
-    AppContext::getTaskScheduler()->registerTopLevelTask(
-        new ExportAnnotations2CSVTask(annotations, QByteArray(),NULL, false, d.getFileName()));
-
+    // same as in ADVExportContext::sl_saveSelectedAnnotations()
+    qStableSort(annotations.begin(), annotations.end(), Annotation::annotationLessThan);
+    
+    // run task
+    Task * t = NULL;
+    if(d.fileFormat() == ExportAnnotationsDialog::CSV_FORMAT_ID) {
+        t = new ExportAnnotations2CSVTask(annotations, QByteArray(),NULL, false, d.filePath());
+    } else {
+        t = ExportUtils::saveAnnotationsTask(d.filePath(), d.fileFormat(), annotations);
+    }
+    AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
 
 } //namespace
