@@ -1,18 +1,29 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ExportSequenceViewItems.h"
 #include "ExportUtils.h"
 #include "ExportSequenceTask.h"
 #include "ExportSequencesDialog.h"
-#include "ExportAnnotations2CSVDialog.h"
+#include "ExportAnnotationsDialog.h"
 #include "ExportAnnotations2CSVTask.h"
 #include "ExportSequences2MSADialog.h"
 #include "GetSequenceByIdDialog.h"
@@ -35,6 +46,7 @@
 #include <U2Core/SelectionUtils.h>
 #include <U2Core/AnnotationSelection.h>
 #include <U2Core/DNASequenceSelection.h>
+#include <U2Core/GObjectRelationRoles.h>
 
 #include <U2View/AnnotatedDNAView.h>
 #include <U2View/ADVSequenceObjectContext.h>
@@ -90,8 +102,8 @@ ADVExportContext::ADVExportContext(AnnotatedDNAView* v) : view(v) {
     annotations2SequenceAction = new QAction(tr("Export sequence of selected annotations..."), this);
     connect(annotations2SequenceAction, SIGNAL(triggered()), SLOT(sl_saveSelectedAnnotationsSequence()));
 
-    annotations2CSVAction = new QAction(tr("Export annotations to CSV format..."), this);
-    connect(annotations2CSVAction, SIGNAL(triggered()), SLOT(sl_saveSelectedAnnotationsToCSV()));
+    annotations2CSVAction = new QAction(tr("Export annotations..."), this);
+    connect(annotations2CSVAction, SIGNAL(triggered()), SLOT(sl_saveSelectedAnnotations()));
 
     annotationsToAlignmentAction = new QAction(QIcon(":core/images/msa.png"), tr("Align selected annotations..."), this);
     connect(annotationsToAlignmentAction, SIGNAL(triggered()), SLOT(sl_saveSelectedAnnotationsToAlignment()));
@@ -121,13 +133,12 @@ ADVExportContext::ADVExportContext(AnnotatedDNAView* v) : view(v) {
     foreach(ADVSequenceObjectContext* sCtx, view->getSequenceContexts()) {
         sl_onSequenceContextAdded(sCtx);
     }
-
 }
 
 void ADVExportContext::sl_onSequenceContextAdded(ADVSequenceObjectContext* c) {
     connect(c->getSequenceSelection(), 
-        SIGNAL(si_selectionChanged(LRegionsSelection*, const QList<LRegion>&, const QList<LRegion>&)), 
-        SLOT(sl_onSequenceSelectionChanged(LRegionsSelection*, const QList<LRegion>&, const QList<LRegion>&)));
+        SIGNAL(si_selectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)), 
+        SLOT(sl_onSequenceSelectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)));
 
     updateActions();
 }
@@ -141,7 +152,7 @@ void ADVExportContext::sl_onAnnotationSelectionChanged(AnnotationSelection* , co
     updateActions();
 }
 
-void ADVExportContext::sl_onSequenceSelectionChanged(LRegionsSelection* , const QList<LRegion>& , const QList<LRegion>& ) {
+void ADVExportContext::sl_onSequenceSelectionChanged(LRegionsSelection* , const QVector<U2Region>& , const QVector<U2Region>& ) {
     updateActions();
 }
 
@@ -311,11 +322,11 @@ void ADVExportContext::sl_saveSelectedAnnotationsSequence() {
     AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
 
-static QList<SharedAnnotationData> findAnnotationsInRegion(const LRegion& region, const QList<AnnotationTableObject*>& aobjects) {
+static QList<SharedAnnotationData> findAnnotationsInRegion(const U2Region& region, const QList<AnnotationTableObject*>& aobjects) {
     QList<SharedAnnotationData> result;
     foreach (const AnnotationTableObject* aobj, aobjects) {
         foreach(Annotation* a, aobj->getAnnotations()) {
-            LRegion areg = LRegion::containingRegion(a->getLocation());
+            U2Region areg = U2Region::containingRegion(a->getRegions());
             if (region.contains(areg)) {
                 result.append(a->data());
             }
@@ -324,6 +335,27 @@ static QList<SharedAnnotationData> findAnnotationsInRegion(const LRegion& region
     return result;
 }
 
+// removes all annotation regions that does not intersect the given region
+// adjusts startpos to make in relative to the given region
+static void adjustAnnotationLocations(const U2Region& r, QList<SharedAnnotationData>& anns) {
+    for (int i = anns.size(); --i >= 0;) {
+        SharedAnnotationData& d = anns[i];
+        for (int j = d->location->regions.size(); --j >= 0; ) {
+            U2Region& ar = d->location->regions[j];
+            U2Region resr = ar.intersect(r);
+            if (resr.isEmpty()) {
+                d->location->regions.remove(j);
+                continue;
+            }
+            resr.startPos -= r.startPos;
+            d->location->regions[j] = resr;
+        }
+        if( d->location->regions.isEmpty()) {
+            anns.removeAt(i);
+        }
+    }
+}
+
 void ADVExportContext::sl_saveSelectedSequences() {
     ADVSequenceObjectContext* seqCtx = view->getSequenceInFocus();
     DNASequenceSelection* sel  = NULL;
@@ -336,7 +368,7 @@ void ADVExportContext::sl_saveSelectedSequences() {
         return;
     }
 
-    const QList<LRegion>& regions =  sel->getSelectedRegions();
+    const QVector<U2Region>& regions =  sel->getSelectedRegions();
     bool merge = regions.size() > 1;
     bool complement = seqCtx->getComplementTT()!=NULL;
     bool amino = seqCtx->getAminoTT()!=NULL;
@@ -360,7 +392,7 @@ void ADVExportContext::sl_saveSelectedSequences() {
     ExportSequenceTaskSettings s;
     ExportUtils::loadDNAExportSettingsFromDlg(s,d);
     QSet<QString> usedNames;
-    foreach(const LRegion& r, regions) {
+    foreach(const U2Region& r, regions) {
         QString prefix = QString("region [%1 %2]").arg(QString::number(r.startPos+1)).arg(QString::number(r.endPos()));
         QString name = prefix;
         for (int i = 0; i < s.items.size(); ++i) {
@@ -370,59 +402,23 @@ void ADVExportContext::sl_saveSelectedSequences() {
         }
         usedNames.insert(name);
         ExportSequenceItem ei;
-        QByteArray seq(sequence.constData() + r.startPos, r.len);
+        QByteArray seq(sequence.constData() + r.startPos, r.length);
         ei.sequence = DNASequence(name, seq, al);
         ei.complTT = seqCtx->getComplementTT();
         ei.aminoTT = d.translate ? (d.useSpecificTable ? GObjectUtils::findAminoTT(seqCtx->getSequenceObject(), false, d.translationTable) : seqCtx->getAminoTT()) : NULL;
         ei.backTT = d.backTranslate ? GObjectUtils::findBackTranslationTT(seqCtx->getSequenceObject(), d.translationTable) : NULL;
-        ei.annotations = findAnnotationsInRegion(r, seqCtx->getAnnotationObjects().toList());
+        if (s.saveAnnotations) {
+            ei.annotations = findAnnotationsInRegion(r, seqCtx->getAnnotationObjects(true).toList());
+            adjustAnnotationLocations(r, ei.annotations);
+        }
         s.items.append(ei);
     }
     Task* t = ExportUtils::wrapExportTask(new ExportSequenceTask(s), d.addToProject);
     AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
 
-static bool annotationLessThan(Annotation *first, Annotation *second) {
-    QListIterator<AnnotationGroup *> firstIterator(first->getGroups());
-    QListIterator<AnnotationGroup *> secondIterator(second->getGroups());
-    while(firstIterator.hasNext() && secondIterator.hasNext()) {
-        if (firstIterator.peekNext()->getGroupName() < secondIterator.peekNext()->getGroupName()) {
-            return true;
-        }
-        if (firstIterator.peekNext()->getGroupName() > secondIterator.peekNext()->getGroupName()) {
-            return false;
-        }
-        firstIterator.next();
-        secondIterator.next();
-    }
-    if (secondIterator.hasNext()) {
-        if(first->getAnnotationName() < secondIterator.peekNext()->getGroupName()) {
-            return true;
-        }
-        if(first->getAnnotationName() > secondIterator.peekNext()->getGroupName()) {
-            return false;
-        }
-        secondIterator.next();
-    }
-    if (firstIterator.hasNext()) {
-        if(firstIterator.peekNext()->getGroupName() < second->getAnnotationName()) {
-            return true;
-        }
-        if(firstIterator.peekNext()->getGroupName() > second->getAnnotationName()) {
-            return false;
-        }
-        firstIterator.next();
-    }
-    if (secondIterator.hasNext()) {
-        return true;
-    }
-    if (firstIterator.hasNext()) {
-        return false;
-    }
-    return (first->getAnnotationName() < second->getAnnotationName());
-}
-
-void ADVExportContext::sl_saveSelectedAnnotationsToCSV() {
+void ADVExportContext::sl_saveSelectedAnnotations() {
+    // find annotations: selected annotations, selected groups
     QSet<Annotation *> annotationSet;
     AnnotationSelection* as = view->getAnnotationsSelection();
     foreach(const AnnotationSelectionData &data, as->getSelection()) {
@@ -437,34 +433,46 @@ void ADVExportContext::sl_saveSelectedAnnotationsToCSV() {
         return;
     }
 
-    ExportAnnotations2CSVDialog d(AppContext::getMainWindow()->getQMainWindow());
-    d.setWindowTitle(annotations2CSVAction->text());
-    
     Annotation* first = *annotationSet.begin();
-    const GUrl& url = first->getGObject()->getDocument()->getURL();
-    QString fileName = url.isLocalFile() ? url.getURLString() : url.fileName();
-    fileName += ".csv";
-    d.setFileName(fileName);
+    Document* doc = first->getGObject()->getDocument();
+    ADVSequenceObjectContext *sequenceContext = view->getSequenceInFocus();
+    
+    GUrl url;
+    if (doc != NULL) {
+        url = doc->getURL();
+    } else if (sequenceContext != NULL) {
+        url = sequenceContext->getSequenceGObject()->getDocument()->getURL();
+    } else {
+        url = GUrl("newfile");
+    }
+    
+    QString fileName = GUrlUtils::rollFileName(url.dirPath() + "/" + url.baseFileName() + "_annotations.csv", 
+        DocumentUtils::getNewDocFileNameExcludesHint());
+    ExportAnnotationsDialog d(fileName, AppContext::getMainWindow()->getQMainWindow());
+    d.setWindowTitle(annotations2CSVAction->text());
     
     if (QDialog::Accepted != d.exec()) {
         return;
     }
-
+    
     //TODO: lock documents or use shared-data objects
     QList<Annotation *> annotationList = annotationSet.toList();
-    qStableSort(annotationList.begin(), annotationList.end(), annotationLessThan);
-
-    ADVSequenceObjectContext *sequenceContext = view->getSequenceInFocus();
-    AppContext::getTaskScheduler()->registerTopLevelTask(
-        new ExportAnnotations2CSVTask(annotationList, sequenceContext->getSequenceData(),
-        sequenceContext->getComplementTT(), d.getExportSequence(), d.getFileName()));
+    qStableSort(annotationList.begin(), annotationList.end(), Annotation::annotationLessThan);
+    
+    // run task
+    Task * t = NULL;
+    if(d.fileFormat() == ExportAnnotationsDialog::CSV_FORMAT_ID) {
+        t = new ExportAnnotations2CSVTask(annotationList, sequenceContext->getSequenceData(),
+            sequenceContext->getComplementTT(), d.exportSequence(), d.filePath());
+    } else {
+        t = ExportUtils::saveAnnotationsTask(d.filePath(), d.fileFormat(), annotationList);
+    }
+    AppContext::getTaskScheduler()->registerTopLevelTask(t);
 }
 
-
 //////////////////////////////////////////////////////////////////////////
 // alignment part
 
-
 #define MAX_ALI_MODEL (10*1000*1000)
 
 QString ADVExportContext::prepareMAFromAnnotations(MAlignment& ma, bool translate) {
@@ -509,7 +517,7 @@ QString ADVExportContext::prepareMAFromAnnotations(MAlignment& ma, bool translat
             return tr("Alignment is too large");
         }
 
-        bool doComplement = a.annotation->isOnComplementStrand();
+        bool doComplement = a.annotation->getStrand().isCompementary();
         DNATranslation* aminoTT = translate ? seqCtx->getAminoTT() : NULL;
         QByteArray rowSequence;
         AnnotationSelection::getAnnotationSequence(rowSequence, a, MAlignment_GapChar, sequence,  doComplement? complTT : NULL, aminoTT);
@@ -554,20 +562,20 @@ QString ADVExportContext::prepareMAFromSequences(MAlignment& ma, bool translate)
     //cache sequences
     QSet<QString> names;
     QList<MAlignmentRow> rows;
-    int maxLen = 0;
+    qint64 maxLen = 0;
     foreach(ADVSequenceObjectContext* c, view->getSequenceContexts()) {
         if (c->getSequenceSelection()->isEmpty()) {
             continue;
         }
         DNAAlphabet* seqAl = c->getAlphabet();
         DNATranslation* aminoTT = ((translate || forceTranslation) && seqAl->isNucleic()) ? c->getAminoTT() : NULL;
-        foreach(const LRegion& r, c->getSequenceSelection()->getSelectedRegions()) {
+        foreach(const U2Region& r, c->getSequenceSelection()->getSelectedRegions()) {
             const QByteArray& seq = c->getSequenceData();
-            maxLen = qMax(maxLen, r.len);
+            maxLen = qMax(maxLen, r.length);
             if (maxLen * rows.size() > MAX_ALI_MODEL) {
                 return tr("Alignment is too large");
             }
-            QByteArray mid = seq.mid(r.startPos, r.len);
+            QByteArray mid = seq.mid(r.startPos, r.length);
             if (aminoTT!=NULL) {
                 int len = aminoTT->translate(mid.data(), mid.size());
                 mid.resize(len);
@@ -677,8 +685,8 @@ void ADVExportContext::sl_getSequenceById() {
 }
 
 void ADVExportContext::fetchSequencesFromRemoteDB(const QString & listId) {
-    const QList<AnnotationSelectionData>& selection = view->getAnnotationsSelection()->getSelection();
-    AnnotationTableObject *ao = selection.first().annotation->getGObject();
+//    const QList<AnnotationSelectionData>& selection = view->getAnnotationsSelection()->getSelection();
+//    AnnotationTableObject *ao = selection.first().annotation->getGObject();
     DNAAlphabet* seqAl = view->getSequenceObjectsWithContexts().first()->getAlphabet();
 
     QString db;
