@@ -1,18 +1,29 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_EXPORT_SEQUENCE_VIEW_ITEMS_H_
 #define _U2_EXPORT_SEQUENCE_VIEW_ITEMS_H_
 
 #include <U2Core/global.h>
-#include <U2Core/LRegion.h>
+#include <U2Core/U2Region.h>
 #include <U2Gui/ObjectViewModel.h>
 
 namespace U2 {
@@ -44,7 +55,7 @@ public:
 protected slots:
     void sl_saveSelectedSequences();
     void sl_saveSelectedAnnotationsSequence();
-    void sl_saveSelectedAnnotationsToCSV();
+    void sl_saveSelectedAnnotations();
     void sl_saveSelectedAnnotationsToAlignment();
     void sl_saveSelectedAnnotationsToAlignmentWithTranslation();
     void sl_saveSelectedSequenceToAlignment();
@@ -57,7 +68,7 @@ protected slots:
     void sl_onSequenceContextRemoved(ADVSequenceObjectContext* c);
 
     void sl_onAnnotationSelectionChanged(AnnotationSelection*, const QList<Annotation*>& added, const QList<Annotation*>& removed);
-    void sl_onSequenceSelectionChanged(LRegionsSelection* thiz, const QList<LRegion>& added, const QList<LRegion>& removed);
+    void sl_onSequenceSelectionChanged(LRegionsSelection* thiz, const QVector<U2Region>& added, const QVector<U2Region>& removed);
 
     void updateActions();
 
