@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ExportTasks.h"
 
@@ -23,6 +34,7 @@
 #include <U2Core/AddDocumentTask.h>
 #include <U2Core/MSAUtils.h>
 #include <U2Core/TextUtils.h>
+#include <U2Core/ProjectModel.h>
 #include <U2Gui/OpenViewTask.h>
 #include <U2Core/MAlignmentObject.h>
 
@@ -32,7 +44,7 @@ namespace U2 {
 //////////////////////////////////////////////////////////////////////////
 // AddDocumentAndOpenViewTask
 
-AddDocumentAndOpenViewTask::AddDocumentAndOpenViewTask(AbstractExportTask* t) 
+AddExportedDocumentAndOpenViewTask::AddExportedDocumentAndOpenViewTask(AbstractExportTask* t) 
 : Task("Export sequence to document", TaskFlags_NR_FOSCOE)
 {
     exportTask = t;
@@ -40,19 +52,31 @@ AddDocumentAndOpenViewTask::AddDocumentAndOpenViewTask(AbstractExportTask* t)
 }
 
 
-QList<Task*> AddDocumentAndOpenViewTask::onSubTaskFinished( Task* subTask ) {
+QList<Task*> AddExportedDocumentAndOpenViewTask::onSubTaskFinished( Task* subTask ) {
     QList<Task*> subTasks;
-    if (subTask == exportTask && !subTask->hasErrors()) {
+    if (subTask == exportTask && !subTask->hasError()) {
         Document* doc = exportTask->getDocument();
         const GUrl& fullPath = doc->getURL();
+        Project* prj = AppContext::getProject();
+        if (prj) {
+            Document* sameURLdoc = prj->findDocumentByURL(fullPath);
+            if (sameURLdoc) {
+                taskLog.trace(tr("Document is already added to the project %1").arg(doc->getURL().getURLString()));
+                subTasks << new LoadUnloadedDocumentAndOpenViewTask(sameURLdoc);
+                return subTasks;
+            }
+        }
         DocumentFormat* format = doc->getDocumentFormat();
         IOAdapterFactory * iof = doc->getIOAdapterFactory();
         Document* clonedDoc = new Document(format, iof, fullPath);
         clonedDoc->loadFrom(doc); // doc was loaded in a separate thread -> clone all GObjects
         assert(!clonedDoc->isTreeItemModified());
         assert(clonedDoc->isLoaded());
-        subTasks.append(new AddDocumentTask(clonedDoc));
-        subTasks.append(new LoadUnloadedDocumentAndOpenViewTask(clonedDoc));           
+        if (!clonedDoc->isStateLocked()) {
+            clonedDoc->setModified(doc->isModified());
+        }
+        subTasks << new AddDocumentTask(clonedDoc);
+        subTasks << new LoadUnloadedDocumentAndOpenViewTask(clonedDoc);
     }
     //TODO: provide a report if subtask fails
     return subTasks;
@@ -116,7 +140,7 @@ void ExportMSA2SequencesTask::run() {
 ExportMSA2MSATask::ExportMSA2MSATask(const MAlignment& _ma, int _offset, int _len, const QString& _url,
     const QList<DNATranslation*>& _aminoTranslations, DocumentFormatId _format) 
 : AbstractExportTask(tr("Export alignment to alignment: %1").arg(_url), TaskFlag_None), 
-ma(_ma), offset(_offset), len(_len), url(_url), aminoTranslations(_aminoTranslations), format(_format)
+ma(_ma), offset(_offset), len(_len), url(_url), format(_format), aminoTranslations(_aminoTranslations)
 {
     GCOUNTER( cvar, tvar, "ExportMSA2MSATask" );
     setVerboseLogMode(true);
@@ -154,10 +178,8 @@ void ExportMSA2MSATask::run() {
             res << new DNASequenceObject(name, s);
         }                
     }
-    QString err;
-    MAlignment ma = MSAUtils::seq2ma(res, err);
-    if (!err.isEmpty()) {
-        stateInfo.setError(err);
+    MAlignment ma = MSAUtils::seq2ma(res, stateInfo);
+    if (hasError()) {
         return;
     }
     doc->addObject(new MAlignmentObject(ma));
@@ -245,7 +267,7 @@ void ExportDNAChromatogramTask::prepare()
     }
     
     SCFFormat::exportDocumentToSCF(settings.url, cd, dna, stateInfo);
-    if (stateInfo.hasErrors()) {
+    if (stateInfo.hasError()) {
         return;
     }
 
