@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ImportAnnotationsFromCSVDialog.h"
 #include "ImportAnnotationsFromCSVTask.h"
@@ -45,7 +56,7 @@ namespace U2 {
 #define SKIP_LINES_PREFIX    QString("skip_lines_prefix")
 
 ImportAnnotationsFromCSVDialog::ImportAnnotationsFromCSVDialog(QWidget* w) 
-: QDialog(w)
+: QDialog (w)
 {
     setupUi(this);
     connect(readFileButton, SIGNAL(clicked()), SLOT(sl_readFileClicked()));
@@ -134,6 +145,7 @@ void ImportAnnotationsFromCSVDialog::accept() {
             case ColumnRole_Name: names++; break;
             case ColumnRole_Ignore: break;
             case ColumnRole_Qualifier: break;
+            default:;
         }
     }
     if (endPos + startPos + length != 2  || endPos > 1 || startPos > 1 || length > 1) {
@@ -306,9 +318,9 @@ void ImportAnnotationsFromCSVDialog::sl_prefixToSkipChanged(const QString& v) {
 
 void ImportAnnotationsFromCSVDialog::sl_readFileClicked() {
     // show the dialog
-    LastOpenDirHelper lod;
-    
-    lod.url = QFileDialog::getOpenFileName(this, tr("Select CSV file to read"), lod);
+    LastOpenDirHelper lod("CSV");
+    QString filter = DialogUtils::prepareFileFilter(tr("CSV Files"), QStringList() << "csv", true, QStringList());
+    lod.url = QFileDialog::getOpenFileName(this, tr("Select CSV file to read"), lod, filter);
     if (lod.url.isEmpty()) {
         return;
     }
@@ -398,7 +410,7 @@ void ImportAnnotationsFromCSVDialog::preview(bool silent) {
     }
     CSVParsingConfig parseOptions;
     toParsingConfig(parseOptions);
-    if (parseOptions.splitToken.isEmpty() || !parseOptions.parsingScript.isEmpty()) {
+    if (parseOptions.splitToken.isEmpty() && parseOptions.parsingScript.isEmpty()) {
         return;
     }
     
@@ -406,7 +418,7 @@ void ImportAnnotationsFromCSVDialog::preview(bool silent) {
     int columnCount = 0;
     TaskStateInfo ti;
     QList<QStringList> lines = ReadCSVAsAnnotationsTask::parseLinesIntoTokens(text, parseOptions, columnCount, ti);
-    if (ti.hasErrors()) {
+    if (ti.hasError()) {
         QMessageBox::critical(this, L10N::errorTitle(), ti.getError());
         return;
     }
