@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ImportAnnotationsFromCSVTask.h" 
 
@@ -64,7 +75,7 @@ static void adjustRelations(AnnotationTableObject* ao) {
     foreach(DNASequenceObject *seqObj, seqView->getSequenceObjectsWithContexts()){
         bool outOfRange = false;
         foreach(const Annotation* ann, ao->getAnnotations()) {
-            QList<LRegion> locations = ann->getLocation();
+            const QVector<U2Region>& locations = ann->getRegions();
             if(locations.last().endPos() > seqObj->getSequenceLen()) {
                 outOfRange = true;
                 break;
@@ -83,7 +94,7 @@ static void adjustRelations(AnnotationTableObject* ao) {
 
 QList<Task*> ImportAnnotationsFromCSVTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> result;
-    if (hasErrors() || subTask == addTask) {
+    if (hasError() || subTask == addTask) {
         return result;
     }
 
@@ -211,7 +222,7 @@ void ReadCSVAsAnnotationsTask::run() {
             switch(columnConf.role) {
                 case ColumnRole_Qualifier: 
                     assert(!columnConf.qualifierName.isEmpty());
-                    a->qualifiers.append(Qualifier(columnConf.qualifierName, token));
+                    a->qualifiers.append(U2Qualifier(columnConf.qualifierName, token));
                     break;
                 case ColumnRole_Name:
                     a->name = token.isEmpty() ? config.defaultAnnotationName : token;
@@ -243,7 +254,7 @@ void ReadCSVAsAnnotationsTask::run() {
                     }
                     break;
                 case ColumnRole_ComplMark:
-                    a->complement = columnConf.complementMark.isEmpty() || token == columnConf.complementMark;
+                    a->location->strand = (columnConf.complementMark.isEmpty() || token == columnConf.complementMark) ? U2Strand::Complementary : U2Strand::Direct;
                     break;
                 default:
                     assert(columnConf.role == ColumnRole_Ignore);
@@ -257,27 +268,27 @@ void ReadCSVAsAnnotationsTask::run() {
                 a->name = config.defaultAnnotationName;
             }
             //set up location
-            LRegion location;
+            U2Region location;
             if (startPos != -1) {
                 location.startPos = startPos + startPosOffset;
                 if (endPos != -1) {
-                    location.len = endPos - startPos;
+                    location.length = endPos - startPos;
                 } else {
-                    location.len = len;
+                    location.length = len;
                 }
             } else {
-                location.len = len;
+                location.length = len;
                 location.startPos = endPos - len;
             }
-            if (location.len < 0) {
-                location.startPos = location.startPos + location.len;
-                location.len = - location.len;
+            if (location.length < 0) {
+                location.startPos = location.startPos + location.length;
+                location.length = - location.length;
             }
             if (location.startPos < 0 || location.startPos > location.endPos()) {
                 algoLog.details(tr("Invalid location: start: %1  len: %2, in line :%3, ignoring")
-                    .arg(QString::number(location.startPos)).arg(QString::number(location.len)).arg(lineTokens.join(config.splitToken)));
+                    .arg(QString::number(location.startPos)).arg(QString::number(location.length)).arg(lineTokens.join(config.splitToken)));
             } else {
-                a->location.append(location);
+                a->location->regions.append(location);
                 result.append(a);
             }
         } else {
@@ -348,7 +359,7 @@ QStringList ReadCSVAsAnnotationsTask::parseLineIntoTokens(const QString& line, c
     vars[LINE_VAR] = QScriptValue(&engine, line);
     vars[LINE_NUM_VAR] = QScriptValue(&engine, lineNum);
     QScriptValue scriptResult = ScriptTask::runScript(&engine, vars, config.parsingScript, ti);
-    if (ti.cancelFlag || ti.hasErrors()) {
+    if (ti.cancelFlag || ti.hasError()) {
         return result;
     }
     if (scriptResult.isString()) {
@@ -357,8 +368,11 @@ QStringList ReadCSVAsAnnotationsTask::parseLineIntoTokens(const QString& line, c
         QScriptValueIterator it(scriptResult);
         while (it.hasNext()) {
             it.next();
+            if (it.flags() & QScriptValue::SkipInEnumeration)
+                continue;
             QScriptValue val = it.value();
-            result.append(val.toString());
+            QString strVal = val.toString();
+            result.append(strVal);
         }
     } else {
         ti.setError(tr("Script result is not an array of strings!"));
