@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QFile>
 #include <QtCore/QTextStream>
@@ -25,7 +36,6 @@
 
 namespace U2 {
 
-static Logger log(ULOG_IMPORT_QUALITY_SCORES);
 
 ReadQualityScoresTask::ReadQualityScoresTask( const QString& file, DNAQualityType t)
 : Task("ReadPhredQuality", TaskFlag_None), fileName(file), type(t)
@@ -95,7 +105,7 @@ void ReadQualityScoresTask::recordQuality( int headerCounter )
             qualCodes.append(code);
         }
         result.insert(headers[headerCounter], DNAQuality(qualCodes,type));
-        log.trace( QString("Phred quality parsed: %1 %2").arg(headers[headerCounter]).arg(qualCodes.constData()) );
+        //log.trace( QString("Phred quality parsed: %1 %2").arg(headers[headerCounter]).arg(qualCodes.constData()) );
     }
 }
 
@@ -118,7 +128,7 @@ void ImportPhredQualityScoresTask::prepare()
 QList<Task*> ImportPhredQualityScoresTask::onSubTaskFinished( Task* subTask )
 {
     QList<Task*> subTasks;
-    if ( subTask->hasErrors() || subTask->isCanceled() ) {
+    if ( subTask->hasError() || subTask->isCanceled() ) {
         return subTasks;
     }
 
