@@ -2,7 +2,7 @@
 <!DOCTYPE TS>
 <TS version="2.0" language="en_US">
 <context>
-    <name>GB2::BaseContentGraphFactory</name>
+    <name>U2::BaseContentGraphFactory</name>
     <message>
         <location filename="../src/BaseContentGraph.cpp" line="15"/>
         <source>ag_content_graph</source>
@@ -15,7 +15,7 @@
     </message>
 </context>
 <context>
-    <name>GB2::CumulativeSkewGraphFactory</name>
+    <name>U2::CumulativeSkewGraphFactory</name>
     <message>
         <location filename="../src/CumulativeSkew.cpp" line="18"/>
         <source>at_cumulative_skew_not_optimal_version</source>
@@ -28,7 +28,7 @@
     </message>
 </context>
 <context>
-    <name>GB2::DNAGraphPackPlugin</name>
+    <name>U2::DNAGraphPackPlugin</name>
     <message>
         <location filename="../src/DNAGraphPackPlugin.cpp" line="28"/>
         <source>dna_graphpack_plugin</source>
@@ -41,7 +41,7 @@
     </message>
 </context>
 <context>
-    <name>GB2::DeviationGraphFactory</name>
+    <name>U2::DeviationGraphFactory</name>
     <message>
         <location filename="../src/DeviationGraph.cpp" line="14"/>
         <source>at_deviation_graph</source>
@@ -54,7 +54,7 @@
     </message>
 </context>
 <context>
-    <name>GB2::EntropyGraphFactory</name>
+    <name>U2::EntropyGraphFactory</name>
     <message>
         <location filename="../src/EntropyAlgorithm.cpp" line="22"/>
         <source>informational_entropy</source>
@@ -62,7 +62,7 @@
     </message>
 </context>
 <context>
-    <name>GB2::GraphMenuAction</name>
+    <name>U2::GraphMenuAction</name>
     <message>
         <location filename="../src/DNAGraphPackPlugin.cpp" line="114"/>
         <source>graph_menu</source>
@@ -70,7 +70,7 @@
     </message>
 </context>
 <context>
-    <name>GB2::KarlinGraphFactory</name>
+    <name>U2::KarlinGraphFactory</name>
     <message>
         <location filename="../src/KarlinSignatureDifferenceGraph.cpp" line="16"/>
         <source>karlin_signature_difference_graph</source>
