@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "DotPlotClasses.h"
 
@@ -82,7 +93,6 @@ void DotPlotResultsListener::setTask(Task *t) {
     stateOk = true;
 }
 
-
 // add new found results to the list
 void DotPlotResultsListener::onResult(const RFResult& r) {
     QMutexLocker locker(&mutex);
@@ -123,9 +133,28 @@ void DotPlotResultsListener::onResults(const QVector<RFResult>& v) {
         DotPlotResults vec(r.x, r.y, r.l);
         dotPlotList->push_back(vec);
     }
+}
+
+// add new found results to the list
+void DotPlotRevComplResultsListener::onResult(const RFResult& r) {
+    RFResult res(xLen - r.x - r.l, r.y , r.l);
+    assert(res.x >= 0 && res.x < xLen);
+    DotPlotResultsListener::onResult(res);
 
 }
 
+void DotPlotRevComplResultsListener::onResults(const QVector<RFResult>& v) {
+    QVector<RFResult> results;
+    results.reserve(v.size());
+    foreach(const RFResult& r, v) {
+        RFResult res(xLen - r.x - r.l, r.y, r.l);
+        assert(res.x >= 0 && res.x < xLen);
+        results << res;
+    }
+    DotPlotResultsListener::onResults(results);
+}
+
+
 // dialogs and error messages
 void DotPlotDialogs::taskRunning() {
 
