@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "DotPlotPlugin.h"
 #include "DotPlotSplitter.h"
@@ -20,6 +31,9 @@
 
 #include <U2Core/AppContext.h>
 #include <U2Core/ProjectModel.h>
+#include <U2Core/U2SafePoints.h>
+#include <U2Core/GObjectUtils.h>
+#include <U2Core/DNASequenceObject.h>
 
 #include <U2Core/GObjectSelection.h>
 #include <U2Algorithm/RepeatFinderTaskFactoryRegistry.h>
@@ -50,12 +64,9 @@ DotPlotPlugin::DotPlotPlugin() : Plugin(tr("Dotplot"), tr("Build dotplot for seq
 void DotPlotPlugin::sl_initDotPlotView() {
     if (AppContext::getMainWindow()) {
         RepeatFinderTaskFactoryRegistry *fr = AppContext::getRepeatFinderTaskFactoryRegistry();
-        Q_ASSERT(fr);
-
         RepeatFinderTaskFactory *factory = fr->getFactory("");
         if (factory) {
             viewCtx = new DotPlotViewContext(this);
-            Q_ASSERT(viewCtx);
             viewCtx->init();
         }
     }
@@ -67,7 +78,7 @@ DotPlotViewContext::DotPlotViewContext(QObject* p)
     // add dotplot item to the tools menu
     QAction* showDlgAction = new QAction( QIcon(":dotplot/images/dotplot.png"), tr("Build dotplot..."), this );
     connect( showDlgAction, SIGNAL( triggered() ), SLOT( sl_showDotPlotDialog() ) );
-    AppContext::getMainWindow()->getMenuManager()->getTopLevelMenu( MWMENU_TOOLS )->addAction( showDlgAction );
+    AppContext::getMainWindow()->getTopLevelMenu( MWMENU_TOOLS )->addAction( showDlgAction );
 
     // need to know it build dotplot wizard finished work
     connect( AppContext::getTaskScheduler(), SIGNAL( si_stateChanged(Task*) ), SLOT( sl_loadTaskStateChanged(Task*) ) );
@@ -81,11 +92,15 @@ void DotPlotViewContext::sl_loadTaskStateChanged(Task* task) {
         return;
     }
 
-    if (loadTask->getStateInfo().hasErrors()) {
+    if (loadTask->getStateInfo().hasError()) {
         DotPlotDialogs::filesOpenError();
         return;
     }
 
+    if(loadTask->isNoView()){
+        return;
+    }
+
     // prepare document objects to open view with
     GObjectSelection os;
 
@@ -103,6 +118,8 @@ void DotPlotViewContext::sl_loadTaskStateChanged(Task* task) {
     if (canCreate) {
         AppContext::getTaskScheduler()->registerTopLevelTask(f->createViewTask(ms, false));
         createdByWizard = true; // set flag that we need to show a dotplot settings dialog
+        firstFile = loadTask->getFirstFile();
+        secondFile = loadTask->getSecondFile();
     }
 }
 
@@ -114,8 +131,7 @@ void DotPlotViewContext::sl_showDotPlotDialog() {
     DotPlotFilesDialog d(QApplication::activeWindow());
     if (d.exec()) {
         if (!AppContext::getProject()) {
-            QList<GUrl> emptyList;
-            tasks->addSubTask( AppContext::getProjectLoader()->openProjectTask(emptyList, false) );
+            tasks->addSubTask( AppContext::getProjectLoader()->createNewProjectTask() );
         }
 
         DotPlotLoadDocumentsTask *t = new DotPlotLoadDocumentsTask(d.getFirstFileName(), d.getFirstGap(), d.getSecondFileName(), d.getSecondGap());
@@ -125,6 +141,20 @@ void DotPlotViewContext::sl_showDotPlotDialog() {
     AppContext::getTaskScheduler()->registerTopLevelTask(tasks);
 }
 
+static DNASequenceObject * getSequenceByFile(QString file) {
+    Project *project = AppContext::getProject();
+    SAFE_POINT(project != NULL, "No project loaded", NULL);
+
+    Document *doc = project->findDocumentByURL(GUrl(file));
+    CHECK(doc != NULL, NULL);
+
+    QList<GObject*> sequences = GObjectUtils::select(doc->getObjects(), GObjectTypes::SEQUENCE, UOF_LoadedOnly);
+    if(! sequences.isEmpty()) {
+        return qobject_cast<DNASequenceObject*>(sequences.first());
+    }
+    return NULL;
+}
+
 // called from the context menu
 void DotPlotViewContext::sl_buildDotPlot() {
 
@@ -140,9 +170,10 @@ void DotPlotViewContext::sl_buildDotPlot() {
     }
 
     DotPlotWidget *dotPlot = new DotPlotWidget(dnaView);
+    dotPlot->setSequences(getSequenceByFile(firstFile), getSequenceByFile(secondFile));
 
     // show settings dialog
-    if (dotPlot && (dotPlot->sl_showSettingsDialog())) {
+    if (dotPlot && (dotPlot->sl_showSettingsDialog(createdByWizard))) {
         DotPlotSplitter* splitter = getView(dnaView, true); // create new splitter
         Q_ASSERT(splitter);
         splitter->addView(dotPlot);
@@ -153,6 +184,7 @@ void DotPlotViewContext::sl_buildDotPlot() {
         delete dotPlot; // user clicked cancel button
         dotPlot = NULL;
     }
+    createdByWizard = false;
 }
 
 // DotPlotWidget said we should remove it from the splitter
@@ -197,7 +229,7 @@ void DotPlotViewContext::initViewContext(GObjectView* v) {
 
     // this view context is created by dotplot wizard
     if (createdByWizard) {
-        createdByWizard = false;
+//        createdByWizard = false;
 
         QWidget* widget = av->getWidget()->parentWidget();
         Q_ASSERT(widget != NULL);
