@@ -1,16 +1,31 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "DotPlotSplitter.h"
 #include "DotPlotWidget.h"
 
+#include <QtCore/QString>
+#include <QtCore/QPair>
+#include <QtCore/QSet>
+
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QAction>
 #include <QtGui/QMenu>
@@ -154,9 +169,11 @@ void DotPlotSplitter::removeView(DotPlotWidget* view) {
     checkLockButtonState();
 }
 
+typedef QPair<QString,QString> QStringPair;
+
 void DotPlotSplitter::checkLockButtonState() {
 
-    QSet< QPair<QString, QString> > dotPlots;
+    QSet<QStringPair> dotPlots;
 
     bool enableLockButton = false;
 
@@ -168,7 +185,7 @@ void DotPlotSplitter::checkLockButtonState() {
 
         if (!nameX.isEmpty() && !nameY.isEmpty()) {
 
-            QPair<QString, QString> p;
+            QStringPair p;
             p.first = nameX;
             p.second = nameY;
 
