@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "DotPlotTasks.h"
 
@@ -214,8 +225,8 @@ bool LoadDotPlotTask::loadDotPlot(QTextStream &stream, int fileSize) {
 }
 
 
-DotPlotLoadDocumentsTask::DotPlotLoadDocumentsTask(QString firstF, int firstG, QString secondF, int secondG)
-: Task(tr("DotPlot loading"), TaskFlags(TaskFlag_NoRun | TaskFlag_FailOnSubtaskCancel))
+DotPlotLoadDocumentsTask::DotPlotLoadDocumentsTask(QString firstF, int firstG, QString secondF, int secondG, bool view)
+: Task(tr("DotPlot loading"), TaskFlags(TaskFlag_NoRun | TaskFlag_FailOnSubtaskCancel)), noView(!view)
 {
     firstFile = firstF;
     firstGap = firstG;
@@ -232,7 +243,7 @@ void DotPlotLoadDocumentsTask::prepare() {
         docs << doc;
     }
 
-    if (hasErrors()) {
+    if (hasError()) {
         return;
     }
     doc = loadFile(secondFile, secondGap);
@@ -243,6 +254,9 @@ void DotPlotLoadDocumentsTask::prepare() {
 
 Document *DotPlotLoadDocumentsTask::loadFile(QString inFile, int gapSize) {
 
+    if(inFile == ""){
+        return NULL;
+    }
     GUrl URL(inFile);
 
     Project *project = AppContext::getProject();
@@ -255,23 +269,24 @@ Document *DotPlotLoadDocumentsTask::loadFile(QString inFile, int gapSize) {
         return doc;
     }
 
-    QList<DocumentFormat*> formats = DocumentUtils::detectFormat(inFile);
+    QList<FormatDetectionResult> formats = DocumentUtils::detectFormat(inFile);
     if (formats.isEmpty()) {
         stateInfo.setError(tr("Detecting format error for file %1").arg(inFile));
         return NULL;
     }
 
-    DocumentFormat* format = formats.first();
+    DocumentFormat* format = formats.first().format;
     Q_ASSERT(format);
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(URL));
 
     QVariantMap formatSettings;
     if (gapSize >= 0) {
-        QString mergeToken = MERGE_MULTI_DOC_GAP_SIZE_SETTINGS;
+        QString mergeToken = DocumentReadingMode_SequenceMergeGapSize;
         formatSettings[mergeToken] = gapSize;
     }
 
     doc = new Document(format, iof, URL, QList<UnloadedObjectInfo>(), formatSettings);
+    doc->setUserModLock(false);
 
     addSubTask(new AddDocumentTask(doc)); // add document to the project
     addSubTask(new LoadUnloadedDocumentTask(doc)); // load document
@@ -282,7 +297,7 @@ Document *DotPlotLoadDocumentsTask::loadFile(QString inFile, int gapSize) {
 DotPlotLoadDocumentsTask::~DotPlotLoadDocumentsTask() {
 
     // error while loading documents
-    if (hasErrors()) {
+    if (hasError()) {
         Project *project = AppContext::getProject();
 
         // skip added to the project documents
