@@ -1,35 +1,49 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "DotPlotWidget.h"
 #include "DotPlotDialog.h"
 #include "DotPlotTasks.h"
 
-#include <U2Algorithm/RepeatFinderTaskFactory.h>
+#include <U2Core/MultiTask.h>
 #include <U2Core/AppContext.h>
-#include <U2Misc/GraphUtils.h>
-#include <U2Misc/DialogUtils.h>
-
 #include <U2Core/AnnotationTableObject.h>
 #include <U2Core/DNASequenceSelection.h>
-#include <U2View/AnnotatedDNAView.h>
-#include <U2View/ADVSequenceObjectContext.h>
-#include <U2View/ADVSingleSequenceWidget.h>
+#include <U2Core/U2SafePoints.h>
+#include <U2Core/DNATranslation.h>
+#include <U2Core/TextUtils.h>
 
 #include <U2Algorithm/RepeatFinderTaskFactoryRegistry.h>
 #include <U2Algorithm/RepeatFinderSettings.h>
 #include <U2Algorithm/RepeatFinderTaskFactory.h>
 
-#include <U2Core/MultiTask.h>
+#include <U2Gui/ExportImageDialog.h>
+
+#include <U2View/AnnotatedDNAView.h>
+#include <U2View/ADVSequenceObjectContext.h>
+#include <U2View/ADVSingleSequenceWidget.h>
 #include <U2View/PanView.h>
 
+#include <U2Misc/GraphUtils.h>
+#include <U2Misc/DialogUtils.h>
 
 #include <QtGui/QMouseEvent>
 #include <QtGui/QFileDialog>
@@ -47,18 +61,18 @@ DotPlotWidget::DotPlotWidget(AnnotatedDNAView* dnaView)
     minLen(100), identity(100),
     pixMapUpdateNeeded(true), deleteDotPlotFlag(false), dotPlotTask(NULL), pixMap(NULL), miniMap(NULL),
     nearestRepeat(NULL),
-    sharedSeqX(NULL), sharedSeqY(NULL)
+    sharedSeqX(NULL), sharedSeqY(NULL),
+    clearedByRepitSel(false)
 {
-    dotPlotDirectResultsListener = new DotPlotResultsListener();
-    dotPlotInverseResultsListener = new DotPlotResultsListener();
+    dpDirectResultListener = new DotPlotResultsListener();
+    dpRevComplResultsListener = new DotPlotRevComplResultsListener();
 
     QFontMetrics fm = QPainter(this).fontMetrics();
     int minTextSpace = fm.width(" 00000 ");
 
     if (defaultTextSpace < minTextSpace) {
         textSpace = minTextSpace;
-    }
-    else {
+    } else {
         textSpace = defaultTextSpace;
     }
 
@@ -87,7 +101,7 @@ DotPlotWidget::DotPlotWidget(AnnotatedDNAView* dnaView)
     exitButton->setIcon(exitIcon);
 
     exitButton->setAutoFillBackground(true);
-
+    exitButton->setAutoRaise(true);
 }
 
 // init menu items, actions and connect signals
@@ -135,8 +149,8 @@ void DotPlotWidget::connectSequenceSelectionSignals() {
         Q_ASSERT(ctx);
 
         connect(ctx->getSequenceSelection(),
-            SIGNAL(si_selectionChanged(LRegionsSelection*, const QList<LRegion>&, const QList<LRegion>&)),
-            SLOT(sl_onSequenceSelectionChanged(LRegionsSelection*, const QList<LRegion>& , const QList<LRegion>&)));
+            SIGNAL(si_selectionChanged(LRegionsSelection*, const QVector<U2Region>&, const QVector<U2Region>&)),
+            SLOT(sl_onSequenceSelectionChanged(LRegionsSelection*, const QVector<U2Region>& , const QVector<U2Region>&)));
     }
 }
 
@@ -153,8 +167,8 @@ DotPlotWidget::~DotPlotWidget() {
     if (dotPlotTask) {
         cancelRepeatFinderTask();
     }
-    delete dotPlotDirectResultsListener;
-    delete dotPlotInverseResultsListener;
+    delete dpDirectResultListener;
+    delete dpRevComplResultsListener;
 }
 
 
@@ -183,16 +197,18 @@ void DotPlotWidget::buildPopupMenu(QMenu *m) const {
     }
 }
 
-QPointF DotPlotWidget::zoomTo(Qt::Axis axis, const LRegion &lr, bool emitSignal) {
+QPointF DotPlotWidget::zoomTo(Qt::Axis axis, const U2Region &lr, bool emitSignal) {
 
-    QPointF oldZoom = zoom;
+    if(lr.length == 0){
+        return zoom;
+    }
 
     int seqLen = 0;
     switch (axis) {
         case Qt::XAxis :
             seqLen = sequenceX->getSequenceLen();
 
-            zoom.setX(seqLen/(float)lr.len);
+            zoom.setX(seqLen/(float)lr.length);
             shiftX = -lr.startPos*w/(float)seqLen;
             shiftX*=zoom.x();
             break;
@@ -200,7 +216,7 @@ QPointF DotPlotWidget::zoomTo(Qt::Axis axis, const LRegion &lr, bool emitSignal)
         case Qt::YAxis :
             seqLen = sequenceY->getSequenceLen();
 
-            zoom.setY(seqLen/(float)lr.len);
+            zoom.setY(seqLen/(float)lr.length);
             shiftY = -lr.startPos*h/(float)seqLen;
             shiftY*=zoom.y();
             break;
@@ -216,7 +232,7 @@ QPointF DotPlotWidget::zoomTo(Qt::Axis axis, const LRegion &lr, bool emitSignal)
     return zoom;
 }
 
-LRegion DotPlotWidget::getVisibleRange(Qt::Axis axis) {
+U2Region DotPlotWidget::getVisibleRange(Qt::Axis axis) {
 
     QPointF zeroPoint(0, 0);
     QPointF rightPoint(w, 0);
@@ -237,17 +253,17 @@ LRegion DotPlotWidget::getVisibleRange(Qt::Axis axis) {
             break;
 
         default:
-            return LRegion();
+            return U2Region();
     }
 
     len-=startPos;
 
-    return LRegion(startPos, len);
+    return U2Region(startPos, len);
 }
 
-int DotPlotWidget::getLrDifference(const LRegion &a, const LRegion &b) {
+int DotPlotWidget::getLrDifference(const U2Region &a, const U2Region &b) {
 
-    return qAbs(a.startPos - b.startPos) + qAbs(a.len - b.len);
+    return qAbs(a.startPos - b.startPos) + qAbs(a.length - b.length);
 }
 
 void DotPlotWidget::sl_panViewChanged() {
@@ -259,20 +275,20 @@ void DotPlotWidget::sl_panViewChanged() {
         return;
     }
 
-    LRegion lr = panView->getVisibleRange();
+    U2Region lr = panView->getVisibleRange();
     ADVSequenceObjectContext* ctx = lw->getSequenceContext();
 
     if (!ctx || ignorePanView) {
         return;
     }
 
-    LRegion xAxisVisibleRange = getVisibleRange(Qt::XAxis);
+    U2Region xAxisVisibleRange = getVisibleRange(Qt::XAxis);
     if ((ctx == sequenceX) && (lr != xAxisVisibleRange)) {
         zoomTo(Qt::XAxis, lr);
     }
 
     if (!shifting) {
-        LRegion yAxisVisibleRange = getVisibleRange(Qt::YAxis);
+        U2Region yAxisVisibleRange = getVisibleRange(Qt::YAxis);
         if ((ctx == sequenceY) && (lr != yAxisVisibleRange)) {
             if(sequenceX == sequenceY){
                 zoomTo(Qt::XAxis, lr, sequenceX != sequenceY);
@@ -290,6 +306,10 @@ void DotPlotWidget::sl_timer(){
         const DotPlotResults *res = findNearestRepeat(pos);
         if(res == nearestRepeat){
             QString text = makeToolTipText();
+            QFont dFont, f("Monospace");
+            f.setPointSize(dFont.pointSize());
+            f.setStyleHint(QFont::Courier);
+            QToolTip::setFont(f);
             QToolTip::showText(QCursor::pos(), text);
         }
     }
@@ -303,12 +323,12 @@ void DotPlotWidget::sl_taskFinished(Task *task) {
         return;
     }
 
-    if (!dotPlotDirectResultsListener->stateOk || !dotPlotInverseResultsListener->stateOk) {
+    if (!dpDirectResultListener->stateOk || !dpRevComplResultsListener->stateOk) {
         DotPlotDialogs::tooManyResults();
     }
     dotPlotTask = NULL;
-    dotPlotDirectResultsListener->setTask(NULL);
-    dotPlotInverseResultsListener->setTask(NULL);
+    dpDirectResultListener->setTask(NULL);
+    dpRevComplResultsListener->setTask(NULL);
 
     if (deleteDotPlotFlag) {
         deleteDotPlotFlag = false;
@@ -326,15 +346,13 @@ void DotPlotWidget::sl_taskFinished(Task *task) {
 void DotPlotWidget::cancelRepeatFinderTask() {
 
     RepeatFinderTaskFactoryRegistry *tfr = AppContext::getRepeatFinderTaskFactoryRegistry();
-    Q_ASSERT(tfr);
     RepeatFinderTaskFactory *factory = tfr->getFactory("");
-    Q_ASSERT(factory);
+    SAFE_POINT(factory != NULL, "Repeats factory is NULL!", );
     factory->setRFResultsListener(dotPlotTask, NULL);
 
     MultiTask *mTask = qobject_cast<MultiTask*>(dotPlotTask);
     if (mTask) {
         foreach(Task *t, mTask->getSubtasks()) {
-
             if (!t->isFinished()) {
                 t->cancel();
             }
@@ -350,6 +368,10 @@ bool DotPlotWidget::event(QEvent *event){
         const DotPlotResults *res = findNearestRepeat(pos);
         if(res == nearestRepeat){
             QString text = makeToolTipText();
+            QFont dFont, f("Monospace");
+            f.setPointSize(dFont.pointSize());
+            f.setStyleHint(QFont::Courier);
+            QToolTip::setFont(f);
             QToolTip::showText(helpEvent->globalPos(), text);
         }
     }
@@ -383,21 +405,27 @@ void DotPlotWidget::sl_sequenceWidgetRemoved(ADVSequenceWidget* w) {
 
 
 // click on the sequence view
-void DotPlotWidget::sl_onSequenceSelectionChanged(LRegionsSelection* s, const QList<LRegion>&, const QList<LRegion>&) {
+void DotPlotWidget::sl_onSequenceSelectionChanged(LRegionsSelection* s, const QVector<U2Region>&, const QVector<U2Region>&) {
 
     QObject *sen = sender();
 
     DNASequenceSelection *dnaSelection = qobject_cast<DNASequenceSelection*>(sen);
     if (dnaSelection) {
+       
         const DNASequenceObject *selectedSequence = dnaSelection->getSequenceObject();
-                if (selectedSequence == sequenceX->getSequenceGObject()) {
+            if (selectedSequence == sequenceX->getSequenceGObject()) {
+                if(!nearestSelecting)
+                    clearedByRepitSel = false;
                 selectionX = s;
             }
 
             if (selectedSequence == sequenceY->getSequenceObject()) {
+                if(!nearestSelecting)
+                    clearedByRepitSel = false;
                 selectionY = s;
             }
 
+
         update();
     }
     emit si_dotPlotSelecting();
@@ -405,19 +433,12 @@ void DotPlotWidget::sl_onSequenceSelectionChanged(LRegionsSelection* s, const QL
 
 // save dotplot as image
 void DotPlotWidget::sl_showSaveImageDialog() {
+    exitButton->hide();
 
-    LastOpenDirHelper lod("Dotplot");
-    lod.url = QFileDialog::getSaveFileName(NULL, tr("Save Dotplot image"), lod.dir, tr("Image Files (*.png *.jpg *.bmp)"));
+    ExportImageDialog dialog(this, this->rect());
+    dialog.exec();
 
-    if (lod.url.length() <= 0) {
-        return; // Cancel button pressed
-    }
-
-    QImage image(width(), height(), QImage::Format_RGB32);
-    QPainter p(&image);
-
-    drawAll(p);
-    image.save(lod.url);
+    exitButton->show();
 }
 
 // save dotplot into a dotplot file, return true if successful
@@ -448,14 +469,14 @@ bool DotPlotWidget::sl_showSaveFileDialog() {
 
         return false;
     }
-    Q_ASSERT(dotPlotDirectResultsListener);
+    Q_ASSERT(dpDirectResultListener);
     Q_ASSERT(sequenceX);
     Q_ASSERT(sequenceY);
 
     dotPlotTask = new SaveDotPlotTask(
             lod.url,
-            dotPlotDirectResultsListener->dotPlotList,
-            dotPlotInverseResultsListener->dotPlotList,
+            dpDirectResultListener->dotPlotList,
+            dpRevComplResultsListener->dotPlotList,
             sequenceX->getSequenceObject(),
             sequenceY->getSequenceObject(),
             minLen,
@@ -512,16 +533,16 @@ bool DotPlotWidget::sl_showLoadFileDialog() {
             break;
     }
 
-    Q_ASSERT(dotPlotDirectResultsListener);
-    Q_ASSERT(dotPlotDirectResultsListener->dotPlotList);
+    Q_ASSERT(dpDirectResultListener);
+    Q_ASSERT(dpDirectResultListener->dotPlotList);
 
-    Q_ASSERT(dotPlotInverseResultsListener);
-    Q_ASSERT(dotPlotInverseResultsListener->dotPlotList);
+    Q_ASSERT(dpRevComplResultsListener);
+    Q_ASSERT(dpRevComplResultsListener->dotPlotList);
 
     dotPlotTask = new LoadDotPlotTask(
             lod.url,
-            dotPlotDirectResultsListener->dotPlotList,
-            dotPlotInverseResultsListener->dotPlotList,
+            dpDirectResultListener->dotPlotList,
+            dpRevComplResultsListener->dotPlotList,
             sequenceX->getSequenceObject(),
             sequenceY->getSequenceObject(),
             &minLen,
@@ -540,7 +561,7 @@ bool DotPlotWidget::sl_showLoadFileDialog() {
 }
 
 // creating new dotplot or changing settings
-bool DotPlotWidget::sl_showSettingsDialog() {
+bool DotPlotWidget::sl_showSettingsDialog(bool disableLoad) {
 
     if (dotPlotTask) { // Check if there is already some dotPlotTask
         DotPlotDialogs::taskRunning();
@@ -549,13 +570,8 @@ bool DotPlotWidget::sl_showSettingsDialog() {
     }
 
     Q_ASSERT(dnaView);
-    QList<ADVSequenceObjectContext *> sequences = dnaView->getSequenceContexts();
 
-    if (sequences.size() <= 0) {
-        return false;
-    }
-
-    DotPlotDialog d(this, sequences, minLen, identity, sequenceX, sequenceY, direct, inverted, dotPlotDirectColor, dotPlotInvertedColor);
+    DotPlotDialog d(this, dnaView, minLen, identity, sequenceX, sequenceY, direct, inverted, dotPlotDirectColor, dotPlotInvertedColor, disableLoad);
     if (d.exec()) {
         setMinimumHeight(200);
 
@@ -590,13 +606,13 @@ bool DotPlotWidget::sl_showSettingsDialog() {
 
         connectSequenceSelectionSignals();
 
-        Q_ASSERT(dotPlotDirectResultsListener);
-        Q_ASSERT(dotPlotDirectResultsListener->dotPlotList);
-        dotPlotDirectResultsListener->dotPlotList->clear();
+        Q_ASSERT(dpDirectResultListener);
+        Q_ASSERT(dpDirectResultListener->dotPlotList);
+        dpDirectResultListener->dotPlotList->clear();
 
-        Q_ASSERT(dotPlotInverseResultsListener);
-        Q_ASSERT(dotPlotInverseResultsListener->dotPlotList);
-        dotPlotInverseResultsListener->dotPlotList->clear();
+        Q_ASSERT(dpRevComplResultsListener);
+        Q_ASSERT(dpRevComplResultsListener->dotPlotList);
+        dpRevComplResultsListener->dotPlotList->clear();
 
         Q_ASSERT(sequenceX);
         Q_ASSERT(sequenceY);
@@ -613,22 +629,7 @@ bool DotPlotWidget::sl_showSettingsDialog() {
         Q_ASSERT(sequenceX->getSequenceObject());
         Q_ASSERT(sequenceY->getSequenceObject());
 
-
-        foreach (ADVSequenceWidget *advSeqWidget, sequenceX->getSequenceWidgets()) {
-            ADVSingleSequenceWidget *ssw = qobject_cast<ADVSingleSequenceWidget*>(advSeqWidget);
-            if (ssw) {
-                zoomUseX.setPanView(ssw->getPanView());
-                break;
-            }
-        }
-        foreach (ADVSequenceWidget *advSeqWidget, sequenceY->getSequenceWidgets()) {
-            ADVSingleSequenceWidget *ssw = qobject_cast<ADVSingleSequenceWidget*>(advSeqWidget);
-            if (ssw) {
-                zoomUseY.setPanView(ssw->getPanView());
-                break;
-            }
-        }
-
+        
         DNAAlphabet *al = sequenceX->getAlphabet();
         if ((al->getId() == BaseDNAAlphabetIds::NUCL_DNA_DEFAULT()) || (al->getId() == BaseDNAAlphabetIds::NUCL_RNA_DEFAULT())) {
             al = sequenceY->getAlphabet();
@@ -638,15 +639,14 @@ bool DotPlotWidget::sl_showSettingsDialog() {
         sharedSeqY = sequenceY->getSequenceObject()->getSequence();
 
         RepeatFinderTaskFactoryRegistry *tfr = AppContext::getRepeatFinderTaskFactoryRegistry();
-        Q_ASSERT(tfr);
         RepeatFinderTaskFactory *factory = tfr->getFactory("");
-        Q_ASSERT(factory);
+        SAFE_POINT(factory != NULL, "Repeats factory is NULL!", false);
 
         QList<Task*> tasks;
 
         if (d.isDirect()) {
             RepeatFinderSettings cDirect(
-                dotPlotDirectResultsListener,
+                dpDirectResultListener,
                 sequenceX->getSequenceObject()->getSequence().data(),
                 sequenceX->getSequenceLen(),
                 false,                        // direct
@@ -658,18 +658,18 @@ bool DotPlotWidget::sl_showSettingsDialog() {
             );
 
             Task *dotPlotDirectTask = factory->getTaskInstance(cDirect);
-            dotPlotDirectResultsListener->setTask(dotPlotDirectTask);
+            dpDirectResultListener->setTask(dotPlotDirectTask);
 
             tasks << dotPlotDirectTask;
         }
 
         if (d.isInverted()) {
             RepeatFinderSettings cInverse(
-                dotPlotInverseResultsListener,
-                sequenceX->getSequenceObject()->getSequence().data(),
+                dpRevComplResultsListener,
+                sequenceX->getSequenceObject()->getSequence().constData(),
                 sequenceX->getSequenceLen(),
-                true,                        // inversed
-                sequenceY->getSequenceObject()->getSequence().data(),
+                true,                        // inverted
+                sequenceY->getSequenceObject()->getSequence().constData(),
                 sequenceY->getSequenceLen(),
                 al,
                 d.getMinLen(), d.getMismatches(),
@@ -677,7 +677,8 @@ bool DotPlotWidget::sl_showSettingsDialog() {
             );
 
             Task *dotPlotInversedTask = factory->getTaskInstance(cInverse);
-            dotPlotInverseResultsListener->setTask(dotPlotInversedTask);
+            dpRevComplResultsListener->setTask(dotPlotInversedTask);
+            dpRevComplResultsListener->xLen = sequenceX->getSequenceLen();
 
             tasks << dotPlotInversedTask;
         }
@@ -757,13 +758,13 @@ void DotPlotWidget::pixMapUpdate() {
 
     QLine line;
 
-    Q_ASSERT(dotPlotDirectResultsListener);
-    Q_ASSERT(dotPlotDirectResultsListener->dotPlotList);
+    Q_ASSERT(dpDirectResultListener);
+    Q_ASSERT(dpDirectResultListener->dotPlotList);
 
     // draw to the dotplot direct results
     if (direct) {
         pixp.setPen(dotPlotDirectColor);
-        foreach(const DotPlotResults &r, *dotPlotDirectResultsListener->dotPlotList) {
+        foreach(const DotPlotResults &r, *dpDirectResultListener->dotPlotList) {
 
             if (!getLineToDraw(r, &line, ratioX, ratioY)) {
                 continue;
@@ -776,7 +777,7 @@ void DotPlotWidget::pixMapUpdate() {
     // draw to the dotplot inverted results
     if (inverted) {
         pixp.setPen(dotPlotInvertedColor);
-        foreach(const DotPlotResults &r, *dotPlotInverseResultsListener->dotPlotList) {
+        foreach(const DotPlotResults &r, *dpRevComplResultsListener->dotPlotList) {
 
             if (!getLineToDraw(r, &line, ratioX, ratioY, true)) {
                 continue;
@@ -900,15 +901,25 @@ void DotPlotWidget::drawNames(QPainter &p) const {
     QString nameX = sequenceX->getSequenceObject()->getGObjectName();
     QString nameY = sequenceY->getSequenceObject()->getGObjectName();
 
-    nameX += " (" + tr("min length")+" "+QString::number(minLen)+", "+tr("identity")+" "+QString::number(identity)+"%)";
+    const QFontMetrics &fm = this->fontMetrics();
 
-    p.drawText(0, h + textSpace, w+2*textSpace, textSpace, Qt::AlignCenter, nameX);
+    nameX += tr(" (min length %1, identity %2%)").arg(minLen).arg(identity);
+    int nameXWidth = fm.width(nameX);
+
+    // If nameX doesn't fit, it should be aligned left instead of center
+    int flags = (nameXWidth < w) ? Qt::AlignCenter : Qt::AlignVCenter | Qt::AlignLeft;
+    p.drawText(textSpace, h + textSpace, w, textSpace, Qt::AlignCenter, nameX);
 
     p.save();
 
-    p.rotate(90);
-    p.translate(0, -(w + textSpace*2));
-    p.drawText(0, 0, h+textSpace, textSpace, Qt::AlignCenter, nameY);
+        p.rotate(90);
+        p.translate(DP_MARGIN + textSpace, -(w +textSpace*2));
+
+        int nameYWidth = fm.width(nameY);
+
+        // If nameY doesn't fit, it should be aligned left instead of center
+        flags = (nameYWidth < h) ? Qt::AlignCenter : Qt::AlignVCenter | Qt::AlignLeft;
+        p.drawText(0, 0, h, textSpace, flags, nameY);
 
     p.restore();
 }
@@ -926,7 +937,6 @@ void DotPlotWidget::drawNearestRepeat(QPainter& p) const {
 
     QLine line;
     if (getLineToDraw(*nearestRepeat, &line, ratioX, ratioY, nearestInverted)) {
-
         p.drawLine(line);
     }
 
@@ -1044,7 +1054,7 @@ void DotPlotWidget::drawRectCorrect(QPainter &p, QRectF r) const {
 }
 
 // part of the sequence is selected, show it
-void DotPlotWidget::drawSelection(QPainter &p) const {
+void DotPlotWidget::drawSelection(QPainter &p) const{
 
     if (!sequenceX || !sequenceY) {
         return;
@@ -1053,6 +1063,9 @@ void DotPlotWidget::drawSelection(QPainter &p) const {
     if (!(selectionX || selectionY)) {
         return;
     }
+    if(clearedByRepitSel){
+        return;
+    }
 
     p.save();
 
@@ -1072,21 +1085,21 @@ void DotPlotWidget::drawSelection(QPainter &p) const {
 
     // for each selected part on the sequence X, highlight selected part on the sequence Y
     if((selectionX && selectionX->getSelectedRegions().size() > 1)){
-        QListIterator<U2::LRegion> it(selectionX->getSelectedRegions());
-        const LRegion &rx = it.next();
+        const QVector<U2Region>& sel = selectionX->getSelectedRegions();
+        const U2Region &rx = sel[0];
         xLeft = rx.startPos/(float)xSeqLen * w*zoom.x();
-        xLen = rx.len/(float)xSeqLen * w*zoom.x();
-        const LRegion &ry = it.next();
+        xLen = rx.length/(float)xSeqLen * w*zoom.x();
+        const U2Region &ry = sel[1];
         yBottom = ry.startPos/(float)ySeqLen * h*zoom.y();
-        yLen = ry.len/(float)ySeqLen * h*zoom.y();
+        yLen = ry.length/(float)ySeqLen * h*zoom.y();
 
         drawRectCorrect(p, QRectF(xLeft + shiftX, yBottom + shiftY, xLen, yLen));
     }else{
         if (selectionX) {
-            foreach(const LRegion &rx, selectionX->getSelectedRegions()) {
+            foreach(const U2Region &rx, selectionX->getSelectedRegions()) {
 
                 xLeft = rx.startPos/(float)xSeqLen * w*zoom.x();
-                xLen = rx.len/(float)xSeqLen * w*zoom.x();
+                xLen = rx.length/(float)xSeqLen * w*zoom.x();
 
                 if (!selectionY || selectionY->getSelectedRegions().size() == 0) {
                     yBottom = 0;
@@ -1095,9 +1108,9 @@ void DotPlotWidget::drawSelection(QPainter &p) const {
                     drawRectCorrect(p, QRectF(xLeft + shiftX, yBottom + shiftY, xLen, yLen));
                 }
                 else {
-                    foreach(const LRegion &ry, selectionY->getSelectedRegions()) {
+                    foreach(const U2Region &ry, selectionY->getSelectedRegions()) {
                         yBottom = ry.startPos/(float)ySeqLen * h*zoom.y();
-                        yLen = ry.len/(float)ySeqLen * h*zoom.y();
+                        yLen = ry.length/(float)ySeqLen * h*zoom.y();
 
                         drawRectCorrect(p, QRectF(xLeft + shiftX, yBottom + shiftY, xLen, yLen));
 
@@ -1111,9 +1124,9 @@ void DotPlotWidget::drawSelection(QPainter &p) const {
             xLeft = 0;
             xLen = 1.0f * w*zoom.x();
 
-            foreach(const LRegion &ry, selectionY->getSelectedRegions()) {
+            foreach(const U2Region &ry, selectionY->getSelectedRegions()) {
                 yBottom = ry.startPos/(float)ySeqLen * h*zoom.y();
-                yLen = ry.len/(float)ySeqLen * h*zoom.y();
+                yLen = ry.length/(float)ySeqLen * h*zoom.y();
 
                 drawRectCorrect(p, QRectF(xLeft + shiftX, yBottom + shiftY, xLen, yLen));
             }
@@ -1145,8 +1158,8 @@ void DotPlotWidget::checkShift(bool emitSignal) {
     if (emitSignal) {
         emit si_dotPlotChanged(sequenceX, sequenceY, shiftX/w, shiftY/h, zoom);
     }
-    LRegion visRangeX;
-    LRegion visRangeY;
+    U2Region visRangeX;
+    U2Region visRangeY;
 
     foreach (ADVSequenceWidget *advSeqWidget, dnaView->getSequenceWidgets()) {
         ADVSingleSequenceWidget *advSingleSeqWidget = qobject_cast<ADVSingleSequenceWidget*>(advSeqWidget);
@@ -1322,7 +1335,7 @@ void DotPlotWidget::sequencesCoordsSelection(const QPointF &start, const QPointF
 
             if ( ((int)(endX-startX) > 0) && (s == sequenceX)) {
                 s->getSequenceSelection()->clear();
-                s->getSequenceSelection()->addRegion(LRegion(startX, endX-startX));
+                s->getSequenceSelection()->addRegion(U2Region(startX, endX-startX));
 
                 w->centerPosition(startX);
             }
@@ -1331,7 +1344,7 @@ void DotPlotWidget::sequencesCoordsSelection(const QPointF &start, const QPointF
                 if(sequenceX != sequenceY){
                     s->getSequenceSelection()->clear();
                 }
-                s->getSequenceSelection()->addRegion(LRegion(startY, endY-startY));
+                s->getSequenceSelection()->addRegion(U2Region(startY, endY-startY));
 
                 w->centerPosition(startY);
             }
@@ -1375,13 +1388,11 @@ void DotPlotWidget::selectNearestRepeat(const QPointF &p) {
     }
 
     nearestSelecting = true;
-    // There is only one sequence view, can't select two places there
-    if (sequenceX != sequenceY) {
-        sequencesCoordsSelection(
-            QPoint(nearestRepeat->x, nearestRepeat->y),
-            QPoint(nearestRepeat->x + nearestRepeat->len, nearestRepeat->y + nearestRepeat->len)
-        );
-    }
+    sequencesCoordsSelection(
+        QPoint(nearestRepeat->x, nearestRepeat->y),
+        QPoint(nearestRepeat->x + nearestRepeat->len, nearestRepeat->y + nearestRepeat->len)
+    );
+
 
     foreach (ADVSequenceWidget *w, dnaView->getSequenceWidgets()) {
         foreach (ADVSequenceObjectContext *s, w->getSequenceContexts()) {
@@ -1417,8 +1428,8 @@ const DotPlotResults* DotPlotWidget::findNearestRepeat(const QPoint &p) {
 
     bool first = true;
 
-    Q_ASSERT (dotPlotDirectResultsListener);
-    foreach (const DotPlotResults &r, *dotPlotDirectResultsListener->dotPlotList) {
+    Q_ASSERT (dpDirectResultListener);
+    foreach (const DotPlotResults &r, *dpDirectResultListener->dotPlotList) {
 
         float halfLen = r.len/(float)2;
         float midX = r.x + halfLen;
@@ -1437,8 +1448,8 @@ const DotPlotResults* DotPlotWidget::findNearestRepeat(const QPoint &p) {
         first = false;
     }
 
-    Q_ASSERT (dotPlotInverseResultsListener);
-    foreach (const DotPlotResults &r, *dotPlotInverseResultsListener->dotPlotList) {
+    Q_ASSERT (dpRevComplResultsListener);
+    foreach (const DotPlotResults &r, *dpRevComplResultsListener->dotPlotList) {
 
         float halfLen = r.len/(float)2;
         float midX = r.x + halfLen;
@@ -1530,8 +1541,6 @@ void DotPlotWidget::wheelEvent(QWheelEvent *e) {
         return;
     }
 
-    QPointF oldCoords = toInnerCoords(e->pos().x(), e->pos().y());
-
     QPointF oldzoom = zoom;
     QPointF newzoom = zoom*(1 + e->delta()/(float)1000);
 
@@ -1541,54 +1550,66 @@ void DotPlotWidget::wheelEvent(QWheelEvent *e) {
 }
 
 QString DotPlotWidget::makeToolTipText() const{
-    if(!nearestRepeat){
+    if (!nearestRepeat){
         return "";
     }
 
-    if(!sequenceX || !sequenceY){
+    if (!sequenceX || !sequenceY){
         return "";
     }
 
-    int shownLen = 20;
-    QString text ="HIT:  len: ";
+    int maxRepeatSequenceShowLen = 32;
+    QString text ="HIT:  len: %1, match: %2, %: %3\n";
+    QString coord = "Coordinates(beg.): x: %1 y: %2\n";
     QString upLineSeq ="";
     QString middleLineSeq = "";
     QString downLineSeq = "";
-    const QByteArray &seqX = sequenceX->getSequenceData();
-    const QByteArray &seqY = sequenceY->getSequenceData();
+    QByteArray repX = sequenceX->getSequenceObject()->getSequence().mid(nearestRepeat->x, nearestRepeat->len);
+    QByteArray repY = sequenceY->getSequenceObject()->getSequence().mid(nearestRepeat->y, nearestRepeat->len);
+    if (nearestInverted) {
+        DNATranslation* complT = AppContext::getDNATranslationRegistry()->lookupComplementTranslation(sequenceX->getAlphabet());
+        assert(complT != NULL);
+        TextUtils::reverse(repX.data(), repX.length());
+        complT->translate(repX.data(), repX.length());
+    }
     int match = 0;
 
-    for(int i = 0; i < nearestRepeat->len; i++){
-        if(seqX.at(nearestRepeat->x +i) == seqY.at(nearestRepeat->y +i)){
+    for (int i = 0; i < nearestRepeat->len; i++){
+        if (repX[i] == repY[i]) {
             match++;
         }
     }
 
-    text.append(QString("%1").arg(nearestRepeat->len));
-    text.append(", match: ");
+    text = text.arg(nearestRepeat->len).arg(match).arg((float)(match/(float)nearestRepeat->len)*100);
 
-    text.append(QString("%1").arg(match));
-    text.append(QString(", %: %1").arg((float)(match/(float)nearestRepeat->len)*100));
 
-    text.append("\nS1:     ");
+    coord = coord.arg(nearestRepeat->x + 1).arg(nearestRepeat->y + 1);
+    text.append(coord);
 
-    for(int i = 0; i < nearestRepeat->len && i<shownLen; i++){
-        if(seqX.at(nearestRepeat->x +i) == seqY.at(nearestRepeat->y +i)){
-            middleLineSeq.append(seqX.at(nearestRepeat->x +i));
-        }else{
+    for(int i = 0; i < nearestRepeat->len && i < maxRepeatSequenceShowLen; i++) {
+        char rx = repX[i];
+        char ry = repY[i];
+        if (rx == ry) {
+            middleLineSeq.append(rx);
+        } else {
             middleLineSeq.append("*");
         }
-        upLineSeq.append(seqX.at(nearestRepeat->x +i));
-        downLineSeq.append(seqY.at(nearestRepeat->y +i));
+        upLineSeq.append(rx);
+        downLineSeq.append(ry);
     }
 
+    QString ttt = nearestRepeat->len <= maxRepeatSequenceShowLen ? "\n" : "...\n";
+    text.append("X: ");
     text.append(upLineSeq);
-    text.append("...\nCons: ");
+    text.append(ttt);
+    text.append(">: ");
 
     text.append(middleLineSeq);
-    text.append("...\nS2:     ");
+    text.append(ttt);
+    text.append("Y: ");
     text.append(downLineSeq);
-    text.append("...");
+    ttt.chop(1);
+    text.append(ttt);
 
     return text;
 }
@@ -1635,7 +1656,9 @@ void DotPlotWidget::mousePressEvent(QMouseEvent *e) {
             return;
         }
 
-        if(e->modifiers() & Qt::ShiftModifier){
+        if(e->modifiers() & Qt::ControlModifier){
+            clearRepeatSelection();
+        }else if(e->modifiers() & Qt::ShiftModifier){
             shifting = true;
             cursor.setShape(Qt::OpenHandCursor);
             setCursor(cursor);
@@ -1685,6 +1708,7 @@ void DotPlotWidget::mouseMoveEvent(QMouseEvent *e) {
 
     if (selecting) {
         if ((clickedFirst.x() != clickedSecond.x()) && (clickedFirst.y() != clickedSecond.y())) {
+            clearedByRepitSel = false;
             sequencesMouseSelection(clickedFirst, clickedSecond);
         }
     }
@@ -1732,6 +1756,16 @@ QString DotPlotWidget::getYSequenceName() {
     return sequenceY->getSequenceObject()->getGObjectName();
 }
 
+void DotPlotWidget::setSequences(DNASequenceObject* seqX, DNASequenceObject* seqY)
+{
+    CHECK(dnaView != NULL,);
+    if(seqX != NULL) {
+        sequenceX = dnaView->getSequenceContext(seqX);
+    }
+    if(seqY != NULL) {
+        sequenceY = dnaView->getSequenceContext(seqY);
+    }
+}
 
 void DotPlotWidget::mouseReleaseEvent(QMouseEvent *e) {
     setFocus();
@@ -1747,12 +1781,14 @@ void DotPlotWidget::mouseReleaseEvent(QMouseEvent *e) {
         if(!shifting){
             selecting = false;
             miniMapLooking = false;
-             if (clickedFirst == clickedSecond) {
+            if (clickedFirst == clickedSecond && !(e->modifiers() & Qt::ControlModifier)) {
                 if(!timer->isActive()){
                      timer->start();
                 }
-                selectNearestRepeat(clickedFirst);
                 sequenceClearSelection();
+                clearedByRepitSel = true;
+                selectNearestRepeat(clickedFirst);
+                
             }
         }
         shifting = false;
@@ -1770,16 +1806,16 @@ void DotPlotWidget::mouseReleaseEvent(QMouseEvent *e) {
 bool DotPlotWidget::hasSelection() {
 
     if (selectionX) {
-        foreach (const LRegion &lr, selectionX->getSelectedRegions()) {
-            if (lr.len>0) {
+        foreach (const U2Region &lr, selectionX->getSelectedRegions()) {
+            if (lr.length>0) {
                 return true;
             }
         }
     }
 
     if (selectionY) {
-        foreach (const LRegion &lr, selectionY->getSelectedRegions()) {
-            if (lr.len>0) {
+        foreach (const U2Region &lr, selectionY->getSelectedRegions()) {
+            if (lr.length>0) {
                 return true;
             }
         }
@@ -1821,4 +1857,10 @@ void DotPlotWidget::updateCursor(){
     }
     setCursor(cursor);
 }
+
+void DotPlotWidget::clearRepeatSelection(){
+    nearestRepeat = NULL; 
+    clearedByRepitSel = true;
+    update();
+}
 } // namespace
