@@ -1,19 +1,30 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_DOT_PLOT_WIDGET_H_
 #define _U2_DOT_PLOT_WIDGET_H_
 
 #include <U2View/ADVSplitWidget.h>
 #include <U2View/PanView.h>
-#include <U2Core/LRegion.h>
+#include <U2Core/U2Region.h>
 
 #include <QtGui/QMenu>
 #include <QtGui/QToolButton>
@@ -29,6 +40,7 @@ class GObjectView;
 class LRegionsSelection;
 
 class DotPlotResultsListener;
+class DotPlotRevComplResultsListener;
 class DotPlotMiniMap;
 struct DotPlotResults;
 class GSequenceLineView;
@@ -66,13 +78,15 @@ public:
     QString getXSequenceName();
     QString getYSequenceName();
 
+    void setSequences(DNASequenceObject* seqX, DNASequenceObject* seqY);
+
 signals:
     void si_removeDotPlot();
     void si_dotPlotChanged(ADVSequenceObjectContext*, ADVSequenceObjectContext*, float, float, QPointF);
     void si_dotPlotSelecting();
 
 public slots:
-    bool sl_showSettingsDialog();
+    bool sl_showSettingsDialog(bool disableLoad = false);
 
 private slots:
     void sl_taskFinished(Task*);
@@ -81,7 +95,7 @@ private slots:
     bool sl_showLoadFileDialog();
     void sl_showDeleteDialog();
 
-    void sl_onSequenceSelectionChanged(LRegionsSelection*, const QList<LRegion>& , const QList<LRegion>&);
+    void sl_onSequenceSelectionChanged(LRegionsSelection*, const QVector<U2Region>& , const QVector<U2Region>&);
 
     void sl_sequenceWidgetRemoved(ADVSequenceWidget*);
     void sl_panViewChanged();
@@ -126,7 +140,8 @@ private:
 
     QPointF clickedFirst, clickedSecond;
 
-    DotPlotResultsListener *dotPlotDirectResultsListener, *dotPlotInverseResultsListener;
+    DotPlotResultsListener*         dpDirectResultListener;
+    DotPlotRevComplResultsListener* dpRevComplResultsListener;
 
     QAction *showSettingsDialogAction;
     QAction *saveImageAction;
@@ -147,7 +162,8 @@ private:
     QColor dotPlotNearestRepeatColor;
 
     QByteArray sharedSeqX, sharedSeqY;
-    PanView::ZoomUseObject zoomUseX, zoomUseY;
+    bool clearedByRepitSel;
+
 
     void pixMapUpdate();
 
@@ -167,6 +183,7 @@ private:
     void sequencesMouseSelection(const QPointF &, const QPointF &);
     void sequencesCoordsSelection(const QPointF &, const QPointF &);
     void sequenceClearSelection();
+    void clearRepeatSelection();
 
     void selectNearestRepeat(const QPointF &);
     const DotPlotResults* findNearestRepeat(const QPoint &); // sets nearestInverted
@@ -181,9 +198,9 @@ private:
 
     QString makeToolTipText() const;
 
-    QPointF zoomTo(Qt::Axis axis, const LRegion &lr, bool emitSignal = true);
-    LRegion getVisibleRange(Qt::Axis axis);
-    int getLrDifference(const LRegion &a, const LRegion &b);
+    QPointF zoomTo(Qt::Axis axis, const U2Region &lr, bool emitSignal = true);
+    U2Region getVisibleRange(Qt::Axis axis);
+    int getLrDifference(const U2Region &a, const U2Region &b);
 
     void miniMapShift();
 
