@@ -85,12 +85,22 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="383"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="365"/>
+        <source>Click to load a sequence from the file system. The sequence will be added to the combo boxes when it is loaded to the project</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/DotPlotDialog.ui" line="368"/>
+        <source>Load Sequence</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/DotPlotDialog.ui" line="393"/>
         <source>OK</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/DotPlotDialog.ui" line="393"/>
+        <location filename="../src/ui/DotPlotDialog.ui" line="403"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
@@ -165,30 +175,35 @@
 <context>
     <name>U2::DotPlotDialog</name>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="26"/>
+        <location filename="../src/DotPlotDialog.cpp" line="63"/>
         <source>Auto</source>
         <translation>Автовыбор</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="27"/>
+        <location filename="../src/DotPlotDialog.cpp" line="64"/>
         <source>Suffix index</source>
         <translation>Суффиксный индекс</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotDialog.cpp" line="28"/>
+        <location filename="../src/DotPlotDialog.cpp" line="65"/>
         <source>Diagonals</source>
         <translation>Диагональный</translation>
     </message>
+    <message>
+        <location filename="../src/DotPlotDialog.cpp" line="274"/>
+        <source>Open file</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>U2::DotPlotDialogs</name>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="122"/>
+        <location filename="../src/DotPlotClasses.cpp" line="142"/>
         <source>Task is already running</source>
         <translation>Задача уже запущена</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="122"/>
+        <location filename="../src/DotPlotClasses.cpp" line="142"/>
         <source>Build or Load DotPlot task is already running</source>
         <translation>Задача построения или загрузки dotplot уже запущена</translation>
     </message>
@@ -201,57 +216,57 @@
         <translation type="obsolete">Сохранить dotplot перед удалением?</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="128"/>
+        <location filename="../src/DotPlotClasses.cpp" line="148"/>
         <source>Save dot-plot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="128"/>
+        <location filename="../src/DotPlotClasses.cpp" line="148"/>
         <source>Save dot-plot data before closing?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="134"/>
+        <location filename="../src/DotPlotClasses.cpp" line="154"/>
         <source>File opening error</source>
         <translation>Ошибка открытия файла</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="134"/>
+        <location filename="../src/DotPlotClasses.cpp" line="154"/>
         <source>Error opening file %1</source>
         <translation>Ошибка открытия файла %1</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="140"/>
+        <location filename="../src/DotPlotClasses.cpp" line="160"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="140"/>
+        <location filename="../src/DotPlotClasses.cpp" line="160"/>
         <source>Error opening files</source>
         <translation>Ошибка открытия файлов</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="146"/>
+        <location filename="../src/DotPlotClasses.cpp" line="166"/>
         <source>Sequences are different</source>
         <translation>Последовательности отличаются</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="146"/>
+        <location filename="../src/DotPlotClasses.cpp" line="166"/>
         <source>Current and loading sequences are different. Continue loading dot-plot anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="152"/>
+        <location filename="../src/DotPlotClasses.cpp" line="172"/>
         <source>Wrong dot-plot file format, loading aborted</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="158"/>
+        <location filename="../src/DotPlotClasses.cpp" line="178"/>
         <source>Both sequence alphabets must be 4-symbols DNA alphabets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="164"/>
+        <location filename="../src/DotPlotClasses.cpp" line="184"/>
         <source>Too many results. Try to increase minimum repeat length</source>
         <translation type="unfinished"></translation>
     </message>
@@ -260,7 +275,7 @@
         <translation type="obsolete">Текущие и загружаемые последовательности отличаются. Продолжать загрузку dotplot?</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="152"/>
+        <location filename="../src/DotPlotClasses.cpp" line="172"/>
         <source>Wrong format</source>
         <translation>Неправильный формат</translation>
     </message>
@@ -269,7 +284,7 @@
         <translation type="obsolete">Неправильный формат файла dotplot, загрузка прервана</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="158"/>
+        <location filename="../src/DotPlotClasses.cpp" line="178"/>
         <source>Wrong alphabet types</source>
         <translation>Неправильные типы алфавитов</translation>
     </message>
@@ -286,7 +301,7 @@
         <translation type="obsolete">Создайте или загрузите проект для начала</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotClasses.cpp" line="164"/>
+        <location filename="../src/DotPlotClasses.cpp" line="184"/>
         <source>Too many results</source>
         <translation>Слишком много результатов</translation>
     </message>
@@ -298,22 +313,22 @@
 <context>
     <name>U2::DotPlotFilesDialog</name>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="48"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="71"/>
         <source>Open first file</source>
         <translation>Открыть первый файл</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="65"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="88"/>
         <source>Open second file</source>
         <translation>Открыть второй файл</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="90"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="113"/>
         <source>Select files</source>
         <translation>Выберите файлы</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotFilesDialog.cpp" line="90"/>
+        <location filename="../src/DotPlotFilesDialog.cpp" line="113"/>
         <source>Select files first to build dotplot</source>
         <translation>Выберите файлы, чтобы посмотрить dotplot</translation>
     </message>
@@ -321,12 +336,12 @@
 <context>
     <name>U2::DotPlotLoadDocumentsTask</name>
     <message>
-        <location filename="../src/DotPlotTasks.cpp" line="208"/>
+        <location filename="../src/DotPlotTasks.cpp" line="229"/>
         <source>DotPlot loading</source>
         <translation>Dotplot загружается</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotTasks.cpp" line="250"/>
+        <location filename="../src/DotPlotTasks.cpp" line="274"/>
         <source>Detecting format error for file %1</source>
         <translation>Ошибка определения формата файла %1</translation>
     </message>
@@ -334,12 +349,12 @@
 <context>
     <name>U2::DotPlotPlugin</name>
     <message>
-        <location filename="../src/DotPlotPlugin.cpp" line="36"/>
+        <location filename="../src/DotPlotPlugin.cpp" line="57"/>
         <source>Dotplot</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotPlugin.cpp" line="36"/>
+        <location filename="../src/DotPlotPlugin.cpp" line="57"/>
         <source>Build dotplot for sequences</source>
         <translation>Построение dotplot для последовательностей</translation>
     </message>
@@ -347,37 +362,37 @@
 <context>
     <name>U2::DotPlotSplitter</name>
     <message>
-        <location filename="../src/DotPlotSplitter.cpp" line="27"/>
+        <location filename="../src/DotPlotSplitter.cpp" line="52"/>
         <source>Multiple view synchronization lock</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotSplitter.cpp" line="28"/>
+        <location filename="../src/DotPlotSplitter.cpp" line="53"/>
         <source>Keep aspect ratio</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotSplitter.cpp" line="29"/>
+        <location filename="../src/DotPlotSplitter.cpp" line="54"/>
         <source>Zoom in (&lt;b&gt; + &lt;/b&gt;)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotSplitter.cpp" line="30"/>
+        <location filename="../src/DotPlotSplitter.cpp" line="55"/>
         <source>Zoom out (&lt;b&gt; - &lt;/b&gt;)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotSplitter.cpp" line="31"/>
+        <location filename="../src/DotPlotSplitter.cpp" line="56"/>
         <source>Reset zooming (&lt;b&gt;0&lt;/b&gt;)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotSplitter.cpp" line="32"/>
+        <location filename="../src/DotPlotSplitter.cpp" line="57"/>
         <source>Select tool (&lt;b&gt;S&lt;/b&gt;)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotSplitter.cpp" line="33"/>
+        <location filename="../src/DotPlotSplitter.cpp" line="58"/>
         <source>Hand tool (&lt;b&gt;H&lt;/b&gt;)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -385,7 +400,7 @@
 <context>
     <name>U2::DotPlotViewAction</name>
     <message>
-        <location filename="../src/DotPlotPlugin.h" line="58"/>
+        <location filename="../src/DotPlotPlugin.h" line="79"/>
         <source>Show dot plot</source>
         <translation>Показать dotplot</translation>
     </message>
@@ -393,8 +408,8 @@
 <context>
     <name>U2::DotPlotViewContext</name>
     <message>
-        <location filename="../src/DotPlotPlugin.cpp" line="58"/>
-        <location filename="../src/DotPlotPlugin.cpp" line="181"/>
+        <location filename="../src/DotPlotPlugin.cpp" line="79"/>
+        <location filename="../src/DotPlotPlugin.cpp" line="205"/>
         <source>Build dotplot...</source>
         <translation>Построить dotplot...</translation>
     </message>
@@ -406,86 +421,79 @@
         <translation type="obsolete">Настройки</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="86"/>
+        <location filename="../src/DotPlotWidget.cpp" line="109"/>
         <source>Parameters</source>
         <translation>Параметры</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="89"/>
+        <location filename="../src/DotPlotWidget.cpp" line="112"/>
         <source>Save as image</source>
         <translation>Сохранить как изображение</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="92"/>
+        <location filename="../src/DotPlotWidget.cpp" line="115"/>
         <source>Save</source>
         <translation>Сохранить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="95"/>
+        <location filename="../src/DotPlotWidget.cpp" line="118"/>
         <source>Load</source>
         <translation>Загрузить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="98"/>
+        <location filename="../src/DotPlotWidget.cpp" line="121"/>
         <source>Remove</source>
         <translation>Удалить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="160"/>
+        <location filename="../src/DotPlotWidget.cpp" line="183"/>
         <source>Save/Load</source>
         <translation>Сохранить/Загрузить</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="159"/>
+        <location filename="../src/DotPlotWidget.cpp" line="916"/>
+        <source> (min length %1, identity %2%)</source>
+        <translation>(мин. длинна %1, идентичность %2%)</translation>
+    </message>
+    <message>
+        <location filename="../src/DotPlotWidget.cpp" line="182"/>
         <source>Dotplot</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="400"/>
         <source>Save Dotplot image</source>
-        <translation>Сохранение изображения dotplot</translation>
+        <translation type="obsolete">Сохранение изображения dotplot</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="400"/>
         <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Файлы изображений (*.png *.jpg *.bmp)</translation>
+        <translation type="obsolete">Файлы изображений (*.png *.jpg *.bmp)</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="417"/>
+        <location filename="../src/DotPlotWidget.cpp" line="441"/>
         <source>Save Dotplot</source>
         <translation>Сохранить dotplot</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="417"/>
-        <location filename="../src/DotPlotWidget.cpp" line="463"/>
+        <location filename="../src/DotPlotWidget.cpp" line="441"/>
+        <location filename="../src/DotPlotWidget.cpp" line="487"/>
         <source>Dotplot files (*.dpt)</source>
         <translation>Файлы dotplot (*.dpt)</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotWidget.cpp" line="463"/>
+        <location filename="../src/DotPlotWidget.cpp" line="487"/>
         <source>Load Dotplot</source>
         <translation>Загрузить dotplot</translation>
     </message>
-    <message>
-        <location filename="../src/DotPlotWidget.cpp" line="893"/>
-        <source>min length</source>
-        <translation>Мин длина</translation>
-    </message>
-    <message>
-        <location filename="../src/DotPlotWidget.cpp" line="893"/>
-        <source>identity</source>
-        <translation>идентичность</translation>
-    </message>
 </context>
 <context>
     <name>U2::LoadDotPlotTask</name>
     <message>
-        <location filename="../src/DotPlotTasks.cpp" line="41"/>
+        <location filename="../src/DotPlotTasks.cpp" line="62"/>
         <source>Wrong dotplot format</source>
         <translation>Неправильный формат файла dotplot</translation>
     </message>
     <message>
-        <location filename="../src/DotPlotTasks.h" line="43"/>
+        <location filename="../src/DotPlotTasks.h" line="64"/>
         <source>DotPlot loading</source>
         <translation>Dotplot загружается</translation>
     </message>
@@ -493,7 +501,7 @@
 <context>
     <name>U2::SaveDotPlotTask</name>
     <message>
-        <location filename="../src/DotPlotTasks.h" line="19"/>
+        <location filename="../src/DotPlotTasks.h" line="40"/>
         <source>DotPlot saving</source>
         <translation>Dotplot сохраняется</translation>
     </message>
