@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <U2Core/AppContext.h>
 #include <U2Core/Counter.h>
@@ -31,177 +42,92 @@
 
 namespace U2 {
 
-DigestSequenceTask::DigestSequenceTask(  const DNASequenceObject* so, AnnotationTableObject* ao, const QList<SEnzymeData>& cutSites, bool searchCutSites )
-:Task("DigestSequenceTask", TaskFlags_NR_FOSCOE | TaskFlag_ReportingIsSupported | TaskFlag_ReportingIsEnabled), enzymeData(cutSites), searchForRestrictionSites(searchCutSites), aObj(ao), dnaObj(so)
+DigestSequenceTask::DigestSequenceTask(  const DNASequenceObject* so, AnnotationTableObject* source, 
+                                       AnnotationTableObject* dest, const QList<SEnzymeData>& cutSites )
+                                       :   Task("DigestSequenceTask", TaskFlags_FOSCOE | TaskFlag_ReportingIsSupported | TaskFlag_ReportingIsEnabled),
+                                       searchForRestrictionSites(false), sourceObj(source), destObj(dest), dnaObj(so), enzymeData(cutSites)
 {
     GCOUNTER(cvar,tvar,"DigestSequenceIntoFragments");
-    
-    assert(aObj != NULL);
+
+    assert(sourceObj != NULL);
+    assert(destObj != NULL);
     assert(dnaObj != NULL);
 
 
 }
 
+DigestSequenceTask::DigestSequenceTask( const DNASequenceObject* so, AnnotationTableObject* aobj, 
+                                       const QList<SEnzymeData>& cutSites )
+:   Task("DigestSequenceTask", TaskFlags_FOSCOE | TaskFlag_ReportingIsSupported | TaskFlag_ReportingIsEnabled),
+    searchForRestrictionSites(true), sourceObj(aobj), destObj(aobj), dnaObj(so), enzymeData(cutSites)
+{
+    GCOUNTER(cvar,tvar,"DigestSequenceIntoFragments");
+    
+    assert(sourceObj != NULL);
+    assert(destObj != NULL);
+    assert(dnaObj != NULL);
+}
+
 void DigestSequenceTask::prepare() {
     seqRange = dnaObj->getSequenceRange();
     isCircular = dnaObj->isCircular();
     
     if (searchForRestrictionSites) {
-        
+        assert(sourceObj == destObj);
         FindEnzymesTaskConfig cfg;
         cfg.circular = isCircular;
-        cfg.region.append(seqRange);
         cfg.groupName = ANNOTATION_GROUP_ENZYME;
-        Task* t = new FindEnzymesToAnnotationsTask(aObj, dnaObj->getDNASequence(), enzymeData, cfg);
+        Task* t = new FindEnzymesToAnnotationsTask(sourceObj, dnaObj->getDNASequence(), enzymeData, cfg);
         addSubTask(t);
     }  
         
 }
 
-AnnotationData* DigestSequenceTask::createFragment( int pos1, const QString& enzymeId1, const QByteArray& leftOverhang, 
-                                                   int pos2, const QString& enzymeId2, const QByteArray& rightOverhang )
+AnnotationData* DigestSequenceTask::createFragment( int pos1, const DNAFragmentTerm& leftTerm, 
+                                                   int pos2, const DNAFragmentTerm& rightTerm )
 {
     AnnotationData* ad = new AnnotationData();
-    ad->location.append(LRegion(pos1, pos2 - pos1 ));
-    ad->qualifiers.append(Qualifier(QUALIFIER_LEFT_TERM, enzymeId1));
-    ad->qualifiers.append(Qualifier(QUALIFIER_RIGHT_TERM, enzymeId2));
-    ad->qualifiers.append(Qualifier(QUALIFIER_LEFT_OVERHANG, leftOverhang));
-    ad->qualifiers.append(Qualifier(QUALIFIER_RIGHT_OVERHANG, rightOverhang));
+    assert(pos1 != pos2 );
+    if (pos1  < pos2) {
+        ad->location->regions.append(U2Region(pos1, pos2 - pos1 ));
+    } else {
+        ad->location->regions.append(U2Region(pos1, seqRange.endPos() - pos1 ));
+        ad->location->regions.append(U2Region(seqRange.startPos, pos2 - seqRange.startPos ));
+    }
     
-    QString leftOverhangType = enzymeId1.isEmpty() ? OVERHANG_TYPE_BLUNT : OVERHANG_TYPE_STICKY;
-    ad->qualifiers.append(Qualifier(QUALIFIER_LEFT_TYPE, leftOverhangType) );
-    QString rightOverhangType = enzymeId2.isEmpty() ? OVERHANG_TYPE_BLUNT : OVERHANG_TYPE_STICKY;
-    ad->qualifiers.append(Qualifier(QUALIFIER_RIGHT_TYPE, rightOverhangType) );
+    ad->qualifiers.append(U2Qualifier(QUALIFIER_LEFT_TERM, leftTerm.enzymeId));
+    ad->qualifiers.append(U2Qualifier(QUALIFIER_RIGHT_TERM, rightTerm.enzymeId));
+    
+    ad->qualifiers.append(U2Qualifier(QUALIFIER_LEFT_OVERHANG, leftTerm.overhang));
+    ad->qualifiers.append(U2Qualifier(QUALIFIER_RIGHT_OVERHANG, rightTerm.overhang));
+    
+    QString leftOverhangStrand = leftTerm.isDirect ? OVERHANG_STRAND_DIRECT : OVERHANG_STRAND_COMPL;
+    ad->qualifiers.append(U2Qualifier(QUALIFIER_LEFT_STRAND, leftOverhangStrand));
+    QString rightOverhangStrand = rightTerm.isDirect ? OVERHANG_STRAND_DIRECT : OVERHANG_STRAND_COMPL;
+    ad->qualifiers.append(U2Qualifier(QUALIFIER_RIGHT_STRAND, rightOverhangStrand));
+    
+    QString leftOverhangType = leftTerm.enzymeId.isEmpty() ? OVERHANG_TYPE_BLUNT : OVERHANG_TYPE_STICKY;
+    ad->qualifiers.append(U2Qualifier(QUALIFIER_LEFT_TYPE, leftOverhangType) );
+    QString rightOverhangType = rightTerm.enzymeId.isEmpty() ? OVERHANG_TYPE_BLUNT : OVERHANG_TYPE_STICKY;
+    ad->qualifiers.append(U2Qualifier(QUALIFIER_RIGHT_TYPE, rightOverhangType) );
 
-    ad->qualifiers.append(Qualifier(QUALIFIER_SOURCE, dnaObj->getGObjectName()));
+    ad->qualifiers.append(U2Qualifier(QUALIFIER_SOURCE, dnaObj->getGObjectName()));
     
     return ad;
 }
 
-// TODO: improve code of region calculation
-/*static LRegion getOverhangRegion(const SEnzymeData& enzyme) {
-    LRegion result;
-    return result;
-}
-*/
 
 Task::ReportResult DigestSequenceTask::report()
 {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return ReportResult_Finished;
     }
-  
-    findCutSites();
-    
-    if (cutSiteMap.isEmpty()) {
-        return ReportResult_Finished;
-    }
-        
-    QMap<int,SEnzymeData>::const_iterator prev = cutSiteMap.constBegin(), current = cutSiteMap.constBegin();
-    int count = 2;
 
-    while ( (++current) != cutSiteMap.constEnd() )  {
-        int pos1 = prev.key();
-        int pos2 = current.key();
-        const SEnzymeData& enzyme1 = prev.value();
-        const SEnzymeData& enzyme2 = current.value();
-        int len1= enzyme1->seq.length();
-        int len2 = enzyme2->seq.length();
-        
-        {
-
-            LRegion region1(pos1, len1);
-            LRegion region2(pos2, len2);
-
-            if (region1.intersects(region2)) {
-                setError(tr("Unable to digest into fragments: intersecting enzymes %1 (%2..%3) and %4 (%5..%6)")
-                    .arg(enzyme1->id).arg(region1.startPos).arg(region1.endPos())
-                    .arg(enzyme2->id).arg(region2.startPos).arg(region2.endPos()));
-                return ReportResult_Finished;
-            }
-
-        }
-
-        int diff1 = enzyme1->seq.length() - enzyme1->cutDirect;
-        int offset1 = enzyme1->cutComplement > diff1 ? diff1 : enzyme1->cutComplement;
-        pos1 = pos1 + len1 - offset1;
-        int cutLen1 = qAbs(diff1 - enzyme1->cutComplement);
-        QByteArray leftOverhang = dnaObj->getSequence().mid(pos1 - cutLen1, cutLen1);
-
-        int diff2 = enzyme2->seq.length() - enzyme2->cutComplement;
-        int offset2 = enzyme1->cutDirect > diff2 ? diff2 : enzyme2->cutDirect;
-        pos2 += offset2;
-        QByteArray rightOverhang = dnaObj->getSequence().mid(pos2, qAbs(diff2 - enzyme2->cutDirect));
-
-        
-        AnnotationData* ad = createFragment(pos1, enzyme1->id, leftOverhang,  pos2, enzyme2->id, rightOverhang);
-        
-        ad->name = QString("Fragment %1").arg(count);
-        results.append(SharedAnnotationData(ad));
-        ++count;
-        ++prev;
-        
-    } 
-        
-    QMap<int,SEnzymeData>::const_iterator first = cutSiteMap.constBegin();
-    
-    const QByteArray& sourceSeq = dnaObj->getSequence();
-    const SEnzymeData& firstCutter = first.value();
-    const SEnzymeData& lastCutter = prev.value();
-    int firstCutPos = first.key();
-    int fdiff = firstCutter->seq.length() - firstCutter->cutComplement;
-    firstCutPos += firstCutter->cutDirect > fdiff ? fdiff : firstCutter->cutDirect;
-    QByteArray firstRightOverhang = dnaObj->getSequence().mid(firstCutPos, qAbs(fdiff - firstCutter->cutDirect));
-    
-    int lastCutPos = prev.key();
-    int ldiff = lastCutter->seq.length() - lastCutter->cutDirect;
-    int loffset = lastCutter->cutComplement > ldiff ? ldiff : lastCutter->cutComplement;
-    
-    lastCutPos = lastCutPos + lastCutter->seq.length() - loffset;
-    
-    if (lastCutPos >= sourceSeq.length()) {
-        // last restriction site is situated between sequence start and end
-        assert(isCircular);
-        int leftCutPos = lastCutPos - sourceSeq.length();
-        QByteArray leftOverhang = sourceSeq.mid(prev.key() + lastCutter->cutDirect) + sourceSeq.mid(0, leftCutPos);
-        QByteArray rightOverhang = first == prev ? leftOverhang : firstRightOverhang;
-        AnnotationData* ad1 = createFragment(leftCutPos, lastCutter->id, leftOverhang, firstCutPos, firstCutter->id, rightOverhang );
-        ad1->name = QString("Fragment 1");
-        results.append(SharedAnnotationData(ad1));
-    } else {
-        int lCutLen = qAbs(ldiff - lastCutter->cutComplement);
-        QByteArray lastLeftOverhang = dnaObj->getSequence().mid(lastCutPos - lCutLen, lCutLen);
-        AnnotationData* ad1 = createFragment(seqRange.startPos, QString(), QByteArray(), firstCutPos, firstCutter->id, firstRightOverhang );
-        AnnotationData* ad2 = createFragment(lastCutPos, lastCutter->id, lastLeftOverhang, seqRange.endPos(), QString(), QByteArray());
-
-        if (isCircular) {
-            int split_size = (seqRange.len - lastCutPos) + firstCutPos; 
-            
-            // For splitted fragments only the one with positive split is valid
-            ad1->qualifiers.append( Qualifier(QUALIFIER_SPLIT, QString("%1").arg(-split_size)) );
-            ad1->name = QString("Fragment 1");
-                        
-            ad2->qualifiers.append( Qualifier(QUALIFIER_SPLIT, QString("%1").arg(split_size)) );
-            ad2->qualifiers.append( Qualifier(QUALIFIER_SPLIT_TERM, firstCutter->id) );
-            ad2->qualifiers.append( Qualifier(QUALIFIER_SPLIT_OVERHANG, firstRightOverhang) );
-            ad2->qualifiers.append( Qualifier(QUALIFIER_SPLIT_TYPE, OVERHANG_TYPE_STICKY) );
-            ad2->name = ad1->name;
-        } else {
-            ad1->name = QString("Fragment 1");
-            ad2->name = QString("Fragment %1").arg(count);
-        }
-    
-        results.append(SharedAnnotationData(ad1));
-        results.append(SharedAnnotationData(ad2));
-    }
-    
     saveResults();
-
+    
     return ReportResult_Finished;
 }
 
-
-
 void DigestSequenceTask::findCutSites()
 {
     foreach (const SEnzymeData& enzyme, enzymeData) {
@@ -212,11 +138,8 @@ void DigestSequenceTask::findCutSites()
         }
 
         QList<Annotation*> anns;
-        foreach (Annotation* a, aObj->getAnnotations()) {
+        foreach (Annotation* a, sourceObj->getAnnotations()) {
             if (a->getAnnotationName() == enzyme->id) {
-                if (GObjectUtils::annotationHasNegativeSplit(a) ) {
-                    continue;
-                }
                 anns.append(a);
             }
         }
@@ -227,8 +150,7 @@ void DigestSequenceTask::findCutSites()
         }
         
         foreach (Annotation * a, anns) {
-            const QList<LRegion>& location = a->getLocation();
-            assert(location.size() == 1);
+            const QVector<U2Region>& location = a->getRegions();
             int cutPos = location.first().startPos;
             cutSiteMap.insertMulti(cutPos, enzyme);
         }
@@ -236,10 +158,119 @@ void DigestSequenceTask::findCutSites()
     }
 }
 
+void DigestSequenceTask::run()
+{
+    if (hasError() || isCanceled()) {
+        return;
+    }
+
+    findCutSites();
+
+    if (cutSiteMap.isEmpty()) {
+        return;
+    }
+
+    QMap<int,SEnzymeData>::const_iterator prev = cutSiteMap.constBegin(), current = cutSiteMap.constBegin();
+    int count = 2;
+    const QByteArray& sourceSeq = dnaObj->getSequence();
+
+    while ( (++current) != cutSiteMap.constEnd() )  {
+        int pos1 = prev.key();
+        int pos2 = current.key();
+        const SEnzymeData& enzyme1 = prev.value();
+        const SEnzymeData& enzyme2 = current.value();
+        int len1= enzyme1->seq.length();
+        int len2 = enzyme2->seq.length();
+
+        {
+
+            U2Region region1(pos1, len1);
+            U2Region region2(pos2, len2);
+
+            if (region1.intersects(region2)) {
+                setError(tr("Unable to digest into fragments: intersecting restriction sites %1 (%2..%3) and %4 (%5..%6)")
+                    .arg(enzyme1->id).arg(region1.startPos).arg(region1.endPos())
+                    .arg(enzyme2->id).arg(region2.startPos).arg(region2.endPos()));
+                return;
+            }
+
+        }
+        
+        DNAFragmentTerm leftTerm;
+        int leftCutCompl = len1 - enzyme1->cutComplement;
+        int leftCutPos = pos1 + qMax(enzyme1->cutDirect, leftCutCompl);
+        int leftOverhangStart = pos1 + qMin(enzyme1->cutDirect, leftCutCompl);
+        leftTerm.overhang = sourceSeq.mid(leftOverhangStart, leftCutPos - leftOverhangStart);
+        leftTerm.enzymeId = enzyme1->id.toAscii();
+        leftTerm.isDirect = enzyme1->cutDirect < leftCutCompl; 
+
+        DNAFragmentTerm rightTerm;
+        int rightCutCompl = len2 - enzyme2->cutComplement;
+        int rightCutPos = pos2 + qMin(enzyme2->cutDirect, rightCutCompl );
+        int rightOverhangStart = pos2 + qMax(enzyme2->cutDirect, rightCutCompl );
+        rightTerm.overhang = sourceSeq.mid(rightCutPos, rightOverhangStart - rightCutPos);
+        rightTerm.enzymeId = enzyme2->id.toAscii();
+        rightTerm.isDirect = enzyme2->cutDirect > rightCutCompl;
+
+        AnnotationData* ad = createFragment(leftCutPos, leftTerm,  rightCutPos, rightTerm);
+        ad->name = QString("Fragment %1").arg(count);
+        results.append(SharedAnnotationData(ad));
+        ++count;
+        ++prev;
+
+    } 
+
+    QMap<int,SEnzymeData>::const_iterator first = cutSiteMap.constBegin();
+
+    const SEnzymeData& firstCutter = first.value();
+    int fcLen = firstCutter->seq.length();
+    int firstCutPos = first.key() + qMin(firstCutter->cutDirect, fcLen - firstCutter->cutComplement);
+    int rightOverhangStart = first.key() + qMax(firstCutter->cutDirect, fcLen - firstCutter->cutComplement);
+    bool rightOverhangIsDirect = firstCutter->cutDirect > fcLen - firstCutter->cutComplement;
+    QByteArray firstRightOverhang = sourceSeq.mid(firstCutPos, rightOverhangStart - firstCutPos);
+    
+    const SEnzymeData& lastCutter = prev.value();
+    int lcLen = lastCutter->seq.length();
+    int lastCutPos = prev.key() + qMax(lastCutter->cutDirect, lcLen - lastCutter->cutComplement);
+    int leftOverhangStart = prev.key() + qMin(lastCutter->cutDirect, fcLen - lastCutter->cutComplement);
+    bool leftOverhangIsDirect = lastCutter->cutDirect < lcLen - lastCutter->cutComplement;
+    
+    if (lastCutPos >= sourceSeq.length()) {
+        // last restriction site is situated between sequence start and end
+        assert(isCircular);
+        int leftCutPos = lastCutPos - sourceSeq.length();
+        QByteArray leftOverhang = sourceSeq.mid(leftOverhangStart) + sourceSeq.mid(0, leftCutPos);
+        QByteArray rightOverhang = first == prev ? leftOverhang : firstRightOverhang;
+        AnnotationData* ad1 = createFragment(leftCutPos, DNAFragmentTerm(lastCutter->id, leftOverhang, leftOverhangIsDirect), 
+            firstCutPos, DNAFragmentTerm(firstCutter->id, rightOverhang, rightOverhangIsDirect) );
+        ad1->name = QString("Fragment 1");
+        results.append(SharedAnnotationData(ad1));
+    } else {
+        QByteArray lastLeftOverhang = sourceSeq.mid(leftOverhangStart, lastCutPos - leftOverhangStart);
+        if (isCircular) {
+            AnnotationData* ad = createFragment(lastCutPos, DNAFragmentTerm(lastCutter->id, lastLeftOverhang, leftOverhangIsDirect), 
+                firstCutPos, DNAFragmentTerm(firstCutter->id, firstRightOverhang,rightOverhangIsDirect) );
+            ad->name = QString("Fragment 1");
+            results.append(SharedAnnotationData(ad));
+        } else {
+            AnnotationData* ad1 = createFragment(seqRange.startPos, DNAFragmentTerm(), 
+                firstCutPos, DNAFragmentTerm(firstCutter->id, firstRightOverhang, rightOverhangIsDirect) );
+            AnnotationData* ad2 = createFragment(lastCutPos, DNAFragmentTerm(lastCutter->id, lastLeftOverhang, leftOverhangIsDirect), 
+                seqRange.endPos(), DNAFragmentTerm() );
+            ad1->name = QString("Fragment 1");
+            ad2->name = QString("Fragment %1").arg(count);
+            results.append(SharedAnnotationData(ad1));
+            results.append(SharedAnnotationData(ad2));
+        }
+    }
+
+}
+
+
 void DigestSequenceTask::saveResults()
 {
     foreach (const SharedAnnotationData& data, results) {
-        aObj->addAnnotation(new Annotation(data), ANNOTATION_GROUP_FRAGMENTS);
+        destObj->addAnnotation(new Annotation(data), ANNOTATION_GROUP_FRAGMENTS);
     }
 }
 
@@ -251,8 +282,8 @@ QString DigestSequenceTask::generateReport() const
     res+=tr("<br>Generated %1 fragments.").arg(results.count());
     int counter = 1;
     foreach (const SharedAnnotationData& sdata, results) {
-        int startPos = sdata->location.first().startPos;
-        int endPos = sdata->location.first().endPos();
+        int startPos = sdata->location->regions.first().startPos;
+        int endPos = sdata->location->regions.first().endPos();
         res+=tr("<br><br>&nbsp;&nbsp;&nbsp;&nbsp;%1:&nbsp;&nbsp;&nbsp;&nbsp;From %3 (%2) To %5 (%4) - %6 bp ").arg(counter)
                   .arg(startPos).arg(sdata->findFirstQualifierValue(QUALIFIER_LEFT_TERM))
                   .arg(endPos).arg(sdata->findFirstQualifierValue(QUALIFIER_RIGHT_TERM))
@@ -264,6 +295,7 @@ QString DigestSequenceTask::generateReport() const
 
 }
 
+
 //////////////////////////////////////////////////////////////////////////
 
 LigateFragmentsTask::LigateFragmentsTask( const QList<DNAFragment>& fragments, const LigateFragmentsTaskConfig& config )
@@ -273,43 +305,29 @@ LigateFragmentsTask::LigateFragmentsTask( const QList<DNAFragment>& fragments, c
     GCOUNTER(cvar,tvar,"LigateFragments");
 }
 
-static bool overhangsAreConsistent(const QByteArray& start, const QByteArray& end, DNAAlphabet* alphabet ) {
-    DNATranslation* trans = AppContext::getDNATranslationRegistry()->lookupComplementTranslation(alphabet);
-    
-    QByteArray compEnd(end);
-    trans->translate(compEnd.data(), end.length());
-    
-    if (compEnd == start) {
-       return true;
-    }
-
-    return false;
-}
-
-
 void LigateFragmentsTask::processOverhangs( const DNAFragment& prevFragment, const DNAFragment& curFragment, QByteArray& overhangAddition )
 {
-    QString prevTermType = prevFragment.getRightTermType();
-    QString curTermType = curFragment.getLeftTermType();
+    const DNAFragmentTerm& prevTerm = prevFragment.getRightTerminus();
+    const DNAFragmentTerm& curTerm = curFragment.getLeftTerminus();
 
-    if (prevTermType != curTermType) {
+    if (prevTerm.type != curTerm.type) {
         stateInfo.setError( tr("Fragments %1 and  %2 are inconsistent. Blunt and sticky ends incompatibility")
             .arg(prevFragment.getName()).arg(curFragment.getName()) );
         return;
     }
     
-    QString prevOverhang = prevFragment.getRightOverhang();
-    QString curOverhang = curFragment.getLeftOverhang();
+    QByteArray prevOverhang = prevFragment.getRightTerminus().overhang;
+    QByteArray curOverhang = curFragment.getLeftTerminus().overhang;
 
-    if (prevTermType == OVERHANG_TYPE_STICKY) {
-        if (prevOverhang != curOverhang) {
+    if (prevTerm.type == OVERHANG_TYPE_STICKY) {
+        if (!overhangsAreConsistent(prevFragment.getRightTerminus(), curFragment.getLeftTerminus())) {
             stateInfo.setError( tr("Right overhang from %1 and left overhang from %2 are inconsistent.")
                 .arg(prevFragment.getName()).arg(curFragment.getName()) );
             return;
         } else {
             overhangAddition += curOverhang;
         }
-    } else if (prevTermType == OVERHANG_TYPE_BLUNT) {
+    } else if (prevTerm.type == OVERHANG_TYPE_BLUNT) {
         overhangAddition += prevOverhang + curOverhang;
     } else {
         assert(0);
@@ -318,18 +336,31 @@ void LigateFragmentsTask::processOverhangs( const DNAFragment& prevFragment, con
 }
 
 
+bool LigateFragmentsTask::overhangsAreConsistent( const DNAFragmentTerm& curTerm, const DNAFragmentTerm& prevTerm )
+{
+    QByteArray curOverhang = curTerm.overhang;
+    QByteArray prevOverhang = prevTerm.overhang;
+    
+    bool curStrand = curTerm.isDirect;
+    bool prevStrand = prevTerm.isDirect;
+    if (curStrand == prevStrand) {
+        return false;
+    }
+
+    return curOverhang == prevOverhang;
+}
 
 void LigateFragmentsTask::prepare()
 {
     QByteArray resultSeq;
-    QList<LRegion> fragmentRegions;
+    QVector<U2Region> fragmentRegions;
 
     DNAFragment prevFragment;
     assert(prevFragment.isEmpty());
 
     foreach (const DNAFragment& dnaFragment, fragmentList) {
 
-        QList<LRegion> location = dnaFragment.getFragmentRegions();
+        QVector<U2Region> location = dnaFragment.getFragmentRegions();
         assert(location.size() > 0);
         
         // check alphabet consistency
@@ -350,7 +381,7 @@ void LigateFragmentsTask::prepare()
         if (cfg.checkOverhangs ) {
              if (!prevFragment.isEmpty()) {
                 processOverhangs(prevFragment, dnaFragment, overhangAddition );
-                if (stateInfo.hasErrors()) {
+                if (stateInfo.hasError()) {
                     return;
                 }
              }
@@ -378,7 +409,7 @@ void LigateFragmentsTask::prepare()
         const DNAFragment& last = fragmentList.last();
         QByteArray overhangAddition;
         processOverhangs(last, first, overhangAddition);
-        if (stateInfo.hasErrors()) {
+        if (stateInfo.hasError()) {
             return;
         }
         resultSeq.append(overhangAddition);
@@ -416,8 +447,8 @@ Annotation* LigateFragmentsTask::createSourceAnnotation( int regLen )
     Version v = Version::ugeneVersion();
     SharedAnnotationData sd( new AnnotationData);
     sd->name = "source";
-    sd->location.append(LRegion(0, regLen));
-    sd->qualifiers.append( Qualifier("comment", QString("Molecule is created with Unipro UGENE v%1.%2").arg(v.major).arg(v.minor)) );
+    sd->location->regions << U2Region(0, regLen);
+    sd->qualifiers.append( U2Qualifier("comment", QString("Molecule is created with Unipro UGENE v%1.%2").arg(v.major).arg(v.minor)) );
     return  new Annotation(sd);
 
 }
@@ -426,13 +457,13 @@ Annotation* LigateFragmentsTask::createFragmentAnnotation( const DNAFragment& fr
 {
     SharedAnnotationData sd( new AnnotationData);
     sd->name = QString("%1 %2").arg(fragment.getSequenceName()).arg(fragment.getName());
-    sd->location.append(LRegion(startPos, fragment.getLength()));
-    sd->qualifiers.append(Qualifier("source_doc", fragment.getSequenceDocName()));
+    sd->location->regions << U2Region(startPos, fragment.getLength());
+    sd->qualifiers.append(U2Qualifier("source_doc", fragment.getSequenceDocName()));
 
     return  new Annotation(sd);
 }
 
-QList<Annotation*> LigateFragmentsTask::cloneAnnotationsInRegion( const LRegion& fragmentRegion, AnnotationTableObject* source, int globalOffset )
+QList<Annotation*> LigateFragmentsTask::cloneAnnotationsInRegion( const U2Region& fragmentRegion, AnnotationTableObject* source, int globalOffset )
 {
     QList<Annotation*> results;
     
@@ -440,8 +471,8 @@ QList<Annotation*> LigateFragmentsTask::cloneAnnotationsInRegion( const LRegion&
     
     foreach(Annotation* a, source->getAnnotations()) {
         bool ok = true;
-        QList<LRegion> location = a->getLocation();
-        foreach(const LRegion& region, location) {
+        const QVector<U2Region>& location = a->getRegions();
+        foreach(const U2Region& region, location) {
             if (!fragmentRegion.contains(region) || fragmentRegion == region) {
                 ok = false;
                 break;
@@ -450,13 +481,13 @@ QList<Annotation*> LigateFragmentsTask::cloneAnnotationsInRegion( const LRegion&
         if (ok) {
             int newPos = globalOffset + location.first().startPos - fragmentRegion.startPos;
             Annotation* cloned = new Annotation(a->data());
-            QList<LRegion> newLocation;
-            foreach (const LRegion& region, a->getLocation()) {
-                LRegion newRegion(region);
+            QVector<U2Region> newLocation;
+            foreach (const U2Region& region, a->getRegions()) {
+                U2Region newRegion(region);
                 newRegion.startPos = newPos;
                 newLocation.append(newRegion);
             }
-            cloned->replaceLocationRegions(newLocation);
+            cloned->replaceRegions(newLocation);
             results.append(cloned);
         }
 
@@ -466,12 +497,12 @@ QList<Annotation*> LigateFragmentsTask::cloneAnnotationsInRegion( const LRegion&
 
 }
 
-static bool fragmentContainsRegion(const DNAFragment& fragment, const LRegion region) {
+static bool fragmentContainsRegion(const DNAFragment& fragment, const U2Region region) {
     
-    QList<LRegion> fragmentRegions = fragment.getFragmentRegions();
+    QVector<U2Region> fragmentRegions = fragment.getFragmentRegions();
 
     bool result = false;
-    foreach (const LRegion& fR, fragmentRegions) {
+    foreach (const U2Region& fR, fragmentRegions) {
         if (fR.contains(region)) {
             result = true;
             break;
@@ -484,17 +515,17 @@ static bool fragmentContainsRegion(const DNAFragment& fragment, const LRegion re
 } 
 
 
-static int getRelativeStartPos(const DNAFragment& fragment, const LRegion region)
+static int getRelativeStartPos(const DNAFragment& fragment, const U2Region region)
 {
     
-    QList<LRegion> fragmentRegions = fragment.getFragmentRegions();
+    QVector<U2Region> fragmentRegions = fragment.getFragmentRegions();
 
     int offset = 0;
-    foreach (const LRegion& fR, fragmentRegions) {
+    foreach (const U2Region& fR, fragmentRegions) {
         if (fR.contains(region)) {
             return offset + region.startPos - fR.startPos;
         }
-        offset += fR.len;
+        offset += fR.length;
     }
     
     // the fragment doesn't contain the region
@@ -510,14 +541,14 @@ QList<Annotation*> LigateFragmentsTask::cloneAnnotationsInFragmentRegion( const
     // TODO: allow to remove annotations
 
     foreach(Annotation* a, source->getAnnotations()) {
-        QList<LRegion> location = a->getLocation();
+        QVector<U2Region> location = a->getRegions();
         
         if (a->getAnnotationName().startsWith("Fragment")) {
             continue;
         }
 
         bool ok = true;
-        foreach (const LRegion& r, location) {
+        foreach (const U2Region& r, location) {
             // sneaky annotations shall not pass!
             if (!fragmentContainsRegion(fragment, r)) {
                 ok = false;
@@ -527,17 +558,26 @@ QList<Annotation*> LigateFragmentsTask::cloneAnnotationsInFragmentRegion( const
 
         if (ok) {
             Annotation* cloned = new Annotation(a->data());
-            QList<LRegion> newLocation;
-            foreach (const LRegion& region, location) {
+            QVector<U2Region> newLocation;
+            foreach (const U2Region& region, location) {
                 int startPos = getRelativeStartPos(fragment, region);
+                if (fragment.isInverted()) {
+                    startPos = fragment.getLength() - startPos - region.length;
+                    U2Strand strand = cloned->getStrand();
+                    if (strand.isDirect()) {
+                        cloned->setStrand(U2Strand::Complementary);
+                    } else {
+                        cloned->setStrand(U2Strand::Direct);
+                    } 
+                }
                 assert(startPos != -1);
                 int newPos = globalOffset + startPos;
-                LRegion newRegion(region);
+                U2Region newRegion(region);
                 newRegion.startPos = newPos;
                 newLocation.append(newRegion);
             }
             
-            cloned->replaceLocationRegions(newLocation);
+            cloned->replaceRegions(newLocation);
             results.append(cloned);
         }
 
@@ -588,7 +628,7 @@ void LigateFragmentsTask::createDocument( const QByteArray& seq, const QList<Ann
 
 void LigateFragmentsTask::cleanup()
 {
-    if (stateInfo.hasErrors()) {
+    if (stateInfo.hasError()) {
         qDeleteAll(annotations);    
     }
 }
@@ -597,5 +637,7 @@ void LigateFragmentsTask::cleanup()
 
 
 
+
+
 } // U2
 
