@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "EnzymesTests.h"
 
@@ -18,6 +29,7 @@
 #include <U2Core/AnnotationTableObject.h>
 #include <U2Core/DocumentModel.h>
 #include <U2Core/GObjectRelationRoles.h>
+#include <U2Formats/GenbankLocationParser.h>
 
 namespace U2 {
 
@@ -62,18 +74,12 @@ void GTest_FindEnzymes::init(XMLTestFormat *tf, const QDomElement& el) {
     }
     enzymesUrl=env->getVar("COMMON_DATA_DIR")+"/" + enzymesUrl;
 
-    // get region to analyze
-    QString regionStr = el.attribute("region");
+    // get regions to exclude
+    QString regionStr = el.attribute("exclude-regions");
     if (!regionStr.isEmpty()) {
-        QRegExp rx("(\\d+)(..)(\\d+)");
-        if (rx.indexIn(regionStr, 0)!=-1) {
-            region.startPos = rx.cap(1).toInt() - 1;
-            region.len = rx.cap(3).toInt() - region.startPos;
-        }
-        if (region.isEmpty() || region.len < 0) {
-            stateInfo.setError(  QString("Invalid region: '%1'").arg(regionStr) );
-            return;
-        }
+        U2Location location;
+        Genbank::LocationParser::parseLocation(qPrintable(regionStr),regionStr.length(), location);
+        excludedRegions = location->regions;
     }
 
     // get enzymes names to find
@@ -110,7 +116,7 @@ void GTest_FindEnzymes::init(XMLTestFormat *tf, const QDomElement& el) {
         while ((pos = rx2.indexIn(regions, pos)) != -1) {
             int start=rx2.cap(1).toInt();
             int end=rx2.cap(3).toInt();
-            resultsPerEnzyme.insert(enzymeId, LRegion(start-1, end - start + 1));
+            resultsPerEnzyme.insert(enzymeId, U2Region(start-1, end - start + 1));
             pos += rx2.matchedLength();
         }
         if (!resultsPerEnzyme.contains(enzymeId)) {
@@ -121,7 +127,7 @@ void GTest_FindEnzymes::init(XMLTestFormat *tf, const QDomElement& el) {
 }
 
 void GTest_FindEnzymes::prepare() {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
     
@@ -134,10 +140,6 @@ void GTest_FindEnzymes::prepare() {
 
     aObj->addObjectRelation(seqObj, GObjectRelationRole::SEQUENCE);
 
-    if (region.isEmpty()) {
-        region = seqObj->getSequenceRange();
-    }
-
     loadTask = new LoadEnzymeFileTask(enzymesUrl);
     addSubTask(loadTask);
 }
@@ -145,7 +147,7 @@ void GTest_FindEnzymes::prepare() {
 
 QList<Task*> GTest_FindEnzymes::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return res;
     }
     if (subTask!=loadTask || loadTask->enzymes.isEmpty()) {
@@ -163,10 +165,10 @@ QList<Task*> GTest_FindEnzymes::onSubTaskFinished(Task* subTask) {
     }
     
     FindEnzymesTaskConfig cfg;
-    cfg.region.append(region);
     cfg.maxResults = INT_MAX;
     cfg.minHitCount = minHits;
     cfg.maxHitCount = maxHits;
+    cfg.excludedRegions = excludedRegions;
 
     FindEnzymesToAnnotationsTask* t = new FindEnzymesToAnnotationsTask(aObj, seqObj->getDNASequence(), enzymesToSearch, cfg);
     res.append(t);
@@ -174,12 +176,12 @@ QList<Task*> GTest_FindEnzymes::onSubTaskFinished(Task* subTask) {
 }
 
 Task::ReportResult GTest_FindEnzymes::report() {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return Task::ReportResult_Finished;
     }
     //for each enzyme from resultsPerEnzyme check that all annotations are present
     foreach(const QString& enzymeId, resultsPerEnzyme.keys()) {
-        QList<LRegion> regions = resultsPerEnzyme.values(enzymeId);
+        QList<U2Region> regions = resultsPerEnzyme.values(enzymeId);
         AnnotationGroup* ag = aObj->getRootGroup()->getSubgroup(enzymeId, false);
         if (ag == NULL) {
             stateInfo.setError(  QString("Group not found %1").arg(enzymeId) );
@@ -192,7 +194,7 @@ Task::ReportResult GTest_FindEnzymes::report() {
             break;
         }
         foreach(const Annotation* a, anns) {
-            LRegion r = a->getLocation().first();
+            U2Region r = a->getRegions().first();
             if (!regions.contains(r)) {
                 stateInfo.setError( QString("Illegal region! Enzyme :%1, region %2..%3")
                     .arg(enzymeId).arg(r.startPos + 1).arg(r.endPos()) );    
@@ -260,7 +262,7 @@ void GTest_DigestIntoFragments::init(XMLTestFormat *tf, const QDomElement& el) {
 }
 
 void GTest_DigestIntoFragments::prepare() {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
 
@@ -284,7 +286,7 @@ void GTest_DigestIntoFragments::prepare() {
 
 QList<Task*> GTest_DigestIntoFragments::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return res;
     }
     if (subTask!=loadTask || loadTask->enzymes.isEmpty()) {
@@ -300,8 +302,13 @@ QList<Task*> GTest_DigestIntoFragments::onSubTaskFinished(Task* subTask) {
         }
         enzymesToSearch.append(enzyme);
     }
-
-    DigestSequenceTask* t = new DigestSequenceTask(seqObj, aObj, enzymesToSearch,searchForEnzymes);
+    
+    DigestSequenceTask* t = NULL;
+    if (searchForEnzymes) {
+        t = new DigestSequenceTask(seqObj, aObj, enzymesToSearch);
+    } else {
+        t = new DigestSequenceTask(seqObj, aObj, aObj, enzymesToSearch);
+    }
     res.append(t);
     return res;
 }
@@ -352,7 +359,7 @@ void GTest_LigateFragments::init(XMLTestFormat *tf, const QDomElement& el) {
 }
 
 void GTest_LigateFragments::prepare() {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
 
@@ -404,11 +411,13 @@ void GTest_LigateFragments::prepareFragmentsList()
         QStringList nameData = searchedName.split(":");  
         QString fName = nameData.at(1);
         QString fDoc = nameData.at(0);
+        bool inverted = nameData.count() > 2 && nameData.at(2) == "inverted";
         bool found = false;
-        foreach (const DNAFragment& fragment, fragments) {
+        foreach (DNAFragment fragment, fragments) {
             QString name = fragment.getName();
             QString docName = fragment.getSequenceDocName();
             if (name == fName && docName == fDoc) {
+                fragment.setInverted(inverted);
                 targetFragments.append(fragment);
                 found = true;
                 break;
@@ -423,11 +432,11 @@ void GTest_LigateFragments::prepareFragmentsList()
 
 Task::ReportResult GTest_LigateFragments::report()
 {
-    if (hasErrors()) {
+    if (hasError()) {
         return ReportResult_Finished;
     }
 
-    if (ligateTask != NULL && ligateTask->hasErrors()) {
+    if (ligateTask != NULL && ligateTask->hasError()) {
         stateInfo.setError( ligateTask->getError() );
     } else if (!resultDocName.isEmpty()) {
         addContext( resultDocName, ligateTask->getResultDocument() );
