@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "FindEnzymesDialog.h"
 #include "FindEnzymesTask.h"
@@ -24,8 +35,10 @@
 #include <U2Gui/GUIUtils.h>
 #include <U2View/ADVSequenceObjectContext.h>
 #include <U2View/AnnotatedDNAView.h>
+#include <U2View/AutoAnnotationUtils.h>
 #include <U2Core/DNASequenceSelection.h>
 #include <U2Core/DNASequenceObject.h>
+#include <U2Formats/GenbankLocationParser.h>
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QFileInfo>
@@ -43,8 +56,6 @@
 namespace U2 {
 
 
-static Logger log(ULOG_ENZYME_PLUGIN);
-
 QList<SEnzymeData>   EnzymesSelectorWidget::loadedEnzymes;
 QSet<QString>        EnzymesSelectorWidget::lastSelection;
 
@@ -74,7 +85,7 @@ EnzymesSelectorWidget::EnzymesSelectorWidget() {
     connect(enzymeInfo, SIGNAL(clicked()), SLOT(sl_openDBPage()));
 
     if (loadedEnzymes.isEmpty()) {
-        QString lastUsedFile = AppContext::getSettings()->getValue(DATA_FILE_KEY).toString();
+        QString lastUsedFile = AppContext::getSettings()->getValue(EnzymeSettings::DATA_FILE_KEY).toString();
         loadFile(lastUsedFile);
     } else {
         setEnzymesList(loadedEnzymes);
@@ -82,23 +93,21 @@ EnzymesSelectorWidget::EnzymesSelectorWidget() {
 }
 
 EnzymesSelectorWidget::~EnzymesSelectorWidget() {
-    QStringList sl(lastSelection.toList());
-    AppContext::getSettings()->setValue(LAST_SELECTION_KEY, sl.join(SEP));
+    saveSettings();
 }
 
-void EnzymesSelectorWidget::initSettings() {
-    QString dir = DialogUtils::getLastOpenFileDir(DATA_DIR_KEY);
+void EnzymesSelectorWidget::setupSettings() {
+    QString dir = DialogUtils::getLastOpenFileDir(EnzymeSettings::DATA_DIR_KEY);
     if (dir.isEmpty() || !QDir(dir).exists()) {
         dir = QDir::searchPaths( PATH_PREFIX_DATA ).first() + "/enzymes/";
-        DialogUtils::setLastOpenFileDir(dir, DATA_DIR_KEY);
+        DialogUtils::setLastOpenFileDir(dir, EnzymeSettings::DATA_DIR_KEY);
     }
-    QString lastEnzFile = AppContext::getSettings()->getValue(DATA_FILE_KEY).toString();
+    QString lastEnzFile = AppContext::getSettings()->getValue(EnzymeSettings::DATA_FILE_KEY).toString();
     if (lastEnzFile.isEmpty() || !QFile::exists(lastEnzFile)) {
-        lastEnzFile = dir + DEFAULT_ENZYMES_FILE;
-        AppContext::getSettings()->setValue(DATA_FILE_KEY, lastEnzFile);
+        lastEnzFile = dir + "/" + DEFAULT_ENZYMES_FILE;
+        AppContext::getSettings()->setValue(EnzymeSettings::DATA_FILE_KEY, lastEnzFile);
     }
-    QString selStr = AppContext::getSettings()->getValue(LAST_SELECTION_KEY).toString();
-    lastSelection = selStr.split(SEP).toSet();
+    initSelection();
 }
 
 QList<SEnzymeData> EnzymesSelectorWidget::getSelectedEnzymes() {
@@ -120,7 +129,7 @@ QList<SEnzymeData> EnzymesSelectorWidget::getSelectedEnzymes() {
 QList<SEnzymeData> EnzymesSelectorWidget::getLoadedEnzymes() {
     if (loadedEnzymes.isEmpty()) {
         TaskStateInfo ti;
-        QString lastUsedFile = AppContext::getSettings()->getValue(DATA_FILE_KEY).toString();
+        QString lastUsedFile = AppContext::getSettings()->getValue(EnzymeSettings::DATA_FILE_KEY).toString();
         loadedEnzymes = EnzymesIO::readEnzymes(lastUsedFile, ti);
     }
     return loadedEnzymes;
@@ -136,19 +145,19 @@ void EnzymesSelectorWidget::loadFile(const QString& url) {
         GTIMER(c1,t1,"FindEnzymesDialog::loadFile [EnzymesIO::readEnzymes]");
         enzymes = EnzymesIO::readEnzymes(url, ti);
     }
-    if (ti.hasErrors()) {
+    if (ti.hasError()) {
         if (isVisible()) {
             QMessageBox::critical(NULL, tr("Error"), ti.getError());
         } else  {
-            log.error(ti.getError());
+            ioLog.error(ti.getError());
         }
         return;
     }
     if (!enzymes.isEmpty()) {
-        if (AppContext::getSettings()->getValue(DATA_FILE_KEY).toString() != url) {
+        if (AppContext::getSettings()->getValue(EnzymeSettings::DATA_FILE_KEY).toString() != url) {
             lastSelection.clear();
         }
-        AppContext::getSettings()->setValue(DATA_FILE_KEY, url);
+        AppContext::getSettings()->setValue(EnzymeSettings::DATA_FILE_KEY, url);
     }
 
     setEnzymesList(enzymes);
@@ -156,7 +165,7 @@ void EnzymesSelectorWidget::loadFile(const QString& url) {
 
 void EnzymesSelectorWidget::saveFile(const QString& url) {
     TaskStateInfo ti;
-    QString source = AppContext::getSettings()->getValue(DATA_FILE_KEY).toString();
+    QString source = AppContext::getSettings()->getValue(EnzymeSettings::DATA_FILE_KEY).toString();
 
     GTIMER(c1,t1,"FindEnzymesDialog::saveFile [EnzymesIO::writeEnzymes]");
 
@@ -174,11 +183,11 @@ void EnzymesSelectorWidget::saveFile(const QString& url) {
 
     EnzymesIO::writeEnzymes(url, source, enzymes, ti);
 
-    if (ti.hasErrors()) {
+    if (ti.hasError()) {
         if (isVisible()) {
             QMessageBox::critical(NULL, tr("Error"), ti.getError());
         } else  {
-            log.error(ti.getError());
+            uiLog.error(ti.getError());
         }
         return;
     }
@@ -261,7 +270,7 @@ void EnzymesSelectorWidget::updateStatus() {
 }
 
 void EnzymesSelectorWidget::sl_selectFile() {
-    LastOpenDirHelper dir(DATA_DIR_KEY);
+    LastOpenDirHelper dir(EnzymeSettings::DATA_DIR_KEY);
     dir.url = QFileDialog::getOpenFileName(this, tr("Select enzyme database file"), dir.dir, EnzymesIO::getFileDialogFilter());
     if (!dir.url.isEmpty()) {
         loadFile(dir.url);
@@ -335,7 +344,7 @@ void EnzymesSelectorWidget::sl_inverseSelection() {
 }
 
 void EnzymesSelectorWidget::sl_saveSelectionToFile() {
-    LastOpenDirHelper dir(DATA_DIR_KEY);
+    LastOpenDirHelper dir(EnzymeSettings::DATA_DIR_KEY);
     dir.url = QFileDialog::getSaveFileName(this, tr("Select enzyme database file"), dir.dir, EnzymesIO::getFileDialogFilter());
     if (!dir.url.isEmpty()) {
         saveFile(dir.url);
@@ -380,24 +389,27 @@ int EnzymesSelectorWidget::getNumSelected()
     return nChecked;
 }
 
+void EnzymesSelectorWidget::saveSettings()
+{
+    QStringList sl(lastSelection.toList());
+    if (!sl.isEmpty()) {
+        AppContext::getSettings()->setValue(EnzymeSettings::LAST_SELECTION, sl.join(ENZYME_LIST_SEPARATOR));
+    }
+}
+
+void EnzymesSelectorWidget::initSelection()
+{
+    QString selStr = AppContext::getSettings()->getValue(EnzymeSettings::LAST_SELECTION).toString();
+    if (selStr.isEmpty()) {
+        selStr = EnzymeSettings::COMMON_ENZYMES;
+    }
+    lastSelection = selStr.split(ENZYME_LIST_SEPARATOR).toSet();
+}
+
 FindEnzymesDialog::FindEnzymesDialog(ADVSequenceObjectContext* sctx)
 : QDialog(sctx->getAnnotatedDNAView()->getWidget()), seqCtx(sctx) {
     setupUi(this);
 
-    CreateAnnotationModel acm;
-    acm.sequenceObjectRef = GObjectReference(sctx->getSequenceGObject());
-    acm.hideAnnotationName = true;
-    acm.hideLocation = true;
-    acm.data->name = ANNOTATION_GROUP_ENZYME;
-    acm.sequenceLen = sctx->getSequenceObject()->getSequenceLen();
-    ac = new CreateAnnotationWidgetController(acm, this);
-    QWidget* caw = ac->getWidget();    
-    QVBoxLayout* l = new QVBoxLayout();
-    l->setMargin(0);
-    l->addWidget(caw);
-    annotationsWidget->setLayout(l);
-    annotationsWidget->setMinimumSize(caw->layout()->minimumSize());
-
     circularButton->setChecked(seqCtx->getSequenceObject()->isCircular());
 
     maxHitSB->setMaximum(INT_MAX);
@@ -406,12 +418,11 @@ FindEnzymesDialog::FindEnzymesDialog(ADVSequenceObjectContext* sctx)
     maxHitSB->setMinimum(ANY_VALUE);
     minHitSB->setMinimum(ANY_VALUE);
 
-    minHitSB->setValue(1);
-    maxHitSB->setValue(2);
-   
     sbRangeStart->setMaximum( seqCtx->getSequenceLen() );
     sbRangeEnd->setMaximum( seqCtx->getSequenceLen() );
 
+    initSettings();
+
     QVBoxLayout* vl = new QVBoxLayout();
     enzSel = new EnzymesSelectorWidget();
     vl->setMargin(0);
@@ -420,9 +431,9 @@ FindEnzymesDialog::FindEnzymesDialog(ADVSequenceObjectContext* sctx)
     enzymesSelectorWidget->setMinimumSize(enzSel->size());
 
     connect(enzSel, SIGNAL(si_selectionModified(int,int)), SLOT(sl_onSelectionModified(int,int)));
+    connect(fillRangeButton, SIGNAL(clicked()), SLOT(sl_onFillRangeButtonClicked()));
     sl_onSelectionModified( enzSel->getTotalNumber(),enzSel->getNumSelected());
     
-    
 }
 
 #define MAX_ENZYMES_TO_FIND 100*1000
@@ -435,13 +446,17 @@ void FindEnzymesDialog::accept() {
     QList<SEnzymeData> selectedEnzymes = enzSel->getSelectedEnzymes();
     
     if (selectedEnzymes.isEmpty()) {
-        QMessageBox::critical(this, tr("Error!"), tr("No enzymes selected!"));
-        return;
-    }
-    
-    QString err = ac->validate();
-    if (!err.isEmpty()) {
-        QMessageBox::critical(this, tr("Error!"), err);
+        int ret = QMessageBox::question(this, windowTitle(), 
+            tr("<html><body align=\"center\">No enzymes are selected!\
+                Do you want to turn off <br>enzymes annotations highlighting?</body></html>"),
+            QMessageBox::Yes, QMessageBox::No );
+        if (ret == QMessageBox::Yes) {
+            QAction* toggleAction = AutoAnnotationUtils::findAutoAnnotationsToggleAction(seqCtx, ANNOTATION_GROUP_ENZYME);
+            if (toggleAction) {
+                toggleAction->setChecked(false);
+            }
+            QDialog::accept();
+        }
         return;
     }
     
@@ -457,45 +472,89 @@ void FindEnzymesDialog::accept() {
         QMessageBox::critical(this, tr("Error!"), tr("Minimum hit value must be lesser or equal then maximum!"));
         return;
     }
-
-    QList<LRegion> range;
-    if (rbSequenceRange->isChecked()) {
-        range.append( LRegion(0, seqCtx->getSequenceLen()) );
-    } else if (rbSelectionRange->isChecked() && !seqCtx->getSequenceSelection()->getSelectedRegions().isEmpty()) {
-        range = seqCtx->getSequenceSelection()->getSelectedRegions();
-    } else {
-        LRegion r;
-        r.startPos = qMin(sbRangeStart->value(), sbRangeEnd->value());
-        r.len = qMax(sbRangeStart->value(), sbRangeEnd->value()) - r.startPos;
-        if (r.len == 0) {
-            QMessageBox::critical(this, tr("Error!"), tr("Invalid range!"));
-            sbRangeStart->setFocus();
-            return;
-        }
-        range.append(r);
-    }
-    ac->prepareAnnotationObject();
-    const CreateAnnotationModel& m = ac->getModel();
-    AnnotationTableObject* obj = m.getAnnotationObject();
-    QString groupName = m.groupName;
-    assert(!groupName.isEmpty() && obj!=NULL);
     
-    FindEnzymesTaskConfig cfg;
-
-    cfg.circular = circularButton->isChecked();
-    cfg.groupName = groupName;
-    cfg.region = range;
-    cfg.maxResults = MAX_ENZYMES_TO_FIND;
-    cfg.maxHitCount = maxHitVal;
-    cfg.minHitCount = minHitVal;
-
-    FindEnzymesToAnnotationsTask* task = new FindEnzymesToAnnotationsTask(obj,  seqCtx->getSequenceObject()->getDNASequence(),
-                                                    selectedEnzymes, cfg); 
-    AppContext::getTaskScheduler()->registerTopLevelTask(task);
-  
+    saveSettings();
+    
+    AutoAnnotationUtils::triggerAutoAnnotationsUpdate(seqCtx, ANNOTATION_GROUP_ENZYME);
+    
     QDialog::accept();
 }
 
+
+void FindEnzymesDialog::initSettings()
+{
+    EnzymesSelectorWidget::initSelection();
+    bool useHitCountControl = AppContext::getSettings()->getValue(EnzymeSettings::ENABLE_HIT_COUNT, false).toBool();
+    int minHitValue = AppContext::getSettings()->getValue(EnzymeSettings::MIN_HIT_VALUE, 1).toInt();
+    int maxHitValue = AppContext::getSettings()->getValue(EnzymeSettings::MAX_HIT_VALUE, 2).toInt();
+    
+    QString exludedRegionStr = AppContext::getSettings()->getValue(EnzymeSettings::NON_CUT_REGION, "").toString();
+    bool excludeRegionOn = false;
+    if (!exludedRegionStr.isEmpty()) {
+        U2Location location;
+        Genbank::LocationParser::parseLocation(qPrintable(exludedRegionStr),exludedRegionStr.length(), location);
+        if (!location->isEmpty()) {
+            excludeRegionOn = true;
+            const U2Region& range = location->regions.first();
+            sbRangeStart->setValue(range.startPos + 1);
+            sbRangeEnd->setValue(range.endPos());
+        }
+    }
+    
+    excludeRegionBox->setChecked(excludeRegionOn);
+
+    filterGroupBox->setChecked(useHitCountControl);
+    if (useHitCountControl) {
+        minHitSB->setValue(minHitValue);
+        maxHitSB->setValue(maxHitValue);
+    } else {
+        minHitSB->setValue(1);
+        maxHitSB->setValue(2);
+    }
+}
+
+void FindEnzymesDialog::saveSettings()
+{
+    AppContext::getSettings()->setValue(EnzymeSettings::ENABLE_HIT_COUNT, filterGroupBox->isChecked());
+    if (filterGroupBox->isChecked()) {
+        AppContext::getSettings()->setValue(EnzymeSettings::MIN_HIT_VALUE, minHitSB->value());
+        AppContext::getSettings()->setValue(EnzymeSettings::MAX_HIT_VALUE, maxHitSB->value());
+    } else {
+        AppContext::getSettings()->setValue(EnzymeSettings::MIN_HIT_VALUE, 1);
+        AppContext::getSettings()->setValue(EnzymeSettings::MAX_HIT_VALUE, INT_MAX);
+    }
+
+    QVector<U2Region> range;
+    if (excludeRegionBox->isChecked()) {
+        U2Region r;
+        r.startPos = qMin(sbRangeStart->value(), sbRangeEnd->value()) - 1;
+        r.length = qMax(sbRangeStart->value(), sbRangeEnd->value()) - r.startPos;
+        if (r.length != 0) {
+            range.append(r);
+        }
+    }
+    AppContext::getSettings()->setValue(EnzymeSettings::NON_CUT_REGION, QVariant::fromValue(range) );
+    
+    enzSel->saveSettings();
+
+}
+
+void FindEnzymesDialog::initDefaultSettings()
+{
+    AppContext::getSettings()->setValue(EnzymeSettings::NON_CUT_REGION, "" );
+}
+
+void FindEnzymesDialog::sl_onFillRangeButtonClicked()
+{
+    DNASequenceSelection* selection = seqCtx->getSequenceSelection();
+    if (!selection->isEmpty()) {
+        const U2Region& range = selection->getSelectedRegions().first();
+        sbRangeStart->setValue(range.startPos + 1);
+        sbRangeEnd->setValue(range.endPos());
+    }
+}
+
+
 //////////////////////////////////////////////////////////////////////////
 // Tree item
 EnzymeTreeItem::EnzymeTreeItem(const SEnzymeData& ed) 
