@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_ENZYMES_DIALOG_H_
 #define _U2_ENZYMES_DIALOG_H_
@@ -16,7 +27,7 @@
 #include <ui/ui_EnzymesSelectorWidget.h>
 #include <ui/ui_FindEnzymesDialog.h>
 
-#include "EnzymeModel.h"
+#include <U2Algorithm/EnzymeModel.h>
 
 #include <QtGui/QTreeWidget>
 #include <QtGui/QTreeWidgetItem>
@@ -33,12 +44,14 @@ public:
     EnzymesSelectorWidget();
     ~EnzymesSelectorWidget();
 
-    static void initSettings();
+    static void setupSettings();
+    static void saveSettings();
+    static void initSelection();
     static QList<SEnzymeData> getLoadedEnzymes();
     QList<SEnzymeData> getSelectedEnzymes();
     int getNumSelected();
     int getTotalNumber() { return totalEnzymes; }
-   
+       
     
 signals:
     void si_selectionModified(int,int);
@@ -73,13 +86,17 @@ class FindEnzymesDialog : public QDialog, public Ui_FindEnzymesDialog {
     Q_OBJECT
 public:
     FindEnzymesDialog(ADVSequenceObjectContext* ctx);
+    static void initDefaultSettings();
     virtual void accept();
 private slots:
     void sl_onSelectionModified(int total, int nChecked);
+    void sl_onFillRangeButtonClicked();
 private:
+    void initSettings();
+    void saveSettings();
     ADVSequenceObjectContext*           seqCtx;
-    CreateAnnotationWidgetController*   ac;
-    EnzymesSelectorWidget* enzSel;
+    EnzymesSelectorWidget*              enzSel;
+    
 };
 
 class EnzymeTreeItem;
@@ -99,11 +116,7 @@ public:
     bool operator<(const QTreeWidgetItem & other) const;
 };
 
-#define DATA_DIR_KEY            QString("enzymes")
-#define DATA_FILE_KEY           QString("plugin_enzymes/lastFile")
-#define LAST_SELECTION_KEY      QString("plugin_enzymes/selection")
-#define SEP                     (",")
-#define ANY_VALUE -1
+#define ANY_VALUE   -1
 
 
 } //namespace
