@@ -1,19 +1,32 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ExternalToolSupportSettingsController.h"
 #include "ExternalToolSupportSettings.h"
 #include "utils/ExternalToolValidateTask.h"
 
 #include <U2Core/AppContext.h>
+#include <U2Core/L10n.h>
 #include <U2Misc/DialogUtils.h>
+#include <U2Gui/GUIUtils.h>
 #include <QtGui>
 #include <blast/BlastAllSupport.h>
 #include <blast/FormatDBSupport.h>
@@ -98,9 +111,13 @@ QWidget* ExternalToolSupportSettingsPageWidget::createPathEditor(QWidget *parent
 
     return widget;
 }
+void ExternalToolSupportSettingsPageWidget::sl_linkActivated(QString url){
+    GUIUtils::runWebBrowser(url);
+}
 void ExternalToolSupportSettingsPageWidget::setState(AppSettingsGUIPageState* s) {
     ExternalToolSupportSettingsPageState* state = qobject_cast<ExternalToolSupportSettingsPageState*>(s);
-
+    connect(selectToolPackButton, SIGNAL(clicked()), this, SLOT(sl_onBrowseToolPackPath()));
+    connect(linkLabel,SIGNAL(linkActivated(QString)),this,SLOT(sl_linkActivated(QString)));
     foreach(ExternalTool* tool, state->externalTools){
         ExternalToolInfo info;
         info.name=tool->getName();
@@ -271,7 +288,7 @@ void ExternalToolSupportSettingsPageWidget::sl_onBrowseToolKitPath(){
     LastOpenDirHelper lod("toolkit path");
     QString dir;
 
-    lod.url = dir = QFileDialog::getExistingDirectory(this, tr("Choose Directory"), lod.dir, QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
+    lod.url = dir = QFileDialog::getExistingDirectory(this, tr("Choose Directory With Executables"), lod.dir, QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
     if (!dir.isEmpty()) {
         assert(treeWidget->selectedItems().isEmpty()==0);
         QString toolKitName=treeWidget->selectedItems().first()->text(0);
@@ -283,22 +300,86 @@ void ExternalToolSupportSettingsPageWidget::sl_onBrowseToolKitPath(){
                     QWidget* itemWid=treeWidget->itemWidget(item,1);
                     PathLineEdit* lineEdit=itemWid->findChild<PathLineEdit*>("PathLineEdit");
                     if(lineEdit->text().isEmpty()){
-                        QString path=QDir::toNativeSeparators(dir+"/"+AppContext::getExternalToolRegistry()->getByName(item->text(0))->getExecutableFileName());
-                        lineEdit->setText(path);
-                        lineEdit->setModified(false);
-                        externalToolsInfo[item->text(0)].path=path;
-                        QToolButton* clearToolPathButton = itemWid->findChild<QToolButton*>("ClearToolPathButton");
-                        assert(clearToolPathButton);
-                        clearToolPathButton->setEnabled(true);
-                        ExternalToolValidateTask* validateTask=new ExternalToolValidateTask(item->text(0), path);
-                        connect(validateTask,SIGNAL(si_stateChanged()),SLOT(sl_validateTaskStateChanged()));
-                        AppContext::getTaskScheduler()->registerTopLevelTask(validateTask);
+                        QDirIterator it(dir,QDirIterator::Subdirectories);
+                        bool fileNotFound=true;
+                        QString executableFileName=AppContext::getExternalToolRegistry()->getByName(item->text(0))->getExecutableFileName();
+                        while (it.hasNext()&&fileNotFound) {
+                            QFileInfo info(it.filePath()+"/"+executableFileName);
+                            if(info.exists() && info.isFile() && info.isExecutable()){
+                                QString path=QDir::toNativeSeparators(it.filePath()+"/"+executableFileName);
+                                lineEdit->setText(path);
+                                lineEdit->setModified(false);
+                                externalToolsInfo[item->text(0)].path=path;
+                                QToolButton* clearToolPathButton = itemWid->findChild<QToolButton*>("ClearToolPathButton");
+                                assert(clearToolPathButton);
+                                clearToolPathButton->setEnabled(true);
+                                ExternalToolValidateTask* validateTask=new ExternalToolValidateTask(item->text(0), path);
+                                connect(validateTask,SIGNAL(si_stateChanged()),SLOT(sl_validateTaskStateChanged()));
+                                AppContext::getTaskScheduler()->registerTopLevelTask(validateTask);
+                                fileNotFound=false;
+                            }
+                            it.next();
+                        }
                     }
                 }
             }
         }
     }
 }
+void ExternalToolSupportSettingsPageWidget::sl_onBrowseToolPackPath(){
+    LastOpenDirHelper lod("toolpack path");
+    QString dirPath;
+    bool isPathValid=false;
+    lod.url = dirPath = QFileDialog::getExistingDirectory(this, tr("Choose Directory With External Tools Pack"), lod.dir, QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
+    if (!dirPath.isEmpty()) {
+        QDir dir=QDir(dirPath);
+        QList<QTreeWidgetItem*> listOfItems=treeWidget->findItems("",Qt::MatchContains|Qt::MatchRecursive);
+        assert(listOfItems.length()!=0);
+        foreach(QString dirName, dir.entryList(QDir::Dirs)){
+            foreach(QTreeWidgetItem* item, listOfItems){
+                if(AppContext::getExternalToolRegistry()->getByName(item->text(0)) != NULL){
+                    QString toolKitName=AppContext::getExternalToolRegistry()->getByName(item->text(0))->getToolKitName();
+                    if(toolKitName=="BLAST" && dirName.contains(toolKitName,Qt::CaseInsensitive) && dirName.contains("BLAST+",Qt::CaseInsensitive)){
+
+                    }else{
+                        if(dirName.contains(toolKitName,Qt::CaseInsensitive)){
+                            isPathValid=true;
+                            QWidget* itemWid=treeWidget->itemWidget(item,1);
+                            PathLineEdit* lineEdit=itemWid->findChild<PathLineEdit*>("PathLineEdit");
+                            if(lineEdit->text().isEmpty()){
+                                QDirIterator it(dirPath+"/"+dirName,QDirIterator::Subdirectories);
+                                bool fileNotFound=true;
+                                QString executableFileName=AppContext::getExternalToolRegistry()->getByName(item->text(0))->getExecutableFileName();
+                                while (it.hasNext()&&fileNotFound) {
+                                    QFileInfo info(it.filePath()+"/"+executableFileName);
+                                    if(info.exists() && info.isFile() && info.isExecutable()){
+                                        QString path=QDir::toNativeSeparators(it.filePath()+"/"+executableFileName);
+                                        lineEdit->setText(path);
+                                        lineEdit->setModified(false);
+                                        externalToolsInfo[item->text(0)].path=path;
+                                        QToolButton* clearToolPathButton = itemWid->findChild<QToolButton*>("ClearToolPathButton");
+                                        assert(clearToolPathButton);
+                                        clearToolPathButton->setEnabled(true);
+                                        ExternalToolValidateTask* validateTask=new ExternalToolValidateTask(item->text(0), path);
+                                        connect(validateTask,SIGNAL(si_stateChanged()),SLOT(sl_validateTaskStateChanged()));
+                                        AppContext::getTaskScheduler()->registerTopLevelTask(validateTask);
+                                        fileNotFound=false;
+                                    }
+                                    it.next();
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+        }
+        if(!isPathValid){
+            QMessageBox::warning(this, L10N::warningTitle(),
+                                            tr("Not a valid external tools directory"),
+                                            QMessageBox::Ok);
+        }
+    }
+}
 ////////////////////////////////////////
 //PathLineEdit
 void PathLineEdit::sl_onBrowse() {
