@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "BlastPlusSupportRunDialog.h"
 #include "BlastPlusSupport.h"
@@ -154,59 +165,11 @@ void BlastPlusSupportRunDialog::sl_runQuery(){
     }
     settings.groupName=ca_c->getModel().groupName;
 
-    settings.databaseNameAndPath=databasePathLineEdit->text()+"/"+baseNameLineEdit->text();
-    settings.expectValue=evalueSpinBox->value();
-    settings.wordSize=wordSizeSpinBox->value();
-    settings.megablast=megablastCheckBox->isChecked();
+    getSettings(settings);
     settings.alphabet=dnaso->getAlphabet();
-    settings.numberOfHits=numberOfHitsSpinBox->value();
-    settings.numberOfProcessors=numberOfCPUSpinBox->value();
-
-    settings.gapOpenCost=costsComboBox->currentText().split(" ").at(0).toInt();
-    settings.gapExtendCost=costsComboBox->currentText().split(" ").at(1).toInt();
-    //setup filters
-    if(lowComplexityFilterCheckBox->isChecked()){
-        settings.filter="L";
-    }
-    if(repeatsCheckBox->isChecked()){
-        settings.filter=settings.filter.isEmpty() ? "R" : settings.filter+"; R";
-    }
-//    if(lowerCaseCheckBox->isChecked()){
-//        settings.filter=settings.filter.isEmpty() ? "???" : settings.filter+"; ???";
-//    }
-    if(lookupMaskCheckBox->isChecked()){
-        settings.filter=settings.filter.isEmpty() ? "m" : "m "+settings.filter;
-    }
-
-    if(settings.isNucleotideSeq){
-        if((((scoresComboBox->currentText() == "1 -4") || (scoresComboBox->currentText() == "1 -3")) && costsComboBox->currentText()=="2 2") || //-G 2 -E 2
-            ((scoresComboBox->currentText() == "1 -2") && costsComboBox->currentText()=="2 2") || //-G 2 -E 2
-            ((scoresComboBox->currentText() == "1 -1") && costsComboBox->currentText()=="4 2") || //-G 4 -E 2
-            (((scoresComboBox->currentText() == "2 -7") || (scoresComboBox->currentText() == "2 -5"))&& costsComboBox->currentText()=="4 4") || //-G 4 -E 4
-            ((scoresComboBox->currentText() == "2 -3") && costsComboBox->currentText()=="6 4") || //-G 6 -E 4
-            (((scoresComboBox->currentText() == "4 -5") || (scoresComboBox->currentText() == "5 -4")) && costsComboBox->currentText()=="12 8"))//-G 12 -E 8
-        {
-            settings.isDefaultCosts=true;
-        }else{
-            settings.isDefaultCosts=false;
-        }
-        settings.isDefautScores=(scoresComboBox->currentText() == "1 -3");
-    }else{
-        if(((matrixComboBox->currentText() == "PAM30") && costsComboBox->currentText()=="9 1") || //-G 9 -E 1
-                ((matrixComboBox->currentText() == "PAM70") && costsComboBox->currentText()=="10 1") || //-G 10 -E 1
-                ((matrixComboBox->currentText() == "BLOSUM45") && costsComboBox->currentText()=="15 2") ||
-                ((matrixComboBox->currentText() == "BLOSUM62") && costsComboBox->currentText()=="11 1") ||
-                ((matrixComboBox->currentText() == "BLOSUM80") && costsComboBox->currentText()=="10 1"))
-        {
-            settings.isDefaultCosts=true;
-        }else{
-            settings.isDefaultCosts=false;
-        }
-        settings.isDefaultMatrix=(matrixComboBox->currentText() == "BLOSUM62");
-
-    }
     lastDBPath=databasePathLineEdit->text();
     lastDBName=baseNameLineEdit->text();
+    settings.outputType=5;//By default set output file format to xml
     accept();
 }
 ////////////////////////////////////////
@@ -258,8 +221,7 @@ void BlastPlusWithExtFileSpecifySupportRunDialog::sl_inputFileLineEditChanged(co
             Project* proj = AppContext::getProject();
             if (proj == NULL) {
                 wasNoOpenProject=true;
-                QList<GUrl> emptyList;
-                tasks.append( AppContext::getProjectLoader()->openProjectTask(emptyList, false) );
+                tasks.append( AppContext::getProjectLoader()->createNewProjectTask());
             }
 
             DocumentFormatConstraints c;
@@ -287,7 +249,7 @@ void BlastPlusWithExtFileSpecifySupportRunDialog::sl_inputFileLineEditChanged(co
 }
 void BlastPlusWithExtFileSpecifySupportRunDialog::sl_inputFileLoadTaskStateChanged(){
     LoadDocumentTask* s=qobject_cast<LoadDocumentTask*>(sender());
-    if((s->isFinished())&&(!s->hasErrors())){
+    if((s->isFinished())&&(!s->hasError())){
         int numOfSequences=0;
         foreach(GObject* gobj, s->getDocument()->getObjects()){
             if(gobj->getGObjectType()==GObjectTypes::SEQUENCE){
@@ -413,66 +375,14 @@ void BlastPlusWithExtFileSpecifySupportRunDialog::sl_runQuery(){
             settingsList[i].aobj = new AnnotationTableObject(sequencesRefList[i].objName+" annotations");
             settingsList[i].aobj->addObjectRelation(GObjectRelation(sequencesRefList[i], GObjectRelationRole::SEQUENCE));
         } else {
-            assert(NULL);//allways created new document for annotations
+            assert(NULL);//always created new document for annotations
 //            ca_c->prepareAnnotationObject();
 //            settings.aobj = caControllers.at(i)->getModel().getAnnotationObject();
         }
         settingsList[i].groupName=ca_c->getModel().groupName;
 
-        settingsList[i].databaseNameAndPath=databasePathLineEdit->text()+"/"+baseNameLineEdit->text();
-        settingsList[i].expectValue=evalueSpinBox->value();
-        settingsList[i].wordSize=wordSizeSpinBox->value();
-        settingsList[i].megablast=megablastCheckBox->isChecked();
-    //    settings.alphabet=dnaso->getAlphabet();
-        settingsList[i].numberOfHits=numberOfHitsSpinBox->value();
-        settingsList[i].numberOfProcessors=numberOfCPUSpinBox->value();
-
-        settingsList[i].gapOpenCost=costsComboBox->currentText().split(" ").at(0).toInt();
-        settingsList[i].gapExtendCost=costsComboBox->currentText().split(" ").at(1).toInt();
-        //setup filters
-        if(lowComplexityFilterCheckBox->isChecked()){
-            settingsList[i].filter="L";
-        }
-        if(repeatsCheckBox->isChecked()){
-            settingsList[i].filter=settingsList[i].filter.isEmpty() ? "R" : settingsList[i].filter+"; R";
-        }
-    //    if(lowerCaseCheckBox->isChecked()){
-    //        settings.filter=settings.filter.isEmpty() ? "???" : settings.filter+"; ???";
-    //    }
-        if(lookupMaskCheckBox->isChecked()){
-            settingsList[i].filter=settingsList[i].filter.isEmpty() ? "m" : "m "+settingsList[i].filter;
-        }
-
-        if(settingsList[i].isNucleotideSeq){
-            if((((scoresComboBox->currentText() == "1 -4") || (scoresComboBox->currentText() == "1 -3")) && costsComboBox->currentText()=="2 2") || //-G 2 -E 2
-                ((scoresComboBox->currentText() == "1 -2") && costsComboBox->currentText()=="2 2") || //-G 2 -E 2
-                ((scoresComboBox->currentText() == "1 -1") && costsComboBox->currentText()=="4 2") || //-G 4 -E 2
-                (((scoresComboBox->currentText() == "2 -7") || (scoresComboBox->currentText() == "2 -5"))&& costsComboBox->currentText()=="4 4") || //-G 4 -E 4
-                ((scoresComboBox->currentText() == "2 -3") && costsComboBox->currentText()=="6 4") || //-G 6 -E 4
-                (((scoresComboBox->currentText() == "4 -5") || (scoresComboBox->currentText() == "5 -4")) && costsComboBox->currentText()=="12 8"))//-G 12 -E 8
-            {
-                settingsList[i].isDefaultCosts=true;
-            }else{
-                settingsList[i].isDefaultCosts=false;
-                settingsList[i].matchReward=scoresComboBox->currentText().split(" ").at(0).toInt();
-                settingsList[i].mismatchPenalty=scoresComboBox->currentText().split(" ").at(1).toInt();
-            }
-            settingsList[i].isDefautScores=(scoresComboBox->currentText() == "1 -3");
-        }else{
-            if(((matrixComboBox->currentText() == "PAM30") && costsComboBox->currentText()=="9 1") || //-G 9 -E 1
-                    ((matrixComboBox->currentText() == "PAM70") && costsComboBox->currentText()=="10 1") || //-G 10 -E 1
-                    ((matrixComboBox->currentText() == "BLOSUM45") && costsComboBox->currentText()=="15 2") ||
-                    ((matrixComboBox->currentText() == "BLOSUM62") && costsComboBox->currentText()=="11 1") ||
-                    ((matrixComboBox->currentText() == "BLOSUM80") && costsComboBox->currentText()=="10 1"))
-            {
-                settingsList[i].isDefaultCosts=true;
-            }else{
-                settingsList[i].isDefaultCosts=false;
-                settingsList[i].matrix=matrixComboBox->currentText();
-            }
-            settingsList[i].isDefaultMatrix=(matrixComboBox->currentText() == "BLOSUM62");
-        }
-        settingsList[i].programName=programName->currentText();
+        getSettings(settingsList[i]);
+        settingsList[i].outputType = 5;//By default set output file format to xml
     }
     bool docAlreadyInProject=false;
     Project* proj=AppContext::getProject();
@@ -482,7 +392,8 @@ void BlastPlusWithExtFileSpecifySupportRunDialog::sl_runQuery(){
         }
     }
     if(!docAlreadyInProject){
-        AppContext::getTaskScheduler()->registerTopLevelTask(AppContext::getProjectLoader()->openProjectTask(inputFileLineEdit->text(),false));
+        QString url = inputFileLineEdit->text();
+        AppContext::getTaskScheduler()->registerTopLevelTask(AppContext::getProjectLoader()->openWithProjectTask(url));
     }
     lastDBPath=databasePathLineEdit->text();
     lastDBName=baseNameLineEdit->text();
