@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_ORFDIALOG_H_
 #define _U2_ORFDIALOG_H_
@@ -14,7 +25,7 @@
 #include "ui/ui_ORFDialogUI.h"
 
 #include <U2Core/global.h>
-#include <U2Core/LRegion.h>
+#include <U2Core/U2Region.h>
 
 #include <QtCore/QList>
 #include <QtGui/QTreeWidget>
@@ -22,6 +33,8 @@
 #include <QtGui/QCloseEvent>
 #include <QtCore/QTimer>
 
+#include <U2Algorithm/ORFAlgorithmTask.h>
+
 namespace U2 {
 
 class ADVSequenceObjectContext;
@@ -37,6 +50,7 @@ public:
 
 public slots:
     virtual void reject();
+    virtual void accept();
 
 protected:
     bool eventFilter(QObject *obj, QEvent *ev);
@@ -47,7 +61,6 @@ private slots:
     void sl_onSaveAnnotations();
     void sl_onClearList();
     void sl_onFindAll();
-    void sl_onClose();
     void sl_onRangeToSelection();
     void sl_onRangeToPanView();
     void sl_onRangeToSequence();
@@ -64,21 +77,24 @@ private:
     void updateState();
     void updateStatus();
     void tunePercentBox();
+    void initSettings();
+    void getSettings(ORFAlgorithmSettings& s);
     
     void runTask();
 
     void importResults();
 
-    LRegion getCompleteSearchRegion() const;
+    U2Region getCompleteSearchRegion() const;
+    ORFAlgorithmStrand getAlgStrand() const;
 
 private:
     ADVSequenceObjectContext* ctx;
     DNASequenceObject* sequence;
 
-    LRegion panViewSelection;
+    U2Region panViewSelection;
     ORFFindTask* task;
     QTimer* timer;
-    LRegion initialSelection;
+    U2Region initialSelection;
 };
 
 }//namespace
