@@ -1,18 +1,29 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ORFMarkerPlugin.h"
 #include "ORFDialog.h"
 #include "ORFWorker.h"
 #include "ORFQuery.h"
-
+#include "ORFMarkerTask.h"
 
 #include <U2Core/GAutoDeleteList.h>
 #include <U2Gui/GUIUtils.h>
@@ -33,7 +44,7 @@
 #include <U2Test/GTestFrameworkComponents.h>
 
 #include <U2Core/AppContext.h>
-
+#include <U2Core/AutoAnnotationsSupport.h>
 
 namespace U2 {
 
@@ -46,6 +57,8 @@ ORFMarkerPlugin::ORFMarkerPlugin() : Plugin(tr("orfname"), tr("orfdesc")), viewC
     if (AppContext::getMainWindow()) {
         viewCtx = new ORFViewContext(this);
         viewCtx->init();
+        AppContext::getAutoAnnotationsSupport()->registerAutoAnnotationsUpdater(new ORFAutoAnnotationsUpdater );
+
     }
 
     LocalWorkflow::ORFWorkerFactory::init();
