@@ -4,206 +4,219 @@
 <context>
     <name>ORFDialogBase</name>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="34"/>
         <source>find_dialog_caption</source>
-        <translation>Поиск открытых рамок считывания</translation>
+        <translation type="obsolete">Поиск открытых рамок считывания</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="40"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="41"/>
         <source>find_dialog_wit</source>
         <translation>Поиск открытых рамок считывания в последовательности</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="59"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="60"/>
         <source>strand_group</source>
         <translation>Направление</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="71"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="72"/>
         <source>strand_both</source>
         <translation>Все</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="81"/>
-        <location filename="../src/ui/ORFDialogUI.ui" line="84"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="82"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="85"/>
         <source>strand_direct_wit</source>
         <translation>Искать только в прямой последовательности</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="87"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="88"/>
         <source>strand_direct_label</source>
         <translation>Прямые</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="100"/>
-        <location filename="../src/ui/ORFDialogUI.ui" line="103"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="101"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="104"/>
         <source>strand_complement_wit</source>
         <translation>Искать только в комплeментарной последовательности</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="106"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="107"/>
         <source>strand_complement_label</source>
         <translation>комплeментарные</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="125"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="126"/>
         <source>param_group</source>
         <translation>Параметры</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="139"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="140"/>
         <source>min_len_label</source>
         <translation>Мин длина, нукл</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="188"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="189"/>
         <source>must_fit_label</source>
         <translation>Терминатор внутри региона</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="201"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="202"/>
         <source>must_init_label</source>
         <translation>Старт-кодон обязателен</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="220"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="212"/>
+        <source>allow_overlap_tip</source>
+        <translation type="unfinished">Учитывать вложенные ORF, когда стартовые кодоны находятся внутри более длинного ORF.
+Таким образом, будут найдены все возможные ORF, а не только самые длинные.</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="215"/>
+        <source>Allow overlap</source>
+        <translation type="unfinished">Учитывать перекрытые</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="231"/>
         <source>allow_alternative_label</source>
         <translation>Альтернативные старт-кодоны</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="246"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="257"/>
         <source>find_all_wit</source>
         <translation>Начать поиск ORF</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="249"/>
         <source>find_all_button</source>
-        <translation>Искать</translation>
+        <translation type="obsolete">Искать</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="290"/>
         <source>hide_button_wit</source>
-        <translation>Остановить поиск и закрыть диалог</translation>
+        <translation type="obsolete">Остановить поиск и закрыть диалог</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="293"/>
         <source>close_button</source>
-        <translation>Закрыть</translation>
+        <translation type="obsolete">Закрыть</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="265"/>
         <source>save_as_features_tt</source>
-        <translation>Сохранить результаты как аннотации</translation>
+        <translation type="obsolete">Сохранить результаты как аннотации</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="268"/>
         <source>save_as_features_wit</source>
-        <translation>Сохранить результаты как аннотации</translation>
+        <translation type="obsolete">Сохранить результаты как аннотации</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="325"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="282"/>
         <source>clear_list_button</source>
         <translation>Сбросить результаты</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="391"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="364"/>
         <source>rstart_label</source>
-        <translation>Начало региона поиска: </translation>
+        <translation>Начало региона поиска:</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="427"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="400"/>
         <source>rend_label</source>
         <translation>Конец региона поиска: </translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="133"/>
-        <location filename="../src/ui/ORFDialogUI.ui" line="136"/>
-        <location filename="../src/ORFQuery.cpp" line="220"/>
-        <location filename="../src/ORFWorker.cpp" line="60"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="134"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="137"/>
+        <location filename="../src/ORFQuery.cpp" line="197"/>
+        <location filename="../src/ORFWorker.cpp" line="80"/>
         <source>min_len_tip</source>
         <translation>Не учитывать ORF короче указанной длины</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="182"/>
-        <location filename="../src/ui/ORFDialogUI.ui" line="185"/>
-        <location filename="../src/ORFWorker.cpp" line="61"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="35"/>
+        <source>Find ORFs settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="183"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="186"/>
+        <location filename="../src/ORFWorker.cpp" line="81"/>
         <source>must_fit_tip</source>
         <translation>Не учитывать ORF продолжающиеся за пределы поcледовательности (или региона поиска).</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="195"/>
-        <location filename="../src/ui/ORFDialogUI.ui" line="198"/>
-        <location filename="../src/ORFQuery.cpp" line="221"/>
-        <location filename="../src/ORFWorker.cpp" line="62"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="196"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="199"/>
+        <location filename="../src/ORFQuery.cpp" line="198"/>
+        <location filename="../src/ORFWorker.cpp" line="82"/>
         <source>must_init_tip</source>
-        <translation>Допускать или нет ORF начинающиеся с любого кодона кроме терминатора.
-Т.е. искать ORF от одного терминатора до другого (или от границы региона до ближайшего терминатора).</translation>
+        <translation>Указывает, что старт-кодон является обязательным</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="214"/>
-        <location filename="../src/ui/ORFDialogUI.ui" line="217"/>
-        <location filename="../src/ORFQuery.cpp" line="222"/>
-        <location filename="../src/ORFWorker.cpp" line="63"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="225"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="228"/>
+        <location filename="../src/ORFQuery.cpp" line="199"/>
+        <location filename="../src/ORFWorker.cpp" line="83"/>
         <source>allow_alt_tip</source>
         <translation>Учитывать ORF начинающиеся с неканонических стартовых кодонов,
 указанных в выбранной таблице трансляции.</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="65"/>
-        <location filename="../src/ui/ORFDialogUI.ui" line="68"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="66"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="69"/>
         <source>strand_both_wit</source>
         <translation>Искать в прямой и комплeментарной последовательностях</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="470"/>
-        <location filename="../src/ui/ORFDialogUI.ui" line="473"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="260"/>
+        <source>Preview</source>
+        <translation type="unfinished">Просмотреть</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/ORFDialogUI.ui" line="443"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="446"/>
         <source>sel_bt_tip</source>
         <translation>Искать в селектированном регионе</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="483"/>
-        <location filename="../src/ui/ORFDialogUI.ui" line="486"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="430"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="433"/>
         <source>pv_bt_tip</source>
         <translation>Установить регион поиска к отображаемому в панораме</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="496"/>
-        <location filename="../src/ui/ORFDialogUI.ui" line="499"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="456"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="459"/>
         <source>seq_bt_tip</source>
         <translation>Искать во всей последовательности</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="271"/>
         <source>save_as_annotations</source>
-        <translation>Сохранить результаты</translation>
+        <translation type="obsolete">Сохранить результаты</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="371"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="344"/>
         <source>region</source>
         <translation>Регион</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="376"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="349"/>
         <source>compl</source>
         <translation>Стренд</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="381"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="354"/>
         <source>len</source>
         <translation>Длина</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="476"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="449"/>
         <source>Selection range</source>
         <translation>Выбранный регион</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="489"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="436"/>
         <source>Overview range</source>
         <translation>Видимый регион</translation>
     </message>
     <message>
-        <location filename="../src/ui/ORFDialogUI.ui" line="502"/>
+        <location filename="../src/ui/ORFDialogUI.ui" line="462"/>
         <source>Sequence range</source>
         <translation>Вся последовательность</translation>
     </message>
@@ -248,47 +261,73 @@
     </message>
 </context>
 <context>
-    <name>U2::LocalWorkflow::ORFPrompter</name>
+    <name>U2::FindORFsToAnnotationsTask</name>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="119"/>
-        <source> from %1</source>
-        <translation> из %1</translation>
+        <location filename="../src/ORFMarkerTask.cpp" line="77"/>
+        <source>Find ORFs and save to annotations</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="130"/>
+        <location filename="../src/ORFMarkerTask.cpp" line="102"/>
+        <source>Annotation obj %1 is locked for modifications</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>U2::LocalWorkflow::ORFPrompter</name>
+    <message>
+        <source> from %1</source>
+        <translation type="obsolete"> из %1</translation>
+    </message>
+    <message>
+        <location filename="../src/ORFWorker.cpp" line="153"/>
+        <source>unset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ORFWorker.cpp" line="154"/>
+        <source> from &lt;u&gt;%1&lt;/u&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ORFWorker.cpp" line="165"/>
         <source>, allow ORFs &lt;u&gt;starting with any codon&lt;/u&gt; other than terminator</source>
         <translation>, допускать ORF &lt;u&gt;начинающиеся с любого кодона&lt;/u&gt; кроме терминатора</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="132"/>
+        <location filename="../src/ORFWorker.cpp" line="167"/>
         <source>, take into account &lt;u&gt;alternative start codons&lt;/u&gt;</source>
         <translation>, принимать во внимание &lt;u&gt;альтернативные старт-кодоны&lt;/u&gt;</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="135"/>
+        <location filename="../src/ORFWorker.cpp" line="170"/>
         <source>, &lt;u&gt;ignore non-terminated&lt;/u&gt; ORFs</source>
         <translation>, &lt;u&gt;исключать нетерминированные&lt;/u&gt; ORF</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="152"/>
+        <location filename="../src/ORFWorker.cpp" line="187"/>
+        <source>For each nucleotide sequence%1, find ORFs in &lt;u&gt;%2&lt;/u&gt; using the &lt;u&gt;%3&lt;/u&gt;.&lt;br&gt;Detect only ORFs &lt;u&gt;not shorter than %4 bps&lt;/u&gt;%5.&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%6&lt;/u&gt;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>For each nucleotide sequence&lt;u&gt;%1&lt;/u&gt;, find ORFs in &lt;u&gt;%2&lt;/u&gt; using the &lt;u&gt;%3&lt;/u&gt;.&lt;br&gt;Detect only ORFs &lt;u&gt;not shorter than %4 bps&lt;/u&gt;%5.&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%6&lt;/u&gt;.</source>
-        <translation>Искать ORF в каждой нуклеотидной последовательности&lt;u&gt;%1&lt;/u&gt;. Рассматривать &lt;u&gt;%2 стренды&lt;/u&gt;, используя &lt;u&gt;%3&lt;/u&gt;.&lt;br&gt;Учитывать только ORF &lt;u&gt;не короче чем %4 нк&lt;/u&gt;%5.&lt;br&gt;Выдать список найденых ORF аннотированных как &lt;u&gt;%6&lt;/u&gt;.</translation>
+        <translation type="obsolete">Искать ORF в каждой нуклеотидной последовательности&lt;u&gt;%1&lt;/u&gt;. Рассматривать &lt;u&gt;%2 стренды&lt;/u&gt;, используя &lt;u&gt;%3&lt;/u&gt;.&lt;br&gt;Учитывать только ORF &lt;u&gt;не короче чем %4 нк&lt;/u&gt;%5.&lt;br&gt;Выдать список найденых ORF аннотированных как &lt;u&gt;%6&lt;/u&gt;.</translation>
     </message>
 </context>
 <context>
     <name>U2::LocalWorkflow::ORFWorker</name>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="242"/>
+        <location filename="../src/ORFWorker.cpp" line="277"/>
         <source>Found %1 ORFs</source>
         <translation>Найдено %1 ORF регионов</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="44"/>
+        <location filename="../src/ORFWorker.cpp" line="65"/>
         <source>Input sequences</source>
         <translation>Анализируемая последовательность</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="46"/>
+        <location filename="../src/ORFWorker.cpp" line="67"/>
         <source>ORF annotations</source>
         <translation>ORF аннотации</translation>
     </message>
@@ -297,32 +336,32 @@
         <translation type="obsolete">Направление</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="59"/>
+        <location filename="../src/ORFWorker.cpp" line="79"/>
         <source>Genetic code</source>
         <translation>Код трансляции</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="61"/>
+        <location filename="../src/ORFWorker.cpp" line="81"/>
         <source>Require stop codon</source>
         <translation>Стоп-кодон обязателен</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="62"/>
+        <location filename="../src/ORFWorker.cpp" line="82"/>
         <source>Require init codon</source>
         <translation>Старт-кодон обязателен</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="63"/>
+        <location filename="../src/ORFWorker.cpp" line="83"/>
         <source>Allow alternative codons</source>
         <translation>Альтернативные кодоны</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="189"/>
+        <location filename="../src/ORFWorker.cpp" line="224"/>
         <source>ORF: result name is empty, default name used</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="194"/>
+        <location filename="../src/ORFWorker.cpp" line="229"/>
         <source>ORF: Incorrect value: min-length must be greater then zero</source>
         <translation type="unfinished"></translation>
     </message>
@@ -331,63 +370,62 @@
         <translation type="obsolete">Поиск ORF</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="140"/>
+        <location filename="../src/ORFWorker.cpp" line="175"/>
         <source>both strands</source>
         <translation>все</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="141"/>
+        <location filename="../src/ORFWorker.cpp" line="176"/>
         <source>direct strand</source>
         <translation>только прямые</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="142"/>
+        <location filename="../src/ORFWorker.cpp" line="177"/>
         <source>complement strand</source>
         <translation>только комплементарные</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="57"/>
+        <location filename="../src/ORFWorker.cpp" line="78"/>
         <source>Name of the result annotations marking found ORFs</source>
         <translation>Имя аннотации для разметки найденных ORF</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="45"/>
+        <location filename="../src/ORFWorker.cpp" line="66"/>
         <source>A nucleotide sequence to search ORFs in. Protein sequences are skipped.</source>
         <translation>Нуклеотидные последовательности для поиска ORF. Протеиновые последовательности допустимы но игнорируются.</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="47"/>
+        <location filename="../src/ORFWorker.cpp" line="68"/>
         <source>A set of annotations marking ORFs found in the sequence.</source>
         <translation>Набор аннотированных регионов для найденных ORF.</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="58"/>
         <source>Which strands should be searched: direct, complement or both.</source>
-        <translation>В каких стрендах последовательности следует искать ORF: прямых, комплементарных или всех.</translation>
+        <translation type="obsolete">В каких стрендах последовательности следует искать ORF: прямых, комплементарных или всех.</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="59"/>
+        <location filename="../src/ORFWorker.cpp" line="79"/>
         <source>Which genetic code should be used for translating the input nucleotide sequence.</source>
         <translation>Выбор генетического кода (таблицы трансляции в протеины) для входных последовательностей</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="74"/>
+        <location filename="../src/ORFWorker.cpp" line="94"/>
         <source>ORF marker</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="75"/>
+        <location filename="../src/ORFWorker.cpp" line="95"/>
         <source>Finds Open Reading Frames (ORFs) in each supplied nucleotide sequence, stores found regions as annotations.&lt;p&gt;Protein sequences are skipped if any supplied to input.&lt;p&gt;&lt;dfn&gt;ORFs are DNA sequence regions that could potentially encode a protein, and usually give a good indication of the presence of a gene in the surrounding sequence.&lt;/dfn&gt;&lt;/p&gt;&lt;p&gt;In the sequence, ORFs are located between a start-code sequence (initiation codon) and a stop-code sequence (termination codon), defined by the selected genetic code.&lt;/p&gt;</source>
         <translation>Поиск открытых рамок считывания (ОRF). ORF ищутся в каждой нуклеотидной последовательности, поданной на вход задачи; найденные регионы выдаются как набор аннотаций. 
 &lt;p&gt; Протеиновые последовательности на входе допустимы но не обрабатываются.</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="57"/>
+        <location filename="../src/ORFWorker.cpp" line="78"/>
         <source>Annotate as</source>
         <translation>Аннотации</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="60"/>
+        <location filename="../src/ORFWorker.cpp" line="80"/>
         <source>Min length</source>
         <translation>Мин длина</translation>
     </message>
@@ -396,70 +434,76 @@
         <translation type="obsolete">нк</translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="195"/>
+        <location filename="../src/ORFWorker.cpp" line="230"/>
         <source>Incorrect value: min-length must be greater then zero</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ORFWorker.cpp" line="219"/>
+        <location filename="../src/ORFWorker.cpp" line="254"/>
         <source>Bad sequence supplied to ORFWorker: %1</source>
         <translation>Неверная последовательность для поиска ORF: %1</translation>
     </message>
 </context>
+<context>
+    <name>U2::ORFAutoAnnotationsUpdater</name>
+    <message>
+        <location filename="../src/ORFMarkerTask.cpp" line="121"/>
+        <source>ORFs</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>U2::ORFDialog</name>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="190"/>
         <source>cancel_button</source>
-        <translation>Остановить</translation>
+        <translation type="obsolete">Остановить</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="190"/>
         <source>close_button</source>
-        <translation>Закрыть</translation>
+        <translation type="obsolete">Закрыть</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="208"/>
+        <location filename="../src/ORFDialog.cpp" line="222"/>
         <source>progress_%1%</source>
         <translation>Прогресс %1</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="210"/>
+        <location filename="../src/ORFDialog.cpp" line="224"/>
         <source>%1_results_found.</source>
         <translation>Найдено %1</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="260"/>
+        <location filename="../src/ORFDialog.cpp" line="274"/>
         <source>warning</source>
         <translation>Подтверждение</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="260"/>
+        <location filename="../src/ORFDialog.cpp" line="274"/>
         <source>results_list_not_empty_ask_clear</source>
         <translation>Сбросить предыдущие результаты?</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="151"/>
+        <location filename="../src/ORFDialog.cpp" line="169"/>
         <source>start_codons</source>
         <translation>Старт-кодоны</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="152"/>
+        <location filename="../src/ORFDialog.cpp" line="170"/>
         <source>alt_start_codons</source>
         <translation>Альтернативные кодоны</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="153"/>
+        <location filename="../src/ORFDialog.cpp" line="171"/>
         <source>stop_codons</source>
         <translation>Стоп-кодоны</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="388"/>
+        <location filename="../src/ORFDialog.cpp" line="441"/>
         <source>complem_strand</source>
         <translation>комплeментарный</translation>
     </message>
     <message>
-        <location filename="../src/ORFDialog.cpp" line="388"/>
+        <location filename="../src/ORFDialog.cpp" line="441"/>
         <source>direct_strand</source>
         <translation>прямой</translation>
     </message>
@@ -467,12 +511,12 @@
 <context>
     <name>U2::ORFMarkerPlugin</name>
     <message>
-        <location filename="../src/ORFMarkerPlugin.cpp" line="35"/>
+        <location filename="../src/ORFMarkerPlugin.cpp" line="56"/>
         <source>orfname</source>
         <translation>Поиск ORF</translation>
     </message>
     <message>
-        <location filename="../src/ORFMarkerPlugin.cpp" line="35"/>
+        <location filename="../src/ORFMarkerPlugin.cpp" line="56"/>
         <source>orfdesc</source>
         <translation type="unfinished">ORF: Поиск открытых рамок считывания</translation>
     </message>
@@ -515,7 +559,7 @@
 <context>
     <name>U2::ORFViewContext</name>
     <message>
-        <location filename="../src/ORFMarkerPlugin.cpp" line="70"/>
+        <location filename="../src/ORFMarkerPlugin.cpp" line="93"/>
         <source>Find ORFs...</source>
         <translation type="unfinished">ORF: Искать рамки считывания</translation>
     </message>
@@ -523,93 +567,116 @@
 <context>
     <name>U2::QDORFActor</name>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="91"/>
+        <location filename="../src/ORFQuery.cpp" line="60"/>
         <source>both strands</source>
         <translation>все стренды</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="93"/>
+        <location filename="../src/ORFQuery.cpp" line="62"/>
         <source>direct strand</source>
         <translation>только прямые стренды</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="95"/>
+        <location filename="../src/ORFQuery.cpp" line="64"/>
         <source>complement strand</source>
         <translation>только комплементарные стренды</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="110"/>
+        <location filename="../src/ORFQuery.cpp" line="78"/>
         <source>, allow ORFs &lt;u&gt;starting with any codon&lt;/u&gt; other than terminator</source>
         <translation>, допускать ORF начинающиеся с любого кодона  кроме терминатора</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="112"/>
+        <location filename="../src/ORFQuery.cpp" line="80"/>
         <source>, take into account &lt;u&gt;alternative start codons&lt;/u&gt;</source>
         <translation>, принимать во внимание альтернативные старт-кодоны</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="123"/>
+        <location filename="../src/ORFQuery.cpp" line="83"/>
+        <source>, &lt;u&gt;ignore non-terminated&lt;/u&gt; ORFs</source>
+        <translation type="unfinished">, &lt;u&gt;исключать нетерминированные&lt;/u&gt; ORF</translation>
+    </message>
+    <message>
+        <location filename="../src/ORFQuery.cpp" line="91"/>
         <source>Finds ORFs in &lt;u&gt;%1&lt;/u&gt; using the &lt;u&gt;%2&lt;/u&gt;.&lt;br&gt;Detects only ORFs &lt;u&gt;not shorter than %3, not longer than %4&lt;/u&gt;%5.</source>
         <translation>Искать ORF в %1, используя %2.&lt;br&gt;Рассматривать результаты не длиннее %3, не короче &lt;u&gt;%4&lt;/u&gt; %5.</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="164"/>
+        <location filename="../src/ORFQuery.cpp" line="140"/>
+        <source>Bad sequence</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ORFQuery.cpp" line="143"/>
         <source>ORF find</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="209"/>
+        <location filename="../src/ORFQuery.cpp" line="187"/>
         <source>ORF</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="210"/>
+        <location filename="../src/ORFQuery.cpp" line="188"/>
         <source>Finds Open Reading Frames (ORFs) in supplied nucleotide sequence, stores found regions as annotations.&lt;p&gt;Protein sequences are skipped if any.&lt;p&gt;&lt;dfn&gt;ORFs are DNA sequence regions that could potentially encode a protein, and usually give a good indication of the presence of a gene in the surrounding sequence.&lt;/dfn&gt;&lt;/p&gt;&lt;p&gt;In the sequence, ORFs are located between a start-code sequence (initiation codon) and a stop-code sequence (termination codon), defined by the selected genetic code.&lt;/p&gt;</source>
         <translation> Поиск открытых рамок считывания (ОRF) в заданной нуклеотидной последовательности, найденные регионы сохраняются как набор аннотаций.&lt;p&gt;Протеиновые последовательности не обрабатываются.&lt;p&gt;</translation>
     </message>
+    <message>
+        <location filename="../src/ORFQuery.cpp" line="200"/>
+        <source>Maximum length of annotation allowed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/ORFQuery.cpp" line="201"/>
+        <source>Require stop codon</source>
+        <translation type="unfinished">Стоп-кодон обязателен</translation>
+    </message>
+    <message>
+        <location filename="../src/ORFQuery.cpp" line="202"/>
+        <source>Ignore boundary ORFs which last beyond the search region (i.e. have no stop codon within the range).</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Search in</source>
         <translation type="obsolete">Направление</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="218"/>
         <source>Which strands should be searched: direct, complement or both.</source>
-        <translation>В каких стрендах последовательности следует искать ORF: прямых, комплементарных или всех.</translation>
+        <translation type="obsolete">В каких стрендах последовательности следует искать ORF: прямых, комплементарных или всех.</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="219"/>
+        <location filename="../src/ORFQuery.cpp" line="196"/>
         <source>Genetic code</source>
         <translation>Код трансляции</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="219"/>
+        <location filename="../src/ORFQuery.cpp" line="196"/>
         <source>Which genetic code should be used for translating the input nucleotide sequence.</source>
         <translation>Выбор генетического кода (таблицы трансляции в протеины) для входных последовательностей.</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="220"/>
+        <location filename="../src/ORFQuery.cpp" line="197"/>
         <source>Min length</source>
         <translation>Мин длина</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="221"/>
+        <location filename="../src/ORFQuery.cpp" line="198"/>
         <source>Require init codon</source>
         <translation>Старт-кодон обязателен</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="222"/>
+        <location filename="../src/ORFQuery.cpp" line="199"/>
         <source>Allow alternative codons</source>
         <translation>Альтернативные кодоны</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="223"/>
+        <location filename="../src/ORFQuery.cpp" line="200"/>
         <source>Max length</source>
         <translation>Макс длина</translation>
     </message>
     <message>
-        <location filename="../src/ORFQuery.cpp" line="223"/>
         <source>Maximum length of annotation allowed</source>
-        <translation>Макс длина</translation>
+        <translation type="obsolete">Макс длина</translation>
     </message>
     <message>
         <source> bp</source>
