@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "QDSceneIOTasks.h"
 #include "QueryViewController.h"
@@ -21,6 +32,7 @@
 
 #include <U2Core/QVariantUtils.h>
 
+#include <QtCore/QFile>
 
 namespace U2 {
 
@@ -78,7 +90,7 @@ QList<Task*> QDLoadSceneTask::onSubTaskFinished(Task* subTask) {
 }
 
 Task::ReportResult QDLoadSceneTask::report() {
-    if (!stateInfo.hasErrors()) {
+    if (!stateInfo.hasError()) {
         QDSceneSerializer::doc2scene(scene, docs);
     }
     return Task::ReportResult_Finished;
@@ -108,7 +120,7 @@ QList<Task*> QDLoadSchemeTask::onSubTaskFinished(Task* subTask) {
 }
 
 Task::ReportResult QDLoadSchemeTask::report() {
-    if (!stateInfo.hasErrors()) {
+    if (!stateInfo.hasError()) {
         QDSceneSerializer::doc2scheme(docs, scheme);
     }
     return Task::ReportResult_Finished;
@@ -229,7 +241,7 @@ bool QDSceneSerializer::doc2scheme(const QList<QDDocument*>& docs, QMap<QDElemen
                 }
             }
             if (actualStmt==NULL) {
-                algoLog.error(QObject::tr("{%1} not found in imported files").arg(actualStmt->getId()));
+                algoLog.error(QObject::tr("{%1} is not found in imported files.").arg(actualStmt->getId()));
                 return false;
             }
             actor = QDSchemeSerializer::loadActor(actualStmt, group);
@@ -278,6 +290,9 @@ bool QDSceneSerializer::doc2scheme(const QList<QDDocument*>& docs, QMap<QDElemen
         }
     }
 
+    QDStrandOption strOpt = docs.first()->getSchemaStrand();
+    scheme->setStrand(strOpt);
+
     //load groups
     bool ok = QDSchemeSerializer::loadGroups(scheme, docs.first());
     if (!ok) {
@@ -305,6 +320,7 @@ QDDocument* QDSceneSerializer::scene2doc(QueryScene* scene) {
             QDElementStatement* unitElement = new QDElementStatement(name, Element);
             unit2stmt[su] = unitElement;
             bool res = doc->addElement(unitElement);
+            Q_UNUSED(res);
             assert(res);
             QDElement const* uv = scene->getUnitView(su);
             assert(uv);
@@ -315,6 +331,7 @@ QDDocument* QDSceneSerializer::scene2doc(QueryScene* scene) {
         QDSchemeSerializer::saveConstraint(c, doc, unit2stmt);
     }
     doc->saveOrder(scheme->getActors());
+    doc->setSchemaStrand(scheme->getStrand());
     QDSchemeSerializer::saveGroups(scheme, doc);
     return doc;
 }
@@ -323,28 +340,28 @@ QDDocument* QDSceneSerializer::scene2doc(QueryScene* scene) {
 //////////////////////////////////////////////////////////////////////////
 static const QString GROUP_ATTR = "group";
 
-static const QString DIRECTION_ATTR = "direction";
-static const QString FORWARD_DIR = "forward";
-static const QString BACKWARD_DIR = "backward";
-static const QString ANY_DIR = "any";
+static const QString STRAND_ATTR = "strand";
+static const QString STRAND_DIRECT = "direct";
+static const QString STRAND_COMPLEMENT = "complement";
+static const QString STRAND_BOTH = "both";
 
-static QMap<QDActor::Direction, QString> initDirectionMap() {
-    QMap<QDActor::Direction, QString> res;
-    res.insertMulti(QDActor::Forward, FORWARD_DIR);
-    res.insertMulti(QDActor::Backward, BACKWARD_DIR);
-    res.insertMulti(QDActor::Any, ANY_DIR);
+static QMap<QDStrandOption, QString> initDirectionMap() {
+    QMap<QDStrandOption, QString> res;
+    res.insertMulti(QDStrand_DirectOnly, STRAND_DIRECT);
+    res.insertMulti(QDStrand_ComplementOnly, STRAND_COMPLEMENT);
+    res.insertMulti(QDStrand_Both, STRAND_BOTH);
     return res;
 }
 
-const QMap<QDActor::Direction, QString> QDSchemeSerializer::DIRECTION_MAP(initDirectionMap());
+const QMap<QDStrandOption, QString> QDSchemeSerializer::STRAND_MAP(initDirectionMap());
 
 QDElementStatement* QDSchemeSerializer::saveActor( QDActor* actor, QDDocument* doc ) {
     /*const QString& suffix = QString::number(doc->getElements(Group).size() + 1);
     QDElementStatement* actorElement = new QDElementStatement("A"+suffix, Group);*/
-    QString actorName = actor->getParameters()->getLabel();
-    const QString& elementName = actorName.replace(" ", "_");
+    QString elementName = actor->getParameters()->getLabel();
     QDElementStatement* actorElement = new QDElementStatement(elementName, Group);
     bool res = doc->addElement(actorElement);
+    Q_UNUSED(res);
     assert(res);
     actorElement->setAttribute(QDElementStatement::ALGO_ATTR_NAME, actor->getActorType());
     QList< QPair<QString,QString> > attrsMap = actor->saveConfiguration();
@@ -355,8 +372,8 @@ QDElementStatement* QDSchemeSerializer::saveActor( QDActor* actor, QDDocument* d
     foreach(const StringAttribute& attr, attrsMap) {
         actorElement->setAttribute(attr.first, attr.second);
     }
-    if (actor->getDirection()!=QDActor::Any) {
-        actorElement->setAttribute(DIRECTION_ATTR, DIRECTION_MAP.value(actor->getDirection()));
+    if (actor->getStrand()!=QDStrand_Both) {
+        actorElement->setAttribute(STRAND_ATTR, STRAND_MAP.value(actor->getStrand()));
     }
     return actorElement;
 }
@@ -369,25 +386,24 @@ QDActor* QDSchemeSerializer::loadActor(QDElementStatement* actorElement, QString
     }
     QDActorPrototypeRegistry* afr = AppContext::getQDActorProtoRegistry();
     if (!afr->getAllIds().contains(algo)) {
-        ioLog.error(QObject::tr("Can not find %1").arg(algo));
+        ioLog.error(QObject::tr("Can not find %1.").arg(algo));
         return NULL;
     }
     QDActor* actor = afr->getProto(algo)->createInstance();
     if (actor==NULL) {
         return NULL;
     }
-    QString elementName = actorElement->getId();
-    const QString& actorName = elementName.replace("_", " ");
+    QString actorName = actorElement->getId();
     actor->getParameters()->setLabel(actorName);
     actor->loadConfiguration(actorElement->getAttributes());
     
-    QString dirAttrVal = actorElement->getAttribute(DIRECTION_ATTR);
+    QString dirAttrVal = actorElement->getAttribute(STRAND_ATTR);
     if (!dirAttrVal.isEmpty()) {
-        if (!DIRECTION_MAP.values().contains(dirAttrVal)) {
+        if (!STRAND_MAP.values().contains(dirAttrVal)) {
             coreLog.error(QObject::tr("Error loading file."));
             return NULL;
         }
-        actor->setDirection(DIRECTION_MAP.key(dirAttrVal));
+        actor->setStrand(STRAND_MAP.key(dirAttrVal));
     }
 
     group = actorElement->getAttribute(GROUP_ATTR);
@@ -501,7 +517,7 @@ bool QDSchemeSerializer::loadGroups(QDScheme* scheme, QDDocument* doc) {
         QPair<QString, QString> attr = el->getAttributes().at(idx);
         QString group = attr.first;
         if (!scheme->getActorGroups().contains(group)) {
-            coreLog.error(QObject::tr("Error loading schema. Schema does not contain group %1").arg(group));
+            coreLog.error(QObject::tr("Error loading schema. Schema does not contain group %1.").arg(group));
             return false;
         }
         bool ok;
