@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "QueryViewController.h"
 #include "QueryViewItems.h"
@@ -45,37 +56,26 @@ namespace U2 {
 /* Scene                                                                */
 /************************************************************************/
 
-#define QS 1000
+const QSizeF QueryScene::MAX_SCENE_SIZE(10*1000, 10*1000);
+const QSizeF QueryScene::DEFAULT_SCENE_SIZE(1000, 1000);
+
 #define MAX_ITEM_SIZE 10000 // max point size for any visual item and whole scene
 #define MIN_ROWS_NUMBER 3
-#define LABEL_HEIGHT 40
-#define LABEL_PIXEL_SIZE 15
-#define LABEL_LEFT_PAD 200
-QueryScene::QueryScene(QueryViewController* parent/* =0 */)
-: QGraphicsScene(parent), dropCandidateLeft(NULL), dropCandidateRight(NULL),
-view(parent), rowsNum(MIN_ROWS_NUMBER), showSchemeLbl(false), showSchemeDesc(false),
-showDesc(true), showOrder(true) {
-    setSceneRect(0, 0, QS, QS);
+#define DESCRIPTION_TOP_PAD 40
+#define DESCRIPTION_BOTTOM_PAD 20
+#define FOOTNOTES_AREA_TOP_MARGIN 20
+#define FOOTNOTE_BOTTOM_MARGIN 20
+
+QueryScene::QueryScene(QueryViewController* parent/* =0 */) : QGraphicsScene(parent),
+dropCandidateLeft(NULL), dropCandidateRight(NULL), view(parent), rowsNum(3),
+showSchemeLbl(false), showDesc(true), showOrder(true), modified(false) {
+    setSceneRect(0, 0, DEFAULT_SCENE_SIZE.width(), DEFAULT_SCENE_SIZE.height());
     setItemIndexMethod(NoIndex);
     scheme = new QDScheme;
 
-    labelTxtItem = new QDLabelItem("NewSchema");
-    if (parent) {
-        connect(labelTxtItem, SIGNAL(si_editingFinished()), parent, SLOT(sl_updateTitle()));
-    }
-    labelTxtItem->setPos(LABEL_LEFT_PAD,0);
-    QFont lblFont;
-    lblFont.setItalic(true);
-    lblFont.setPixelSize(LABEL_PIXEL_SIZE);
-    labelTxtItem->setFont(lblFont);
-
-    descTxtItem = new QDDescriptionItem("<Write description here>");
-    descTxtItem->setTextWidth(200);
-
-    ruler = new QDRulerItem;
-    connect(this, SIGNAL(si_schemeChanged()), ruler, SLOT(sl_updateText()));
-    addItem(ruler);
-    ruler->setPos(0,0);
+    initTitle();
+    initRuler();
+    initDescription();
 }
 
 QueryScene::~QueryScene() {
@@ -86,6 +86,47 @@ QueryScene::~QueryScene() {
     delete ruler;
 }
 
+#define LABEL_HEIGHT 40
+#define LABEL_PIXEL_SIZE 15
+#define LABEL_LEFT_PAD 200
+
+void QueryScene::initTitle() {
+    labelTxtItem = new QDLabelItem("NewSchema");
+    QFont lblFont;
+    lblFont.setItalic(true);
+    lblFont.setPixelSize(LABEL_PIXEL_SIZE);
+    labelTxtItem->setFont(lblFont);
+    labelTxtItem->setPos(LABEL_LEFT_PAD,0);
+    if (view) {
+        connect(labelTxtItem, SIGNAL(si_editingFinished()), view, SLOT(sl_updateTitle()));
+    }
+}
+
+void QueryScene::initRuler() {
+    ruler = new QDRulerItem;
+    connect(this, SIGNAL(si_schemeChanged()), ruler, SLOT(sl_updateText()));
+    ruler->setPos(0,0);
+    addItem(ruler);
+}
+
+void QueryScene::initDescription() {
+    descTxtItem = new QDDescriptionItem("<Write description here>");
+    descTxtItem->setTextWidth(200);
+    qreal viewWidth(0);
+    if (views().isEmpty()) {
+        viewWidth = sceneRect().width();
+    } else {
+        assert(views().size() == 1);
+        QGraphicsView* v = views().first();
+        viewWidth = v->viewport()->width();
+    }
+    qreal xPos = (viewWidth - descTxtItem->boundingRect().width()) / 2.0;
+    qreal yPos = footnotesArea().bottom() + DESCRIPTION_TOP_PAD;
+    descTxtItem->setPos(xPos, yPos);
+    addItem(descTxtItem);
+    descTxtItem->setVisible(false);
+}
+
 int QueryScene::getRow(QDElement* const uv) const {
     const QPointF& pos = uv->scenePos();
     qreal top=annotationsArea().top();
@@ -131,8 +172,7 @@ void QueryScene::sl_adaptRowsNumber() {
     for (int i=rowsNum-1;i>=MIN_ROWS_NUMBER; i--) {
         if (unitsIntersectedByRow(i).isEmpty()) {
             --adaptedNum;
-        }
-        else {
+        } else {
             break;
         }
     }
@@ -164,14 +204,14 @@ void QueryScene::sl_showLabel(bool show) {
         return;
     }
     showSchemeLbl = show;
-    int dy;
+    int dy(0);
     if (showSchemeLbl) {
-        dy=LABEL_HEIGHT;
+        addItem(labelTxtItem);
+        dy = LABEL_HEIGHT;
         ruler->setPos(0, LABEL_HEIGHT);
-    }
-    else {
-        dy = -LABEL_HEIGHT;
+    } else {
         removeItem(labelTxtItem);
+        dy = -LABEL_HEIGHT;
         ruler->setPos(0,0);
     }
     foreach(QGraphicsItem* it, items()) {
@@ -179,25 +219,12 @@ void QueryScene::sl_showLabel(bool show) {
             it->moveBy(0.0, dy);
         }
     }
+    descTxtItem->moveBy(0.0, dy);
     update();
-    if (showSchemeLbl) {
-        addItem(labelTxtItem);
-    }
-    updateDescriptionPos();
 }
 
 void QueryScene::sl_showSchemeDesc(bool show) {
-    if (showSchemeDesc==show) {
-        return;
-    }
-    showSchemeDesc = show;
-    if (!showSchemeDesc) {
-        removeItem(descTxtItem);
-    }
-    else {
-        addItem(descTxtItem);
-        updateDescriptionPos();
-    }
+    descTxtItem->setVisible(show);
 }
 
 void QueryScene::sl_showItemDesc(bool show) {
@@ -223,12 +250,6 @@ void QueryScene::sl_showOrder(bool show) {
     }
 }
 
-#define DESCRIPTION_TOP_PAD 40
-void QueryScene::updateDescriptionPos() {
-    qreal y = footnotesArea().bottom() + DESCRIPTION_TOP_PAD;
-    descTxtItem->setPos(descTxtItem->x(),y);
-}
-
 QRectF QueryScene::rulerArea() const {
     QRectF area = ruler->boundingRect();
     area.moveTopLeft(ruler->scenePos());
@@ -248,7 +269,6 @@ QRectF QueryScene::annotationsArea() const {
     return QRectF(rect.left(), top, rect.width(), areaHeight);
 }
 
-#define FOOTNOTES_AREA_TOP_MARGIN 20
 QRectF QueryScene::footnotesArea() const {
     qreal tlX = sceneRect().left();
     qreal tlY = annotationsArea().bottom() + FOOTNOTES_AREA_TOP_MARGIN;
@@ -262,6 +282,7 @@ QRectF QueryScene::footnotesArea() const {
             }
         }
     }
+    brY += FOOTNOTE_BOTTOM_MARGIN;
     QRectF rect(QPointF(tlX,tlY), QPointF(brX,brY));
     assert(rect.width() < MAX_ITEM_SIZE && rect.height() < MAX_ITEM_SIZE);
     return rect;
@@ -297,20 +318,32 @@ QDElement* QueryScene::getUnitView(QDSchemeUnit* su) const {
     return NULL;
 }
 
+#define MAX_ROWS_NUMBER 200
 void QueryScene::setRowsNumber(int count) {
-    rowsNum = count;
-    QList<Footnote*> footnotes;
-    foreach(QGraphicsItem* item, items()) {
-        if(item->type()==FootnoteItemType) {
-            footnotes << qgraphicsitem_cast<Footnote*>(item);
+    if (count <= MAX_ROWS_NUMBER) {
+        qreal dY = (count - rowsNum)*GRID_STEP;
+        rowsNum = count;
+        foreach(QGraphicsItem* item, items()) {
+            if(item->type()==FootnoteItemType) {
+                Footnote* fn = qgraphicsitem_cast<Footnote*>(item);
+                fn->moveBy(0.0, dY);
+            }
         }
+
+        descTxtItem->moveBy(0.0, dY);        
+        qreal bottom = descTxtItem->mapRectToScene(descTxtItem->boundingRect()).bottom();
+        bottom = footnotesArea().bottom() + DESCRIPTION_TOP_PAD;
+        descTxtItem->setY(bottom);
+        qreal newH = qMax(QueryScene::DEFAULT_SCENE_SIZE.height(),
+            descTxtItem->mapRectToScene(descTxtItem->boundingRect()).bottom() + DESCRIPTION_BOTTOM_PAD);
+
+        QRectF r = sceneRect();
+        if (newH > r.height()) {
+            r.setHeight(newH);
+            setSceneRect(r);
+        }
+        update();
     }
-    foreach(Footnote* footnote, footnotes) {
-        footnote->updatePos();
-    }
-    //to do: evaluate row area and update it instead of whole scene
-    updateDescriptionPos();
-    update();
 }
 
 void QueryScene::drawBackground(QPainter *painter, const QRectF &rect) {
@@ -444,7 +477,7 @@ void QueryScene::addActor(QDActor* actor, const QPointF& pos) {
     QDActorParameters* actorCfg = actor->getParameters();
     QString defaultName = actor->getProto()->getDisplayName();
     if (count>0) {
-        actorCfg->setLabel(QString("%1 %2").arg(defaultName).arg(count));
+        actorCfg->setLabel(QString("%1%2").arg(defaultName).arg(count));
     }
     else {
         actorCfg->setLabel(defaultName);
@@ -474,9 +507,10 @@ void QueryScene::addActor(QDActor* actor, const QPointF& pos) {
             addItem(fn);
             fn->updatePos();
         }
-    }
+    }    
     connect(actor->getParameters(), SIGNAL(si_modified()), ruler, SLOT(sl_updateText()));
     emit_schemeChanged();
+    setModified(true);
 }
 
 void QueryScene::addDistanceConstraint(QDElement* src, QDElement* dst, QDDistanceType distType, int min, int max) {
@@ -490,8 +524,10 @@ void QueryScene::addDistanceConstraint(QDElement* src, QDElement* dst, QDDistanc
         Footnote* fn = new Footnote(src, dst, distType, c);
         addItem(fn);
         fn->updatePos();
+        updateDescription();
         emit_schemeChanged();
     }
+    setModified(true);
 }
 
 void QueryScene::removeActor(QDActor* actor) {    
@@ -518,6 +554,7 @@ void QueryScene::removeActor(QDActor* actor) {
         }
     }
     emit_schemeChanged();
+    setModified(true);
 }
 
 void QueryScene::removeActors(const QList<QDActor*>& actors) {
@@ -528,7 +565,7 @@ void QueryScene::removeActors(const QList<QDActor*>& actors) {
 
 void QueryScene::removeConstraint(QDConstraint* constraint) {
     QDSchemeUnit* su = constraint->getSchemeUnits().at(0);
-    QDActor* actor = su->getActor();
+    Q_UNUSED(su);
     assert(su->getConstraints().contains(constraint));
     foreach(QGraphicsItem* it, getFootnotes()) {
         Footnote* fn = qgraphicsitem_cast<Footnote*>(it);
@@ -539,7 +576,9 @@ void QueryScene::removeConstraint(QDConstraint* constraint) {
         }
     }
     scheme->removeConstraint(constraint);
+    updateDescription();
     emit_schemeChanged();
+    setModified(true);
 }
 
 void QueryScene::clearScene() {
@@ -559,7 +598,24 @@ QList<QGraphicsItem*> QueryScene::unitsIntersectedByRow(int idx) const {
     }
     return rowItems;
 }
-    
+
+void QueryScene::setModified( bool b ) {
+    modified=b;
+    if (view) {
+        view->enableSaveAction(b);
+    }
+}
+
+void QueryScene::updateDescription() {
+    qreal y = footnotesArea().bottom() + DESCRIPTION_TOP_PAD;
+    descTxtItem->setY(y);
+    QRectF rect = sceneRect();
+    y = descTxtItem->mapRectToScene(descTxtItem->boundingRect()).bottom();
+    qreal newH = qMax(y + DESCRIPTION_BOTTOM_PAD, QueryScene::DEFAULT_SCENE_SIZE.height());
+    rect.setHeight(newH);
+    setSceneRect(rect);
+}
+
 /************************************************************************/
 /* View Controller                                                      */
 /************************************************************************/
@@ -567,7 +623,6 @@ enum {ElementsTab,GroupsTab,SamplesTab};
 
 #define PALETTE_STATE "query_palette_settings"
 
-#define DESCRIPTION_HEIGHT 200
 QueryViewController::QueryViewController() : MWMDIWindow(tr("Query Designer")) {
     GCOUNTER(cvar, tvar, "OpenQDWindow");
     scene = new QueryScene(this);
@@ -591,6 +646,7 @@ QueryViewController::QueryViewController() : MWMDIWindow(tr("Query Designer")) {
     connect(samples, SIGNAL(setupGlass(GlassPane*)), sceneView, SLOT(setGlass(GlassPane*)));
     connect(samples, SIGNAL(itemActivated(QDDocument*)), SLOT(sl_pasteSample(QDDocument*)));
     connect(tabs, SIGNAL(currentChanged(int)), samples, SLOT(sl_cancel()));
+    connect(editor, SIGNAL(modified()), scene, SLOT(sl_setModified()));
 
     QSplitter* splitter = new QSplitter(Qt::Horizontal, this);
     splitter->addWidget(tabs);
@@ -613,9 +669,6 @@ QueryViewController::QueryViewController() : MWMDIWindow(tr("Query Designer")) {
     sl_updateTitle();
     
     sl_scrollUp();
-    qreal viewportW = sceneView->viewport()->width();
-    qreal xp = (viewportW - scene->descTxtItem->boundingRect().width())/2.0;
-    scene->descTxtItem->setPos(xp, 0);
 }
 
 void QueryViewController::loadScene(const QString& content) {
@@ -624,28 +677,35 @@ void QueryViewController::loadScene(const QString& content) {
     QList<QDDocument*> docs;
     docs << &doc;
     QDSceneSerializer::doc2scene(scene, docs);
+    scene->setModified(false);
     sl_updateTitle();
 }
 
 void QueryViewController::createActions() {
-    runAction = new QAction(tr("Run schema"), this);
+    runAction = new QAction(tr("Run Schema..."), this);
     runAction->setIcon(QIcon(":query_designer/images/run.png"));
     connect(runAction, SIGNAL(triggered()), SLOT(sl_run()));
 
-    newAction = new QAction(tr("New schema"), this);
+    newAction = new QAction(tr("New Schema"), this);
     newAction->setShortcuts(QKeySequence::New);
     newAction->setIcon(QIcon(":query_designer/images/filenew.png"));
     connect(newAction, SIGNAL(triggered()), SLOT(sl_newScene()));
     
-    loadAction = new QAction(tr("Load schema"), this);
+    loadAction = new QAction(tr("Load Schema..."), this);
     loadAction->setShortcut(QKeySequence("Ctrl+L"));
     loadAction->setIcon(QIcon(":query_designer/images/fileopen.png"));
     connect(loadAction, SIGNAL(triggered()), SLOT(sl_loadScene()));
 
-    saveAction = new QAction(tr("Save schema"), this);
+    saveAction = new QAction(tr("Save Schema"), this);
     saveAction->setShortcut(QKeySequence::Save);
     saveAction->setIcon(QIcon(":query_designer/images/filesave.png"));
+    saveAction->setDisabled(true);
     connect(saveAction, SIGNAL(triggered()), SLOT(sl_saveScene()));
+    
+    saveAsAction = new QAction(tr("Save Schema As..."), this);
+    saveAsAction->setShortcut(QKeySequence::SaveAs);
+    saveAsAction->setIcon(QIcon(":query_designer/images/filesave.png"));
+    connect(saveAsAction, SIGNAL(triggered()), SLOT(sl_saveSceneAs()));
 
     deleteAction = new QAction(tr("Delete"), this);
     deleteAction->setShortcut(QKeySequence::Delete);
@@ -671,6 +731,35 @@ void QueryViewController::createActions() {
     showOrderAction->setCheckable(true);
     showOrderAction->setChecked(true);
     connect(showOrderAction, SIGNAL(toggled(bool)), scene, SLOT(sl_showOrder(bool)));
+
+    strandActions = new QActionGroup(this);
+
+    directStrandAction = new QAction(tr("Direct strand"), strandActions);
+    directStrandAction->setCheckable(true);
+
+    complementStrandAction = new QAction(tr("Reverse complementary strand"), strandActions);
+    complementStrandAction->setCheckable(true);
+
+    bothStrandsAction = new QAction(tr("Both strands"), strandActions);
+    bothStrandsAction->setCheckable(true);
+
+    QDStrandOption strand = scene->getScheme()->getStrand();
+    switch (strand)
+    {
+    case QDStrand_Both:
+        bothStrandsAction->setChecked(true);
+        break;
+    case QDStrand_DirectOnly:
+        directStrandAction->setChecked(true);
+        break;
+    case QDStrand_ComplementOnly:
+        complementStrandAction->setChecked(true);
+        break;
+    default:
+        assert(0);
+        break;
+    }
+    connect(strandActions, SIGNAL(triggered(QAction*)), SLOT(sl_setGlobalStrand(QAction*)));
 }
 
 void QueryViewController::setupViewModeMenu(QMenu* m) {
@@ -680,37 +769,70 @@ void QueryViewController::setupViewModeMenu(QMenu* m) {
     m->addAction(showOrderAction);
 }
 
+void QueryViewController::setupQuerySequenceModeMenu(QMenu* m) {
+    m->addAction(directStrandAction);
+    m->addAction(complementStrandAction);
+    m->addAction(bothStrandsAction);
+}
+
+void QueryViewController::setupStrandMenu(QMenu* m) {
+    m->addActions(strandActions->actions());
+}
+
 void QueryViewController::setupMDIToolbar(QToolBar* tb) {
     tb->addAction(newAction);
     tb->addAction(loadAction);
     tb->addAction(saveAction);
+    tb->addAction(saveAsAction);
     tb->addSeparator();
+
     tb->addAction(runAction);
     tb->addSeparator();
-    tb->addAction(deleteAction);
-    tb->addSeparator();
-    
+
     QToolButton* tt = new QToolButton(tb);
-    QMenu* viewModeMenu = new QMenu(tr("View mode"), this);
+    QMenu* viewModeMenu = new QMenu(tr("View Mode"), this);
     setupViewModeMenu(viewModeMenu);
     QAction* a = viewModeMenu->menuAction();
     tt->setDefaultAction(a);
     tt->setPopupMode(QToolButton::InstantPopup);
+    tt->setIcon(QIcon(":query_designer/images/eye.png"));
     tb->addWidget(tt);
+
+    QToolButton* st = new QToolButton(tb);
+    QMenu* strandMenu = new QMenu(tr("Query Sequence Mode"), this);
+    setupStrandMenu(strandMenu);
+    QAction* sa = strandMenu->menuAction();
+    st->setDefaultAction(sa);
+    st->setPopupMode(QToolButton::InstantPopup);
+    st->setIcon(QIcon(":query_designer/images/strands.png"));
+    tb->addWidget(st);
+
+    tb->addSeparator();
+    tb->addAction(deleteAction);
 }
 
 void QueryViewController::setupViewMenu(QMenu* m) {
-    m->addAction(deleteAction);
-    m->addSeparator();
     m->addAction(newAction);
     m->addAction(loadAction);
     m->addAction(saveAction);
+    m->addAction(saveAsAction);
     m->addSeparator();
     m->addAction(runAction);
     m->addSeparator();
-    QMenu* viewModeMenu = new QMenu(tr("View mode"), this);
+
+    QMenu* viewModeMenu = new QMenu(tr("View Mode"), this);
+    viewModeMenu->setIcon(QIcon(":query_designer/images/eye.png"));
     setupViewModeMenu(viewModeMenu);
     m->addMenu(viewModeMenu);
+
+    QMenu* querySequenceModeMenu = new QMenu(tr("Query Sequence Mode"), this);
+    querySequenceModeMenu->setIcon((QIcon(":query_designer/images/strands.png")));
+    setupQuerySequenceModeMenu(querySequenceModeMenu);
+    m->addMenu(querySequenceModeMenu);
+
+    m->addSeparator();
+    m->addAction(deleteAction);
+    m->addSeparator();
 }
 
 void QueryViewController::switchToGroupsTab() {
@@ -719,7 +841,7 @@ void QueryViewController::switchToGroupsTab() {
 
 bool QueryViewController::onCloseEvent() {
     saveState();
-    return true;
+    return confirmModified();
 }
 
 void QueryViewController::saveState() {
@@ -730,39 +852,65 @@ void QueryViewController::sl_run() {
     QDScheme* scheme = scene->getScheme();
     if (scheme->isEmpty()) {
         QMessageBox::critical(this, L10N::errorTitle(), tr("The schema is empty!"));
-    } else if (scheme->isValid()) {
+    } else if (!scheme->isValid()) {
+        QMessageBox::critical(this, L10N::errorTitle(), tr("The schema is invalid! Please see the log for details."));
+    } else {
         QDRunDialog runDlg(scene->getScheme(), this, inFile_, outFile_);
         runDlg.exec();
     }
 }
 
 void QueryViewController::sl_newScene() {
+    if(!scene->getScheme()->getActors().isEmpty()) {
+        if (!confirmModified()) {
+            return;
+        }
+    }
+    schemeUri.clear();
     scene->setLabel("NewSchema");
     scene->setDescription("<Insert description here>");
     scene->clearScene();
     sl_updateTitle();
+
 }
 
 void QueryViewController::sl_loadScene() {
+    if(!scene->getScheme()->getActors().isEmpty()) {
+        if (!confirmModified()) {
+            return;
+        }
+    }
     LastOpenDirHelper dir(QUERY_DESIGNER_ID);
-    dir.url = QFileDialog::getOpenFileName(this, tr("Load schema"), dir, QString("*.%1").arg(QUERY_SCHEME_EXTENSION));
+    dir.url = QFileDialog::getOpenFileName(this, tr("Load Schema"), dir, QString("*.%1").arg(QUERY_SCHEME_EXTENSION));
     if (!dir.url.isEmpty()) {
         QDLoadSceneTask* t = new QDLoadSceneTask(scene, dir.url);
         connect(new TaskSignalMapper(t), SIGNAL(si_taskFinished(Task*)), SLOT(sl_updateTitle()));
         AppContext::getTaskScheduler()->registerTopLevelTask(t);
+        scene->setModified(false);
+        schemeUri = dir.url;
     }
 }
 
 void QueryViewController::sl_saveScene() {
-    LastOpenDirHelper dir(QUERY_DESIGNER_ID);
-    dir.url = QFileDialog::getSaveFileName(this, tr("Save schema"), dir, QString("*.%1").arg(QUERY_SCHEME_EXTENSION));
-    if (!dir.url.isEmpty()) {
+    if (schemeUri.isEmpty()) {
+        sl_saveSceneAs();
+    } else {
         QDSceneInfo info;
-        info.path = dir.url;
+        info.path = schemeUri;
         info.schemeName = scene->getLabel();
         info.description = scene->getDescription();
         QDSaveSceneTask* t = new QDSaveSceneTask(scene, info);
         AppContext::getTaskScheduler()->registerTopLevelTask(t);
+        scene->setModified(false);
+    }
+}
+
+void QueryViewController::sl_saveSceneAs() {
+    LastOpenDirHelper dir(QUERY_DESIGNER_ID);
+    dir.url = QFileDialog::getSaveFileName(this, tr("Save Schema"), dir, QString("*.%1").arg(QUERY_SCHEME_EXTENSION));
+    if (!dir.url.isEmpty()) {
+        schemeUri = dir.url;
+        sl_saveScene();
     }
 }
 
@@ -797,17 +945,23 @@ void QueryViewController::sl_deleteItem() {
         }
     }
 
-    foreach(QDConstraint* c, constraints2remove) {
+    QList<QDConstraint*> removedConstraints;
+    foreach (QDConstraint* c, constraints2remove) {
+        if (removedConstraints.contains(c)) {
+            continue;
+        }
         QDSchemeUnit* su = c->getSchemeUnits().at(0);
         QDActor* actor = su->getActor();
         if (!su->getConstraints().contains(c)) { //param constraint
             actors2remove.removeAll(actor);
+            removedConstraints << actor->getConstraints();
             scene->removeActor(actor);
             continue;
         }
         scene->removeConstraint(c);
     }
     scene->removeActors(actors2remove);
+    scene->setModified(true);
 }
 
 void QueryViewController::sl_editItem() {
@@ -836,11 +990,18 @@ void QueryViewController::sl_elementSelected(QDActorPrototype* proto) {
 }
 
 void QueryViewController::sl_pasteSample(QDDocument* content) {
+    if(!scene->getScheme()->getActors().isEmpty()) {
+        if (!confirmModified()) {
+            return;
+        }
+    }
     tabs->setCurrentIndex(ElementsTab);
     scene->clearScene();
     QList<QDDocument*> docList = ( QList<QDDocument*>() << content );
     QDSceneSerializer::doc2scene(scene, docList);
     sl_updateTitle();
+    scene->setModified(false);
+    schemeUri.clear();
 }
 
 void QueryViewController::sl_selectEditorCell(const QString& link) {
@@ -848,7 +1009,23 @@ void QueryViewController::sl_selectEditorCell(const QString& link) {
 }
 
 void QueryViewController::sl_updateTitle() {
-    setWindowName(tr("Query Designer - %1").arg(scene->getLabel()));
+    setWindowTitle(tr("Query Designer - %1").arg(scene->getLabel()));
+}
+
+void QueryViewController::sl_setGlobalStrand(QAction* a) {
+    QDScheme* scheme = scene->getScheme();
+    QDStrandOption old = scheme->getStrand();
+    if (a==bothStrandsAction) {
+        scheme->setStrand(QDStrand_Both);
+    } else if (a==directStrandAction) {
+        scheme->setStrand(QDStrand_DirectOnly);
+    } else {
+        assert(a==complementStrandAction);
+        scheme->setStrand(QDStrand_ComplementOnly);
+    }
+    if (scheme->getStrand()!=old) {
+        scene->setModified(true);
+    }
 }
 
 void QueryViewController::sl_scrollUp() {
@@ -873,6 +1050,30 @@ void QueryViewController::setupConstraintEditor(QDConstraint* c) {
     }
 }
 
+bool QueryViewController::confirmModified() {
+    if (scene->isModified()) {
+        AppContext::getMainWindow()->getMDIManager()->activateWindow(this);
+        int ret = QMessageBox::question(this, tr("Query Designer"),
+            tr("The schema has been modified.\n"
+            "Do you want to save changes?"),
+            QMessageBox::Save | QMessageBox::Discard
+            | QMessageBox::Cancel,
+            QMessageBox::Save);
+        if (QMessageBox::Cancel == ret) {
+            return false;
+        } else if (QMessageBox::Save == ret){
+            sl_saveScene();
+        }
+    }
+    return true;
+}
+
+void QueryViewController::enableSaveAction( bool enable ) {
+    if (saveAction) {
+        saveAction->setEnabled(enable);
+    }
+}
+
 /************************************************************************/
 /* AddConstraintDialog                                                  */
 /************************************************************************/
@@ -882,7 +1083,7 @@ AddConstraintDialog::AddConstraintDialog(QueryScene* _scene, QDDistanceType _kin
 : scene(_scene), kind(_kind) {
     setupUi(this);
 
-    QString title = "Add %1 constraint";
+    QString title = "Add %1 Constraint";
     switch (kind)
     {
     case E2S:
@@ -964,12 +1165,12 @@ QPixmap QDUtils::generateSnapShot( QueryScene* scene, const QRect& rect) {
 
     QPixmap pixmap(bounds.size().toSize());
     if (pixmap.isNull()) { // failed to allocate 
-        uiLog.trace(QString("Failed to allocate pixmap for qd-scene, bounds: x:%1 y:%2 w:%3 h:%4")
+        uiLog.trace(QString("Failed to allocate pixmap for the QD scene, bounds: x:%1 y:%2 w:%3 h:%4")
             .arg(bounds.x()).arg(bounds.y()).arg(bounds.width()).arg(bounds.height()));
         QPixmap naPixmap = QPixmap(rect.size());
         naPixmap.fill();
         QPainter p(&naPixmap);
-        p.drawText(naPixmap.rect(), Qt::AlignHCenter | Qt::AlignTop, QueryScene::tr("Preview is not available"));
+        p.drawText(naPixmap.rect(), Qt::AlignHCenter | Qt::AlignTop, QueryScene::tr("Preview is not available."));
         return naPixmap;
     }
     pixmap.fill();
