@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "QueryViewItems.h"
 #include "QueryViewController.h"
@@ -37,8 +48,8 @@ namespace U2 {
 #define MARGIN 4
 #define ARR_W 15
 QDElement::QDElement(QDSchemeUnit* _unit)
-: unit(_unit), font(QFont()), bound(0,0,3*ANNOTATION_MIN_SIZE,ANNOTATION_MIN_SIZE),
-dragging(false), itemResizeFlags(0), highlighted(false), extendedHeight(ANNOTATION_MIN_SIZE) {
+: highlighted(false), unit(_unit), font(QFont()), bound(0,0,3*ANNOTATION_MIN_SIZE,ANNOTATION_MIN_SIZE),
+dragging(false), extendedHeight(ANNOTATION_MIN_SIZE), itemResizeFlags(0) {
     setFlag(QGraphicsItem::ItemIsSelectable, true);
 #if (QT_VERSION >= QT_VERSION_CHECK(4, 6, 0))
     setFlag(QGraphicsItem::ItemSendsGeometryChanges, true);
@@ -50,7 +61,7 @@ dragging(false), itemResizeFlags(0), highlighted(false), extendedHeight(ANNOTATI
 
     QDParameters* params = unit->getActor()->getParameters();
     connect(params, SIGNAL(si_modified()), SLOT(sl_refresh()));
-    connect(unit->getActor(), SIGNAL(si_directionChanged(QDActor::Direction)), SLOT(sl_refresh()));
+    connect(unit->getActor(), SIGNAL(si_strandChanged(QDStrandOption)), SLOT(sl_refresh()));
 
     itemDescription = new QDElementDescription(this);
     itemDescription->setDocument(doc);
@@ -164,13 +175,8 @@ void QDElement::saveState(QDElementStatement* el) const {
 }
 
 void QDElement::sl_refresh() {
-    QDActor* a = qobject_cast<QDActor*>(sender());
-    if (a) {
-        printf("");
-    }
     QString baseHtml = "<center>" + getHeaderString();
     QueryScene* qs = qobject_cast<QueryScene*>(scene());
-    assert(qs);
     if (qs && !qs->showActorDesc()) {
         doc->setHtml(baseHtml);
     }
@@ -215,7 +221,7 @@ QString QDElement::getHeaderString() const {
     return res;
 }
 
-bool QDElement::isLinkedWith(QDElement* other, QDDistanceType kind) {
+bool QDElement::isLinkedWith(QDElement* /*other*/, QDDistanceType /*kind*/) {
     /*foreach(Footnote* linkIt, links) {
         if(other->links.contains(linkIt) && linkIt->kind()==kind) {
             return true;
@@ -301,11 +307,6 @@ QPointF QDElement::getLeftConnector() {
     return mapToScene(QPointF(boundingRect().left(), (boundingRect().top() + boundingRect().bottom())/2));
 }
 
-void QDElement::mousePressEvent(QGraphicsSceneMouseEvent *event) {
-    //dragPoint = event->pos();
-    QGraphicsItem::mousePressEvent(event);
-}
-
 void QDElement::mouseMoveEvent(QGraphicsSceneMouseEvent *event) {
     if(event->buttons() & Qt::LeftButton) {
         foreach(Footnote* link, links) {
@@ -325,8 +326,9 @@ void QDElement::mouseMoveEvent(QGraphicsSceneMouseEvent *event) {
             newPos.ry()+=p.y();
         }
         setPos(newPos);
+    } else {
+        QGraphicsItem::mouseMoveEvent(event);
     }
-    QGraphicsItem::mouseMoveEvent(event);
 }
 
 void QDElement::mouseReleaseEvent(QGraphicsSceneMouseEvent *event) {
@@ -480,7 +482,6 @@ bool QDElement::sceneEvent(QEvent *event) {
         }
         case QEvent::GraphicsSceneHoverLeave:
         case QEvent::GraphicsSceneMouseRelease:
-            unsetCursor();
             itemResizeFlags = 0;
             break;
         case QEvent::GraphicsSceneMouseMove:
@@ -592,22 +593,21 @@ bool QDElement::sceneEvent(QEvent *event) {
                         }
                     }
 
-                    prepareGeometryChange();
-
                     //update
                     updateDescription();
-                    qs->update(qs->rulerArea());
                     updateFootnotes();
+                    qs->setModified(true);
+                    qs->update();
                 }
             }
         }
         break;
+        default:;
     }
 
     if(itemResizeFlags) {
         return true;
-    }
-    else {
+    } else {
         return QGraphicsItem::sceneEvent(event);
     }
 }
@@ -622,6 +622,25 @@ QVariant QDElement::itemChange( GraphicsItemChange change, const QVariant & valu
                 if (qs==NULL) {
                     return newPos;
                 }
+                // Adjust position for item to fit in row
+                qreal start = qs->annotationsArea().top();
+                newPos.setY(round(newPos.y() - start, GRID_STEP) + start);
+                QRectF rect = qs->annotationsArea();
+                rect.setHeight(rect.height()-boundingRect().height());
+                rect.setWidth(rect.width()-boundingRect().width());
+                if (!rect.contains(newPos)) {
+                    if (newPos.y()>rect.bottom()) {
+                        int prevRowsNum = qs->getRowsNumber();
+                        qreal bottomEdge = newPos.y() + boundingRect().height();
+                        int reqRowNum = (bottomEdge - qs->annotationsArea().top())/GRID_STEP;
+                        int rowNum = qMax(prevRowsNum, reqRowNum);
+                        qs->setRowsNumber(rowNum);
+                    }
+                    // Keep the item inside the annotation area
+                    newPos.setX(qBound(rect.left(), newPos.x(), rect.left() + QueryScene::MAX_SCENE_SIZE.width()));
+                    newPos.setY(qMax(newPos.y(), rect.top()));
+                }
+                
                 //prevent collision
                 QRectF itemRect = boundingRect();
                 const QPointF& topLeft = mapToScene(itemRect.topLeft());
@@ -650,8 +669,7 @@ QVariant QDElement::itemChange( GraphicsItemChange change, const QVariant & valu
                         if(right.x()-left.x()<=0) {
                             return oldPos;
                         }
-                    }
-                    else {
+                    } else {
                         QPointF right = fn->getDstPoint();
                         right+=newPos-scenePos();
                         QPointF left = fn->getSrcPoint();
@@ -660,25 +678,6 @@ QVariant QDElement::itemChange( GraphicsItemChange change, const QVariant & valu
                         }
                     }
                 }
-                //////////////////////////////////////////////////////////////////////////
-                qreal start = qs->annotationsArea().top();
-                newPos.setY(round(newPos.y() - start, GRID_STEP) + start);
-                QRectF rect = qs->annotationsArea();
-                rect.setHeight(rect.height()-boundingRect().height());
-                rect.setWidth(rect.width()-boundingRect().width());
-                if (!rect.contains(newPos)) {
-                    if (newPos.y()>rect.bottom()) {
-                        int prevRowsNum = qs->getRowsNumber();
-                        qreal bottomEdge = newPos.y() + boundingRect().height();
-                        int reqRowNum = (bottomEdge - qs->annotationsArea().top())/GRID_STEP;
-                        int rowNum = qMax(prevRowsNum, reqRowNum);
-                        qs->setRowsNumber(rowNum);
-                    }
-                    // Keep the item inside the annotation area
-                    newPos.setX(qMin(rect.right(), qMax(newPos.x(), rect.left())));
-                    newPos.setY(qMax(newPos.y(), rect.top()));
-                }
-                //////////////////////////////////////////////////////////////////////////
                 return newPos;
             }
             break;
@@ -689,7 +688,19 @@ QVariant QDElement::itemChange( GraphicsItemChange change, const QVariant & valu
                     return QGraphicsItem::itemChange(change, value);
                 }
                 qs->sl_adaptRowsNumber();
+                
+                QRectF rect = qs->sceneRect();
+                qreal rightEdge = mapRectToScene(boundingRect()).right();
+                qreal min = rect.left() + QueryScene::DEFAULT_SCENE_SIZE.width();
+                qreal max = rect.left() + QueryScene::MAX_SCENE_SIZE.width();
+                rightEdge = qBound(min, rightEdge, max);
+                if (rightEdge > rect.right()) {
+                    rect.setRight(rightEdge);
+                    qs->setSceneRect(rect);
+                }
+                
                 updateFootnotes();
+                qs->setModified(true);
             }
             break;
         case ItemSceneChange:
@@ -704,18 +715,11 @@ QVariant QDElement::itemChange( GraphicsItemChange change, const QVariant & valu
             if(qVariantValue<QGraphicsScene*>(value)!=NULL) {
                 sl_refresh();
                 adaptSize();
-                {
-                    QueryScene* qs = qobject_cast<QueryScene*>(scene());
-                    assert(qs);
-                    QueryViewController* view = qs->getViewController();
-                    /*connect(itemDescription, SIGNAL(linkActivated(const QString&)),
-                        view, SLOT(sl_selectEditorCell(const QString&)));*/
-                    if (view) {
-                        connect(itemDescription, SIGNAL(linkClicked(const QString&)),
-                            view, SLOT(sl_selectEditorCell(const QString&)));
-                    }
-                    connect(itemDescription, SIGNAL(linkHovered(const QString&)),
-                        SLOT(sl_onHoverLink(const QString&)));
+                QueryScene* qs = qobject_cast<QueryScene*>(scene());
+                QueryViewController* view = qs->getViewController();
+                if (view) {
+                    connect(itemDescription, SIGNAL(linkActivated(const QString&)), view, SLOT(sl_selectEditorCell(const QString&)));
+                    connect(itemDescription, SIGNAL(linkHovered(const QString&)), SLOT(sl_onHoverLink(const QString&)));
                 }
             }
             break;
@@ -735,16 +739,12 @@ void QDElement::updateFootnotes() {
         fn->updatePos();
     }
     view->setViewportUpdateMode(mode);
-    QRectF area = qs->footnotesArea();
-    area.setTop(qs->annotationsArea().bottom());
-    qs->update(area);
 }
 
 void QDElement::sl_onHoverLink(const QString &link) {
     if (link.isEmpty()) {
         unsetCursor();
-    }
-    else {
+    } else {
         setCursor(Qt::PointingHandCursor);
     }
 }
@@ -753,11 +753,9 @@ void QDElement::sl_onHoverLink(const QString &link) {
 /* QDElementDescription                                                 */
 /************************************************************************/
 
-QDElementDescription::QDElementDescription(QGraphicsItem* parent/* =NULL */)
-: QGraphicsTextItem(parent), curLnk("") {
+QDElementDescription::QDElementDescription(QGraphicsItem* parent/* =NULL */) : QGraphicsTextItem(parent) {
     setAcceptHoverEvents(true);
     setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::LinksAccessibleByKeyboard);
-    connect(this, SIGNAL(linkHovered(const QString&)), SLOT(sl_setCurrentLink(const QString&)));
 }
 
 QRectF QDElementDescription::boundingRect() const {
@@ -772,32 +770,30 @@ void QDElementDescription::paint(QPainter *painter, const QStyleOptionGraphicsIt
     QGraphicsTextItem::paint(painter, &deselectedOption, widget);
 }
 
+// subscribe to mouse release event (link activation in QGraphicsTextItem) by accepting mouse press
 void QDElementDescription::mousePressEvent(QGraphicsSceneMouseEvent *event) {
-    if (event->buttons()&Qt::LeftButton) {
-        emit linkClicked(curLnk);
-    }
     QGraphicsTextItem::mousePressEvent(event);
+    event->accept();
 }
 
 bool QDElementDescription::sceneEvent(QEvent *event) {
     bool res = QGraphicsTextItem::sceneEvent(event);
-    switch (event->type())
-    {
-    case QEvent::GraphicsSceneHoverEnter:
-    //case QEvent::GraphicsSceneHoverLeave:
-    case QEvent::GraphicsSceneHoverMove:
-    case QEvent::GraphicsSceneMouseRelease:
-    case QEvent::GraphicsSceneMouseMove:
-        {
-            QGraphicsSceneMouseEvent* me = static_cast<QGraphicsSceneMouseEvent*>(event);
-            assert(me);
-            QDElement* parent = qgraphicsitem_cast<QDElement*>(parentItem());
-            assert(parent);
-            me->setPos(mapToParent(me->pos()));
-            res = parent->sceneEvent(me);
-        }
-    default:
-        break;
+    switch (event->type()) {
+        case QEvent::GraphicsSceneHoverEnter:
+        case QEvent::GraphicsSceneHoverMove:
+        case QEvent::GraphicsSceneMouseRelease:
+        case QEvent::GraphicsSceneMouseMove:
+        case QEvent::GraphicsSceneMousePress:
+            {
+                QGraphicsSceneMouseEvent* me = static_cast<QGraphicsSceneMouseEvent*>(event);
+                QDElement* parent = qgraphicsitem_cast<QDElement*>(parentItem());
+                assert(parent);
+                me->setPos(mapToParent(me->pos()));
+                res = parent->sceneEvent(me);
+            }
+            break;
+        default:
+            break;
     }
     return res;
 }
@@ -808,6 +804,9 @@ bool QDElementDescription::sceneEvent(QEvent *event) {
 
 Footnote::Footnote(QDElement* _from, QDElement* _to, QDDistanceType _distType, QDConstraint* parent, const QFont& _font)
 : from(_from), to(_to), distType(_distType), constraint(parent), font(_font), draging(false) {
+#if (QT_VERSION >= QT_VERSION_CHECK(4, 6, 0))
+    setFlag(QGraphicsItem::ItemSendsGeometryChanges, true);
+#endif
     connect(constraint->getParameters(), SIGNAL(si_modified()), SLOT(sl_update()));
     init();
 }
@@ -866,7 +865,6 @@ void Footnote::updatePos() {
     //assert(qs->footnotesArea().contains(QPointF(xPos,y)));
     setPos(xPos, y);
     updateLines(QPointF(xPos, y));
-    qs->updateDescriptionPos();
 }
 
 void Footnote::updateLines(const QPointF& p) {
@@ -891,8 +889,7 @@ QVariant Footnote::itemChange(GraphicsItemChange change, const QVariant &value)
             scene()->addItem(leftRef);
             scene()->addItem(rightRef);
         }
-    }
-    else if(change==ItemSceneChange){
+    } else if(change==ItemSceneChange) {
         if(qVariantValue<QGraphicsScene*>(value)==NULL) {
             scene()->removeItem(leftRef);
             scene()->removeItem(rightRef);
@@ -901,6 +898,10 @@ QVariant Footnote::itemChange(GraphicsItemChange change, const QVariant &value)
             from->links.removeAll(this);
             to->links.removeAll(this);
         }
+    } else if (change==ItemPositionHasChanged) {
+        updateLines(scenePos());
+        leftRef->update();
+        rightRef->update();
     }
     return QGraphicsItem::itemChange(change, value);
 }
@@ -1088,7 +1089,7 @@ bool QDDescriptionItem::sceneEvent(QEvent *event) {
         case QEvent::GraphicsSceneMouseMove:
         {
             if(resize) {
-                QueryScene* qs = qobject_cast<QueryScene*>(scene());
+                //QueryScene* qs = qobject_cast<QueryScene*>(scene());
                 QGraphicsSceneMouseEvent* me = static_cast<QGraphicsSceneMouseEvent *>(event);
                 if(me->buttons()&Qt::LeftButton) {
                     QPointF p = me->pos();
@@ -1106,6 +1107,7 @@ bool QDDescriptionItem::sceneEvent(QEvent *event) {
             }
         }
         break;
+        default:;
     }
     return QGraphicsTextItem::sceneEvent(event);
 }
@@ -1143,7 +1145,7 @@ QRectF QDRulerItem::txtBound() const {
     return txtBound;
 }
 
-void QDRulerItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget ) {
+void QDRulerItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *, QWidget * ) {
     if (rightPos - leftPos < MIN_LEN_TO_DRAW) {
         return;
     }
