@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QCryptographicHash>
 #include <QtCore/QThread>
@@ -92,7 +103,7 @@ qint64 RemoteServiceMachine::runTask(TaskStateInfo& si, const QString & taskFact
     }    
 
     initSession(si);
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return taskId;
     }
     
@@ -104,7 +115,7 @@ qint64 RemoteServiceMachine::runTask(TaskStateInfo& si, const QString & taskFact
     
     RunRemoteTaskRequest request(session.get(), schema, inUrls);
     QMap<QString,UctpElementData> replyData = sendRequest(si, request);
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return taskId;
     }
     UctpElementData elData = replyData.value(UctpElements::TASK);
@@ -145,7 +156,7 @@ static QString getElementValueByNameAttr(const QString& name, const QList<UctpEl
     GetRemoteTaskPropertyRequest request(session.get(), taskId, properties);
 
     QMap<QString,UctpElementData> replyData = sendRequest(si, request);
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return state;
     }
 
@@ -171,7 +182,7 @@ int RemoteServiceMachine::getTaskProgress(TaskStateInfo& si, qint64 taskId) {
     
     QMap<QString,UctpElementData> replyData = sendRequest(si, request);
     
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return res;
     }
 
@@ -195,7 +206,7 @@ void RemoteServiceMachine::getTaskResult(TaskStateInfo& si, qint64 taskId, const
         GetRemoteTaskResultRequst request(session.get(), taskId);
 
         QMap<QString,UctpElementData> replyData = sendRequest(si, request);
-        if (si.hasErrors()) {
+        if (si.hasError()) {
             return;
         }
 
@@ -226,7 +237,7 @@ QString RemoteServiceMachine::getTaskErrorMessage(TaskStateInfo& si, qint64 task
     GetRemoteTaskPropertyRequest request(session.get(), taskId, properties);
 
     QMap<QString,UctpElementData> replyData = sendRequest(si, request);
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return res;
     }
 
@@ -245,13 +256,13 @@ void RemoteServiceMachine::ping(TaskStateInfo& si) {
 QString RemoteServiceMachine::getServerName(TaskStateInfo& si) {
     QString res;
     initSession(si);
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return res;
     }
      
     GetGlobalPropertyRequest request(session.get(), BaseGlobalProperties::HOST_NAME);
     QMap<QString,UctpElementData> replyData = sendRequest(si, request);
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return res;
     }
     UctpElementData elData = replyData.value(UctpElements::PROPERTY);
@@ -264,44 +275,44 @@ QString RemoteServiceMachine::getServerName(TaskStateInfo& si) {
 void RemoteServiceMachineReplyHandler::sl_onReplyFinished(QNetworkReply* reply ) {
     assert(reply != NULL);
     assert(eventLoop != NULL);
-	si->setStateDesc("");
+    si->setDescription("");
     if (reply->error() == QNetworkReply::NoError) {
         bool parseOk = protocolHandler->parseReply(reply, command, *replyData);
         if (!parseOk) {
             si->setError(QString(tr("Failed to parse server response. %1")).arg(protocolHandler->getErrorText()));
         }
     } else {
-		if(!si->hasErrors()) {
-			si->setError(reply->errorString());
-		}
+        if(!si->hasError()) {
+            si->setError(reply->errorString());
+        }
     }
     
     eventLoop->exit();
 }
 
 void RemoteServiceMachineReplyHandler::sl_onUploadProgress(qint64 bytesSent, qint64 bytesTotal) {
-	if(bytesTotal != -1) {
-		si->setStateDesc(RemoteServiceMachineReplyHandler::tr("Uploading %1%").arg((int)(bytesSent / (float)bytesTotal * 100)));
-	}
-	inactiveCount = 0;
+    if(bytesTotal != -1) {
+        si->setDescription(RemoteServiceMachineReplyHandler::tr("Uploading %1%").arg((int)(bytesSent / (float)bytesTotal * 100)));
+    }
+    inactiveCount = 0;
 }
 
 void RemoteServiceMachineReplyHandler::sl_onDownloadProgress(qint64 bytesSent, qint64 bytesTotal) {
-	if(bytesTotal != -1) {
-		si->setStateDesc(RemoteServiceMachineReplyHandler::tr("Downloading %1%").arg((int)(bytesSent / (float)bytesTotal * 100)));
-	}
-	inactiveCount = 0;
+    if(bytesTotal != -1) {
+        si->setDescription(RemoteServiceMachineReplyHandler::tr("Downloading %1%").arg((int)(bytesSent / (float)bytesTotal * 100)));
+    }
+    inactiveCount = 0;
 }
 
 void RemoteServiceMachineReplyHandler::sl_onTimer() {
-	if(si->cancelFlag) {
-		reply->abort();
-	}
-	if(static_cast<QTimer*>(sender())->interval() * inactiveCount > requestTimeout ) {
-		si->setError(RemoteServiceMachineReplyHandler::tr("Request inactivity time is up"));
-		reply->abort();
-	}
-	inactiveCount++;
+    if(si->cancelFlag) {
+        reply->abort();
+    }
+    if(static_cast<QTimer*>(sender())->interval() * inactiveCount > requestTimeout ) {
+        si->setError(RemoteServiceMachineReplyHandler::tr("Request inactivity time is up"));
+        reply->abort();
+    }
+    inactiveCount++;
 }
 
 
@@ -319,7 +330,7 @@ QMap<QString,UctpElementData> RemoteServiceMachine::sendRequest(TaskStateInfo& s
         return replyData;
     }
     
-    qint64 dataLength = dataSource->size();
+    //qint64 dataLength = dataSource->size();
     QEventLoop eventLoop;
     QNetworkAccessManager networkManager;
 
@@ -328,19 +339,19 @@ QMap<QString,UctpElementData> RemoteServiceMachine::sendRequest(TaskStateInfo& s
         
 #ifndef QT_NO_OPENSSL
     QSslConfiguration sslConf = QSslConfiguration::defaultConfiguration();
-	
+
     sslConf.setProtocol(sslProtocol);
     request.setSslConfiguration(sslConf);
 #endif
 
     QNetworkReply *reply = networkManager.post(request, dataSource );
-	QTimer timer;
-	RemoteServiceMachineReplyHandler handler(protocolHandler.get(), &eventLoop, &replyData, command, &si, reply, AppContext::getAppSettings()->getNetworkConfiguration()->remoteRequestTimeout() * 1000);
+    QTimer timer;
+    RemoteServiceMachineReplyHandler handler(protocolHandler.get(), &eventLoop, &replyData, command, &si, reply, AppContext::getAppSettings()->getNetworkConfiguration()->remoteRequestTimeout() * 1000);
 
-	connect(&networkManager, SIGNAL(finished(QNetworkReply*)), &handler, SLOT(sl_onReplyFinished(QNetworkReply*)));
-	connect(reply, SIGNAL(uploadProgress(qint64, qint64)), &handler, SLOT(sl_onUploadProgress(qint64, qint64)));
-	connect(reply, SIGNAL(downloadProgress(qint64, qint64)), &handler, SLOT(sl_onDownloadProgress(qint64, qint64)));
-	connect(&timer, SIGNAL(timeout()), &handler, SLOT(sl_onTimer()));
+    connect(&networkManager, SIGNAL(finished(QNetworkReply*)), &handler, SLOT(sl_onReplyFinished(QNetworkReply*)));
+    connect(reply, SIGNAL(uploadProgress(qint64, qint64)), &handler, SLOT(sl_onUploadProgress(qint64, qint64)));
+    connect(reply, SIGNAL(downloadProgress(qint64, qint64)), &handler, SLOT(sl_onDownloadProgress(qint64, qint64)));
+    connect(&timer, SIGNAL(timeout()), &handler, SLOT(sl_onTimer()));
 
 #ifndef QT_NO_OPENSSL
     // QNetworkAccessManager bug workaround:
@@ -351,11 +362,11 @@ QMap<QString,UctpElementData> RemoteServiceMachine::sendRequest(TaskStateInfo& s
     connect(&networkManager, SIGNAL(sslErrors( QNetworkReply *, const QList<QSslError> & )), SLOT(sl_onSslErrors( QNetworkReply*, const QList<QSslError>& )), connectionType );
 #endif
 
-	timer.start(1000);
+    timer.start(1000);
 
     eventLoop.exec();
 
-	timer.stop();
+    timer.stop();
 
     return replyData;
 }
@@ -380,7 +391,7 @@ void RemoteServiceMachine::initSession(TaskStateInfo& si) {
     InitSessionRequest request(userName, pass);
     
     QMap<QString,UctpElementData> replyData =  sendRequest(si, request);
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return;
     }
     UctpElementData elData = replyData.value(UctpElements::SESSION);
@@ -422,7 +433,7 @@ void RemoteServiceMachine::getTaskProperties( TaskStateInfo& si, qint64 taskId,
     GetRemoteTaskPropertyRequest request( session.get(), taskId, properties.keys());
 
     QMap<QString,UctpElementData> replyData = sendRequest(si, request);
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return;
     }
     QList<UctpElementData> propertyList = replyData.values(UctpElements::PROPERTY);
@@ -445,14 +456,14 @@ QList<qint64> RemoteServiceMachine::getFinishedTasks(TaskStateInfo& si) {
 QList<qint64> RemoteServiceMachine::getTasksList( TaskStateInfo& si, const QByteArray& taskState) {
     QList<qint64> res;
     initSession(si);
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return res;
     }   
 
     GetGlobalPropertyRequest request( session.get(), taskState);
 
     QMap<QString,UctpElementData> replyData = sendRequest(si, request);
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return res;
     }
     QList<UctpElementData> propertyList = replyData.values(UctpElements::PROPERTY);
