@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "FindRepeatsDialog.h"
 //#include "FindRepeatsTask.h"
@@ -187,7 +198,7 @@ void FindRepeatsDialog::sl_endRangeChanged(int i) {
 }
 
 
-bool FindRepeatsDialog::getRegions(QCheckBox* cb, QLineEdit* le, QVector<LRegion>& res) {
+bool FindRepeatsDialog::getRegions(QCheckBox* cb, QLineEdit* le, QVector<U2Region>& res) {
     bool enabled = cb->isChecked();
     QString names = le->text();
     if (!enabled || names.isEmpty()) {
@@ -198,7 +209,7 @@ bool FindRepeatsDialog::getRegions(QCheckBox* cb, QLineEdit* le, QVector<LRegion
     foreach(AnnotationTableObject* obj, aObjs) {
         foreach(Annotation* a, obj->getAnnotations()) {
             if (aNames.contains(a->getAnnotationName())) {
-                res << a->getLocation().toVector();
+                res << a->getRegions();
             }
         }
     }
@@ -210,13 +221,13 @@ bool FindRepeatsDialog::getRegions(QCheckBox* cb, QLineEdit* le, QVector<LRegion
     return true;
 }
 
-LRegion FindRepeatsDialog::getActiveRange() const {
-    LRegion range(0, sc->getSequenceLen());
+U2Region FindRepeatsDialog::getActiveRange() const {
+    U2Region range(0, sc->getSequenceLen());
     if (selectionRangeButton->isChecked() && !sc->getSequenceSelection()->isEmpty()) {
         range = sc->getSequenceSelection()->getSelectedRegions().at(0);
     } else if (customRangeButton->isChecked()) {
         range.startPos = customRangeStartBox->value();
-        range.len = customRangeEndBox->value() - range.startPos;
+        range.length = customRangeEndBox->value() - range.startPos;
     }
     return range;
 }
@@ -227,15 +238,15 @@ void FindRepeatsDialog::accept() {
     int minDist = minDistCheck->isChecked() ? minDistBox->value() : 0;
     int maxDist = maxDistCheck->isChecked() ? maxDistBox->value(): sc->getSequenceLen();
     bool inverted = invertCheck->isChecked();
-    LRegion range = getActiveRange();
-    assert(range.len > 0);
+    U2Region range = getActiveRange();
+    assert(range.length > 0);
     assert(minDist <= maxDist);
     QString err = ac->validate();
     if (!err.isEmpty()) {
         QMessageBox::critical(this, tr("Error"), err);
         return;
     }
-    QVector<LRegion> fitRegions, aroundRegions, filterRegions;
+    QVector<U2Region> fitRegions, aroundRegions, filterRegions;
     if (!getRegions(annotationFitCheck, annotationFitEdit, fitRegions) 
         || !getRegions(annotationAroundKeepCheck, annotationAroundKeepEdit, aroundRegions) 
         || !getRegions(annotationAroundFilterCheck, annotationAroundFilterEdit, filterRegions)) 
@@ -291,7 +302,7 @@ void FindRepeatsDialog::saveState() {
 }
 
 quint64 FindRepeatsDialog::areaSize() const {
-    quint64 range = getActiveRange().len;
+    quint64 range = getActiveRange().length;
     if (range <=0) {
         return 0;
     }
