@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "FindTandemsDialog.h"
 
@@ -175,7 +186,7 @@ void FindTandemsDialog::sl_endRangeChanged(int i) {
 }
 
 
-bool FindTandemsDialog::getRegions(QCheckBox* cb, QLineEdit* le, QVector<LRegion>& res) {
+bool FindTandemsDialog::getRegions(QCheckBox* cb, QLineEdit* le, QVector<U2Region>& res) {
     bool enabled = cb->isChecked();
     QString names = le->text();
     if (!enabled || names.isEmpty()) {
@@ -186,7 +197,7 @@ bool FindTandemsDialog::getRegions(QCheckBox* cb, QLineEdit* le, QVector<LRegion
     foreach(AnnotationTableObject* obj, aObjs) {
         foreach(Annotation* a, obj->getAnnotations()) {
             if (aNames.contains(a->getAnnotationName())) {
-                res << a->getLocation().toVector();
+                res << a->getRegions();
             }
         }
     }
@@ -198,13 +209,13 @@ bool FindTandemsDialog::getRegions(QCheckBox* cb, QLineEdit* le, QVector<LRegion
     return true;
 }
 
-LRegion FindTandemsDialog::getActiveRange() const {
-    LRegion range(0, sc->getSequenceLen());
+U2Region FindTandemsDialog::getActiveRange() const {
+    U2Region range(0, sc->getSequenceLen());
     if (selectionRangeButton->isChecked() && !sc->getSequenceSelection()->isEmpty()) {
         range = sc->getSequenceSelection()->getSelectedRegions().at(0);
     } else if (customRangeButton->isChecked()) {
         range.startPos = customRangeStartBox->value();
-        range.len = customRangeEndBox->value() - range.startPos;
+        range.length = customRangeEndBox->value() - range.startPos;
     }
     return range;
 }
@@ -213,8 +224,8 @@ void FindTandemsDialog::accept() {
     int minPeriod = minPeriodBox->value();
     int maxPeriod = maxPeriodBox->value();
 //    int identPerc = identityBox->value();
-    LRegion range = getActiveRange();
-    assert(range.len > 0);
+    U2Region range = getActiveRange();
+    assert(range.length > 0);
     QString err = ac->validate();
     if (!err.isEmpty()) {
         QMessageBox::critical(this, tr("Error"), err);
@@ -251,7 +262,7 @@ void FindTandemsDialog::saveState() {
 }
 
 quint64 FindTandemsDialog::areaSize() const {
-    quint64 range = getActiveRange().len;
+    quint64 range = getActiveRange().length;
     if (range <=0) {
         return 0;
     }
