@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_FIND_TANDEMS_DIALOG_H_
 #define _U2_FIND_TANDEMS_DIALOG_H_
@@ -16,7 +27,7 @@
 
 #include <U2Core/PluginModel.h>
 #include <U2Gui/ObjectViewModel.h>
-#include <U2Core/LRegion.h>
+#include <U2Core/U2Region.h>
 
 #include <QtGui/QDialog>
 #include <QtGui/QCheckBox>
@@ -48,10 +59,10 @@ protected slots:
     //void sl_minMaxToggle(bool);
 
 private:
-    LRegion getActiveRange() const;
+    U2Region getActiveRange() const;
     void saveState();
     QStringList getAvailableAnnotationNames() const;
-    bool getRegions(QCheckBox* cb, QLineEdit* le, QVector<LRegion>& res);
+    bool getRegions(QCheckBox* cb, QLineEdit* le, QVector<U2Region>& res);
     void prepareAMenu(QToolButton* tb, QLineEdit* le, const QStringList& names);
     void updateStatus();
 
