@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "RF_SArray_TandemFinder.h"
 #include "RFConstants.h"
@@ -35,7 +46,7 @@ Task(tr("Find repeats to annotations"), TaskFlags_NR_FOSCOE), annName(_an), annG
 
 QList<Task*> FindTandemsToAnnotationsTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return res;
     }
 
@@ -63,13 +74,13 @@ QList<SharedAnnotationData> FindTandemsToAnnotationsTask::importTandemAnnotation
             const quint32 tandemEnd = tan.offset+tan.size+seqStart;
             quint32 pos = tan.offset+seqStart+offset;
             for(; pos<=tandemEnd-tan.repeatLen; pos+=tan.repeatLen){
-                ad->location << LRegion(pos, tan.repeatLen);
+                ad->location->regions << U2Region(pos, tan.repeatLen);
             }
-            if (ad->location.isEmpty()){
+            if (ad->location->isEmpty()){
                 continue;
             }
-            ad->qualifiers.append(Qualifier("repeat_len", QString::number(tan.repeatLen)));
-            ad->qualifiers.append(Qualifier("tandem_size", QString::number(tan.size)));
+            ad->qualifiers.append(U2Qualifier("repeat_len", QString::number(tan.repeatLen)));
+            ad->qualifiers.append(U2Qualifier("tandem_size", QString::number(tan.size)));
             res.append(ad);
             offset++;
         }while(showOverlapped && offset<=maxOffset);
@@ -80,8 +91,8 @@ QList<SharedAnnotationData> FindTandemsToAnnotationsTask::importTandemAnnotation
 TandemFinder::TandemFinder(const FindTandemsTaskSettings& _settings, const DNASequence& directSequence):
 Task(tr("Find tandems"), TaskFlags_FOSCOE),
 settings(_settings),regionCount(0){
-    if (settings.seqRegion.len == 0) {
-        settings.seqRegion= LRegion(0, directSequence.length());
+    if (settings.seqRegion.length == 0) {
+        settings.seqRegion= U2Region(0, directSequence.length());
     }
     startTime = GTimer::currentTimeMicros();
     sequence = (char*)directSequence.constData() + settings.seqRegion.startPos;
@@ -106,7 +117,7 @@ void TandemFinder::prepare(){
     int chunkSize = 32*1024*1024; // optimized for 32Mb mem-chunk
     addSubTask(
         new SequenceWalkerTask(
-            TF_WalkerConfig(sequence, settings.seqRegion.len, chunkSize),
+            TF_WalkerConfig(sequence, settings.seqRegion.length, chunkSize),
                 this,
                 tr("Find tandems"),
                 TaskFlags_NR_FOSCOE
@@ -146,7 +157,7 @@ QList<Task*> TandemFinder::onSubTaskFinished(Task* subTask){
 }
 
 void TandemFinder::onRegion(SequenceWalkerSubtask* t, TaskStateInfo& ti){
-    if(ti.hasErrors()){return;}
+    if(ti.hasError()){return;}
     quint64 offs = t->getRegionSequence() - t->getGlobalConfig().seq;
     QMutexLocker lock(&subtasksQueue); //TODO: fix me
     regionTasks.append(new TandemFinder_Region(regionCount++, t->getRegionSequence(), t->getRegionSequenceLen(), offs, settings));
@@ -203,8 +214,7 @@ ConcreteTandemFinder::ConcreteTandemFinder(QString taskName, const char* _sequen
             suffArrMemory = seqSize*sizeof(quint32)*2;
         }
         suffArrMemory = qMax(suffArrMemory/(1024*1024),1); //in Mb
-        TaskResourceUsage resUsage(RESOURCE_MEMORY, suffArrMemory, true);
-        taskResources.append(resUsage);
+        addTaskResource(TaskResourceUsage(RESOURCE_MEMORY, suffArrMemory, true));
 }
 
 void ConcreteTandemFinder::prepare(){
