@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "RepeatFinderTests.h"
 
@@ -41,8 +52,8 @@ namespace U2 {
 #define ALG_ATTR    "alg"
 
 
-LRegion GTest_FindSingleSequenceRepeatsTask::parseRegion(const QString& n, const QDomElement& el) {
-    LRegion res;
+U2Region GTest_FindSingleSequenceRepeatsTask::parseRegion(const QString& n, const QDomElement& el) {
+    U2Region res;
     QString v = el.attribute(n);
     if (v.isEmpty()) {
         return res;
@@ -57,7 +68,7 @@ LRegion GTest_FindSingleSequenceRepeatsTask::parseRegion(const QString& n, const
     int endPos = v2.toInt();
     if (startPos >= 0 && endPos > startPos) {
         res.startPos = startPos - 1;
-        res.len = endPos - startPos + 1;
+        res.length = endPos - startPos + 1;
     }
     return res;
 }
@@ -135,7 +146,7 @@ static QString getAlgName(RFAlgorithm alg) {
 }
 
 void GTest_FindSingleSequenceRepeatsTask::prepare() {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
     DNASequenceObject * seqObj = getContext<DNASequenceObject>(this, seq);
@@ -198,7 +209,7 @@ void GTest_FindSingleSequenceRepeatsTask::prepare() {
 }
 
 void GTest_FindSingleSequenceRepeatsTask::run() {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
     QVector<RFResult> expectedResults;
@@ -275,7 +286,7 @@ void GTest_FindTandemRepeatsTask::init(XMLTestFormat *tf, const QDomElement& el)
 }
 
 void GTest_FindTandemRepeatsTask::prepare() {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
     //this->getContext(this,"")
@@ -311,7 +322,7 @@ void GTest_FindTandemRepeatsTask::prepare() {
 }
 
 void GTest_FindTandemRepeatsTask::run() {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
     QList<Tandem> expectedResults;
@@ -365,8 +376,8 @@ void GTest_FindTandemRepeatsTask::run() {
 //---------------------------------------------------------------------------------------------------------
 
 
-LRegion GTest_FindRealTandemRepeatsTask::parseRegion(const QString& n, const QDomElement& el) {
-    LRegion res;
+U2Region GTest_FindRealTandemRepeatsTask::parseRegion(const QString& n, const QDomElement& el) {
+    U2Region res;
     QString v = el.attribute(n);
     if (v.isEmpty()) {
         return res;
@@ -381,7 +392,7 @@ LRegion GTest_FindRealTandemRepeatsTask::parseRegion(const QString& n, const QDo
     int endPos = v2.toInt();
     if (startPos >= 0 && endPos > startPos) {
         res.startPos = startPos - 1;
-        res.len = endPos - startPos + 1;
+        res.length = endPos - startPos + 1;
     }
     return res;
 }
@@ -413,7 +424,7 @@ void GTest_FindRealTandemRepeatsTask::init(XMLTestFormat *tf, const QDomElement&
 }
 
 void GTest_FindRealTandemRepeatsTask::prepare() {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
     DNASequenceObject * seqObj = getContext<DNASequenceObject>(this, sequence);
@@ -443,7 +454,7 @@ void GTest_FindRealTandemRepeatsTask::prepare() {
 }
 
 void GTest_FindRealTandemRepeatsTask::run() {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
     QList<Tandem> expectedResults;
@@ -557,7 +568,7 @@ void GTest_SArrayBasedFindTask::init(XMLTestFormat *tf, const QDomElement& el) {
 
 void GTest_SArrayBasedFindTask::prepare()
 {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
     DNASequenceObject * seqObj = getContext<DNASequenceObject>(this, seqObjName);
@@ -583,7 +594,7 @@ void GTest_SArrayBasedFindTask::prepare()
     
     index = new SArrayIndex(seqObj->getSequence().constData(), seqObj->getSequenceLen(), prefixSize, stateInfo, unknownChar, bitMask, bitCharLen);
     
-    if (hasErrors()) {
+    if (hasError()) {
         return;
     }
     
@@ -600,7 +611,7 @@ void GTest_SArrayBasedFindTask::prepare()
 
 void GTest_SArrayBasedFindTask::run()
 {
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return;
     }
     
