@@ -1,19 +1,30 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_REPEAT_FINDER_TESTS_H_
 #define _U2_REPEAT_FINDER_TESTS_H_
 
 #include "RFBase.h"
 
-#include <U2Core/LRegion.h>
+#include <U2Core/U2Region.h>
 
 #include <U2Test/XMLTestUtils.h>
 
@@ -39,12 +50,12 @@ public:
 
     void prepare();
     void run();
-    LRegion parseRegion(const QString& n, const QDomElement& el); 
+    U2Region parseRegion(const QString& n, const QDomElement& el); 
 
     QString     seq, seq2;
     RFAlgorithm alg;
     
-    LRegion     region;
+    U2Region     region;
     
     int         w, c, minD, maxD;
     bool        inverted;
@@ -63,9 +74,9 @@ public:
 
     void prepare();
     void run();
-    LRegion parseRegion(const QString& n, const QDomElement& el); 
+    U2Region parseRegion(const QString& n, const QDomElement& el); 
 
-    LRegion         region;
+    U2Region         region;
     
     char*           string;
     int             minD, maxD;
@@ -86,9 +97,9 @@ public:
 
     void prepare();
     void run();
-    LRegion parseRegion(const QString& n, const QDomElement& el);
+    U2Region parseRegion(const QString& n, const QDomElement& el);
 
-    LRegion         region;
+    U2Region         region;
 
     char*           string;
     int             minD, maxD;
