@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "RepeatWorker.h"
 #include "FindRepeatsDialog.h"
@@ -14,9 +25,10 @@
 #include <U2Lang/IntegralBusModel.h>
 #include <U2Lang/WorkflowEnv.h>
 #include <U2Lang/ActorPrototypeRegistry.h>
-#include <U2Lang/CoreDataTypes.h>
-#include <U2Lang/BioDatatypes.h>
-#include <U2Lang/BioActorLibrary.h>
+#include <U2Lang/BaseTypes.h>
+#include <U2Lang/BaseSlots.h>
+#include <U2Lang/BasePorts.h>
+#include <U2Lang/BaseActorCategories.h>
 #include <U2Designer/DelegateEditors.h>
 #include <U2Lang/CoreLibConstants.h>
 
@@ -55,15 +67,15 @@ void RepeatWorkerFactory::init() {
     QList<PortDescriptor*> p; QList<Attribute*> a;
 
     {
-        Descriptor id(CoreLibConstants::IN_SEQ_PORT_ID, RepeatWorker::tr("Input sequences"), 
+        Descriptor id(BasePorts::IN_SEQ_PORT_ID(), RepeatWorker::tr("Input sequences"), 
                         RepeatWorker::tr("A nucleotide sequence to search repeats in."));
-        Descriptor od(CoreLibConstants::OUT_ANNOTATIONS_PORT_ID, RepeatWorker::tr("Repeat annotations"), 
+        Descriptor od(BasePorts::OUT_ANNOTATIONS_PORT_ID(), RepeatWorker::tr("Repeat annotations"), 
                         RepeatWorker::tr("A set of annotations marking repeats found in the sequence."));
         QMap<Descriptor, DataTypePtr> inM;
-        inM[BioActorLibrary::SEQ_SLOT()] = BioDataTypes::DNA_SEQUENCE_TYPE();
+        inM[BaseSlots::DNA_SEQUENCE_SLOT()] = BaseTypes::DNA_SEQUENCE_TYPE();
         p << new PortDescriptor(id, DataTypePtr(new MapDataType("repeat.seq", inM)), true /*input*/);
         QMap<Descriptor, DataTypePtr> outM;
-        outM[BioActorLibrary::FEATURE_TABLE_SLOT()] = BioDataTypes::ANNOTATION_TABLE_TYPE();
+        outM[BaseSlots::ANNOTATION_TABLE_SLOT()] = BaseTypes::ANNOTATION_TABLE_TYPE();
         p << new PortDescriptor(od, DataTypePtr(new MapDataType("repeat.annotations", outM)), false /*input*/, true /*multi*/);
     }
     {
@@ -78,15 +90,15 @@ void RepeatWorkerFactory::init() {
         Descriptor thd(THREADS_ATTR, RepeatWorker::tr("Parallel threads"), RepeatWorker::tr("Number of parallel threads used for the task."));
 
         FindRepeatsTaskSettings cfg = FindRepeatsDialog::defaultSettings();
-        a << new Attribute(nd, CoreDataTypes::STRING_TYPE(), true, "repeat_unit");
-        a << new Attribute(ld, CoreDataTypes::NUM_TYPE(), false, cfg.minLen);
-        a << new Attribute(idd, CoreDataTypes::NUM_TYPE(), false, cfg.getIdentity());
-        a << new Attribute(mid, CoreDataTypes::NUM_TYPE(), false, cfg.minDist);
-        a << new Attribute(mad, CoreDataTypes::NUM_TYPE(), false, cfg.maxDist);
-        a << new Attribute(ind, CoreDataTypes::BOOL_TYPE(), false, cfg.inverted);
-        a << new Attribute(nsd, CoreDataTypes::BOOL_TYPE(), false, cfg.filterNested);
-        a << new Attribute(ald, CoreDataTypes::NUM_TYPE(), false, cfg.algo);
-        a << new Attribute(thd, CoreDataTypes::NUM_TYPE(), false, cfg.nThreads);
+        a << new Attribute(nd, BaseTypes::STRING_TYPE(), true, "repeat_unit");
+        a << new Attribute(ld, BaseTypes::NUM_TYPE(), false, cfg.minLen);
+        a << new Attribute(idd, BaseTypes::NUM_TYPE(), false, cfg.getIdentity());
+        a << new Attribute(mid, BaseTypes::NUM_TYPE(), false, cfg.minDist);
+        a << new Attribute(mad, BaseTypes::NUM_TYPE(), false, cfg.maxDist);
+        a << new Attribute(ind, BaseTypes::BOOL_TYPE(), false, cfg.inverted);
+        a << new Attribute(nsd, BaseTypes::BOOL_TYPE(), false, cfg.filterNested);
+        a << new Attribute(ald, BaseTypes::NUM_TYPE(), false, cfg.algo);
+        a << new Attribute(thd, BaseTypes::NUM_TYPE(), false, cfg.nThreads);
     }
 
     Descriptor desc(ACTOR_ID, RepeatWorker::tr("Find repeats"), 
@@ -121,7 +133,7 @@ void RepeatWorkerFactory::init() {
     proto->setPrompter(new RepeatPrompter());
     proto->setEditor(new DelegateEditor(delegates));
     proto->setIconPath(":repeat_finder/images/repeats.png");
-    WorkflowEnv::getProtoRegistry()->registerProto(BioActorLibrary::CATEGORY_BASIC(), proto);
+    WorkflowEnv::getProtoRegistry()->registerProto(BaseActorCategories::CATEGORY_BASIC(), proto);
 
     DomainFactory* localDomain = WorkflowEnv::getDomainRegistry()->getById(LocalDomainFactory::ID);
     localDomain->registerEntry(new RepeatWorkerFactory());
@@ -131,8 +143,8 @@ void RepeatWorkerFactory::init() {
  * RepeatPrompter
  ******************************/
 QString RepeatPrompter::composeRichDoc() {
-    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(CoreLibConstants::IN_SEQ_PORT_ID));
-    Actor* producer = input->getProducer(BioActorLibrary::SEQ_SLOT().getId());
+    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(BasePorts::IN_SEQ_PORT_ID()));
+    Actor* producer = input->getProducer(BaseSlots::DNA_SEQUENCE_SLOT().getId());
     QString unsetStr = "<font color='red'>"+tr("unset")+"</font>";
     QString producerName = tr(" from <u>%1</u>").arg(producer ? producer->getLabel() : unsetStr);
     
@@ -144,10 +156,10 @@ QString RepeatPrompter::composeRichDoc() {
         "<br>Detect <u>%3% identical</u> repeats <u>not shorter than %4 bps</u>."
         "<br>Output the list of found regions annotated as <u>%5</u>.")
         .arg(producerName) //sequence from Read Fasta 1
-        .arg(inverted) 
-        .arg(getParameter(IDENTITY_ATTR).toInt())
-        .arg(getParameter(LEN_ATTR).toInt())
-        .arg(resultName);
+        .arg(getHyperlink(INVERT_ATTR, inverted))
+        .arg(getHyperlink(IDENTITY_ATTR, getParameter(IDENTITY_ATTR).toInt()))
+        .arg(getHyperlink(LEN_ATTR, getParameter(LEN_ATTR).toInt()))
+        .arg(getHyperlink(NAME_ATTR, resultName));
     
     return doc;
 }
@@ -159,8 +171,8 @@ RepeatWorker::RepeatWorker(Actor* a) : BaseWorker(a), input(NULL), output(NULL)
 }
 
 void RepeatWorker::init() {
-    input = ports.value(CoreLibConstants::IN_SEQ_PORT_ID);
-    output = ports.value(CoreLibConstants::OUT_ANNOTATIONS_PORT_ID);
+    input = ports.value(BasePorts::IN_SEQ_PORT_ID());
+    output = ports.value(BasePorts::OUT_ANNOTATIONS_PORT_ID());
 }
 
 bool RepeatWorker::isReady() {
@@ -188,7 +200,7 @@ Task* RepeatWorker::tick() {
         return new FailTask(tr("Incorrect value: identity value must be between 0 and 100"));
     }
     QVariantMap map = inputMessage.getData().toMap();
-    DNASequence seq = map.value(BioActorLibrary::SEQ_SLOT().getId()).value<DNASequence>();
+    DNASequence seq = map.value(BaseSlots::DNA_SEQUENCE_SLOT().getId()).value<DNASequence>();
     
     if(cfg.minDist < 0){
         algoLog.error(tr("Incorrect value: minimal distance must be greater then zero"));
@@ -211,11 +223,11 @@ Task* RepeatWorker::tick() {
 
 void RepeatWorker::sl_taskFinished() {
     FindRepeatsToAnnotationsTask* t = qobject_cast<FindRepeatsToAnnotationsTask*>(sender());
-    if (t->getState() != Task::State_Finished || t->hasErrors()) return;
+    if (t->getState() != Task::State_Finished || t->hasError()) return;
     if (output) {
         const QList<SharedAnnotationData>& res = t->importAnnotations();
         QVariant v = qVariantFromValue<QList<SharedAnnotationData> >(res);
-        output->put(Message(BioDataTypes::ANNOTATION_TABLE_TYPE(), v));
+        output->put(Message(BaseTypes::ANNOTATION_TABLE_TYPE(), v));
         if (input->isEnded()) {
             output->setEnded();
         }
