@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "SWAlgorithmPlugin.h"
 
@@ -14,6 +25,7 @@
 #include "SWTaskFactory.h"
 #include "SmithWatermanTests.h"
 #include "SWQuery.h"
+#include "SWWorker.h"
 
 #include <U2Gui/GUIUtils.h>
 #include <U2View/AnnotatedDNAView.h>
@@ -61,6 +73,8 @@ SWAlgorithmPlugin::SWAlgorithmPlugin()
         ctxADV->init();
     }
 
+    LocalWorkflow::SWWorkerFactory::init();
+
     QDActorPrototypeRegistry* qdpr = AppContext::getQDActorProtoRegistry();
     qdpr->registerProto(new SWQDActorFactory());
 
@@ -79,16 +93,16 @@ SWAlgorithmPlugin::SWAlgorithmPlugin()
     }    
     SmithWatermanTaskFactoryRegistry* swar = AppContext::getSmithWatermanTaskFactoryRegistry();
 
-    coreLog.trace("Registering classic SW implementation");        
-    swar->registerFactory(new SWTaskFactory(SW_classic), QString("Classic 2"));    
+    coreLog.trace("Registering classic SW implementation");
+    swar->registerFactory(new SWTaskFactory(SW_classic), QString("Classic 2"));
     regDependedIMPLFromOtherPlugins();
 
 #ifdef SW2_BUILD_WITH_SSE2
-    coreLog.trace("Registering SSE2 SW implementation");        
+    coreLog.trace("Registering SSE2 SW implementation");
     swar->registerFactory(new SWTaskFactory(SW_sse2), QString("SSE2"));
 #endif    
 
-    this->connect(AppContext::getPluginSupport(), SIGNAL(si_allStartUpPluginsLoaded()), SLOT(regDependedIMPLFromOtherPlugins()));    
+    this->connect(AppContext::getPluginSupport(), SIGNAL(si_allStartUpPluginsLoaded()), SLOT(regDependedIMPLFromOtherPlugins()));
 }
 
 QList<XMLTestFactory*> SWAlgorithmTests::createTestFactories() {
