@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifdef SW2_BUILD_WITH_CUDA
 #include <cuda_runtime.h>
@@ -50,11 +61,9 @@ SWAlgorithmTask::SWAlgorithmTask(const SmithWatermanSettings& s,
 
     //acquiring resourses for GPU computations
     if( SW_cuda == algType ) {
-        TaskResourceUsage tru( RESOURCE_CUDA_GPU, 1, true /*prepareStage*/);
-        taskResources.append( tru );
+        addTaskResource(TaskResourceUsage( RESOURCE_CUDA_GPU, 1, true /*prepareStage*/));
     } else if( SW_opencl == algType ) {
-        TaskResourceUsage tru( RESOURCE_OPENCL_GPU, 1, true /*prepareStage*/);
-        taskResources.append( tru );
+        addTaskResource(TaskResourceUsage( RESOURCE_OPENCL_GPU, 1, true /*prepareStage*/));
     }
 
     int maxScore = calculateMaxScore(s.ptrn, s.pSm);    
@@ -101,7 +110,7 @@ void SWAlgorithmTask::setupTask(int maxScore) {
         PARTS_NUMBER = 1;
     }
 
-    if ((PARTS_NUMBER != 1) && (PARTS_NUMBER - 1) * overlapSize < sWatermanConfig.globalRegion.len) {
+    if ((PARTS_NUMBER != 1) && (PARTS_NUMBER - 1) * overlapSize < sWatermanConfig.globalRegion.length) {
         c.chunkSize = (c.seqSize + overlapSize * (PARTS_NUMBER - 1)) / PARTS_NUMBER;
         if (c.chunkSize == overlapSize) c.chunkSize++;
         c.overlapSize = overlapSize;            
@@ -216,12 +225,12 @@ void SWAlgorithmTask::onRegion(SequenceWalkerSubtask* t, TaskStateInfo& ti) {
 
         if (t->isAminoTranslated()) {
             res[i].intervalSeq1.startPos *= 3;
-            res[i].intervalSeq1.len *= 3;
+            res[i].intervalSeq1.length *= 3;
         }
 
         
         if (t->isDNAComplemented()) {
-            const LRegion& wr = t->getGlobalRegion();
+            const U2Region& wr = t->getGlobalRegion();
             res[i].intervalSeq1.startPos =
                 wr.endPos() - res[i].intervalSeq1.endPos() - sWatermanConfig.globalRegion.startPos;
         }
@@ -240,7 +249,7 @@ void SWAlgorithmTask::onRegion(SequenceWalkerSubtask* t, TaskStateInfo& ti) {
 void SWAlgorithmTask::removeResultFromOverlap(QList<PairAlignSequences> & res) {     
     for (int i = 0; i < res.size() - 1; i++) {
         for (int j = i + 1; j < res.size(); j++) {
-            if (res.at(i).intervalSeq1 == res.at(j).intervalSeq1) {
+            if (res.at(i).intervalSeq1 == res.at(j).intervalSeq1 && res.at(i).isDNAComplemented == res.at(j).isDNAComplemented) {
                 if (res.at(i).score > res.at(j).score) {
                     res.removeAt(j);
                     j--;
@@ -324,7 +333,7 @@ Task::ReportResult SWAlgorithmTask::report() {
 
 QList<Task*> SWAlgorithmTask::onSubTaskFinished( Task* subTask ){
     QList<Task*> res;
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return res;
     }
 
@@ -349,7 +358,7 @@ void SWResultsPostprocessingTask::run(){
     SmithWatermanResult r;
     for (int i = 0; i < resPAS.size(); i++) {
 
-        r.complement = resPAS.at(i).isDNAComplemented;
+        r.strand = resPAS.at(i).isDNAComplemented ? U2Strand::Complementary : U2Strand::Direct;
         r.trans = resPAS.at(i).isAminoTranslated;
         r.region = resPAS.at(i).intervalSeq1;
         r.region.startPos += sWatermanConfig.globalRegion.startPos;
