@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _SMITHWATERMANALGORITHM_H
 #define _SMITHWATERMANALGORITHM_H
@@ -66,10 +77,10 @@ protected:
 
     struct KeyOfPairAlignSeq
     {
-        KeyOfPairAlignSeq(int _score, LRegion const & _intervalSeq1) {
+        KeyOfPairAlignSeq(int _score, U2Region const & _intervalSeq1) {
             setValues(_score, _intervalSeq1);
         }
-//         KeyOfPairAlignSeq(int _score, LRegion const & _intervalSeq1, LRegion const & _intervalSeq2) {
+//         KeyOfPairAlignSeq(int _score, U2Region const & _intervalSeq1, U2Region const & _intervalSeq2) {
 //             setValues(_score, _intervalSeq1, _intervalSeq2);
 //         }
 
@@ -87,7 +98,7 @@ protected:
             score = 0;
 
             intervalSeq1.startPos = 0;
-            intervalSeq1.len = 0;
+            intervalSeq1.length = 0;
         };
 
 
@@ -111,19 +122,19 @@ protected:
             b = bufKey;
         }
 
-//         void setValues(int _score, LRegion const & _intervalSeq1, LRegion const & _intervalSeq2) {
+//         void setValues(int _score, U2Region const & _intervalSeq1, U2Region const & _intervalSeq2) {
 //             score = _score;
 //             intervalSeq1 = _intervalSeq1;
 //             intervalSeq2 = _intervalSeq2;
 //         }
 
-        void setValues(int _score, LRegion const & _intervalSeq1) {
+        void setValues(int _score, U2Region const & _intervalSeq1) {
             score = _score;
             intervalSeq1 = _intervalSeq1;            
         }
 
         int score;
-        LRegion intervalSeq1;
+        U2Region intervalSeq1;
         
     };
 
