@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifdef SW2_BUILD_WITH_OPENCL
 
@@ -25,14 +36,14 @@
 
 namespace U2 {   
 
-SmithWatermanAlgorithmOPENCL::SmithWatermanAlgorithmOPENCL()  : clEvent(NULL), clKernel(NULL), clProgram(NULL), 
-clCommandQueue(NULL), clContext(NULL), queryProfBuf(NULL),
-seqLibProfBuf(NULL), hDataMaxBuf(NULL), hDataUpBufTmp(NULL), 
-fDataUpBuf(NULL), hDataRecBufTmp(NULL), directionsUpBufTmp(NULL), 
-directionsRecBufTmp(NULL), directionsMaxBuf(NULL),
-
-MAX_SHARED_VECTOR_LENGTH(32),
-MAX_BLOCKS_NUMBER(AppContext::getOpenCLGpuRegistry()->getAnyEnabledGpu()->getMaxComputeUnits())
+SmithWatermanAlgorithmOPENCL::SmithWatermanAlgorithmOPENCL()  :
+        MAX_BLOCKS_NUMBER(AppContext::getOpenCLGpuRegistry()->getAnyEnabledGpu()->getMaxComputeUnits()),
+        MAX_SHARED_VECTOR_LENGTH(32),
+        clEvent(NULL), clKernel(NULL), clProgram(NULL),
+        clCommandQueue(NULL), clContext(NULL), queryProfBuf(NULL),
+        seqLibProfBuf(NULL), hDataMaxBuf(NULL), hDataUpBufTmp(NULL),
+        hDataRecBufTmp(NULL), fDataUpBuf(NULL), directionsUpBufTmp(NULL),
+        directionsRecBufTmp(NULL), directionsMaxBuf(NULL)
 {}
 
 quint64 SmithWatermanAlgorithmOPENCL::estimateNeededGpuMemory( const SMatrix& sm, QByteArray const & _patternSeq, QByteArray const & _searchSeq ) {
@@ -113,7 +124,7 @@ void SmithWatermanAlgorithmOPENCL::launch(const SMatrix& sm, QByteArray const &
     cl_uint clNumDevices = 1;
     cl_device_id deviceId = (cl_device_id) AppContext::getOpenCLGpuRegistry()->getAnyEnabledGpu()->getId();
 
-    OpenCLHelper openCLHelper;
+    const OpenCLHelper& openCLHelper = AppContext::getOpenCLGpuRegistry()->getOpenCLHelper();
     if (!openCLHelper.isLoaded()) {
         coreLog.error(openCLHelper.getErrorString());
         return;
@@ -195,8 +206,6 @@ void SmithWatermanAlgorithmOPENCL::launch(const SMatrix& sm, QByteArray const &
         sizeof(ScoreType) * (sizeRow), g_directionsRec, &err);
     if (hasOPENCLError(err, "Can't allocate memory in buffer")) return;
 
-    cl_int status = 0;
-
     algoLog.trace(QString("partsNumber: %1 queryDevider: %2").arg(partsNumber).arg(queryDevider));
     algoLog.trace(QString("seqLen: %1 partSeqSize: %2 overlapSize: %3").arg(seqLibLength).arg(partSeqSize).arg(overlapLength));
     algoLog.trace(QString("queryLen %1 partQuerySize: %2 sizeRow: %3").arg(queryLength).arg(partQuerySize).arg(sizeRow));
@@ -328,6 +337,11 @@ void SmithWatermanAlgorithmOPENCL::launch(const SMatrix& sm, QByteArray const &
         err = openCLHelper.clWaitForEvents_p(1, &clEvent);
         if (hasOPENCLError(err, "clWaitForEvents failed")) return;
 
+        if (clEvent) {
+            err = openCLHelper.clReleaseEvent_p (clEvent);
+            if (hasOPENCLError(err, "clReleaseEvent 1 failed")) return;
+        }
+
         //revert arrays
         hDataTmpBuf = hDataRecBuf;
         hDataRecBuf = hDataUpBuf;
@@ -367,12 +381,22 @@ void SmithWatermanAlgorithmOPENCL::launch(const SMatrix& sm, QByteArray const &
     err = openCLHelper.clWaitForEvents_p(1, &clEvent);
     if (hasOPENCLError(err, "clWaitForEvents failed")) return;
 
+    if (clEvent) {
+        err = openCLHelper.clReleaseEvent_p (clEvent);
+        if (hasOPENCLError(err, "clReleaseEvent 2 failed")) return;
+    }
+
     err = openCLHelper.clEnqueueReadBuffer_p(clCommandQueue, directionsMaxBuf, CL_FALSE, 0, sizeof(ScoreType) * (sizeRow), g_directionsRec, 0, NULL, &clEvent);
     if (hasOPENCLError(err, "clEnqueueReadBuffer failed")) return;
 
     err = openCLHelper.clWaitForEvents_p(1, &clEvent);
     if (hasOPENCLError(err, "clWaitForEvents failed")) return;
 
+    if (clEvent) {
+        err = openCLHelper.clReleaseEvent_p (clEvent);
+        if (hasOPENCLError(err, "clReleaseEvent 3 failed")) return;
+    }
+
     err = openCLHelper.clFinish_p(clCommandQueue);
     if (hasOPENCLError(err, "clFinish failed")) return;
 
@@ -393,7 +417,7 @@ void SmithWatermanAlgorithmOPENCL::launch(const SMatrix& sm, QByteArray const &
     for (int j = 0; j < (sizeRow); j++) {
         if (g_HdataTmp[j] >= minScore) {
             tmp.intervalSeq1.startPos = g_directionsRec[j];
-            tmp.intervalSeq1.len = j - tmp.intervalSeq1.startPos + 1 - (j) / (partSeqSize + 1) * overlapLength - (j) / (partSeqSize + 1);
+            tmp.intervalSeq1.length = j - tmp.intervalSeq1.startPos + 1 - (j) / (partSeqSize + 1) * overlapLength - (j) / (partSeqSize + 1);
             tmp.score = g_HdataTmp[j];
             //                        cout <<"score: " <<tmp.score <<" reg: " <<tmp.intervalSeq1.startPos <<".." <<tmp.intervalSeq1.endPos() <<endl;
             pairAlignmentStrings.append(tmp);
@@ -406,14 +430,10 @@ void SmithWatermanAlgorithmOPENCL::launch(const SMatrix& sm, QByteArray const &
 SmithWatermanAlgorithmOPENCL::~SmithWatermanAlgorithmOPENCL() {
     algoLog.details(QObject::tr("Starting cleanup OpenCL resources"));
 
-    OpenCLHelper openCLHelper;
+    const OpenCLHelper& openCLHelper = AppContext::getOpenCLGpuRegistry()->getOpenCLHelper();
 
     cl_int err = CL_SUCCESS;
 
-    if (clEvent) {
-        err = openCLHelper.clReleaseEvent_p (clEvent);  
-        hasOPENCLError(err, "clReleaseEvent failed");
-    }
     if (clKernel) {
         err = openCLHelper.clReleaseKernel_p (clKernel);
         hasOPENCLError(err, "clReleaseEvent failed");
