@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifdef SW2_BUILD_WITH_SSE2
 
@@ -156,8 +167,8 @@ void SmithWatermanAlgorithmSSE2::calculateMatrix() {
 
     PairAlignSequences p;
     QByteArray pairAlign;
-    LRegion sReg;
-    LRegion pReg;
+    U2Region sReg;
+    U2Region pReg;
 
     QVector<QVector<int> > directionSearchSeq;    
     directionSearchSeq.push_back(rowInts);
@@ -241,7 +252,7 @@ void SmithWatermanAlgorithmSSE2::calculateMatrix() {
                 if (max >= p.score) {
                     p.score = max;
                     p.intervalSeq1.startPos = directionSearchSeq[even][col];
-                    p.intervalSeq1.len = i - p.intervalSeq1.startPos;
+                    p.intervalSeq1.length = i - p.intervalSeq1.startPos;
                 }
             }
         }    
@@ -346,6 +357,7 @@ int SmithWatermanAlgorithmSSE2::calculateMatrixSSE2(unsigned queryLength, unsign
     vMaxScore = _mm_slli_epi16 (vMaxScore, 15);    
 
     vMinimums = _mm_shuffle_epi32 (vMaxScore, 0);
+    Q_UNUSED(vMinimums);
 
     vMin = _mm_shuffle_epi32 (vMaxScore, 0);
     vMin = _mm_srli_si128 (vMin, 14);
@@ -357,7 +369,7 @@ int SmithWatermanAlgorithmSSE2::calculateMatrixSSE2(unsigned queryLength, unsign
     }
 
     PairAlignSequences p;
-    LRegion sReg;    
+    U2Region sReg;    
 
     for (i = 0; i < dbLength; ++i) {    
 
