@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "SmithWatermanTests.h"
 
@@ -51,7 +62,7 @@ void GTest_SmithWatermnan::sortByScore(QList<SmithWatermanResult> & resultsForSo
             }
             if (resultsForSort.at(i).score == resultsForSort.at(j).score &&
                 resultsForSort.at(i).region.startPos == resultsForSort.at(j).region.startPos &&
-                resultsForSort.at(i).region.len > resultsForSort.at(j).region.len) {
+                resultsForSort.at(i).region.length > resultsForSort.at(j).region.length) {
                     SmithWatermanResult buf = resultsForSort.at(i);
                     resultsForSort[i] = resultsForSort.at(j);
                     resultsForSort[j] = buf;
@@ -174,7 +185,7 @@ void GTest_SmithWatermnan::prepare() {
     s.sqnc = searchSeq;
     s.ptrn = patternSeq;
     s.globalRegion.startPos = 0;
-    s.globalRegion.len = searchSeq.length();
+    s.globalRegion.length = searchSeq.length();
     s.gapModel.scoreGapOpen = gapOpen;
     s.gapModel.scoreGapExtd = gapExtension;
     s.percentOfScore = percentOfScore;
@@ -235,7 +246,7 @@ bool GTest_SmithWatermnan::parseExpected_res() {
             return false;
         }
         swRes.sInterval.startPos = start;
-        swRes.sInterval.len = finish - start;
+        swRes.sInterval.length = finish - start;
         
         start = resValues.at(0).toInt(&startOk);
         if (startOk != true) {
@@ -261,7 +272,7 @@ bool GTest_SmithWatermnan::toInt(QString & str, int & num) {
 Task::ReportResult GTest_SmithWatermnan::report() {
     
     propagateSubtaskError();
-    if( hasErrors() ) {
+    if( hasError() ) {
         return ReportResult_Finished;
     }
     
@@ -365,7 +376,7 @@ void GTest_SmithWatermnanPerf::prepare() {
     s.sqnc = searchSeq;
     s.ptrn = patternSeq;
     s.globalRegion.startPos = 0;
-    s.globalRegion.len = searchSeq.length();
+    s.globalRegion.length = searchSeq.length();
     s.gapModel.scoreGapOpen = gapOpen;
     s.gapModel.scoreGapExtd = gapExtension;
     s.percentOfScore = percentOfScore;
@@ -387,7 +398,7 @@ void GTest_SmithWatermnanPerf::prepare() {
 
 Task::ReportResult GTest_SmithWatermnanPerf::report() {
     propagateSubtaskError();
-    if( hasErrors() ) {
+    if( hasError() ) {
         return ReportResult_Finished;
     }
 
