@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "PWMBuildDialogController.h"
 
@@ -71,23 +82,23 @@ void PWMBuildDialogController::sl_inFileButtonClicked() {
     QString inFile = QFileInfo(lod.url).absoluteFilePath();
     inputEdit->setText(inFile);
     
-    QList<DocumentFormat*> formats = DocumentUtils::detectFormat(inFile);
+    QList<FormatDetectionResult> formats = DocumentUtils::detectFormat(inFile);
     if (formats.isEmpty()) {
         return;
     }
 
     DocumentFormat* format = NULL;
-    foreach(DocumentFormat* f, formats) {
-        if(f->getSupportedObjectTypes().contains(GObjectTypes::MULTIPLE_ALIGNMENT)) {
-            format = f;
+    foreach(const FormatDetectionResult& i, formats) {
+        if (i.format->getSupportedObjectTypes().contains(GObjectTypes::MULTIPLE_ALIGNMENT)) {
+            format = i.format;
             break;
         } 
     }
 
-    if(format == NULL) {
-        foreach(DocumentFormat* f, formats){
-            if(f->getSupportedObjectTypes().contains(GObjectTypes::SEQUENCE)) {
-                format = f;
+    if (format == NULL) {
+        foreach(const FormatDetectionResult& i, formats) {
+            if (i.format->getSupportedObjectTypes().contains(GObjectTypes::SEQUENCE)) {
+                format = i.format;
                 break;
             }
         }
@@ -98,7 +109,7 @@ void PWMBuildDialogController::sl_inFileButtonClicked() {
     TaskStateInfo ti;
     QVariantMap hints;
     Document *doc = format->loadDocument(iof, inFile, ti, hints);
-    if (ti.hasErrors()) {
+    if (ti.hasError()) {
         return;
     }
 
@@ -125,7 +136,7 @@ void PWMBuildDialogController::sl_inFileButtonClicked() {
             replaceLogo(ma);
         } else {
             PFMatrix pfm = WeightMatrixIO::readPFMatrix(iof, lod.url, ti);
-            if (ti.hasErrors()) {
+            if (ti.hasError()) {
                 logoArea->hide();
                 return;
             }
@@ -293,7 +304,7 @@ void PWMBuildDialogController::sl_onStateChanged() {
     }
     task->disconnect(this);
     const TaskStateInfo& si = task->getStateInfo();
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         statusLabel->setText(tr("Build finished with errors: %1").arg(si.getError()));
         lastURL = "";
     } else if (task->isCanceled()) {
@@ -310,7 +321,7 @@ void PWMBuildDialogController::sl_onStateChanged() {
 
 void PWMBuildDialogController::sl_onProgressChanged() {
     assert(task==sender());
-    statusLabel->setText(tr("Running state %1 progress %2%").arg(task->getStateInfo().getStateDesc()).arg(task->getProgress()));
+    statusLabel->setText(tr("Running state %1 progress %2%").arg(task->getStateInfo().getDescription()).arg(task->getProgress()));
 }
 
 void PWMBuildDialogController::reject() {
@@ -348,14 +359,14 @@ void PFMatrixBuildTask::run() {
         stateInfo.setError(  tr("Alignment is not nucleic") );
         return;
     }
-    stateInfo.setStateDesc( tr("Calculating frequencies of nucleotids") );
+    stateInfo.setDescription( tr("Calculating frequencies of nucleotids") );
     if (settings.type == PM_MONONUCLEOTIDE) {
         m = PFMatrix(ma, PFM_MONONUCLEOTIDE);
     } else {
         m = PFMatrix(ma, PFM_DINUCLEOTIDE);
     }
     stateInfo.progress+=50;
-    if (stateInfo.hasErrors() || isCanceled()) {
+    if (stateInfo.hasError() || isCanceled()) {
         return;
     }
     return;
@@ -371,23 +382,23 @@ PFMatrixBuildToFileTask::PFMatrixBuildToFileTask(const QString& inFile, const QS
     c.supportedObjectTypes += GObjectTypes::MULTIPLE_ALIGNMENT;
     c.supportedObjectTypes += GObjectTypes::SEQUENCE;
     c.rawData = BaseIOAdapters::readFileHeader(inFile);
-    QList<DocumentFormat*> formats = DocumentUtils::detectFormat(inFile);
+    QList<FormatDetectionResult> formats = DocumentUtils::detectFormat(inFile);
     if (formats.isEmpty()) {
         stateInfo.setError(  tr("Input format error") );
         return;
     }
 
     DocumentFormatId format = "";
-    foreach(const DocumentFormat* f, formats) {
-        if(f->getSupportedObjectTypes().contains(GObjectTypes::MULTIPLE_ALIGNMENT)) {
-            format = f->getFormatId();
+    foreach(const FormatDetectionResult& i, formats) {
+        if (i.format->getSupportedObjectTypes().contains(GObjectTypes::MULTIPLE_ALIGNMENT)) {
+            format = i.format->getFormatId();
             break;
         } 
     }
     if(format.isEmpty()) {
-        foreach(const DocumentFormat* f, formats) {
-            if(f->getSupportedObjectTypes().contains(GObjectTypes::SEQUENCE)) {
-                format = f->getFormatId();
+        foreach(const FormatDetectionResult& i, formats) {
+            if (i.format->getSupportedObjectTypes().contains(GObjectTypes::SEQUENCE)) {
+                format = i.format->getFormatId();
                 break;
             }
         }
@@ -398,7 +409,7 @@ PFMatrixBuildToFileTask::PFMatrixBuildToFileTask(const QString& inFile, const QS
     loadTask = new LoadDocumentTask(format, inFile, iof);
     loadTask->setSubtaskProgressWeight(0.03F);
     stateInfo.progress = 0;
-    stateInfo.setStateDesc(tr("Loading alignment"));
+    stateInfo.setDescription(tr("Loading alignment"));
     addSubTask(loadTask);
 }
 
@@ -407,7 +418,7 @@ QList<Task*> PFMatrixBuildToFileTask::onSubTaskFinished(Task* subTask) {
     if (isCanceled()) {
         return res;
     }
-    if (subTask->getStateInfo().hasErrors()) {
+    if (subTask->getStateInfo().hasError()) {
         stateInfo.setError(  subTask->getStateInfo().getError() );
         return res;
     }
@@ -473,7 +484,7 @@ void PWMatrixBuildTask::run() {
             tempMatrix = PFMatrix::convertDi2Mono(tempMatrix);
         }
         stateInfo.progress+=40;
-        if (stateInfo.hasErrors() || isCanceled()) {
+        if (stateInfo.hasError() || isCanceled()) {
             return;
         }
     } else {
@@ -496,7 +507,7 @@ void PWMatrixBuildTask::run() {
             tempMatrix = PFMatrix(ma, PFM_DINUCLEOTIDE);
         }
         stateInfo.progress+=40;
-        if (stateInfo.hasErrors() || isCanceled()) {
+        if (stateInfo.hasError() || isCanceled()) {
             return;
         }
     }
@@ -518,17 +529,17 @@ PWMatrixBuildToFileTask::PWMatrixBuildToFileTask(const QString& inFile, const QS
     c.supportedObjectTypes += GObjectTypes::MULTIPLE_ALIGNMENT;
     c.supportedObjectTypes += GObjectTypes::SEQUENCE;
     c.rawData = BaseIOAdapters::readFileHeader(inFile);
-    QList<DocumentFormat*> formats = DocumentUtils::detectFormat(inFile);
+    QList<FormatDetectionResult> formats = DocumentUtils::detectFormat(inFile);
     if (formats.isEmpty()) {
         stateInfo.setError(  tr("Input format error") );
         return;
     }
-    DocumentFormatId format = formats.first()->getFormatId();
+    DocumentFormatId format = formats.first().format->getFormatId();
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(inFile));
     loadTask = new LoadDocumentTask(format, inFile, iof);
     loadTask->setSubtaskProgressWeight(0.03F);
     stateInfo.progress = 0;
-    stateInfo.setStateDesc(tr("Loading alignment"));
+    stateInfo.setDescription(tr("Loading alignment"));
     addSubTask(loadTask);
 }
 
@@ -537,7 +548,7 @@ QList<Task*> PWMatrixBuildToFileTask::onSubTaskFinished(Task* subTask) {
     if (isCanceled()) {
         return res;
     }
-    if (subTask->getStateInfo().hasErrors()) {
+    if (subTask->getStateInfo().hasError()) {
         stateInfo.setError(  subTask->getStateInfo().getError() );
         return res;
     }
