@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "PWMSearchDialogController.h"
 #include "PWMBuildDialogController.h"
@@ -61,7 +72,7 @@ public:
             case 1:
                 return res.modelInfo < o->res.modelInfo;
             case 2: 
-                return res.complement != o->res.complement ? res.complement :  (res.region.startPos < o->res.region.startPos);
+                return res.strand != o->res.strand ? res.strand.isCompementary() :  (res.region.startPos < o->res.region.startPos);
             case 3:
                 return res.score < o->res.score;
         }
@@ -99,7 +110,7 @@ PWMSearchDialogController::PWMSearchDialogController(ADVSequenceObjectContext* _
     ctx = _ctx;
     task = NULL;
     
-    initialSelection = ctx->getSequenceSelection()->isEmpty() ? LRegion() : ctx->getSequenceSelection()->getSelectedRegions().first();
+    initialSelection = ctx->getSequenceSelection()->isEmpty() ? U2Region() : ctx->getSequenceSelection()->getSelectedRegions().first();
     int seqLen = ctx->getSequenceLen();
     sbRangeStart->setMinimum(1);
     sbRangeStart->setMaximum(seqLen);
@@ -149,7 +160,7 @@ void PWMSearchDialogController::connectGUI() {
 
 
 void PWMSearchDialogController::updateState() {
-    bool hasInitialSelection = initialSelection.len > 0;
+    bool hasInitialSelection = initialSelection.length > 0;
     rbSelectionRange->setEnabled(hasInitialSelection);
 
     bool hasActiveTask = task!=NULL;
@@ -437,15 +448,15 @@ void PWMSearchDialogController::runTask() {
         return;
     }
     
-    LRegion reg;
+    U2Region reg;
     if (rbSequenceRange->isChecked()) {
         reg = ctx->getSequenceObject()->getSequenceRange();
     } else if (rbSelectionRange->isChecked()) {
         reg = initialSelection;
     } else {
         reg.startPos = sbRangeStart->value();
-        reg.len = sbRangeEnd->value() - sbRangeStart->value() + 1;
-        if (reg.len <= model.getLength()) {
+        reg.length = sbRangeEnd->value() - sbRangeStart->value() + 1;
+        if (reg.length <= model.getLength()) {
             QMessageBox::critical(this, L10N::errorTitle(), tr("Range is too small"));
             sbRangeEnd->setFocus();
             return;
@@ -461,7 +472,7 @@ void PWMSearchDialogController::runTask() {
         queue[i].second.complOnly = complOnly;
     }
 
-    int len = reg.len;
+    int len = reg.length;
 
     sl_onClearList();
 
@@ -514,10 +525,10 @@ void PWMSearchDialogController::loadFile(QString filename) {
     TaskStateInfo siPFM;
     PWMatrix m;
     intermediate = WeightMatrixIO::readPFMatrix(iof, filename, siPFM);
-    if (siPFM.hasErrors()) {
+    if (siPFM.hasError()) {
         TaskStateInfo siPWM;    
         m = WeightMatrixIO::readPWMatrix(iof, filename, siPWM);
-        if (siPWM.hasErrors()) {
+        if (siPWM.hasError()) {
             QMessageBox::critical(this, L10N::errorTitle(), siPWM.getError());
             return;
         }
@@ -551,7 +562,7 @@ WeightMatrixResultItem::WeightMatrixResultItem(const WeightMatrixSearchResult& r
     QString range = QString("%1..%2").arg(r.region.startPos + 1).arg(r.region.endPos());
     setText(0, range);
     setText(1, r.modelInfo);
-    QString strand = res.complement ? PWMSearchDialogController::tr("Complement strand") : PWMSearchDialogController::tr("Direct strand") ;
+    QString strand = res.strand.isCompementary()? PWMSearchDialogController::tr("Complementary strand") : PWMSearchDialogController::tr("Direct strand") ;
     setText(2, strand);
     setText(3, QString::number(res.score, 'f', 2)+"%");
 }
