@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "WeightMatrixWorkers.h"
 #include "WeightMatrixIOWorkers.h"
@@ -20,9 +31,10 @@
 #include <U2Lang/IntegralBusModel.h>
 #include <U2Lang/WorkflowEnv.h>
 #include <U2Lang/ActorPrototypeRegistry.h>
-#include <U2Lang/CoreDataTypes.h>
-#include <U2Lang/BioDatatypes.h>
-#include <U2Lang/BioActorLibrary.h>
+#include <U2Lang/BaseTypes.h>
+#include <U2Lang/BaseSlots.h>
+#include <U2Lang/BasePorts.h>
+#include <U2Lang/BaseActorCategories.h>
 #include <U2Designer/DelegateEditors.h>
 #include <U2Lang/CoreLibConstants.h>
 
@@ -53,9 +65,9 @@ const QString PFMatrixConvertWorker::ACTOR_ID("fmatrix-to-wmatrix");
 void PWMatrixBuildWorker::registerProto() {
     QList<PortDescriptor*> p; QList<Attribute*> a;
     QMap<Descriptor, DataTypePtr> m;
-    Descriptor id(CoreLibConstants::IN_MSA_PORT_ID, PWMatrixBuildWorker::tr("Input alignment"), 
+    Descriptor id(BasePorts::IN_MSA_PORT_ID(), PWMatrixBuildWorker::tr("Input alignment"), 
         PWMatrixBuildWorker::tr("Input multiple sequence alignment for building statistical model."));
-    m[BioActorLibrary::MA_SLOT()] = BioDataTypes::MULTIPLE_ALIGNMENT_TYPE();
+    m[BaseSlots::MULTIPLE_ALIGNMENT_SLOT()] = BaseTypes::MULTIPLE_ALIGNMENT_TYPE();
     DataTypePtr t(new MapDataType(Descriptor("build.pwmatrix.content"), m));
 
     Descriptor od(WMATRIX_OUT_PORT_ID, PWMatrixBuildWorker::tr("Weight matrix"), PWMatrixBuildWorker::tr("Produced statistical model of specified TFBS data."));
@@ -68,13 +80,13 @@ void PWMatrixBuildWorker::registerProto() {
     {
         Descriptor ad(ALG_ATTR, PWMatrixBuildWorker::tr("Weight algorithm"), 
             QApplication::translate("PWMBuildDialog", "algo_tip", 0, QApplication::UnicodeUTF8));
-        a << new Attribute(ad, CoreDataTypes::STRING_TYPE(), true, BuiltInPWMConversionAlgorithms::BVH_ALGO);
+        a << new Attribute(ad, BaseTypes::STRING_TYPE(), true, BuiltInPWMConversionAlgorithms::BVH_ALGO);
     }
 
     {
         Descriptor td(TYPE_ATTR, PWMatrixBuildWorker::tr("Matrix type"), 
             QApplication::translate("PWMBuildDialog", "type_tip", 0, QApplication::UnicodeUTF8));
-        a << new Attribute(td, CoreDataTypes::BOOL_TYPE(), true, false /* false = mononucleic, true = dinucleic */);
+        a << new Attribute(td, BaseTypes::BOOL_TYPE(), true, false /* false = mononucleic, true = dinucleic */);
     }
 
     Descriptor desc(ACTOR_ID, tr("Build weight matrix"),
@@ -101,12 +113,12 @@ void PWMatrixBuildWorker::registerProto() {
     proto->setPrompter(new PWMatrixBuildPrompter());
     proto->setEditor(new DelegateEditor(delegates));
     proto->setIconPath(":weight_matrix/images/weight_matrix.png");
-    WorkflowEnv::getProtoRegistry()->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
+    WorkflowEnv::getProtoRegistry()->registerProto(BaseActorCategories::CATEGORY_TRANSCRIPTION(), proto);
 }
 
 QString PWMatrixBuildPrompter::composeRichDoc() {
-    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(CoreLibConstants::IN_MSA_PORT_ID));
-    Actor* msaProducer = input->getProducer(CoreLibConstants::IN_MSA_PORT_ID);
+    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(BasePorts::IN_MSA_PORT_ID()));
+    Actor* msaProducer = input->getProducer(BasePorts::IN_MSA_PORT_ID());
 
     QString msaName = msaProducer ? tr("For each MSA from <u>%1</u>,").arg(msaProducer->getLabel()) : "";
     QString doc = tr("%1 build weight matrix.")
@@ -116,7 +128,7 @@ QString PWMatrixBuildPrompter::composeRichDoc() {
 }
 
 void PWMatrixBuildWorker::init() {
-    input = ports.value(CoreLibConstants::IN_MSA_PORT_ID);
+    input = ports.value(BasePorts::IN_MSA_PORT_ID());
     output = ports.value(WMATRIX_OUT_PORT_ID);
 }
 
@@ -130,7 +142,7 @@ Task* PWMatrixBuildWorker::tick() {
     QVariantMap data = inputMessage.getData().toMap();
     cfg.algo = actor->getParameter(ALG_ATTR)->getAttributeValue<QString>();
     cfg.type = actor->getParameter(TYPE_ATTR)->getAttributeValue<bool>() ? PM_DINUCLEOTIDE : PM_MONONUCLEOTIDE;
-    const MAlignment& ma = data.value(BioActorLibrary::MA_SLOT().getId()).value<MAlignment>();
+    const MAlignment& ma = data.value(BaseSlots::MULTIPLE_ALIGNMENT_SLOT().getId()).value<MAlignment>();
     Task* t = new PWMatrixBuildTask(cfg, ma);
     connect(t, SIGNAL(si_stateChanged()), SLOT(sl_taskFinished()));
     return t;
@@ -158,9 +170,9 @@ bool PWMatrixBuildWorker::isDone() {
 void PFMatrixBuildWorker::registerProto() {
     QList<PortDescriptor*> p; QList<Attribute*> a;
     QMap<Descriptor, DataTypePtr> m;
-    Descriptor id(CoreLibConstants::IN_MSA_PORT_ID, PFMatrixBuildWorker::tr("Input alignment"), 
+    Descriptor id(BasePorts::IN_MSA_PORT_ID(), PFMatrixBuildWorker::tr("Input alignment"), 
         PFMatrixBuildWorker::tr("Input multiple sequence alignment for building statistical model."));
-    m[BioActorLibrary::MA_SLOT()] = BioDataTypes::MULTIPLE_ALIGNMENT_TYPE();
+    m[BaseSlots::MULTIPLE_ALIGNMENT_SLOT()] = BaseTypes::MULTIPLE_ALIGNMENT_TYPE();
     DataTypePtr t(new MapDataType(Descriptor("build.pfmatrix.content"), m));
 
     Descriptor od(FMATRIX_OUT_PORT_ID, PFMatrixBuildWorker::tr("Frequency matrix"), 
@@ -174,7 +186,7 @@ void PFMatrixBuildWorker::registerProto() {
     {
         Descriptor td(TYPE_ATTR, PWMatrixBuildWorker::tr("Matrix type"), 
             QApplication::translate("PWMBuildDialog", "type_tip", 0, QApplication::UnicodeUTF8));
-        a << new Attribute(td, CoreDataTypes::BOOL_TYPE(), true, false /* false = mononucleic, true = dinucleic */);
+        a << new Attribute(td, BaseTypes::BOOL_TYPE(), true, false /* false = mononucleic, true = dinucleic */);
     }
 
     Descriptor desc(ACTOR_ID, tr("Build frequency matrix"),
@@ -192,12 +204,12 @@ void PFMatrixBuildWorker::registerProto() {
     proto->setPrompter(new PFMatrixBuildPrompter());
     proto->setEditor(new DelegateEditor(delegates));
     proto->setIconPath(":weight_matrix/images/weight_matrix.png");
-    WorkflowEnv::getProtoRegistry()->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
+    WorkflowEnv::getProtoRegistry()->registerProto(BaseActorCategories::CATEGORY_TRANSCRIPTION(), proto);
 }
 
 QString PFMatrixBuildPrompter::composeRichDoc() {
-    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(CoreLibConstants::IN_MSA_PORT_ID));
-    Actor* msaProducer = input->getProducer(CoreLibConstants::IN_MSA_PORT_ID);
+    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(BasePorts::IN_MSA_PORT_ID()));
+    Actor* msaProducer = input->getProducer(BasePorts::IN_MSA_PORT_ID());
 
     QString msaName = msaProducer ? tr("For each MSA from <u>%1</u>,").arg(msaProducer->getLabel()) : "";
     QString doc = tr("%1 build frequency matrix.")
@@ -207,7 +219,7 @@ QString PFMatrixBuildPrompter::composeRichDoc() {
 }
 
 void PFMatrixBuildWorker::init() {
-    input = ports.value(CoreLibConstants::IN_MSA_PORT_ID);
+    input = ports.value(BasePorts::IN_MSA_PORT_ID());
     output = ports.value(FMATRIX_OUT_PORT_ID);
 }
 
@@ -220,7 +232,7 @@ Task* PFMatrixBuildWorker::tick() {
     mtype = PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE();
     QVariantMap data = inputMessage.getData().toMap();
     cfg.type = actor->getParameter(TYPE_ATTR)->getAttributeValue<bool>() ? PM_DINUCLEOTIDE : PM_MONONUCLEOTIDE;
-    const MAlignment& ma = data.value(BioActorLibrary::MA_SLOT().getId()).value<MAlignment>();
+    const MAlignment& ma = data.value(BaseSlots::MULTIPLE_ALIGNMENT_SLOT().getId()).value<MAlignment>();
     Task* t = new PFMatrixBuildTask(cfg, ma);
     connect(t, SIGNAL(si_stateChanged()), SLOT(sl_taskFinished()));
     return t;
@@ -263,12 +275,12 @@ void PFMatrixConvertWorker::registerProto() {
     
     {
         Descriptor ad(ALG_ATTR, PWMatrixBuildWorker::tr("Weight algorithm"), QApplication::translate("PWMBuildDialog", "algo_tip", 0, QApplication::UnicodeUTF8));
-        a << new Attribute(ad, CoreDataTypes::STRING_TYPE(), true, BuiltInPWMConversionAlgorithms::BVH_ALGO);
+        a << new Attribute(ad, BaseTypes::STRING_TYPE(), true, BuiltInPWMConversionAlgorithms::BVH_ALGO);
     }
 
     {
         Descriptor td(TYPE_ATTR, PWMatrixBuildWorker::tr("Matrix type"), QApplication::translate("PWMBuildDialog", "type_tip", 0, QApplication::UnicodeUTF8));
-        a << new Attribute(td, CoreDataTypes::BOOL_TYPE(), true, false /* false = mononucleic, true = dinucleic */);
+        a << new Attribute(td, BaseTypes::BOOL_TYPE(), true, false /* false = mononucleic, true = dinucleic */);
     }
 
     Descriptor desc(ACTOR_ID, tr("Convert frequency matrix"),
@@ -295,7 +307,7 @@ void PFMatrixConvertWorker::registerProto() {
     proto->setPrompter(new PFMatrixConvertPrompter());
     proto->setEditor(new DelegateEditor(delegates));
     proto->setIconPath(":weight_matrix/images/weight_matrix.png");
-    WorkflowEnv::getProtoRegistry()->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
+    WorkflowEnv::getProtoRegistry()->registerProto(BaseActorCategories::CATEGORY_TRANSCRIPTION(), proto);
 }
 
 QString PFMatrixConvertPrompter::composeRichDoc() {
@@ -323,7 +335,7 @@ Task* PFMatrixConvertWorker::tick() {
     mtype = PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE();
     QVariantMap data = inputMessage.getData().toMap();
     PWMatrix model = data.value(PWMatrixWorkerFactory::WEIGHT_MATRIX_MODEL_TYPE_ID).value<PWMatrix>();
-    QString url = data.value(CoreLibConstants::URL_SLOT().getId()).toString();
+    QString url = data.value(BaseSlots::URL_SLOT().getId()).toString();
     cfg.algo = actor->getParameter(ALG_ATTR)->getAttributeValue<QString>();
     cfg.type = actor->getParameter(TYPE_ATTR)->getAttributeValue<bool>() ? PM_DINUCLEOTIDE : PM_MONONUCLEOTIDE;
     const PFMatrix& ma = data.value(PFMatrixWorkerFactory::FMATRIX_SLOT.getId()).value<PFMatrix>();
