@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "WeightMatrixIO.h"
 #include "WeightMatrixPlugin.h"
@@ -77,14 +88,14 @@ PFMatrix WeightMatrixIO::readPFMatrix(IOAdapterFactory* iof, const QString& url,
         }
     }
     io->close();
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return matrix;
     }
 
     QTextStream reader(text);
     QString line;
 
-    while (!reader.atEnd() && !si.hasErrors()) {
+    while (!reader.atEnd() && !si.hasError()) {
         line = reader.readLine();
         if (line.isEmpty()) {
             continue;
@@ -118,7 +129,7 @@ PFMatrix WeightMatrixIO::readPFMatrix(IOAdapterFactory* iof, const QString& url,
         msize++;
     }
     
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return matrix;
     }
 
@@ -179,14 +190,14 @@ PWMatrix WeightMatrixIO::readPWMatrix(IOAdapterFactory* iof, const QString& url,
         }
     }
     io->close();
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return matrix;
     }
 
     QTextStream reader(text);
     QString line;
     
-    while (!reader.atEnd() && !si.hasErrors()) {
+    while (!reader.atEnd() && !si.hasError()) {
         line = reader.readLine();
         if (line.isEmpty()) {
             continue;
@@ -221,7 +232,7 @@ PWMatrix WeightMatrixIO::readPWMatrix(IOAdapterFactory* iof, const QString& url,
         msize++;
     }
     
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return matrix;
     }
 
