@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "WeightMatrixIOWorkers.h"
 #include "WeightMatrixWorkers.h"
@@ -16,8 +27,10 @@
 #include <U2Lang/IntegralBusModel.h>
 #include <U2Lang/WorkflowEnv.h>
 #include <U2Lang/ActorPrototypeRegistry.h>
-#include <U2Lang/BioActorLibrary.h>
-#include <U2Lang/CoreDataTypes.h>
+#include <U2Lang/BaseSlots.h>
+#include <U2Lang/BaseTypes.h>
+#include <U2Lang/BaseAttributes.h>
+#include <U2Lang/BaseActorCategories.h>
 #include <U2Designer/DelegateEditors.h>
 #include <U2Lang/CoreLibConstants.h>
 
@@ -87,34 +100,34 @@ bool PWMatrixIOProto::isAcceptableDrop(const QMimeData * md, QVariantMap * param
 ReadPWMatrixProto::ReadPWMatrixProto(const Descriptor& _desc, const QList<PortDescriptor*>& _ports, const QList<Attribute*>& _attrs ) 
     : PWMatrixIOProto( _desc, _ports, _attrs ) {
 
-        attrs << new Attribute(CoreLibConstants::URL_IN_ATTR(), CoreDataTypes::STRING_TYPE(), true);
+        attrs << new Attribute(BaseAttributes::URL_IN_ATTRIBUTE(), BaseTypes::STRING_TYPE(), true);
         QMap<QString, PropertyDelegate*> delegateMap;
-        delegateMap[CoreLibConstants::URL_IN_ATTR().getId()] = new URLDelegate(WeightMatrixIO::getPWMFileFilter(), WeightMatrixIO::WEIGHT_MATRIX_ID, true);
+        delegateMap[BaseAttributes::URL_IN_ATTRIBUTE().getId()] = new URLDelegate(WeightMatrixIO::getPWMFileFilter(), WeightMatrixIO::WEIGHT_MATRIX_ID, true);
         setEditor(new DelegateEditor(delegateMap));
         setIconPath(":weight_matrix/images/weight_matrix.png");
 }
 
 bool ReadPWMatrixProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return PWMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_IN_ATTR().getId() );
+    return PWMatrixIOProto::isAcceptableDrop( md, params, BaseAttributes::URL_IN_ATTRIBUTE().getId() );
 }
 
 WritePWMatrixProto::WritePWMatrixProto(const Descriptor& _desc, const QList<PortDescriptor*>& _ports, const QList<Attribute*>& _attrs ) 
     : PWMatrixIOProto( _desc, _ports, _attrs ) {
-        attrs << new Attribute(CoreLibConstants::URL_OUT_ATTR(), CoreDataTypes::STRING_TYPE(), true );
-        attrs << new Attribute(BioActorLibrary::FILE_MODE_ATTR(), CoreDataTypes::NUM_TYPE(), false, SaveDoc_Roll);
+        attrs << new Attribute(BaseAttributes::URL_OUT_ATTRIBUTE(), BaseTypes::STRING_TYPE(), true );
+        attrs << new Attribute(BaseAttributes::FILE_MODE_ATTRIBUTE(), BaseTypes::NUM_TYPE(), false, SaveDoc_Roll);
 
         QMap<QString, PropertyDelegate*> delegateMap;
-        delegateMap[CoreLibConstants::URL_OUT_ATTR().getId()] = new URLDelegate(WeightMatrixIO::getPWMFileFilter(), WeightMatrixIO::WEIGHT_MATRIX_ID, false );
-        delegateMap[BioActorLibrary::FILE_MODE_ATTR_ID] = new FileModeDelegate(false);
+        delegateMap[BaseAttributes::URL_OUT_ATTRIBUTE().getId()] = new URLDelegate(WeightMatrixIO::getPWMFileFilter(), WeightMatrixIO::WEIGHT_MATRIX_ID, false );
+        delegateMap[BaseAttributes::FILE_MODE_ATTRIBUTE().getId()] = new FileModeDelegate(false);
 
         setEditor(new DelegateEditor(delegateMap));
         setIconPath(":weight_matrix/images/weight_matrix.png");
-        setValidator(new ScreenedParamValidator(CoreLibConstants::URL_OUT_ATTR().getId(), ports.first()->getId(), CoreLibConstants::URL_SLOT().getId()));
-        setPortValidator(WMATRIX_IN_PORT_ID, new ScreenedSlotValidator(CoreLibConstants::URL_SLOT().getId()));
+        setValidator(new ScreenedParamValidator(BaseAttributes::URL_OUT_ATTRIBUTE().getId(), ports.first()->getId(), BaseSlots::URL_SLOT().getId()));
+        setPortValidator(WMATRIX_IN_PORT_ID, new ScreenedSlotValidator(BaseSlots::URL_SLOT().getId()));
 }
 
 bool WritePWMatrixProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return PWMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_OUT_ATTR().getId() );
+    return PWMatrixIOProto::isAcceptableDrop( md, params, BaseAttributes::URL_OUT_ATTRIBUTE().getId() );
 }
 
 void PWMatrixWorkerFactory::init() 
@@ -123,8 +136,8 @@ void PWMatrixWorkerFactory::init()
     assert(r);
     {        
         QMap<Descriptor, DataTypePtr> m;
-        Descriptor sd(CoreLibConstants::URL_SLOT().getId(), WeightMatrixIO::tr("Location"), WeightMatrixIO::tr("Location hint for the target file."));
-        m[CoreLibConstants::URL_SLOT()] = CoreDataTypes::STRING_TYPE();
+        Descriptor sd(BaseSlots::URL_SLOT().getId(), WeightMatrixIO::tr("Location"), WeightMatrixIO::tr("Location hint for the target file."));
+        m[BaseSlots::URL_SLOT()] = BaseTypes::STRING_TYPE();
         m[WMATRIX_SLOT] = WEIGHT_MATRIX_MODEL_TYPE();
         DataTypePtr t(new MapDataType(Descriptor("write.pwmatrix.content"), m));
 
@@ -134,7 +147,7 @@ void PWMatrixWorkerFactory::init()
         Descriptor desc(PWMatrixWriter::ACTOR_ID, WeightMatrixIO::tr("Write weight matrix"), WeightMatrixIO::tr("Saves all input weight matrices to specified location."));
         IntegralBusActorPrototype* proto = new WritePWMatrixProto(desc, p, a);
         proto->setPrompter(new PWMatrixWritePrompter());
-        r->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
+        r->registerProto(BaseActorCategories::CATEGORY_TRANSCRIPTION(), proto);
     }
     {
         QList<PortDescriptor*> p; QList<Attribute*> a;
@@ -147,7 +160,7 @@ void PWMatrixWorkerFactory::init()
         Descriptor desc(PWMatrixReader::ACTOR_ID, WeightMatrixIO::tr("Read weight matrix"), WeightMatrixIO::tr("Reads weight matrices from file(s). The files can be local or Internet URLs."));
         IntegralBusActorPrototype* proto = new ReadPWMatrixProto(desc, p, a);
         proto->setPrompter(new PWMatrixReadPrompter());
-        r->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
+        r->registerProto(BaseActorCategories::CATEGORY_TRANSCRIPTION(), proto);
     }
 
     PWMatrixBuildWorker::registerProto();
@@ -179,25 +192,24 @@ Worker* PWMatrixWorkerFactory::createWorker(Actor* a) {
 }
 
 QString PWMatrixReadPrompter::composeRichDoc() {
-    return tr("Read model(s) from <u>%1</u>").arg(getURL(CoreLibConstants::URL_IN_ATTR().getId()));
+    return tr("Read model(s) from <u>%1</u>").arg(getHyperlink(BaseAttributes::URL_IN_ATTRIBUTE().getId(), getURL(BaseAttributes::URL_IN_ATTRIBUTE().getId())));
 }
 
 QString PWMatrixWritePrompter::composeRichDoc() {
     IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(WMATRIX_IN_PORT_ID));
     Actor* producer = input->getProducer(PWMatrixWorkerFactory::WEIGHT_MATRIX_MODEL_TYPE_ID);
-    if (!producer) {
-        return getURL(CoreLibConstants::URL_OUT_ATTR().getId());
-    }
-    QString url = getScreenedURL(input, CoreLibConstants::URL_OUT_ATTR().getId(), CoreLibConstants::URL_SLOT().getId()); 
+    QString from = producer ? producer->getLabel() : "<font color='red'>"+tr("unset")+"</font>";
+    QString url = getScreenedURL(input, BaseAttributes::URL_OUT_ATTRIBUTE().getId(), BaseSlots::URL_SLOT().getId()); 
+    url = getHyperlink(BaseAttributes::URL_OUT_ATTRIBUTE().getId(), url);
     QString doc = tr("Save the profile(s) from <u>%1</u> to %2.")
-        .arg(producer->getLabel())
+        .arg(from)
         .arg(url);
     return doc;
 }
 
 void PWMatrixReader::init() {
     output = ports.value(WMATRIX_OUT_PORT_ID);
-    urls = WorkflowUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR().getId())->getAttributeValue<QString>());
+    urls = WorkflowUtils::expandToUrls(actor->getParameter(BaseAttributes::URL_IN_ATTRIBUTE().getId())->getAttributeValue<QString>());
     mtype = PWMatrixWorkerFactory::WEIGHT_MATRIX_MODEL_TYPE();
 }
 
@@ -213,7 +225,7 @@ void PWMatrixReader::sl_taskFinished() {
     if (t->getState() != Task::State_Finished) return;
     tasks.removeAll(t);
     if (output) {
-        if (!t->hasErrors()) {
+        if (!t->hasError()) {
             QVariant v = qVariantFromValue<PWMatrix>(t->getResult());
             output->put(Message(mtype, v));
         }
@@ -230,14 +242,14 @@ void PWMatrixWriter::init() {
 
 Task* PWMatrixWriter::tick() {
     Message inputMessage = getMessageAndSetupScriptValues(input);
-    url = actor->getParameter(CoreLibConstants::URL_OUT_ATTR().getId())->getAttributeValue<QString>();
-    fileMode = actor->getParameter(BioActorLibrary::FILE_MODE_ATTR_ID)->getAttributeValue<uint>();
+    url = actor->getParameter(BaseAttributes::URL_OUT_ATTRIBUTE().getId())->getAttributeValue<QString>();
+    fileMode = actor->getParameter(BaseAttributes::FILE_MODE_ATTRIBUTE().getId())->getAttributeValue<uint>();
     QVariantMap data = inputMessage.getData().toMap();
     
     PWMatrix model = data.value(PWMatrixWorkerFactory::WMATRIX_SLOT.getId()).value<PWMatrix>();
     QString anUrl = url;
     if (anUrl.isEmpty()) {
-        anUrl = data.value(CoreLibConstants::URL_SLOT().getId()).toString();
+        anUrl = data.value(BaseSlots::URL_SLOT().getId()).toString();
     }
     if (anUrl.isEmpty()) {
         QString err = tr("Unspecified URL for writing weight matrix");
@@ -303,34 +315,34 @@ bool PFMatrixIOProto::isAcceptableDrop(const QMimeData * md, QVariantMap * param
 ReadPFMatrixProto::ReadPFMatrixProto(const Descriptor& _desc, const QList<PortDescriptor*>& _ports, const QList<Attribute*>& _attrs ) 
 : PFMatrixIOProto( _desc, _ports, _attrs ) {
 
-    attrs << new Attribute(CoreLibConstants::URL_IN_ATTR(), CoreDataTypes::STRING_TYPE(), true);
+    attrs << new Attribute(BaseAttributes::URL_IN_ATTRIBUTE(), BaseTypes::STRING_TYPE(), true);
     QMap<QString, PropertyDelegate*> delegateMap;
-    delegateMap[CoreLibConstants::URL_IN_ATTR().getId()] = new URLDelegate(WeightMatrixIO::getPFMFileFilter(), WeightMatrixIO::FREQUENCY_MATRIX_ID, true);
+    delegateMap[BaseAttributes::URL_IN_ATTRIBUTE().getId()] = new URLDelegate(WeightMatrixIO::getPFMFileFilter(), WeightMatrixIO::FREQUENCY_MATRIX_ID, true);
     setEditor(new DelegateEditor(delegateMap));
     setIconPath(":weight_matrix/images/weight_matrix.png");
 }
 
 bool ReadPFMatrixProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return PFMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_IN_ATTR().getId());
+    return PFMatrixIOProto::isAcceptableDrop( md, params, BaseAttributes::URL_IN_ATTRIBUTE().getId());
 }
 
 WritePFMatrixProto::WritePFMatrixProto(const Descriptor& _desc, const QList<PortDescriptor*>& _ports, const QList<Attribute*>& _attrs ) 
 : PFMatrixIOProto( _desc, _ports, _attrs ) {
-    attrs << new Attribute(CoreLibConstants::URL_OUT_ATTR(), CoreDataTypes::STRING_TYPE(), true );
-    attrs << new Attribute(BioActorLibrary::FILE_MODE_ATTR(), CoreDataTypes::NUM_TYPE(), false, SaveDoc_Roll);
+    attrs << new Attribute(BaseAttributes::URL_OUT_ATTRIBUTE(), BaseTypes::STRING_TYPE(), true );
+    attrs << new Attribute(BaseAttributes::FILE_MODE_ATTRIBUTE(), BaseTypes::NUM_TYPE(), false, SaveDoc_Roll);
 
     QMap<QString, PropertyDelegate*> delegateMap;
-    delegateMap[CoreLibConstants::URL_OUT_ATTR().getId()] = new URLDelegate(WeightMatrixIO::getPFMFileFilter(), WeightMatrixIO::FREQUENCY_MATRIX_ID, false );
-    delegateMap[BioActorLibrary::FILE_MODE_ATTR_ID] = new FileModeDelegate(false);
+    delegateMap[BaseAttributes::URL_OUT_ATTRIBUTE().getId()] = new URLDelegate(WeightMatrixIO::getPFMFileFilter(), WeightMatrixIO::FREQUENCY_MATRIX_ID, false );
+    delegateMap[BaseAttributes::FILE_MODE_ATTRIBUTE().getId()] = new FileModeDelegate(false);
 
     setEditor(new DelegateEditor(delegateMap));
     setIconPath(":weight_matrix/images/weight_matrix.png");
-    setValidator(new ScreenedParamValidator(CoreLibConstants::URL_OUT_ATTR().getId(), ports.first()->getId(), CoreLibConstants::URL_SLOT().getId()));
-    setPortValidator(FMATRIX_IN_PORT_ID, new ScreenedSlotValidator(CoreLibConstants::URL_SLOT().getId()));
+    setValidator(new ScreenedParamValidator(BaseAttributes::URL_OUT_ATTRIBUTE().getId(), ports.first()->getId(), BaseSlots::URL_SLOT().getId()));
+    setPortValidator(FMATRIX_IN_PORT_ID, new ScreenedSlotValidator(BaseSlots::URL_SLOT().getId()));
 }
 
 bool WritePFMatrixProto::isAcceptableDrop(const QMimeData * md, QVariantMap * params ) const {
-    return PFMatrixIOProto::isAcceptableDrop( md, params, CoreLibConstants::URL_OUT_ATTR().getId() );
+    return PFMatrixIOProto::isAcceptableDrop( md, params, BaseAttributes::URL_OUT_ATTRIBUTE().getId() );
 }
 
 void PFMatrixWorkerFactory::init() 
@@ -339,8 +351,8 @@ void PFMatrixWorkerFactory::init()
     assert(r);
     {        
         QMap<Descriptor, DataTypePtr> m;
-        Descriptor sd(CoreLibConstants::URL_SLOT().getId(), WeightMatrixIO::tr("Location"), WeightMatrixIO::tr("Location hint for the target file."));
-        m[CoreLibConstants::URL_SLOT()] = CoreDataTypes::STRING_TYPE();
+        Descriptor sd(BaseSlots::URL_SLOT().getId(), WeightMatrixIO::tr("Location"), WeightMatrixIO::tr("Location hint for the target file."));
+        m[BaseSlots::URL_SLOT()] = BaseTypes::STRING_TYPE();
         m[PFMatrixWorkerFactory::FMATRIX_SLOT] = PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE();
         DataTypePtr t(new MapDataType(Descriptor("write.pfmatrix.content"), m));
 
@@ -350,7 +362,7 @@ void PFMatrixWorkerFactory::init()
         Descriptor desc(PFMatrixWriter::ACTOR_ID, WeightMatrixIO::tr("Write frequency matrix"), WeightMatrixIO::tr("Saves all input frequency matrices to specified location."));
         IntegralBusActorPrototype* proto = new WritePFMatrixProto(desc, p, a);
         proto->setPrompter(new PFMatrixWritePrompter());
-        r->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
+        r->registerProto(BaseActorCategories::CATEGORY_TRANSCRIPTION(), proto);
     }
     {
         QList<PortDescriptor*> p; QList<Attribute*> a;
@@ -363,7 +375,7 @@ void PFMatrixWorkerFactory::init()
         Descriptor desc(PFMatrixReader::ACTOR_ID, WeightMatrixIO::tr("Read frequency matrix"), WeightMatrixIO::tr("Reads frequency matrices from file(s). The files can be local or Internet URLs."));
         IntegralBusActorPrototype* proto = new ReadPFMatrixProto(desc, p, a);
         proto->setPrompter(new PFMatrixReadPrompter());
-        r->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
+        r->registerProto(BaseActorCategories::CATEGORY_TRANSCRIPTION(), proto);
     }
 
     PFMatrixBuildWorker::registerProto();
@@ -395,25 +407,24 @@ Worker* PFMatrixWorkerFactory::createWorker(Actor* a) {
 }
 
 QString PFMatrixReadPrompter::composeRichDoc() {
-    return tr("Read model(s) from <u>%1</u>").arg(getURL(CoreLibConstants::URL_IN_ATTR().getId()));
+    return tr("Read model(s) from <u>%1</u>").arg(getHyperlink(BaseAttributes::URL_IN_ATTRIBUTE().getId(), getURL(BaseAttributes::URL_IN_ATTRIBUTE().getId())));
 }
 
 QString PFMatrixWritePrompter::composeRichDoc() {
     IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(FMATRIX_IN_PORT_ID));
     Actor* producer = input->getProducer(PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE_ID);
-    if (!producer) {
-        return getURL(CoreLibConstants::URL_OUT_ATTR().getId());
-    }
-    QString url = getScreenedURL(input, CoreLibConstants::URL_OUT_ATTR().getId(), CoreLibConstants::URL_SLOT().getId()); 
+    QString from = producer ? producer->getLabel() : "<font color='red'>"+tr("unset")+"</font>";
+    QString url = getScreenedURL(input, BaseAttributes::URL_OUT_ATTRIBUTE().getId(), BaseSlots::URL_SLOT().getId()); 
+    url = getHyperlink(BaseAttributes::URL_OUT_ATTRIBUTE().getId(), url);
     QString doc = tr("Save the profile(s) from <u>%1</u> to %2.")
-        .arg(producer->getLabel())
+        .arg(from)
         .arg(url);
     return doc;
 }
 
 void PFMatrixReader::init() {
     output = ports.value(FMATRIX_OUT_PORT_ID);
-    urls = WorkflowUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR().getId())->getAttributeValue<QString>());
+    urls = WorkflowUtils::expandToUrls(actor->getParameter(BaseAttributes::URL_IN_ATTRIBUTE().getId())->getAttributeValue<QString>());
     mtype = PFMatrixWorkerFactory::FREQUENCY_MATRIX_MODEL_TYPE();
 }
 
@@ -429,7 +440,7 @@ void PFMatrixReader::sl_taskFinished() {
     if (t->getState() != Task::State_Finished) return;
     tasks.removeAll(t);
     if (output) {
-        if (!t->hasErrors()) {
+        if (!t->hasError()) {
             QVariant v = qVariantFromValue<PFMatrix>(t->getResult());
             output->put(Message(mtype, v));
         }
@@ -446,14 +457,14 @@ void PFMatrixWriter::init() {
 
 Task* PFMatrixWriter::tick() {
     Message inputMessage = getMessageAndSetupScriptValues(input);
-    url = actor->getParameter(CoreLibConstants::URL_OUT_ATTR().getId())->getAttributeValue<QString>();
-    fileMode = actor->getParameter(BioActorLibrary::FILE_MODE_ATTR_ID)->getAttributeValue<uint>();
+    url = actor->getParameter(BaseAttributes::URL_OUT_ATTRIBUTE().getId())->getAttributeValue<QString>();
+    fileMode = actor->getParameter(BaseAttributes::FILE_MODE_ATTRIBUTE().getId())->getAttributeValue<uint>();
     QVariantMap data = inputMessage.getData().toMap();
     PFMatrix model = data.value(PFMatrixWorkerFactory::FMATRIX_SLOT.getId()).value<PFMatrix>();
     
     QString anUrl = url;
     if (anUrl.isEmpty()) {
-        anUrl = data.value(CoreLibConstants::URL_SLOT().getId()).toString();
+        anUrl = data.value(BaseSlots::URL_SLOT().getId()).toString();
     }
     if (anUrl.isEmpty()) {
         QString err = tr("Unspecified URL for writing frequency matrix");
