@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <U2Core/Counter.h>
 
@@ -64,8 +75,8 @@ void WeightMatrixSingleSearchTask::onRegion(SequenceWalkerSubtask* t, TaskStateI
     if (cfg.complOnly && !t->isDNAComplemented()) {
         return;
     }
-    LRegion globalRegion = t->getGlobalRegion();
-    int seqLen = globalRegion.len;
+    U2Region globalRegion = t->getGlobalRegion();
+    int seqLen = globalRegion.length;
     const char* seq = t->getGlobalConfig().seq + globalRegion.startPos;;
     int modelSize = model.getLength();
     ti.progress =0;
@@ -81,9 +92,9 @@ void WeightMatrixSingleSearchTask::onRegion(SequenceWalkerSubtask* t, TaskStateI
         WeightMatrixSearchResult r;
         r.score = 100*psum;
         if (r.score >= cfg.minPSUM) {//report result
-            r.complement = t->isDNAComplemented();
+            r.strand = t->isDNAComplemented() ? U2Strand::Complementary : U2Strand::Direct;
             r.region.startPos = globalRegion.startPos +  i + resultsOffset;
-            r.region.len = modelSize;
+            r.region.length = modelSize;
             r.qual = model.getProperties();
             r.modelInfo = cfg.modelName.split("/").last();
             addResult(r);
