@@ -1,19 +1,30 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_WEIGHT_MATRIX_SEARCH_TASK_H_
 #define _U2_WEIGHT_MATRIX_SEARCH_TASK_H_
 
 #include "WeightMatrixAlgorithm.h"
 
-#include <U2Core/LRegion.h>
+#include <U2Core/U2Region.h>
 #include <U2Core/AnnotationData.h>
 #include <U2Core/SequenceWalkerTask.h>
 
@@ -24,7 +35,7 @@ namespace U2 {
 
 class WeightMatrixSearchResult {
 public:
-    WeightMatrixSearchResult() : complement(false), score(-1) {
+    WeightMatrixSearchResult() : strand(U2Strand::Direct), score(-1) {
         qual = QMap<QString, QString>();
     }
 
@@ -32,17 +43,16 @@ public:
         SharedAnnotationData data;
         data = new AnnotationData;
         data->name = name;
-        data->location.append(region);
-        data->aminoFrame = TriState_No;
-        data->complement = complement;
+        data->location->regions << region;
+        data->setStrand(strand);
         if (!modelInfo.isEmpty()) {
-            data->qualifiers.append(Qualifier("Weight matrix model", modelInfo));
+            data->qualifiers.append(U2Qualifier("Weight matrix model", modelInfo));
         }
-        data->qualifiers.append(Qualifier("Score", QString::number(score)));
+        data->qualifiers.append(U2Qualifier("Score", QString::number(score)));
         QMapIterator<QString, QString> iter(qual);
         while (iter.hasNext()) {
             iter.next();
-            data->qualifiers.append(Qualifier(iter.key(), iter.value()));
+            data->qualifiers.append(U2Qualifier(iter.key(), iter.value()));
         }
         return data;
     }
@@ -57,8 +67,8 @@ public:
     }
 
 
-    LRegion region;
-    bool    complement;
+    U2Region region;
+    U2Strand strand;
     float   score;
     QString modelInfo;
     QMap<QString, QString> qual;
