@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "WeightMatrixWorkers.h"
 #include "WeightMatrixIOWorkers.h"
@@ -15,11 +26,12 @@
 #include <U2Lang/IntegralBusModel.h>
 #include <U2Lang/WorkflowEnv.h>
 #include <U2Lang/ActorPrototypeRegistry.h>
-#include <U2Lang/CoreDataTypes.h>
-#include <U2Lang/BioDatatypes.h>
-#include <U2Lang/BioActorLibrary.h>
+#include <U2Lang/BaseTypes.h>
+#include <U2Lang/BaseSlots.h>
+#include <U2Lang/BasePorts.h>
+#include <U2Lang/BaseActorCategories.h>
 #include <U2Designer/DelegateEditors.h>
-#include <U2Lang/CoreLibConstants.h>
+#include <U2Lang/BaseAttributes.h>
 
 #include <U2Core/DNASequence.h>
 #include <U2Core/DNATranslation.h>
@@ -38,9 +50,7 @@ namespace U2 {
 namespace LocalWorkflow {
 
 static const QString MODEL_PORT("in-wmatrix");
-
 static const QString NAME_ATTR("result-name");
-static const QString STRAND_ATTR("strand");
 static const QString SCORE_ATTR("min-score");
 
 const QString PWMatrixSearchWorker::ACTOR_ID("wmatrix-search");
@@ -49,31 +59,29 @@ void PWMatrixSearchWorker::registerProto() {
     QList<PortDescriptor*> p; QList<Attribute*> a;
     {
         Descriptor md(MODEL_PORT, PWMatrixSearchWorker::tr("Weight matrix"), PWMatrixSearchWorker::tr("Profile data to search with."));
-        Descriptor sd(CoreLibConstants::IN_SEQ_PORT_ID, PWMatrixSearchWorker::tr("Sequence"), PWMatrixSearchWorker::tr("Input nucleotide sequence to search in."));
-        Descriptor od(CoreLibConstants::OUT_ANNOTATIONS_PORT_ID, PWMatrixSearchWorker::tr("Weight matrix annotations"), 
+        Descriptor sd(BasePorts::IN_SEQ_PORT_ID(), PWMatrixSearchWorker::tr("Sequence"), PWMatrixSearchWorker::tr("Input nucleotide sequence to search in."));
+        Descriptor od(BasePorts::OUT_ANNOTATIONS_PORT_ID(), PWMatrixSearchWorker::tr("Weight matrix annotations"), 
             PWMatrixSearchWorker::tr("Annotations marking found TFBS sites."));
         
         QMap<Descriptor, DataTypePtr> modelM;
         modelM[PWMatrixWorkerFactory::WMATRIX_SLOT] = PWMatrixWorkerFactory::WEIGHT_MATRIX_MODEL_TYPE();
         p << new PortDescriptor(md, DataTypePtr(new MapDataType("wmatrix.search.model", modelM)), true /*input*/, false, IntegralBusPort::BLIND_INPUT);
         QMap<Descriptor, DataTypePtr> seqM;
-        seqM[BioActorLibrary::SEQ_SLOT()] = BioDataTypes::DNA_SEQUENCE_TYPE();
+        seqM[BaseSlots::DNA_SEQUENCE_SLOT()] = BaseTypes::DNA_SEQUENCE_TYPE();
         p << new PortDescriptor(sd, DataTypePtr(new MapDataType("wmatrix.search.sequence", seqM)), true /*input*/);
         QMap<Descriptor, DataTypePtr> outM;
-        outM[BioActorLibrary::FEATURE_TABLE_SLOT()] = BioDataTypes::ANNOTATION_TABLE_TYPE();
+        outM[BaseSlots::ANNOTATION_TABLE_SLOT()] = BaseTypes::ANNOTATION_TABLE_TYPE();
         p << new PortDescriptor(od, DataTypePtr(new MapDataType("wmatrix.search.out", outM)), false /*input*/, true /*multi*/);
     }
     {
         Descriptor nd(NAME_ATTR, PWMatrixSearchWorker::tr("Result annotation"), 
             PWMatrixSearchWorker::tr("Annotation name for marking found regions"));
-        Descriptor snd(STRAND_ATTR, L10N::searchIn(),
-            PWMatrixSearchWorker::tr("Which strands should be searched: direct, complement or both."));
         Descriptor scd(SCORE_ATTR, PWMatrixSearchWorker::tr("Min score"), 
             QApplication::translate("PWMSearchDialog", "min_err_tip", 0, QApplication::UnicodeUTF8));
         
-        a << new Attribute(nd, CoreDataTypes::STRING_TYPE(), true, "misc_feature");
-        a << new Attribute(snd, CoreDataTypes::NUM_TYPE(), false, 0);
-        a << new Attribute(scd, CoreDataTypes::NUM_TYPE(), false, 85);
+        a << new Attribute(nd, BaseTypes::STRING_TYPE(), true, "misc_feature");
+        a << new Attribute(BaseAttributes::STRAND_ATTRIBUTE(), BaseTypes::STRING_TYPE(), false, BaseAttributes::STRAND_BOTH());
+        a << new Attribute(scd, BaseTypes::NUM_TYPE(), false, 85);
     }
 
     Descriptor desc(ACTOR_ID, tr("Search for TFBS with weight matrix"), 
@@ -87,41 +95,57 @@ void PWMatrixSearchWorker::registerProto() {
         QVariantMap m; m["minimum"] = 1; m["maximum"] = 100; m["suffix"] = "%";
         delegates[SCORE_ATTR] = new SpinBoxDelegate(m);
     }
-
-    QVariantMap strandMap; 
-    strandMap[tr("both strands")] = 0;
-    strandMap[tr("direct strand")] = 1;
-    strandMap[tr("complement strand")] = -1;
-    delegates[STRAND_ATTR] = new ComboBoxDelegate(strandMap);
-    
+    delegates[BaseAttributes::STRAND_ATTRIBUTE().getId()] = new ComboBoxDelegate(BaseAttributes::STRAND_ATTRIBUTE_VALUES_MAP());
     proto->setPrompter(new PWMatrixSearchPrompter());
     proto->setEditor(new DelegateEditor(delegates));
     proto->setIconPath(":weight_matrix/images/weight_matrix.png");
-    WorkflowEnv::getProtoRegistry()->registerProto(BioActorLibrary::CATEGORY_TRANSCRIPTION(), proto);
+    WorkflowEnv::getProtoRegistry()->registerProto(BaseActorCategories::CATEGORY_TRANSCRIPTION(), proto);
+}
+
+static int getStrand(const QString & s) {
+    QString str = s.toLower();
+    if(BaseAttributes::STRAND_BOTH().startsWith(str)) {
+        return 0;
+    } else if(BaseAttributes::STRAND_DIRECT().startsWith(str)) {
+        return 1;
+    } else if(BaseAttributes::STRAND_COMPLEMENTARY().startsWith(str)) {
+        return -1;
+    } else {
+        bool ok = false;
+        int num = str.toInt(&ok);
+        if(ok) {
+            return num;
+        } else {
+            return 0;
+        }
+    }
 }
 
 QString PWMatrixSearchPrompter::composeRichDoc() {
-    Actor* modelProducer = qobject_cast<IntegralBusPort*>(target->getPort(MODEL_PORT))->getProducer(MODEL_PORT);
-    Actor* seqProducer = qobject_cast<IntegralBusPort*>(target->getPort(CoreLibConstants::IN_SEQ_PORT_ID))->getProducer(CoreLibConstants::IN_SEQ_PORT_ID);
+    Actor* modelProducer = qobject_cast<IntegralBusPort*>(target->getPort(MODEL_PORT))->getProducer(PWMatrixWorkerFactory::WMATRIX_SLOT.getId());
+    Actor* seqProducer = qobject_cast<IntegralBusPort*>(target->getPort(BasePorts::IN_SEQ_PORT_ID()))->getProducer(BaseSlots::DNA_SEQUENCE_SLOT().getId());
 
-    QString seqName = seqProducer ? tr("For each sequence from <u>%1</u>,").arg(seqProducer->getLabel()) : "";
-    QString modelName = modelProducer ? tr("with all profiles provided by <u>%1</u>,").arg(modelProducer->getLabel()) : "";
+    QString unsetStr = "<font color='red'>"+tr("unset")+"</font>";
+    QString seqName = tr("For each sequence from <u>%1</u>,").arg(seqProducer ? seqProducer->getLabel() : unsetStr);
+    QString modelName = tr("with all profiles provided by <u>%1</u>,").arg(modelProducer ? modelProducer->getLabel() : unsetStr);
 
     QString resultName = getRequiredParam(NAME_ATTR);
+    resultName = getHyperlink(NAME_ATTR, resultName);
 
     QString strandName;
-    switch (getParameter(STRAND_ATTR).toInt()) {
+    switch (getStrand(getParameter(BaseAttributes::STRAND_ATTRIBUTE().getId()).value<QString>())) {
     case 0: strandName = PWMatrixSearchWorker::tr("both strands"); break;
     case 1: strandName = PWMatrixSearchWorker::tr("direct strand"); break;
     case -1: strandName = PWMatrixSearchWorker::tr("complement strand"); break;
     }
+    strandName = getHyperlink(BaseAttributes::STRAND_ATTRIBUTE().getId(), strandName);
 
     QString doc = tr("%1 search transcription factor binding sites (TFBS) %2."
         "<br>Recognize sites with <u>similarity %3%</u>, process <u>%4</u>."
         "<br>Output the list of found regions annotated as <u>%5</u>.")
         .arg(seqName)
         .arg(modelName)
-        .arg(getParameter(SCORE_ATTR).toInt())
+        .arg(getHyperlink(SCORE_ATTR, getParameter(SCORE_ATTR).toInt()))
         .arg(strandName)
         .arg(resultName);
 
@@ -130,12 +154,12 @@ QString PWMatrixSearchPrompter::composeRichDoc() {
 
 void PWMatrixSearchWorker::init() {
     modelPort = ports.value(MODEL_PORT);
-    dataPort = ports.value(CoreLibConstants::IN_SEQ_PORT_ID);
-    output = ports.value(CoreLibConstants::OUT_ANNOTATIONS_PORT_ID);
+    dataPort = ports.value(BasePorts::IN_SEQ_PORT_ID());
+    output = ports.value(BasePorts::OUT_ANNOTATIONS_PORT_ID());
     dataPort->addComplement(output);
     output->addComplement(dataPort);
 
-    strand = actor->getParameter(STRAND_ATTR)->getAttributeValue<int>();
+    strand = getStrand(actor->getParameter(BaseAttributes::STRAND_ATTRIBUTE().getId())->getAttributeValue<QString>());
     cfg.minPSUM = actor->getParameter(SCORE_ATTR)->getAttributeValue<int>();
     resultName = actor->getParameter(NAME_ATTR)->getAttributeValue<QString>();
 }
@@ -151,7 +175,7 @@ Task* PWMatrixSearchWorker::tick() {
     if (models.isEmpty() || !modelPort->isEnded() || !dataPort->hasMessage()) {
         return NULL;
     }
-    DNASequence seq = dataPort->get().getData().toMap().value(BioActorLibrary::SEQ_SLOT().getId()).value<DNASequence>();
+    DNASequence seq = dataPort->get().getData().toMap().value(BaseSlots::DNA_SEQUENCE_SLOT().getId()).value<DNASequence>();
     
     if (!seq.isNull() && seq.alphabet->getType() == DNAAlphabet_NUCL) {
         WeightMatrixSearchCfg config(cfg);
@@ -191,7 +215,7 @@ void PWMatrixSearchWorker::sl_taskFinished(Task* t) {
         res += WeightMatrixSearchResult::toTable(sst->takeResults(), resultName);
     }
     QVariant v = qVariantFromValue<QList<SharedAnnotationData> >(res);
-    output->put(Message(BioDataTypes::ANNOTATION_TABLE_TYPE(), v));
+    output->put(Message(BaseTypes::ANNOTATION_TABLE_TYPE(), v));
     if (dataPort->isEnded()) {
         output->setEnded();
     }
