@@ -1,21 +1,32 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QDebug>
 
 #include <U2Core/Log.h>
 #include <U2Lang/WorkflowUtils.h>
-#include <U2Lang/CoreDataTypes.h>
 #include <U2Lang/WorkflowSettings.h>
 #include <U2Lang/IntegralBusType.h>
 #include <U2Lang/Datatype.h>
+#include <U2Lang/BaseTypes.h>
 
 #include "WorkflowEditorDelegates.h"
 #include "WorkflowEditor.h"
@@ -66,7 +77,7 @@ void ActorCfgModel::setupAttributesScripts() {
         
         DataTypePtr attributeType = attribute->getAttributeType();
         // FIXME: add support for all types in scripting
-        if(attributeType != CoreDataTypes::STRING_TYPE() && attributeType != CoreDataTypes::NUM_TYPE()) {
+        if(attributeType != BaseTypes::STRING_TYPE() && attributeType != BaseTypes::NUM_TYPE()) {
             continue;
         }
         
@@ -145,10 +156,58 @@ int ActorCfgModel::rowCount( const QModelIndex & parent ) const {
         return 0;
     }
 
-    return attrs.isEmpty() || parent.isValid() ? 0 : attrs.size();
+    /*int x = iterationIdx;
+    if(x < 0) {
+        return 0;
+    }
+    if (x >= iterations.size()) {
+        //FIXME: handle error
+        x = 0;
+    }
+    QVariantMap& cfg = iterations[x].cfg[subject->getId()]
+
+    int rows = 0;
+    foreach(Attribute *a, attrs) {
+        if(a->isVisible(cfg)) {
+            rows++;
+        }
+    }*/
+
+    return attrs.isEmpty() || parent.isValid() ? 0 : attrs.size()/*rows*/;
 }
 
 Qt::ItemFlags ActorCfgModel::flags( const QModelIndex & index ) const {
+    int x = iterationIdx;
+    if (x >= iterations.size()) {
+        //FIXME: handle error
+        x = 0;
+    }
+    QVariantMap cfg = iterations[x].cfg.value(subject->getId());
+    if(cfg.isEmpty()) {
+        QVariantMap def;
+        foreach(Attribute *a, attrs) {
+            def[a->getId()] = a->getAttributePureValue();
+        }
+        Attribute *currentAttribute = attrs.at(index.row());
+        if(! currentAttribute->isVisible(def)) {
+            return 0;
+        }
+    } else {
+        QVariantMap map;
+        foreach(Attribute *a, attrs) {
+            if(cfg.contains(a->getId())) {
+                map[a->getId()] = cfg[a->getId()];
+            } else {
+                map[a->getId()] = a->getAttributePureValue();
+            }
+        }
+        Attribute *currentAttribute = attrs.at(index.row());
+        if(! currentAttribute->isVisible(map)) {
+            return 0;
+        }
+    }
+
+
     int col = index.column();
     int row = index.row();
     switch(col) {
@@ -162,7 +221,7 @@ Qt::ItemFlags ActorCfgModel::flags( const QModelIndex & index ) const {
                 Attribute * currentAttribute = attrs.at(row);
                 assert(currentAttribute != NULL);
                 // FIXME: add support for all types in scripting
-                if(currentAttribute->getAttributeType() != CoreDataTypes::STRING_TYPE() && currentAttribute->getAttributeType() != CoreDataTypes::NUM_TYPE()) {
+                if(currentAttribute->getAttributeType() != BaseTypes::STRING_TYPE() && currentAttribute->getAttributeType() != BaseTypes::NUM_TYPE()) {
                     return Qt::ItemIsEnabled;    
                 } else {
                     return Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable;
@@ -225,16 +284,37 @@ bool ActorCfgModel::setAttributeValue( const Attribute * attr, QVariant & attrVa
     return isDefaultVal;
 }
 
-static QString getStringForDisplayRole(const QVariant & value) {
-    QString str = value.toString();
-    if(!str.isEmpty() && str.at(0).isLower()) {
-        return str.at(0).toUpper() + str.mid(1);
+Attribute* ActorCfgModel::getAttributeByRow(int row) const{
+    int x = iterationIdx;
+    if (x >= iterations.size()) {
+        //FIXME: handle error
+        x = 0;
     }
-    return str;
+    QVariantMap& cfg = iterations[x].cfg[subject->getId()];
+
+    QList<Attribute*>visibleAttrs;
+    foreach(Attribute* a, attrs) {
+        if(a->isVisible(cfg)) {
+            visibleAttrs << a;
+        }
+    }
+    return visibleAttrs.at(row);
 }
 
 QVariant ActorCfgModel::data(const QModelIndex & index, int role ) const {
     const Attribute *currentAttribute = attrs.at(index.row());
+    //const Attribute *currentAttribute = getAttributeByRow(index.row());
+
+    /*int x = iterationIdx;
+    if (x >= iterations.size()) {
+        //FIXME: handle error
+        x = 0;
+    }
+    QVariantMap& cfg = iterations[x].cfg[subject->getId()];
+
+    if(! currentAttribute->isVisible(cfg)) {
+        return QVariant();
+    }*/
     if (role == DescriptorRole) { // descriptor that will be shown in under editor. 'propDoc' in WorkflowEditor
         return qVariantFromValue<Descriptor>(*currentAttribute);
     }
@@ -275,12 +355,8 @@ QVariant ActorCfgModel::data(const QModelIndex & index, int role ) const {
                     if(propertyDelegate) {
                         return propertyDelegate->getDisplayValue(attributeValue);
                     } else {
-                        QString valueStr = getStringForDisplayRole(attributeValue);
-                        if(!valueStr.isEmpty()) {
-                            return valueStr;
-                        } else {
-                            return attributeValue;
-                        }
+                        QString valueStr = WorkflowUtils::getStringForParameterDisplayRole(attributeValue);
+                        return !valueStr.isEmpty() ? valueStr : attributeValue;
                     }
                 }
             case Qt::ForegroundRole:
@@ -297,7 +373,7 @@ QVariant ActorCfgModel::data(const QModelIndex & index, int role ) const {
     case SCRIPT_COLUMN:
         {
             // FIXME: add support for all types in scripting
-            if(currentAttribute->getAttributeType() != CoreDataTypes::STRING_TYPE() && currentAttribute->getAttributeType() != CoreDataTypes::NUM_TYPE() ) {
+            if(currentAttribute->getAttributeType() != BaseTypes::STRING_TYPE() && currentAttribute->getAttributeType() != BaseTypes::NUM_TYPE() ) {
                 if( role == Qt::DisplayRole || role == Qt::ToolTipRole ) {
                     return QVariant(tr("N/A"));
                 } else {
@@ -334,6 +410,7 @@ QVariant ActorCfgModel::data(const QModelIndex & index, int role ) const {
 bool ActorCfgModel::setData( const QModelIndex & index, const QVariant & value, int role ) {
     int col = index.column();
     Attribute* editingAttribute = attrs[index.row()];
+    //Attribute *editingAttribute = getAttributeByRow(index.row());
     assert(editingAttribute != NULL);
     
     switch(col) {
