@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "CreateScriptWorker.h"
 #include "WorkflowEditorDelegates.h"
@@ -15,6 +26,8 @@
 #include <U2Core/Log.h>
 #include <U2Lang/ActorPrototypeRegistry.h>
 #include <U2Lang/WorkflowSettings.h>
+#include <U2Lang/BaseTypes.h>
+#include <U2Lang/BaseSlots.h>
 
 #include <QtCore/QAbstractItemModel>
 #include <QtGui/QTableView>
@@ -48,31 +61,42 @@ public:
 
     static QVariantMap getAttrTypes() {
         QVariantMap res;
-        DataTypePtr ptr = CoreDataTypes::BOOL_TYPE();
-        res[ptr->getDisplayName()] = CoreDataTypes::BOOL_TYPE_ID;
+        DataTypePtr ptr = BaseTypes::BOOL_TYPE();
+        res[ptr->getDisplayName()] = BaseTypes::BOOL_TYPE()->getId();
 
-        ptr = CoreDataTypes::NUM_TYPE();
-        res[ptr->getDisplayName()] = CoreDataTypes::NUM_TYPE_ID;
+        ptr = BaseTypes::NUM_TYPE();
+        res[ptr->getDisplayName()] = BaseTypes::NUM_TYPE()->getId();
 
-        ptr = CoreDataTypes::STRING_TYPE();
-        res[ptr->getDisplayName()] = CoreDataTypes::STRING_TYPE_ID;
+        ptr = BaseTypes::STRING_TYPE();
+        res[ptr->getDisplayName()] = BaseTypes::STRING_TYPE()->getId();
 
         return res;
     }
 
     static QVariantMap getPortTypes() {
         QVariantMap res;
-        DataTypePtr ptr = BioDataTypes::DNA_SEQUENCE_TYPE();
-        res[ptr->getDisplayName()] = BioDataTypes::DNA_SEQUENCE_TYPE()->getId();
+        DataTypePtr ptr = BaseTypes::DNA_SEQUENCE_TYPE();
+        res[ptr->getDisplayName()] = BaseTypes::DNA_SEQUENCE_TYPE()->getId();
 
-        ptr = BioDataTypes::ANNOTATION_TABLE_TYPE();
-        res[ptr->getDisplayName()] = BioDataTypes::ANNOTATION_TABLE_TYPE()->getId();
+        ptr = BaseTypes::ANNOTATION_TABLE_TYPE();
+        res[ptr->getDisplayName()] = BaseTypes::ANNOTATION_TABLE_TYPE()->getId();
 
-        ptr = BioDataTypes::MULTIPLE_ALIGNMENT_TYPE();
-        res[ptr->getDisplayName()] = BioDataTypes::MULTIPLE_ALIGNMENT_TYPE()->getId();
+        ptr = BaseTypes::MULTIPLE_ALIGNMENT_TYPE();
+        res[ptr->getDisplayName()] = BaseTypes::MULTIPLE_ALIGNMENT_TYPE()->getId();
 
-        ptr = CoreDataTypes::STRING_TYPE();
-        res[ptr->getDisplayName()] = CoreDataTypes::STRING_TYPE_ID;
+        ptr = BaseTypes::STRING_TYPE();
+        res[ptr->getDisplayName()] = BaseTypes::STRING_TYPE()->getId();
+        /*Descriptor ptr = BaseSlots::DNA_SEQUENCE_SLOT();
+        res[ptr.getDisplayName()] = BaseSlots::DNA_SEQUENCE_SLOT().getId();
+
+        ptr = BaseSlots::ANNOTATION_TABLE_SLOT();
+        res[ptr.getDisplayName()] = BaseSlots::ANNOTATION_TABLE_SLOT().getId();
+
+        ptr = BaseSlots::MULTIPLE_ALIGNMENT_SLOT();
+        res[ptr.getDisplayName()] = BaseSlots::MULTIPLE_ALIGNMENT_SLOT().getId();
+
+        ptr = BaseSlots::TEXT_SLOT();
+        res[ptr.getDisplayName()] = BaseSlots::TEXT_SLOT().getId();*/
         return res;
     }
 
@@ -94,11 +118,11 @@ public:
     CfgListItem(DelegateType t)  {
         if(t == DelegateForPort) {
             delegate = new ComboBoxDelegate(MapForTypesDelegate::portMap);
-            dataTypeId = BioDataTypes::DNA_SEQUENCE_TYPE()->getId();
+            dataTypeId = BaseTypes::DNA_SEQUENCE_TYPE()->getId();
         }
         else if(t == DelegateForAttribute) {
             delegate = new ComboBoxDelegate(MapForTypesDelegate::attrMap);
-            dataTypeId = CoreDataTypes::STRING_TYPE_ID;
+            dataTypeId = BaseTypes::STRING_TYPE()->getId();
         }
         else {
             assert(0);
@@ -361,6 +385,24 @@ CreateScriptElementDialog::CreateScriptElementDialog(QWidget *p, ActorPrototype*
     }
 }
 
+static DataTypePtr getDatatypeOfSlotDesc(const Descriptor & dt) {
+    QString dtId = dt.getId();
+    if(dtId == BaseSlots::DNA_SEQUENCE_SLOT().getId()) {
+        return BaseTypes::DNA_SEQUENCE_TYPE();
+    }
+    if(dtId == BaseSlots::ANNOTATION_TABLE_SLOT().getId()) {
+        return BaseTypes::ANNOTATION_TABLE_TYPE();
+    }
+    if(dtId == BaseSlots::MULTIPLE_ALIGNMENT_SLOT().getId()) {
+        return BaseTypes::MULTIPLE_ALIGNMENT_TYPE();
+    }
+    if(dtId == BaseSlots::TEXT_SLOT().getId()) {
+        return BaseTypes::STRING_TYPE();
+    }
+    assert(false);
+    return DataTypePtr();
+}
+
 void CreateScriptElementDialog::fillFields(ActorPrototype *proto) {
     proto->getPortDesciptors();
     int inputInd = 0;
@@ -370,7 +412,7 @@ void CreateScriptElementDialog::fillFields(ActorPrototype *proto) {
             inputList->model()->insertRows(0,desc->getType()->getAllDescriptors().size() - 1, QModelIndex());
             foreach(const Descriptor &d, desc->getType()->getAllDescriptors()) {
                 QModelIndex mi = inputList->model()->index(inputInd,0);
-                inputList->model()->setData(mi,d.getId());
+                inputList->model()->setData(mi,getDatatypeOfSlotDesc(d)->getId());
                 inputInd++;
             }
             
@@ -378,7 +420,7 @@ void CreateScriptElementDialog::fillFields(ActorPrototype *proto) {
             outputList->model()->insertRows(0,desc->getType()->getAllDescriptors().size() - 1, QModelIndex());
             foreach(const Descriptor &d, desc->getType()->getAllDescriptors()) {
                 QModelIndex mi = outputList->model()->index(outputInd,0);
-                outputList->model()->setData(mi,d.getId());
+                outputList->model()->setData(mi,getDatatypeOfSlotDesc(d)->getId());
                 outputInd++;
             }
         }
@@ -495,7 +537,7 @@ void CreateScriptElementDialog::sl_okClicked() {
 
         DataTypePtr ptr = dtr->getById(item->getDataType());
         Descriptor desc(itemName, itemName, ptr->getDisplayName());      
-        if(ptr == CoreDataTypes::BOOL_TYPE()) {
+        if(ptr == BaseTypes::BOOL_TYPE()) {
             attrs << new Attribute(desc, ptr, false, QVariant(false));
         }
         else {
