@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <U2Core/Log.h>
 #include <U2Lang/WorkflowUtils.h>
@@ -15,6 +26,8 @@
 #include "ItemViewStyle.h"
 #include "HRSceneSerializer.h"
 
+#include <QtCore/QTextStream>
+
 namespace U2 {
 
 static const QString DESCRIPTION_ATTR   = "description";
@@ -135,6 +148,10 @@ static QString metaData(WorkflowScene * scene, const HRSchemaSerializer::NamesMa
         res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::ALIASES_START, HRSchemaSerializer::NO_NAME, 
                                              HRSchemaSerializer::schemaAliases(schema.getProcesses(), nmap), 2);
     }
+    if(schema.hasAliasHelp()) {
+        res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::ALIASES_HELP_START, HRSchemaSerializer::NO_NAME, 
+                                             HRSchemaSerializer::aliasesHelp(schema.getProcesses()), 2);
+    }
     res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::VISUAL_START, HRSchemaSerializer::NO_NAME, visualData(scene->items(), nmap), 2);
     return res;
 }
@@ -171,6 +188,16 @@ static QString itemsMeta(const QList<Actor*> & procs, const QList<QGraphicsItem*
         res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::ALIASES_START, HRSchemaSerializer::NO_NAME,
                                                 HRSchemaSerializer::schemaAliases(procs, nmap), 2);
     }
+    bool hasAliasHelp = false;
+    foreach(Actor * a, procs) {
+        if(a->hasAliasHelp()) {
+            hasAliasHelp = true; break;
+        }
+    }
+    if(hasAliasHelp) {
+        res += HRSchemaSerializer::makeBlock(HRSchemaSerializer::ALIASES_HELP_START, HRSchemaSerializer::NO_NAME, 
+                                             HRSchemaSerializer::aliasesHelp(procs), 2);
+    }
     return res + HRSchemaSerializer::makeBlock(HRSchemaSerializer::VISUAL_START, HRSchemaSerializer::NO_NAME, visualData(items, nmap));
 }
 
@@ -431,8 +458,11 @@ static void parseMeta(WorkflowSceneReaderData & data) {
             data.tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
             parseVisual(data);
             data.tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
-        }
-        else {
+        } else if(tok == HRSchemaSerializer::ALIASES_HELP_START) {
+            data.tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
+            HRSchemaSerializer::parseAliasesHelp(data.tokenizer, data.actorMap.values());
+            data.tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
+        } else {
             throw HRSchemaSerializer::ReadFailed(HRSchemaSerializer::UNDEFINED_META_BLOCK.arg(tok));
         }
     }
@@ -447,11 +477,15 @@ static void parseBodyItself(WorkflowSceneReaderData & data) {
             tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
             parseMeta(data);
             tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
-        } else if(tok == HRSchemaSerializer::ITERATION_START) {
+        } else if(tok == HRSchemaSerializer::DOT_ITERATION_START) {
             QString itName = tokenizer.look() == HRSchemaSerializer::BLOCK_START ? "" : tokenizer.take();
             tokenizer.assertToken(HRSchemaSerializer::BLOCK_START);
             data.iterations << HRSchemaSerializer::parseIteration(tokenizer, itName, data.actorMap, data.pasteMode);
             tokenizer.assertToken(HRSchemaSerializer::BLOCK_END);
+        } else if (tok == HRSchemaSerializer::ACTOR_BINDINGS) {
+            HRSchemaSerializer::backwardIncapability();
+        } else if (tok == HRSchemaSerializer::FUNCTION_START) {
+            HRSchemaSerializer::backwardIncapability();
         } else if(nextTok == HRSchemaSerializer::DATAFLOW_SIGN) {
             data.dataflowLinks << HRSchemaSerializer::parseDataflow(tokenizer, tok, data.actorMap);
         } else if(nextTok == HRSchemaSerializer::BLOCK_START) {
