@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <qmath.h>
 #include <QtGui/QBitmap>
@@ -40,7 +51,8 @@ const StyleId ItemStyles::EXTENDED = "ext";
 #define BGC QString("-bgc")
 #define FONT QString("-font")
 
-ItemViewStyle::ItemViewStyle(const QString& id) : active(false), defFont(WorkflowSettings::defaultFont()), id(id) {
+ItemViewStyle::ItemViewStyle(WorkflowProcessItem* p, const QString& id) : QGraphicsObject(p), defFont(WorkflowSettings::defaultFont()), id(id) {
+    setVisible(false);
     bgColorAction = new QAction(tr("Background color"), this);
     connect(bgColorAction, SIGNAL(triggered()), SLOT(selectBGColor()));
 
@@ -90,7 +102,7 @@ void ItemViewStyle::loadState(QDomElement& el) {
     }
 }
 
-SimpleProcStyle::SimpleProcStyle(WorkflowProcessItem* pit) : ItemViewStyle(ItemStyles::SIMPLE) {
+SimpleProcStyle::SimpleProcStyle(WorkflowProcessItem* pit) : ItemViewStyle(pit, ItemStyles::SIMPLE) {
     owner = (pit);
     owner->connect(owner->getProcess(), SIGNAL(si_labelChanged()), SLOT(sl_update()));
     bgColor = defaultColor();
@@ -154,7 +166,7 @@ void SimpleProcStyle::paint(QPainter *painter,
 
 #define MARGIN 5
 
-ExtendedProcStyle::ExtendedProcStyle(WorkflowProcessItem* pit) : ItemViewStyle(ItemStyles::EXTENDED),
+ExtendedProcStyle::ExtendedProcStyle(WorkflowProcessItem* pit) : ItemViewStyle(pit, ItemStyles::EXTENDED),
 autoResize(true), resizing(NoResize) {
     owner = (pit);
     Actor* process = pit->getProcess();
@@ -168,6 +180,7 @@ autoResize(true), resizing(NoResize) {
             .arg(process->getLabel()).arg(process->getProto()->getDocumentation()));
     }
     owner->connect(fontAction, SIGNAL(triggered()), SLOT(sl_update()));
+    desc = new DescriptionItem(this);
     refresh();
 
     resizeModeAction = new QAction(tr("Auto-resize to text"), this);
@@ -176,7 +189,6 @@ autoResize(true), resizing(NoResize) {
     connect(resizeModeAction, SIGNAL(toggled(bool)), SLOT(setAutoResizeEnabled(bool)));
 
     bgColor = defaultColor();
-    snap2GridFlag = WorkflowSettings::snap2Grid();
 }
 
 QColor ExtendedProcStyle::defaultColor() const {
@@ -221,6 +233,7 @@ void ExtendedProcStyle::refresh() {
     } else {
         //bounds.setSize(bounds.size().expandedTo(doc->size() + QSizeF(MARGIN*2,MARGIN*2)));
     }
+    desc->setDocument(doc);
 }
 
 QPainterPath ExtendedProcStyle::shape () const {
@@ -240,12 +253,6 @@ void ExtendedProcStyle::paint(QPainter *painter,
     bgColor.setAlpha(64);
     QRectF tb = boundingRect();
     painter->fillRect(tb, QBrush(bgColor));
-
-    painter->save();
-    painter->translate(-R + MARGIN, -R + MARGIN);
-    doc->drawContents(painter, QRectF(QPointF(),bounds.size() - QSizeF(MARGIN*2,MARGIN*2)));
-    painter->restore();
-
     
     painter->setRenderHint(QPainter::Antialiasing);
 
@@ -289,61 +296,20 @@ bool ExtendedProcStyle::sceneEventFilter( QGraphicsItem * watched, QEvent * even
     case QEvent::GraphicsSceneHoverEnter:
     case QEvent::GraphicsSceneHoverMove:
         {
-            snap2GridFlag = WorkflowSettings::snap2Grid();
-            resizing = NoResize;
-            QGraphicsSceneHoverEvent* he = (static_cast<QGraphicsSceneHoverEvent *>(event));
-            QPointF p = he->pos();
-            qreal dx = qAbs(bounds.right() - p.x());
-            qreal dy = qAbs(bounds.bottom() - p.y());
-            if (dx < RESIZE_AREA) {
-                resizing |= RightResize;
-            }
-            if(dx > (bounds.width() - RESIZE_AREA)) {
-                resizing |= LeftResize;
-            }
-            if (dy < RESIZE_AREA) {
-                resizing |= BottomResize;
-            }
-            if(dy > (bounds.height() - RESIZE_AREA)) {
-                resizing |= TopResize;
-            }
-
-            switch (resizing)
-            {
-            case NoResize:
-                owner->unsetCursor();
-                break;
-            case RightResize:
-            case LeftResize:
-                owner->setCursor(Qt::SizeHorCursor);
-                break;
-            case BottomResize:
-            case TopResize:
-                owner->setCursor(Qt::SizeVerCursor);
-                break;
-            case RBResize:
-            case LTResize:
-                owner->setCursor(Qt::SizeFDiagCursor);
-                break;
-            case LBResize:
-            case RTResize:
-                owner->setCursor(Qt::SizeBDiagCursor);
-                break;
-            }
-            ret = (resizing != NoResize);
+            QGraphicsSceneHoverEvent* he = static_cast<QGraphicsSceneHoverEvent*>(event);
+            ret = updateCursor(he->pos());
         }
         break;
-    case QEvent::GraphicsSceneHoverLeave:
     case QEvent::GraphicsSceneMouseRelease:
-        if (resizing) 
-        {
+        desc->mouseReleaseEvent(event);
+    case QEvent::GraphicsSceneHoverLeave:
+        if (resizing) {
             owner->unsetCursor();
-            WorkflowSettings::setSnap2Grid(snap2GridFlag);
         }
         resizing = NoResize;
         break;
     case QEvent::GraphicsSceneMouseMove:
-        if (resizing) {
+        if (resizing && event->spontaneous()) {
             QGraphicsSceneMouseEvent* me = (static_cast<QGraphicsSceneMouseEvent *>(event));
             WorkflowSettings::setSnap2Grid(false);
             QPointF newPos;
@@ -397,7 +363,9 @@ bool ExtendedProcStyle::sceneEventFilter( QGraphicsItem * watched, QEvent * even
                     newPos.setY(newPos.y() - (b2.height() - bounds.height()));
 
                     qreal minHeight = R + MARGIN*2;
-                    if (b2.height() < minHeight) {
+
+                    WorkflowScene * sc = qobject_cast<WorkflowScene*>(owner->scene());
+                    if (b2.height() < minHeight || newPos.y() < sc->sceneRect().top()) {
                         return true;
                     }
 
@@ -452,6 +420,50 @@ bool ExtendedProcStyle::sceneEventFilter( QGraphicsItem * watched, QEvent * even
     return ret;
 }
 
+bool ExtendedProcStyle::updateCursor(const QPointF& p) {
+    bool ret = false;
+    resizing = NoResize;
+    qreal dx = qAbs(bounds.right() - p.x());
+    qreal dy = qAbs(bounds.bottom() - p.y());
+    if (dx < RESIZE_AREA) {
+        resizing |= RightResize;
+    }
+    if(dx > (bounds.width() - RESIZE_AREA)) {
+        resizing |= LeftResize;
+    }
+    if (dy < RESIZE_AREA) {
+        resizing |= BottomResize;
+    }
+    if(dy > (bounds.height() - RESIZE_AREA)) {
+        resizing |= TopResize;
+    }
+
+    switch (resizing)
+    {
+    case NoResize:
+        owner->unsetCursor();
+        break;
+    case RightResize:
+    case LeftResize:
+        owner->setCursor(Qt::SizeHorCursor);
+        break;
+    case BottomResize:
+    case TopResize:
+        owner->setCursor(Qt::SizeVerCursor);
+        break;
+    case RBResize:
+    case LTResize:
+        owner->setCursor(Qt::SizeFDiagCursor);
+        break;
+    case LBResize:
+    case RTResize:
+        owner->setCursor(Qt::SizeBDiagCursor);
+        break;
+    }
+    ret = (resizing != NoResize);
+    return ret;
+}
+
 void ExtendedProcStyle::setFixedBounds( const QRectF& b)
 {
     doc->setPageSize(b.size() - QSizeF(MARGIN*2,MARGIN*2));
@@ -467,11 +479,6 @@ void ExtendedProcStyle::setFixedBounds( const QRectF& b)
     resizeModeAction->setChecked(false);
 }
 
-void ExtendedProcStyle::setActive( bool v )
-{
-    /*autoResize =*/ active = v;
-}
-
 void ExtendedProcStyle::setAutoResizeEnabled(bool b) {
     autoResize = b;
     if (autoResize) {
@@ -508,11 +515,20 @@ void ExtendedProcStyle::loadState(QDomElement& el) {
     ItemViewStyle::loadState(el);
 }
 
+void ExtendedProcStyle::linkHovered(const QString& url) {
+    if (url.isEmpty()) {
+        owner->unsetCursor();
+    } else {
+        owner->setCursor(Qt::PointingHandCursor);
+    }
+}
 
-HintItem::HintItem( const QString & text, QGraphicsItem * parent) : QGraphicsTextItem(text, parent) 
-{
-    setFlag(QGraphicsItem::ItemIsMovable);
+HintItem::HintItem( const QString & text, QGraphicsItem * parent)
+: QGraphicsTextItem(text, parent), dragging(false) {
     setFlag(QGraphicsItem::ItemIsSelectable);
+#if (QT_VERSION >= QT_VERSION_CHECK(4, 6, 0))
+    setFlag(QGraphicsItem::ItemSendsGeometryChanges, true);
+#endif
     document()->setDefaultTextOption(QTextOption(Qt::AlignCenter));
     setTextWidth(qMin(3*R, document()->idealWidth()));
     QRectF tb = boundingRect();
@@ -529,10 +545,97 @@ QVariant HintItem::itemChange( GraphicsItemChange change, const QVariant & value
         parentItem()->setSelected(true);
         return false;
     }
+    if (change == ItemPositionChange) {
+        QPointF newPos = value.toPointF();
+        if (scene()) {
+            QRectF bound = boundingRect();
+            QRectF sceneRect = scene()->sceneRect();
+            // scene topLeft in parent coords
+            QPointF tl = mapToParent(mapFromScene(sceneRect.topLeft()));
+            sceneRect.moveTopLeft(tl);
+
+            qreal x0 = sceneRect.left() - bound.left();
+            qreal x1 = sceneRect.left() + sceneRect.width() - bound.right();
+            qreal y0 = sceneRect.top() - bound.top();
+            qreal y1 = sceneRect.top() + sceneRect.height() - bound.bottom();
+
+            newPos.setX( qBound(x0, newPos.x(), x1) );
+            newPos.setY( qBound(y0, newPos.y(), y1) );
+        }
+        return newPos;
+    }
     if (change == ItemPositionHasChanged) {
         parentItem()->update();
+        if (scene()) {
+            foreach(QGraphicsView* v, scene()->views()) {
+                v->ensureVisible(this, 0, 0);
+            }
+        }
     }
     return QGraphicsItem::itemChange(change, value);
 }
 
+void HintItem::mouseMoveEvent(QGraphicsSceneMouseEvent *event) {
+    if (event->buttons() & Qt::LeftButton) {
+        if (!dragging) {
+            initPos = pos();
+            dragging = true;
+        }
+        
+        QPointF delta = event->screenPos() - event->buttonDownScreenPos(Qt::LeftButton);
+        setPos(initPos + delta);
+    } else {
+        event->ignore();
+    }
+}
+
+void HintItem::mouseReleaseEvent( QGraphicsSceneMouseEvent *event ) {
+    dragging = false;
+    QGraphicsTextItem::mouseReleaseEvent(event);
+}
+
+DescriptionItem::DescriptionItem(ExtendedProcStyle* p) : QGraphicsTextItem(p) {
+    setPos(-R + MARGIN, -R + MARGIN);
+    setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::LinksAccessibleByKeyboard);
+    p->connect(this, SIGNAL(linkActivated(const QString&)), SIGNAL(linkActivated(const QString&)));
+    p->connect(this, SIGNAL(linkHovered(const QString&)), SLOT(linkHovered(const QString&)));
+}
+
+QRectF DescriptionItem::boundingRect() const {
+    QRectF bounds = parentItem()->boundingRect();
+    bounds.translate(R - MARGIN, R - MARGIN);
+    return bounds;
+}
+
+void DescriptionItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) {
+    QStyleOptionGraphicsItem deselectedOption = *option;
+    deselectedOption.state &= ~(QStyle::State_Selected | QStyle::State_HasFocus);
+    QGraphicsTextItem::paint(painter, &deselectedOption, widget);
+}
+
+void DescriptionItem::mouseReleaseEvent(QEvent *event) {
+    QGraphicsSceneMouseEvent* e = static_cast<QGraphicsSceneMouseEvent*>(event);
+    e->setPos(mapFromParent(e->pos()));
+    QGraphicsTextItem::mouseReleaseEvent(e);
+}
+
+bool DescriptionItem::sceneEvent(QEvent *event) {
+    switch (event->type()) {
+        case QEvent::GraphicsSceneHoverMove:
+        case QEvent::GraphicsSceneHoverEnter:
+            {
+                ExtendedProcStyle* owner = qgraphicsitem_cast<ExtendedProcStyle*>(parentItem());
+                if (owner->resizing) {
+                    QGraphicsSceneHoverEvent* he = static_cast<QGraphicsSceneHoverEvent*>(event);
+                    const QPointF& p = mapToParent(he->pos());
+                    owner->updateCursor(p);
+                }
+            }
+            break;
+        default:
+            break;
+    }
+    return QGraphicsTextItem::sceneEvent(event);
+}
+
 }//namespace
