@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "WorkflowEditor.h"
 #include "WorkflowViewController.h"
@@ -386,7 +397,6 @@ void WorkflowEditor::editPort(Port* p) {
         BusPortEditor* ed = new BusPortEditor(qobject_cast<IntegralBusPort*>(p));
         ed->setParent(p);
         p->setEditor(ed);
-        QWidget *w = ed->getWidget();
         paramHeight = ed->getOptimalHeight();
 
         edit(p);
@@ -446,16 +456,16 @@ void WorkflowEditor::edit(Configuration* cfg) {
         connect(paramBox, SIGNAL(toggled(bool)), SLOT(sl_resizeSplitter(bool)));
     }
     
-    int h = 0;
+    //int h = 0;
     if (subject && !customWidget) {
         assert(actor);
         actorModel->setActor(actor);
         updateIterationData();
         tableSplitter->setVisible(paramBox->isChecked());
-        if(paramBox->isChecked()) {
+        /*if(paramBox->isChecked()) {
             h = table->sizeHint().height();
             
-        }
+        }*/
         connect(paramBox, SIGNAL(toggled(bool)), tableSplitter, SLOT(setVisible(bool)));
         connect(paramBox, SIGNAL(toggled(bool)), SLOT(sl_resizeSplitter(bool)));
     } else {
@@ -464,9 +474,9 @@ void WorkflowEditor::edit(Configuration* cfg) {
             if (actor) assert(0 && "No support for iterations yet");
             paramBox->layout()->addWidget(customWidget);
             customWidget->setVisible(paramBox->isChecked());
-            if(paramBox->isChecked()) {
+            /*if(paramBox->isChecked()) {
                 h = customWidget->minimumSizeHint().height();
-            }
+            }*/
         }
     }
 }
@@ -497,4 +507,23 @@ bool WorkflowEditor::eventFilter(QObject* object, QEvent* event) {
     return false;
 }
 
+static const QString& PARAM_ARG("param:");
+
+void WorkflowEditor::sl_linkActivated(const QString& url) {
+    QStringList args = url.split('&');
+    QString id;
+    foreach(QString arg, args) {
+        if (arg.startsWith(PARAM_ARG)) {
+            id = arg.mid(PARAM_ARG.length());
+        }
+    }
+    
+    QModelIndex modelIndex = actorModel->modelIndexById(id);
+    QModelIndex prev = table->selectionModel()->currentIndex();
+    if (modelIndex==prev) {
+        table->selectionModel()->reset();
+    }
+    table->setCurrentIndex(modelIndex);
+}
+
 }//namespace
