@@ -1,20 +1,33 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "WorkflowPalette.h"
 
 #include "CreateScriptWorker.h"
 #include "library/ScriptWorker.h"
+#include "library/ExternalProcessWorker.h"
+#include "library/CreateExternalProcessDialog.h"
 
 #include <U2Lang/ActorPrototypeRegistry.h>
-#include <U2Lang/BioActorLibrary.h>
+#include <U2Lang/BaseActorCategories.h>
 #include <U2Lang/WorkflowEnv.h>
 
 #include <U2Lang/WorkflowSettings.h>
@@ -38,6 +51,7 @@
 #include <QtGui/QItemDelegate>
 #include <QtGui/QTreeView>
 #include <QtGui/QContextMenuEvent>
+#include <QtGui/QMessageBox>
 
 #include <QtCore/QDir>
 
@@ -177,7 +191,7 @@ void WorkflowPalette::setContent(ActorPrototypeRegistry* reg) {
 void WorkflowPalette::sortTree() {
     sortItems(0,Qt::AscendingOrder);
 
-    QString text = BioActorLibrary::CATEGORY_DATASRC().getDisplayName();
+    QString text = BaseActorCategories::CATEGORY_DATASRC().getDisplayName();
     QTreeWidgetItem *item;
     if(!findItems(text,Qt::MatchExactly).isEmpty()) {
         item = findItems(text,Qt::MatchExactly).first();
@@ -185,14 +199,14 @@ void WorkflowPalette::sortTree() {
         insertTopLevelItem(0,item);
     }
 
-    text = BioActorLibrary::CATEGORY_DATASINK().getDisplayName();
+    text = BaseActorCategories::CATEGORY_DATASINK().getDisplayName();
     if(!findItems(text,Qt::MatchExactly).isEmpty()) {
         item = findItems(text,Qt::MatchExactly).first();
         takeTopLevelItem(indexFromItem(item).row());
         insertTopLevelItem(1,item);
     }
 
-    text = BioActorLibrary::CATEGORY_SCRIPT().getDisplayName();
+    text = BaseActorCategories::CATEGORY_SCRIPT().getDisplayName();
     if(!findItems(text,Qt::MatchExactly).isEmpty()) {
         item = findItems(text,Qt::MatchExactly).first();
         if(item) {
@@ -200,11 +214,22 @@ void WorkflowPalette::sortTree() {
             addTopLevelItem(item);
         }
     }
-} 
+
+    text = BaseActorCategories::CATEGORY_EXTERNAL().getDisplayName();
+    if (!findItems(text, Qt::MatchExactly).isEmpty())
+    {
+        item = findItems(text, Qt::MatchExactly).first();
+        if (item)
+        {
+            takeTopLevelItem(indexFromItem(item).row());
+            addTopLevelItem(item);
+        }
+    }
+}
 
 QMenu* WorkflowPalette::createMenu(const QString& name) {
     QMenu* itemsMenu = new QMenu(name, this);
-    QMenu *dataSink = NULL, *dataSource = NULL, *userScript = NULL;
+    QMenu *dataSink = NULL, *dataSource = NULL, *userScript = NULL, *externalTools = NULL;
     QAction *firstAction = NULL;
     QMapIterator<QString, QList<QAction*> > it(categoryMap);
     while (it.hasNext()) {
@@ -219,12 +244,14 @@ QMenu* WorkflowPalette::createMenu(const QString& name) {
             jt.next();
             grpMenu->addAction(jt.value());
         }
-        if(it.key() == BioActorLibrary::CATEGORY_DATASRC().getDisplayName()) {
+        if(it.key() == BaseActorCategories::CATEGORY_DATASRC().getDisplayName()) {
             dataSource = grpMenu;
-        }else if(it.key() == BioActorLibrary::CATEGORY_DATASINK().getDisplayName()) {
+        }else if (it.key() == BaseActorCategories::CATEGORY_DATASINK().getDisplayName()) {
             dataSink = grpMenu;
-        } else if(it.key() == BioActorLibrary::CATEGORY_SCRIPT().getDisplayName()) {
+        } else if (it.key() == BaseActorCategories::CATEGORY_SCRIPT().getDisplayName()) {
             userScript = grpMenu;
+        } else if (it.key() == BaseActorCategories::CATEGORY_EXTERNAL().getDisplayName()) {
+            externalTools = grpMenu;
         } else {
             QAction * a = itemsMenu->addMenu(grpMenu);
             firstAction = firstAction ? firstAction : a;
@@ -233,9 +260,12 @@ QMenu* WorkflowPalette::createMenu(const QString& name) {
 
     itemsMenu->insertMenu(firstAction, dataSource);
     itemsMenu->insertMenu(firstAction, dataSink);
-    if(userScript) {
+    if (userScript) {
         itemsMenu->addMenu(userScript);
     }
+    if (externalTools) {
+        itemsMenu->addMenu(externalTools);
+    }
 
     return itemsMenu;
 }
@@ -312,7 +342,8 @@ void WorkflowPalette::contextMenuEvent(QContextMenuEvent *e)
     QMenu menu;
     menu.addAction(tr("Expand all"), this, SLOT(expandAll()));
     menu.addAction(tr("Collapse all"), this, SLOT(collapseAll()));
-    if(itemAt(e->pos()) && itemAt(e->pos())->parent() && itemAt(e->pos())->parent()->text(0) == BioActorLibrary::CATEGORY_SCRIPT().getDisplayName()) {
+    if(itemAt(e->pos()) && itemAt(e->pos())->parent() && (itemAt(e->pos())->parent()->text(0) == BaseActorCategories::CATEGORY_SCRIPT().getDisplayName() 
+        || itemAt(e->pos())->parent()->text(0) == BaseActorCategories::CATEGORY_EXTERNAL().getDisplayName())) {
         menu.addAction(tr("Edit"), this, SLOT(editElement()));
         menu.addAction(tr("Remove"), this, SLOT(removeElement()));
         currentAction = actionMap.key(itemAt(e->pos()));
@@ -322,11 +353,23 @@ void WorkflowPalette::contextMenuEvent(QContextMenuEvent *e)
 }
 
 void WorkflowPalette::removeElement() {
+    QMessageBox msg(this);
+    msg.setWindowTitle("Remove element");
+    msg.setText("Remove this element?");
+    msg.addButton(QMessageBox::Ok);
+    msg.addButton(QMessageBox::Cancel);
+    if(msg.exec() == QMessageBox::Cancel) {
+        return;
+    }
+
     ActorPrototype *proto = currentAction->data().value<ActorPrototype *>();
 
     QString path = WorkflowSettings::getUserDirectory();
 
     QString fileName = path + proto->getDisplayName() + ".usa"; //use constant
+    if(!QFile::exists(fileName)) {
+        fileName = WorkflowSettings::getExternalToolDirectory() + proto->getDisplayName() + ".etc";
+    }
     QFile::setPermissions(fileName, QFile::ReadOwner | QFile::WriteOwner);
     if(!QFile::remove(fileName)) {
         uiLog.error(tr("Can't remove element %1").arg(proto->getDisplayName()));
@@ -343,24 +386,47 @@ void WorkflowPalette::removeElement() {
 void WorkflowPalette::editElement() {
     ActorPrototype *proto = currentAction->data().value<ActorPrototype *>();
     QString oldName = proto->getDisplayName();
+    ActorPrototypeRegistry *reg = WorkflowEnv::getProtoRegistry();
+    QMap<Descriptor, QList<ActorPrototype*> > categories = reg->getProtos();
 
-    CreateScriptElementDialog dlg(this, proto);
-    if(dlg.exec() == QDialog::Accepted) {
-        ActorPrototypeRegistry *reg = WorkflowEnv::getProtoRegistry();
-        assert(reg);
+    if(categories.value(BaseActorCategories::CATEGORY_SCRIPT()).contains(proto)) {
+        CreateScriptElementDialog dlg(this, proto);
+        if(dlg.exec() == QDialog::Accepted) {
+            ActorPrototypeRegistry *reg = WorkflowEnv::getProtoRegistry();
+            assert(reg);
 
-        QList<DataTypePtr > input = dlg.getInput();
-        QList<DataTypePtr > output = dlg.getOutput();
-        QList<Attribute*> attrs = dlg.getAttributes();
-        QString name = dlg.getName();
-        QString desc = dlg.getDescription();
+            QList<DataTypePtr > input = dlg.getInput();
+            QList<DataTypePtr > output = dlg.getOutput();
+            QList<Attribute*> attrs = dlg.getAttributes();
+            QString name = dlg.getName();
+            QString desc = dlg.getDescription();
 
-        if(oldName != name) {
-            removeElement();
-        } else {
-            reg->unregisterProto(proto->getId());
+            if(oldName != name) {
+                removeElement();
+            } else {
+                QString id = proto->getId();
+                emit si_protoDeleted(id);
+                reg->unregisterProto(proto->getId());
+            }
+            LocalWorkflow::ScriptWorkerFactory::init(input, output, attrs, name,desc);
+        }
+    } else { //External process category
+        ExternalProcessConfig *cfg = WorkflowEnv::getExternalCfgRegistry()->getConfigByName(proto->getId());
+        CreateExternalProcessDialog dlg(this, cfg);
+        if(dlg.exec() == QDialog::Accepted) {
+            cfg = dlg.config();
+
+            WorkflowEnv::getExternalCfgRegistry()->unregisterConfig(oldName);
+            WorkflowEnv::getExternalCfgRegistry()->registerExternalTool(cfg);
+            if(oldName != cfg->name) {
+                removeElement();
+            } else {
+                QString id = proto->getId();
+                emit si_protoDeleted(id);
+                reg->unregisterProto(proto->getId());
+            }
+            LocalWorkflow::ExternalProcessWorkerFactory::init(cfg);
         }
-        LocalWorkflow::ScriptWorkerFactory::init(input, output, attrs, name,desc);
     }
 }
 
