@@ -1,18 +1,31 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "WorkflowSettingsController.h"
 #include "WorkflowViewController.h"
 #include "WorkflowViewItems.h"
 
 #include <U2Lang/WorkflowSettings.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/Version.h>
 
 #include <QtGui/QMouseEvent>
 #include <QtGui/QFileDialog>
@@ -34,6 +47,8 @@ AppSettingsGUIPageState* WorkflowSettingsPageController::getSavedState() {
     state->font = WorkflowSettings::defaultFont();
     state->path = WorkflowSettings::getUserDirectory();
     state->color = WorkflowSettings::getBGColor();
+    state->runSchemaInSeparateProcess = WorkflowSettings::runInSeparateProcess();
+    state->externalToolCfgDir = WorkflowSettings::getExternalToolDirectory();
     return state;
 }
 
@@ -47,6 +62,8 @@ void WorkflowSettingsPageController::saveState(AppSettingsGUIPageState* s) {
     WorkflowSettings::setDefaultFont(state->font);
     WorkflowSettings::setUserDirectory(state->path);
     WorkflowSettings::setBGColor(state->color);
+    WorkflowSettings::setRunInSeparateProcess(state->runSchemaInSeparateProcess);
+    WorkflowSettings::setExternalToolDirectory(state->externalToolCfgDir);
 }
 
 AppSettingsGUIPageWidget* WorkflowSettingsPageController::createWidget(AppSettingsGUIPageState* state) {
@@ -60,8 +77,14 @@ WorkflowSettingsPageWidget::WorkflowSettingsPageWidget(WorkflowSettingsPageContr
     styleCombo->addItem(U2::WorkflowView::tr("Minimal"), ItemStyles::SIMPLE);
     styleCombo->addItem(U2::WorkflowView::tr("Extended"), ItemStyles::EXTENDED);
     connect(dirButton, SIGNAL(clicked()), SLOT(sl_getDirectory()));
-    connect(colorWidget, SIGNAL(clicked()), SLOT(sl_getColor()));
+    connect(extToolDirButton, SIGNAL(clicked()), SLOT(sl_getExternalToolCfgDir()));
+    colorWidget->setMinimumHeight(label->height());
     colorWidget->installEventFilter(this);
+#ifdef RUN_WORKFLOW_IN_THREADS
+    runInSeparateProcessBox->setVisible(false);
+#else
+    runInSeparateProcessBox->setVisible(Version::ugeneVersion().isDevVersion);
+#endif // RUN_WORKFLOW_IN_THREADS
 }
 
 void WorkflowSettingsPageWidget::sl_getDirectory() {
@@ -79,9 +102,11 @@ void WorkflowSettingsPageWidget::sl_getDirectory() {
 
 void WorkflowSettingsPageWidget::sl_getColor() {
     QColor newColor = QColorDialog::getColor(colorWidget->palette().color(colorWidget->backgroundRole()), this);
-    QPalette pal = colorWidget->palette();
-    pal.setColor(colorWidget->backgroundRole() , newColor);
-    colorWidget->setPalette(pal);
+    if(newColor.isValid()) {
+        QPalette pal = colorWidget->palette();
+        pal.setColor(colorWidget->backgroundRole() , newColor);
+        colorWidget->setPalette(pal);
+    }
 }
 
 bool WorkflowSettingsPageWidget::eventFilter(QObject *, QEvent * event)
@@ -110,6 +135,8 @@ void WorkflowSettingsPageWidget::setState(AppSettingsGUIPageState* s) {
     QPalette pal = colorWidget->palette();
     pal.setColor(colorWidget->backgroundRole(), state->color);
     colorWidget->setPalette(pal);
+    runInSeparateProcessBox->setChecked(state->runSchemaInSeparateProcess);
+    extToolDirEdit->setText(state->externalToolCfgDir);
 }
 
 AppSettingsGUIPageState* WorkflowSettingsPageWidget::getState(QString& ) const {
@@ -122,8 +149,22 @@ AppSettingsGUIPageState* WorkflowSettingsPageWidget::getState(QString& ) const {
     state->font = fontCombo->currentFont();
     state->path = dirEdit->text();
     state->color = colorWidget->palette().color(colorWidget->backgroundRole());
-
+    state->runSchemaInSeparateProcess = runInSeparateProcessBox->isChecked();
+    state->externalToolCfgDir = extToolDirEdit->text();
     return state;
 }
 
+void WorkflowSettingsPageWidget::sl_getExternalToolCfgDir() {
+    QString url = WorkflowSettings::getExternalToolDirectory();
+
+    QFileDialog dialog(this);
+    dialog.setFileMode(QFileDialog::Directory);
+    dialog.setViewMode(QFileDialog::List);
+    dialog.setDirectory(url);
+    if(dialog.exec() == QDialog::Accepted) {
+        QString dir = dialog.selectedFiles().first();
+        extToolDirEdit->setText(dir + "/");
+    }
+}
+
 } //namespace
