@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 
 #include <algorithm>
@@ -34,6 +45,7 @@
 
 #include <U2Core/AppContext.h>
 #include <U2Gui/MainWindow.h>
+#include <U2Gui/ExportImageDialog.h>
 #include <U2Core/Log.h>
 #include <U2Core/Settings.h>
 #include <U2Core/DocumentModel.h>
@@ -45,9 +57,11 @@
 #include <U2Lang/MapDatatypeEditor.h>
 #include <U2Lang/WorkflowUtils.h>
 #include <U2Lang/WorkflowRunTask.h>
+#include <U2Lang/BaseAttributes.h>
+#include <U2Lang/ExternalToolCfg.h>
+#include <U2Lang/HRSchemaSerializer.h>
 #include <U2Remote/RemoteWorkflowRunTask.h>
 #include <U2Lang/WorkflowSettings.h>
-#include <U2Lang/CoreDataTypes.h>
 #include <U2Designer/DelegateEditors.h>
 #include <U2Lang/CoreLibConstants.h>
 #include <U2Misc/GlassView.h>
@@ -57,6 +71,7 @@
 #include <U2Core/TaskSignalMapper.h>
 #include <U2Designer/DesignerUtils.h>
 #include <U2Core/ProjectService.h>
+#include <U2Core/IOAdapter.h>
 
 #include "WorkflowDesignerPlugin.h"
 #include "WorkflowViewItems.h"
@@ -75,6 +90,9 @@
 #include "SceneSerializer.h"
 #include "WorkflowViewItems.h"
 #include "WorkflowViewController.h"
+#include "library/CreateExternalProcessDialog.h"
+#include "library/ExternalProcessWorker.h"
+
 
 /* TRANSLATOR U2::LocalWorkflow::WorkflowView*/
 
@@ -89,6 +107,7 @@ namespace U2 {
 enum {ElementsTab,SamplesTab};
 
 #define WS 1000
+#define MAX_FILE_SIZE 1000000
 
 static QString percentStr = WorkflowView::tr("%");
 
@@ -105,6 +124,11 @@ public:
     }
 }; // PercentValidator
 
+static const QString XML_SCHEMA_WARNING = WorkflowView::tr("You opened obsolete schema in XML format. It is strongly recommended"
+                                                           " to clear working space and create schema from scratch.");
+
+static const QString XML_SCHEMA_APOLOGIZE = WorkflowView::tr("Sorry! This schema is obsolete and cannot be opened.");
+
 /********************************
 * WorkflowView
 ********************************/
@@ -165,6 +189,7 @@ scriptingMode(false) {
     //connect(scene, SIGNAL(selectionChanged()), propertyEditor, SLOT(clearContents()));
     //connect(scene, SIGNAL(selectionChanged()), propertyEditor, SLOT(hide()));
     connect(scene, SIGNAL(selectionChanged()), SLOT(sl_editItem()));
+    connect(scene, SIGNAL(selectionChanged()), SLOT(sl_onSelectionChanged()));
     splitter->addWidget(propertyEditor);
 
     Settings* settings = AppContext::getSettings();
@@ -204,17 +229,19 @@ scriptingMode(false) {
             xml.setContent(go->getSceneRawData().toUtf8());
             err = SceneSerializer::xml2scene(xml.documentElement(), scene, remapping);
             SchemaSerializer::readMeta(&meta, xml.documentElement());
-            QList<Iteration> lst;
-            SchemaSerializer::readIterations(lst, xml.documentElement(), remapping);
-            scene->setIterations(lst);
             scene->setModified(false);
+            if(err.isEmpty()) {
+                QMessageBox::warning(this, tr("Warning!"), XML_SCHEMA_WARNING);
+            } else {
+                QMessageBox::warning(this, tr("Warning!"), XML_SCHEMA_APOLOGIZE);
+            }
         } else {
             coreLog.error(tr("Undefined workflow format for %1").arg(go->getDocument() ? go->getDocument()->getURLString() : tr("file")));
             sl_newScene();
         }
         
         if (!err.isEmpty()) {
-            scene->sl_reset();
+            sl_newScene();
             coreLog.error(err);
         } else {
             if (go->getDocument()) {
@@ -252,6 +279,12 @@ void WorkflowView::sl_rescaleScene(const QString &scale)
     scene->views().at(0)->resetMatrix();
     scene->views().at(0)->translate(oldMatrix.dx(), oldMatrix.dy());
     scene->views().at(0)->scale(newScale, newScale);
+    QRectF rect = scene->sceneRect();
+    qreal w = rect.width()/newScale;
+    qreal h = rect.height()/newScale;
+    rect.setWidth(w);
+    rect.setHeight(h);
+    scene->setSceneRect(rect);
 }
 
 
@@ -285,6 +318,7 @@ void WorkflowView::createActions() {
     connect(saveAction, SIGNAL(triggered()), SLOT(sl_saveScene()));
     
     saveAsAction = new QAction(tr("&Save schema as..."), this);
+    saveAsAction->setIcon(QIcon(":workflow_designer/images/filesaveas.png"));
     connect(saveAsAction, SIGNAL(triggered()), SLOT(sl_saveSceneAs()));
 
 
@@ -303,15 +337,15 @@ void WorkflowView::createActions() {
     deleteAction->setShortcuts(QKeySequence::Delete);
     connect(deleteAction, SIGNAL(triggered()), scene, SLOT(sl_deleteItem()));
 
-    configureIterationsAction = new QAction(tr("Configure iterations"), this);
+    configureAliasesAction = new QAction(tr("Configure command line aliases..."), this);
+    configureAliasesAction->setIcon(QIcon(":workflow_designer/images/table_relationship.png"));
+    connect(configureAliasesAction, SIGNAL(triggered()), SLOT(sl_configureAliases()));
+
+    configureIterationsAction = new QAction(tr("Configure iterations..."), this);
     configureIterationsAction->setIcon(QIcon(":workflow_designer/images/tag.png"));
     //configureIterationsAction ->setShortcut(QKeySequence::Delete);
     connect(configureIterationsAction , SIGNAL(triggered()), SLOT(sl_configureIterations()));
     
-    configureAliasesAction = new QAction(tr("Configure command line aliases"), this);
-    configureAliasesAction->setIcon(QIcon(":workflow_designer/images/cmdline.png"));
-    connect(configureAliasesAction, SIGNAL(triggered()), SLOT(sl_configureAliases()));
-    
     selectAction = new QAction(tr("Select all elements"), this);
     selectAction->setShortcuts(QKeySequence::SelectAll);
     connect(selectAction, SIGNAL(triggered()), scene, SLOT(sl_selectAll()));
@@ -335,7 +369,7 @@ void WorkflowView::createActions() {
     sceneScaleCombo->setEditable(true);
     sceneScaleCombo->setValidator(new PercentValidator(this));
     QStringList scales;
-    scales << tr("25%") << tr("50%") << tr("75%") << tr("100%") << tr("125%") << tr("150%") << tr("200%");
+    scales << "25%" << "50%" << "75%" << "100%" << "125%" << "150%" << "200%";
     sceneScaleCombo->addItems(scales);
     sceneScaleCombo->setCurrentIndex(3);
     connect(sceneScaleCombo, SIGNAL(currentIndexChanged(const QString &)), SLOT(sl_rescaleScene(const QString &)));
@@ -373,13 +407,22 @@ void WorkflowView::createActions() {
     unlockAction->setChecked(true);
     connect(unlockAction, SIGNAL(toggled(bool)), SLOT(sl_toggleLock(bool)));
 
-    createScriptAcction = new QAction(tr("Create Script Object"), this);
+    createScriptAcction = new QAction(tr("Create element with script..."), this);
     createScriptAcction->setIcon(QIcon(":workflow_designer/images/script.png"));
     connect(createScriptAcction, SIGNAL(triggered()), SLOT(sl_createScript()));
 
-    editScriptAction = new QAction(tr("Edit script text"),this);
-    editScriptAction->setIcon(QIcon(":workflow_designer/images/edit_script.png"));
+    editScriptAction = new QAction(tr("Edit script of the element..."),this);
+    editScriptAction->setIcon(QIcon(":workflow_designer/images/script_edit.png"));
+    editScriptAction->setEnabled(false); // because user need to select actor with script to enable it
     connect(editScriptAction, SIGNAL(triggered()), SLOT(sl_editScript()));
+
+    externalToolAction = new QAction(tr("Create element with command line tool..."), this);
+    externalToolAction->setIcon(QIcon(":workflow_designer/images/external_cmd_tool.png"));
+    connect(externalToolAction, SIGNAL(triggered()), SLOT(sl_externalAction()));
+
+    appendExternalTool = new QAction(tr("Add element with command line tool..."), this);
+    appendExternalTool->setIcon(QIcon(":workflow_designer/images/external_cmd_tool_add.png"));
+    connect(appendExternalTool, SIGNAL(triggered()), SLOT(sl_appendExternalToolWorker()));
 }
 
 void WorkflowView::sl_createScript() {
@@ -395,13 +438,60 @@ void WorkflowView::sl_createScript() {
             QRectF rect = scene->sceneRect();
             scene->addProcess( scene->createActor( proto, QVariantMap()), rect.center());
         }
-        
+    }
+}
+
+void WorkflowView::sl_externalAction() {
+    CreateExternalProcessDialog dlg(this);
+    if(dlg.exec() == QDialog::Accepted) {
+        ExternalProcessConfig *cfg = dlg.config();
+        if(LocalWorkflow::ExternalProcessWorkerFactory::init(cfg)) {
+            ActorPrototype *proto = WorkflowEnv::getProtoRegistry()->getProto(cfg->name);
+            QRectF rect = scene->sceneRect();
+            scene->addProcess( scene->createActor( proto, QVariantMap()), rect.center());
+        }
+    }
+}
+
+void WorkflowView::sl_appendExternalToolWorker() {
+    QString filter = DialogUtils::prepareFileFilter(WorkflowUtils::tr("UGENE workflow element"), QStringList() << "etc", true);
+    QString url = QFileDialog::getOpenFileName(this, tr("Add element"), QString(), filter);
+    if (!url.isEmpty()) {
+        IOAdapter *io = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(GUrl(url)))->createIOAdapter();
+        if(!io->open(url, IOAdapterMode_Read)) {
+            coreLog.error(tr("Can't load element."));
+            return;
+        }
+        QByteArray data;
+        data.resize(MAX_FILE_SIZE);
+        data.fill(0);
+        io->readBlock(data.data(), MAX_FILE_SIZE);
+        //file.open(QIODevice::ReadOnly);
+        //QString data = file.readAll().data();
+
+        ExternalProcessConfig *cfg = NULL;
+        cfg = HRSchemaSerializer::string2Actor(data.data());
+
+        if(cfg) {
+            if(WorkflowEnv::getProtoRegistry()->getProto(cfg->name)) {
+                coreLog.error("Element with this name already exists");
+            } else {
+                LocalWorkflow::ExternalProcessWorkerFactory::init(cfg);
+                ActorPrototype *proto = WorkflowEnv::getProtoRegistry()->getProto(cfg->name);
+                QRectF rect = scene->sceneRect();
+                scene->addProcess( scene->createActor( proto, QVariantMap()), rect.center());
+            }
+            
+        } else {
+            coreLog.error(tr("Can't load element."));
+        }
+        io->close();
     }
 }
 
 void WorkflowView::sl_editScript() {
     QList<Actor *> selectedActors = scene->getSelectedProcItems();
-    if(selectedActors.count() == 1) {
+    if(selectedActors.size() == 1) {
         Actor *scriptActor = selectedActors.first();
         AttributeScript *script = scriptActor->getScript();
         if(script!= NULL) {
@@ -412,7 +502,6 @@ void WorkflowView::sl_editScript() {
             }
         }
     }
-    
 }
 
 void WorkflowView::sl_protoDeleted(const QString &id) {
@@ -433,6 +522,7 @@ void WorkflowView::sl_protoDeleted(const QString &id) {
     }
 }
 
+
 void WorkflowView::sl_toggleLock(bool b) {
     if (sender() != unlockAction) {
         unlockAction->setChecked(b);
@@ -484,16 +574,16 @@ void WorkflowView::sl_setStyle() {
 // FIXME: move to utils classes
 static void removeUrlLocationParameter( Actor * actor ) {
     assert( NULL != actor );
-    Attribute * attr = actor->getParameter( CoreLibConstants::URL_LOCATION_ATTR().getId() );
+    Attribute * attr = actor->getParameter( BaseAttributes::URL_LOCATION_ATTRIBUTE().getId() );
     if( NULL != attr ) {
-        Attribute * removed = actor->removeParameter( CoreLibConstants::URL_LOCATION_ATTR().getId() );
+        Attribute * removed = actor->removeParameter( BaseAttributes::URL_LOCATION_ATTRIBUTE().getId() );
         assert( attr == removed );
         Q_UNUSED(removed);
 
         delete attr;
-        delete actor->getEditor()->removeDelegate( CoreLibConstants::URL_LOCATION_ATTR().getId() );
+        delete actor->getEditor()->removeDelegate( BaseAttributes::URL_LOCATION_ATTRIBUTE().getId() );
     }
-    URLDelegate * urlDelegate = qobject_cast<URLDelegate*>( actor->getEditor()->getDelegate( CoreLibConstants::URL_IN_ATTR().getId() ) );
+    URLDelegate * urlDelegate = qobject_cast<URLDelegate*>( actor->getEditor()->getDelegate( BaseAttributes::URL_IN_ATTRIBUTE().getId() ) );
     if( NULL != urlDelegate ) {
         urlDelegate->sl_showEditorButton( true );
     }
@@ -502,16 +592,16 @@ static void removeUrlLocationParameter( Actor * actor ) {
 // FIXME: move to utils classes
 static void addUrlLocationParameter( Actor * actor ) {
     assert( NULL != actor );
-    Attribute * urlAttr = actor->getParameter( CoreLibConstants::URL_IN_ATTR().getId() );
-    Attribute * urlLocationAttr = actor->getParameter( CoreLibConstants::URL_LOCATION_ATTR().getId() );
+    Attribute * urlAttr = actor->getParameter( BaseAttributes::URL_IN_ATTRIBUTE().getId() );
+    Attribute * urlLocationAttr = actor->getParameter( BaseAttributes::URL_LOCATION_ATTRIBUTE().getId() );
     if( NULL != urlAttr && NULL == urlLocationAttr ) {
-        actor->addParameter( CoreLibConstants::URL_LOCATION_ATTR().getId(), 
-            new Attribute( CoreLibConstants::URL_LOCATION_ATTR(), CoreDataTypes::BOOL_TYPE(), false, true ) );
+        actor->addParameter( BaseAttributes::URL_LOCATION_ATTRIBUTE().getId(), 
+            new Attribute( BaseAttributes::URL_LOCATION_ATTRIBUTE(), BaseTypes::BOOL_TYPE(), false, true ) );
         SchemaRunModeDelegate * runModeDelegate = new SchemaRunModeDelegate();
         URLDelegate * urlDelegate = qobject_cast<URLDelegate*>
-            ( actor->getEditor()->getDelegate( CoreLibConstants::URL_IN_ATTR().getId() ) );
+            ( actor->getEditor()->getDelegate( BaseAttributes::URL_IN_ATTRIBUTE().getId() ) );
         QObject::connect( runModeDelegate, SIGNAL( si_showOpenFileButton( bool ) ), urlDelegate, SLOT( sl_showEditorButton( bool ) ) );
-        actor->getEditor()->addDelegate( runModeDelegate, CoreLibConstants::URL_LOCATION_ATTR().getId() );
+        actor->getEditor()->addDelegate( runModeDelegate, BaseAttributes::URL_LOCATION_ATTRIBUTE().getId() );
     }
 }
 
@@ -588,30 +678,31 @@ void WorkflowView::setupMDIToolbar(QToolBar* tb) {
     tb->addAction(newAction);
     tb->addAction(loadAction);
     tb->addAction(saveAction);
+    tb->addAction(saveAsAction);
     tb->addSeparator();
     tb->addAction(validateAction);
     tb->addAction(runAction);
     tb->addAction(stopAction);
-    tb->addAction(configureIterationsAction);
     tb->addAction(configureAliasesAction);
+    tb->addAction(configureIterationsAction);
     tb->addSeparator();
     tb->addAction(createScriptAcction);
     tb->addAction(editScriptAction);
     tb->addSeparator();
+    tb->addAction(externalToolAction);
+    tb->addAction(appendExternalTool);
+    tb->addSeparator();
     tb->addAction(copyAction);
     tb->addAction(pasteAction);
     pasteAction->setEnabled(!lastPaste.isEmpty());
     tb->addAction(cutAction);
     tb->addAction(deleteAction);
     tb->addSeparator();
-    //tb->addAction(bringToFrontAction);
-    //tb->addAction(sendToBackAction);
-    //tb->addSeparator();
     tb->addWidget(sceneScaleCombo);
     tb->addSeparator();
 
     QToolButton* tt = new QToolButton(tb);
-    QMenu* ttMenu = new QMenu(tr("Item style"), this);
+    QMenu* ttMenu = new QMenu(tr("Element style"), this);
     foreach(QAction* a, styleActions) {
         ttMenu->addAction(a);
     }
@@ -655,16 +746,19 @@ void WorkflowView::setupViewMenu(QMenu* m) {
     m->addAction(exportAction);
     m->addSeparator();
     m->addAction(validateAction);
-    m->addAction(configureIterationsAction);
-    m->addAction(configureAliasesAction);
     m->addAction(runAction);
     m->addAction(stopAction);
+    m->addAction(configureAliasesAction);
+    m->addAction(configureIterationsAction);
     m->addSeparator();
     m->addAction(createScriptAcction);
     m->addAction(editScriptAction);
     m->addSeparator();
+    m->addAction(externalToolAction);
+    m->addAction(appendExternalTool);
+    m->addSeparator();
 
-    QMenu* ttMenu = new QMenu(tr("Item style"));
+    QMenu* ttMenu = new QMenu(tr("Element style"));
     foreach(QAction* a, styleActions) {
         ttMenu->addAction(a);
     }
@@ -686,6 +780,7 @@ void WorkflowView::setupViewMenu(QMenu* m) {
         m->addSeparator();
         m->addAction(unlockAction);
     }
+    m->addSeparator();
 }
 
 void WorkflowView::setupContextMenu(QMenu* m) {
@@ -700,7 +795,7 @@ void WorkflowView::setupContextMenu(QMenu* m) {
     }
     QList<QGraphicsItem*> sel = scene->selectedItems();
     if (!sel.isEmpty()) {
-        if(!(sel.size() == 1 && sel.first()->type() == WorkflowBusItemType || sel.first()->type() == WorkflowPortItemType)) {
+        if(!((sel.size() == 1 && sel.first()->type() == WorkflowBusItemType) || sel.first()->type() == WorkflowPortItemType)) {
             m->addAction(copyAction);
             m->addAction(cutAction);
         }
@@ -718,14 +813,14 @@ void WorkflowView::setupContextMenu(QMenu* m) {
 
             m->addSeparator();
 
-            QMenu* itMenu = new QMenu(tr("Item properties"));
+            QMenu* itMenu = new QMenu(tr("Element properties"));
             foreach(QAction* a, wit->getContextMenuActions()) {
                 itMenu->addAction(a);
             }
             m->addMenu(itMenu);
         }
         if(!(sel.size() == 1 && (sel.first()->type() == WorkflowBusItemType || sel.first()->type() == WorkflowPortItemType))) {
-            QMenu* ttMenu = new QMenu(tr("Item style"));
+            QMenu* ttMenu = new QMenu(tr("Element style"));
             foreach(QAction* a, styleActions) {
                 ttMenu->addAction(a);
             }
@@ -816,7 +911,17 @@ void WorkflowView::localHostLaunch() {
         sh.setDomain(WorkflowEnv::getDomainRegistry()->getAllIds().value(0));
     }
     
-    WorkflowRunTask* t = new WorkflowRunTask(sh, scene->getIterations());
+    WorkflowAbstractRunner * t = NULL;
+#ifndef RUN_WORKFLOW_IN_THREADS
+    if(WorkflowSettings::runInSeparateProcess() && !WorkflowSettings::getCmdlineUgenePath().isEmpty()) {
+        t = new WorkflowRunInProcessTask(sh, scene->getIterations());
+    } else {
+        t = new WorkflowRunTask(sh, scene->getIterations());
+    }
+#else
+    t = new WorkflowRunTask(sh, scene->getIterations());
+#endif // RUN_WORKFLOW_IN_THREADS
+
     t->setReportingEnabled(true);
     if (WorkflowSettings::monitorRun()) {
         unlockAction->setChecked(false);
@@ -905,17 +1010,18 @@ void WorkflowView::sl_configureAliases() {
                 actor->getParamAliases().clear();
             }
             SchemaAliasesCfgDlgModel model = dlg.getModel();
-            SchemaAliasesCfgDlgModel::const_iterator it = model.constBegin();
-            while( it != model.constEnd() ) {
-                QMap<Descriptor, QString>::const_iterator aliasIt = it.value().constBegin();
-                while( aliasIt != it.value().constEnd() ) {
-                    assert( !aliasIt.value().isEmpty() );
-                    Actor * actor = findActorById( scene->getSchema(), it.key() );
-                    assert( actor != NULL );
-                    actor->getParamAliases().insert( aliasIt.key().getId(), aliasIt.value() );
-                    ++aliasIt;
+            foreach(const ActorId & id, model.aliases.keys()) {
+                foreach(const Descriptor & d, model.aliases.value(id).keys()) {
+                    Actor * actor = findActorById(scene->getSchema(), id);
+                    assert(actor != NULL);
+                    QString alias = model.aliases.value(id).value(d);
+                    assert(!alias.isEmpty());
+                    actor->getParamAliases().insert(d.getId(), alias);
+                    QString help = model.help.value(id).value(d);
+                    if( !help.isEmpty() ) {
+                        actor->getAliasHelp().insert(alias, help);
+                    }
                 }
-                ++it;
             }
             break;
         } else if( ret == QDialog::Rejected ) {
@@ -985,6 +1091,7 @@ void WorkflowView::sl_pasteSample(const QString& s) {
         sl_updateTitle();
     } else {
         scene->clearScene();
+        propertyEditor->resetIterations();
         sl_pasteSample(s);
     }
 }
@@ -997,7 +1104,9 @@ void WorkflowView::sl_pasteItems(const QString& s) {
         pasteCount = 0;
         lastPaste = tmp;
     }
-    if( !AppContext::getDocumentFormatRegistry()->getFormatById(WorkflowDocFormat::FORMAT_ID)->checkRawData(lastPaste.toAscii()) ) {
+    QByteArray lpt = lastPaste.toAscii();
+    DocumentFormat* wf = AppContext::getDocumentFormatRegistry()->getFormatById(WorkflowDocFormat::FORMAT_ID);
+    if (wf->checkRawData(lpt).score != FormatDetection_Matched) {
         return;
     }
     scene->clearSelection();
@@ -1105,46 +1214,21 @@ void WorkflowView::sl_editItem() {
     }
 }
 
+void WorkflowView::sl_onSelectionChanged() {
+    QList<Actor*> actorsSelected = scene->getSelectedProcItems();
+    editScriptAction->setEnabled(actorsSelected.size() == 1 && actorsSelected.first()->getScript() != NULL);
+}
+
 void WorkflowView::sl_exportScene() {
     propertyEditor->commit();
 
-    // TODO more export options and features
-    QString dir = AppContext::getSettings()->getValue(LAST_DIR, QString("")).toString();
-    QString filter = tr("Raster image (*.png *.bmp *.jpg *.jpeg *.ppm *.xbm *.xpm)");
-    filter += "\n" + tr("Vector image (*.svg)");
-    filter += "\n"+ tr("Portable document (*.pdf *.ps)");
-    QString selectedFilter = "";//AppContext::getSettings()->getValue(LAST_FILE_FILTER, QString("")).toString();
-    QString url = QFileDialog::getSaveFileName(0, tr("Export workflow schema to image"), dir, filter,&selectedFilter);
-    if (!url.isEmpty()) {
-        AppContext::getSettings()->setValue(LAST_DIR, QFileInfo(url).absoluteDir().absolutePath());
-        uiLog.details(tr("Saving scene image to file: %1").arg(url));
-
-        QPoint renderPoint = infoSplitter->mapToParent(sceneView->mapToParent(sceneView->viewport()->rect().topLeft()));
-        QSize renderSize = sceneView->viewport()->rect().size();
-        QRect rect(renderPoint, renderSize);
-
-        if (url.endsWith(".svg", Qt::CaseInsensitive)) {
-            QSvgGenerator svg;
-            svg.setFileName(url);
-            svg.setSize(renderSize);
-            QPainter painter(&svg);
-            render(&painter,QPoint(), rect);
-            painter.end();
-        } else if (url.endsWith(".pdf", Qt::CaseInsensitive) || url.endsWith(".ps", Qt::CaseInsensitive)) {
-            QPrinter printer;
-            printer.setOutputFileName(url);
-            render(&printer, QPoint(), rect);
-        } else {
-            QPixmap pixmap(renderSize);
-            render(&pixmap, QPoint(), rect);
-            pixmap.save(url);
-        }
-    }
+    ExportImageDialog dialog(sceneView->viewport(),sceneView->viewport()->rect(),true,true);
+    dialog.exec();
 }
 
 void WorkflowView::sl_saveScene() {
     if (meta.url.isEmpty()) {
-        WorkflowMetaDialog md(meta);
+        WorkflowMetaDialog md(this, meta);
         int rc = md.exec();
         if (rc != QDialog::Accepted) {
             return;
@@ -1158,7 +1242,7 @@ void WorkflowView::sl_saveScene() {
 }
 
 void WorkflowView::sl_saveSceneAs() {
-    WorkflowMetaDialog md(meta);
+    WorkflowMetaDialog md(this, meta);
     int rc = md.exec();
     if (rc != QDialog::Accepted) {
         return;
@@ -1176,7 +1260,7 @@ void WorkflowView::sl_loadScene() {
     }
 
     QString dir = AppContext::getSettings()->getValue(LAST_DIR, QString("")).toString();
-    QString filter = DesignerUtils::getSchemaFileFilter(true);
+    QString filter = DesignerUtils::getSchemaFileFilter(true, true);
     QString url = QFileDialog::getOpenFileName(0, tr("Open workflow schema file"), dir, filter);
     if (!url.isEmpty()) {
         AppContext::getSettings()->setValue(LAST_DIR, QFileInfo(url).absoluteDir().absolutePath());
@@ -1185,10 +1269,22 @@ void WorkflowView::sl_loadScene() {
         connect(m, SIGNAL(si_taskFinished(Task*)), SLOT(sl_updateTitle()));
         connect(m, SIGNAL(si_taskFinished(Task*)), scene, SLOT(centerView()));
         connect(m, SIGNAL(si_taskFinished(Task*)), propertyEditor, SLOT(resetIterations()));
+        if(LoadWorkflowTask::detectFormat(BaseIOAdapters::readFileHeader(url)) == LoadWorkflowTask::XML) {
+            connect(m, SIGNAL(si_taskFinished(Task*)), SLOT(sl_xmlSchemaLoaded(Task*)));
+        }
         AppContext::getTaskScheduler()->registerTopLevelTask(t);
     }
 }
 
+void WorkflowView::sl_xmlSchemaLoaded(Task* t) {
+    assert(t != NULL);
+    if(!t->hasError()) {
+        QMessageBox::warning(this, tr("Warning!"), XML_SCHEMA_WARNING);
+    } else {
+        QMessageBox::warning(this, tr("Warning!"), XML_SCHEMA_APOLOGIZE);
+    }
+}
+
 void WorkflowView::sl_newScene() {
     if (!confirmModified()) {
         return;
@@ -1204,7 +1300,7 @@ void WorkflowView::sl_newScene() {
 }
 
 void WorkflowView::sl_updateTitle() {
-    setWindowName(tr("Workflow Designer - %1").arg(meta.name));    
+    setWindowTitle(tr("Workflow Designer - %1").arg(meta.name));    
 }
 
 void WorkflowView::saveState() {
@@ -1452,6 +1548,7 @@ void WorkflowScene::clearScene() {
     foreach(WorkflowProcessItem *item, deleteList) {
         removeItem(item);
     }
+    iterations.clear();
 }
 
 static QString newActorName(ActorPrototype * proto, const QList<Actor*> & procs) {
@@ -1599,7 +1696,7 @@ void WorkflowScene::centerView() {
         QTransform matrix = child->transform() * QTransform().translate(childPos.x(), childPos.y());
         childRect |= matrix.mapRect(child->boundingRect() | child->childrenBoundingRect());
     }
-    QPointF zero = childRect.center();
+//    QPointF zero = childRect.center();
     //log.info(QString("center [%1 %2]").arg(zero.x()).arg(zero.y()));
     //FIXME does not work
     //views().first()->centerOn(zero);
