@@ -1,16 +1,29 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "WorkflowViewItems.h"
 #include "ItemViewStyle.h"
 #include "WorkflowViewController.h"
+#include "HRSceneSerializer.h"
+#include "WorkflowEditor.h"
 
 #include <U2Lang/ActorPrototypeRegistry.h>
 #include <U2Lang/ActorModel.h>
@@ -40,8 +53,8 @@ namespace U2 {
 
 WorkflowProcessItem::WorkflowProcessItem(Actor* prc) : process(prc) {
     setToolTip(process->getProto()->getDocumentation());
-    setFlag(QGraphicsItem::ItemIsMovable, true);
     setFlag(QGraphicsItem::ItemIsSelectable, true);
+    setFlag(QGraphicsItem::ItemIsMovable, true);
 #if (QT_VERSION >= QT_VERSION_CHECK(4, 6, 0))
     setFlag(QGraphicsItem::ItemSendsGeometryChanges, true);
 #endif
@@ -50,7 +63,7 @@ WorkflowProcessItem::WorkflowProcessItem(Actor* prc) : process(prc) {
     styles[ItemStyles::SIMPLE] = new SimpleProcStyle(this);
     styles[ItemStyles::EXTENDED] = new ExtendedProcStyle(this);
     currentStyle = getStyleByIdSafe(WorkflowSettings::defaultStyle());
-    currentStyle->setActive(true);
+    currentStyle->setVisible(true);
     createPorts();
 }
 
@@ -127,9 +140,9 @@ void WorkflowProcessItem::sl_update() {
 
 void WorkflowProcessItem::setStyle(StyleId s) {
     prepareGeometryChange();
-    currentStyle->setActive(false);
+    currentStyle->setVisible(false);
     currentStyle = getStyleByIdSafe(s);
-    currentStyle->setActive(true);
+    currentStyle->setVisible(true);
     currentStyle->refresh();
     foreach(WorkflowPortItem* pit, ports) {
         pit->setStyle(s);
@@ -146,16 +159,27 @@ QRectF WorkflowProcessItem::boundingRect(void) const {
     return brect;
 }
 
+QRectF WorkflowProcessItem::portsBoundingRect() const {
+    QRectF rect; // null rect
+    foreach(WorkflowPortItem* p, getPortItems()) {
+        QRectF pBound = p->boundingRect();
+        QPointF pCenter = pBound.center();
+        pCenter = p->mapToItem(this, pCenter);
+        pBound.moveCenter(pCenter);
+        rect |= pBound;
+    }
+    return rect;
+}
+
 QPainterPath WorkflowProcessItem::shape () const {
     return currentStyle->shape();
 }
 
 void WorkflowProcessItem::paint(QPainter *painter,
-                          const QStyleOptionGraphicsItem *option,
-                          QWidget *widget)
+                          const QStyleOptionGraphicsItem */*option*/,
+                          QWidget */*widget*/)
 {
-    currentStyle->paint(painter,option,widget);
-    WorkflowRunTask* rt = getWorkflowScene()->getRunner();
+    WorkflowAbstractRunner* rt = getWorkflowScene()->getRunner();
     if (rt) {
         //{WorkerWaiting, WorkerReady, WorkerRunning, WorkerDone};
         static QColor rsColors[4] = {QColor(234,143,7),"#04AA04", "#AA0404", "#0404AA"};
@@ -271,18 +295,32 @@ QVariant WorkflowProcessItem::itemChange ( GraphicsItemChange change, const QVar
     }
         break;
     case ItemPositionChange:
+    {
+        // value is the new position.
+        QPointF newPos = value.toPointF();
+        if (scene() && pos() != QPointF(0,0)) {
+            QRectF bound = boundingRect() | childrenBoundingRect() | portsBoundingRect();
+            QRectF sceneRect = scene()->sceneRect();
+
+            qreal x0 = sceneRect.left() - bound.left();
+            qreal x1 = sceneRect.left() + sceneRect.width() - bound.right() - 10; //extra space for scroll bars
+            qreal y0 = sceneRect.top() - bound.top();
+            qreal y1 = sceneRect.top() + sceneRect.height() - bound.bottom() - 10;
+
+            newPos.setX( qBound(x0, newPos.x(), x1) );
+            newPos.setY( qBound(y0, newPos.y(), y1) );
+        }
         if (WorkflowSettings::snap2Grid()) {
-            // value is the new position.
-            QPointF newPos = value.toPointF();
             newPos.setX(round(newPos.x(), GRID_STEP));
             newPos.setY(round(newPos.y(), GRID_STEP));
-            return newPos;
         }
+        return newPos;
         /*foreach(WorkflowPortItem* pit, ports) {
-            foreach(WorkflowBusItem*bit, pit->getDataFlows()) {
-                bit->prepareGeometryChange();
-            }
+        foreach(WorkflowBusItem*bit, pit->getDataFlows()) {
+        bit->prepareGeometryChange();
+        }
         }*/
+    }
         break;
     case ItemPositionHasChanged:
         {
@@ -294,15 +332,42 @@ QVariant WorkflowProcessItem::itemChange ( GraphicsItemChange change, const QVar
             }
             WorkflowScene * sc = qobject_cast<WorkflowScene*>(scene());
             if(sc != NULL) {
+                if (!sc->views().isEmpty()) {
+                    foreach(QGraphicsView* view, sc->views()) {
+                        QRectF itemRect = boundingRect() | childrenBoundingRect();
+                        // ports are not the child items atm
+                        // unite with their bounds
+                        itemRect |= portsBoundingRect();
+                        QPointF itemCenter = itemRect.center();
+                        itemCenter = mapToScene(itemCenter);
+                        itemRect.moveCenter(itemCenter);
+                        view->ensureVisible(itemRect, 0, 0);
+                    }
+                }
                 sc->setModified(true);
             }
+            if (scene()) {
+                scene()->update();
+            }
         }
         break;
     case ItemSceneHasChanged:
-        if (scene()) {
-            foreach(WorkflowPortItem* pit, ports) {
-                scene()->addItem(pit);
-            }
+        {
+	        WorkflowScene* ws = getWorkflowScene();
+	        if (ws) {
+	            ItemViewStyle* viewStyle = styles.value(ItemStyles::EXTENDED);
+	            ExtendedProcStyle* extStyle = qgraphicsitem_cast<ExtendedProcStyle*>(viewStyle);
+	            assert(extStyle);
+	            WorkflowView* view = ws->getController();
+	            if (view) {
+	                connect(extStyle, SIGNAL(linkActivated(const QString&)),
+                        view->getPropertyEditor(), SLOT(sl_linkActivated(const QString&)));
+	            }
+	
+	            foreach(WorkflowPortItem* pit, ports) {
+	                ws->addItem(pit);
+	            }
+	        }
         }
         break;
     case ItemSceneChange:
@@ -359,6 +424,44 @@ void WorkflowProcessItem::loadState(QDomElement& el) {
     }
 }
 
+void WorkflowProcessItem::mouseMoveEvent( QGraphicsSceneMouseEvent *event ) {
+    if (event->buttons() & Qt::LeftButton) {
+        if (initialPositions.isEmpty()) {
+            if (isSelected()) {
+                QList<QGraphicsItem *> selectedItems = scene()->selectedItems();
+                foreach(QGraphicsItem* item, selectedItems) {
+                    if (item->type()==WorkflowProcessItemType) {
+                        initialPositions[item] = item->scenePos();
+                    }
+                }
+            } else {
+                initialPositions[this] = scenePos();
+            }
+        }
+
+        // Find the active view.
+        QGraphicsView *view = 0;
+        if (event->widget()) {
+            view = qobject_cast<QGraphicsView *>(event->widget()->parentWidget());
+        }
+
+        for (int i=0, n=initialPositions.keys().size(); i<n; i++) {
+            QGraphicsItem *item = initialPositions.keys().at(i);
+
+            QPointF currentParentPos = view->mapToScene(view->mapFromGlobal(event->screenPos()));
+            QPointF buttonDownParentPos = view->mapToScene(view->mapFromGlobal(event->buttonDownScreenPos(Qt::LeftButton)));
+
+            item->setPos(initialPositions.value(item) + currentParentPos - buttonDownParentPos);
+        }
+    } else {
+        event->ignore();
+    }
+}
+
+void WorkflowProcessItem::mouseReleaseEvent( QGraphicsSceneMouseEvent *event ) {
+    initialPositions.clear();
+    QGraphicsItem::mouseReleaseEvent(event);
+}
 ///////////// PIO /////////////
 
 WorkflowPortItem* WorkflowPortItem::findNearbyBindingCandidate(const QPointF& pos) const {
@@ -571,6 +674,7 @@ WorkflowBusItem* WorkflowPortItem::tryBind(WorkflowPortItem* otherPit) {
         otherPit->flows << dit;
         WorkflowScene * sc = qobject_cast<WorkflowScene*>(scene());
         assert(sc != NULL);
+        
         sc->addItem(dit);
         sc->setModified(true);
         dit->updatePos();
@@ -699,10 +803,27 @@ void WorkflowPortItem::paint(QPainter *painter,
         if (sticky) {
             pen.setColor(stickyLight);
         }
+        //put drag point inside of the scene rect
+        QPointF pp = dragPoint;
+        QRectF scRect = scene()->sceneRect();
+        QList<QLineF> sceneEdges;
+        sceneEdges << QLineF(scRect.topLeft(), scRect.topRight())
+            << QLineF(scRect.topRight(), scRect.bottomRight())
+            << QLineF(scRect.bottomLeft(), scRect.bottomRight())
+            << QLineF(scRect.topLeft(), scRect.bottomLeft());
+        QLineF arr(mapToScene(dragPoint), mapToScene(p1));
+        QPointF crossPt;
+        foreach(QLineF scEdge, sceneEdges) {
+            if (scEdge.intersect(arr, &crossPt) == QLineF::BoundedIntersection) {
+                pp = mapFromScene(crossPt);
+                break;
+            }
+        }
+        //////////////////////////////////////////////////////////////////////////
         if (port->isInput())
-            drawArrow(painter, pen, dragPoint, p1);
+            drawArrow(painter, pen, pp, p1);
         else
-            drawArrow(painter, pen, p1, dragPoint);
+            drawArrow(painter, pen, p1, pp);
     } 
     else if (option->state & QStyle::State_Selected) {
         QPen pen;
@@ -711,7 +832,6 @@ void WorkflowPortItem::paint(QPainter *painter,
         painter->setPen(pen);
         painter->drawRoundedRect(boundingRect(), 30, 30, Qt::RelativeSize);
     }
-
 }
 
 void WorkflowPortItem::mouseMoveEvent( QGraphicsSceneMouseEvent * event ) {
@@ -751,7 +871,18 @@ void WorkflowPortItem::mouseMoveEvent( QGraphicsSceneMouseEvent * event ) {
         setOrientation(angle);
     } 
     if (dragging) {
-        dragPoint = rotating ? mapFromScene(event->scenePos()) : event->pos();
+        foreach(QGraphicsView* v, scene()->views()) {
+            QRectF r(0,0,5,5);
+            r.moveCenter(mapToScene(dragPoint));
+            v->ensureVisible(r,0,0);
+        }
+        /*dragPoint = rotating ? mapFromScene(event->scenePos()) : event->pos();*/
+        if (rotating) {
+            dragPoint += event->scenePos() - event->lastScenePos();
+        } else {
+            dragPoint += event->pos() - event->lastPos();
+        }
+            
         WorkflowPortItem* preferable = findNearbyBindingCandidate(event->scenePos());
         if (preferable) {
             dragPoint = preferable->head(this);
@@ -963,7 +1094,7 @@ void WorkflowBusItem::paint ( QPainter * painter, const QStyleOptionGraphicsItem
     painter->fillRect(textRec, QBrush(yc));
     painter->drawRect(textRec);
 
-    WorkflowRunTask* rt = getWorkflowScene()->getRunner();
+    WorkflowAbstractRunner* rt = getWorkflowScene()->getRunner();
     if (rt) {
         int msgsInQueue = rt->getMsgNum(this->bus);
         int passed = rt->getMsgPassed(this->bus);
