@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QFile>
 
@@ -21,6 +32,8 @@
 
 #include <U2Lang/WorkflowEnv.h>
 #include <U2Lang/WorkflowUtils.h>
+#include <U2Lang/WorkflowManager.h>
+#include <U2Lang/WorkflowRunTask.h>
 
 #include "WorkflowDesignerPlugin.h"
 #include "WorkflowCMDLineTasks.h"
@@ -29,8 +42,6 @@
 
 namespace U2 {
 
-static Logger log( WORKFLOW_CMDLINE_TASK_LOG_CAT );
-
 /*******************************************
 * WorkflowRunFromCMDLineBase
 *******************************************/
@@ -74,7 +85,7 @@ void WorkflowRunFromCMDLineBase::processLoadSchemaTask( const QString & schemaNa
 LoadWorkflowTask * WorkflowRunFromCMDLineBase::prepareLoadSchemaTask( const QString & schemaName ) {
     QString pathToSchema = WorkflowUtils::findPathToSchemaFile( schemaName );
     if( pathToSchema.isEmpty() ) {
-        log.error( tr( "Cannot find schema: %1" ).arg( schemaName ) );
+        coreLog.error( tr( "Cannot find schema: %1" ).arg( schemaName ) );
         return NULL;
     }
 
@@ -87,27 +98,6 @@ WorkflowRunFromCMDLineBase::~WorkflowRunFromCMDLineBase() {
     delete schema;
 }
 
-static Actor * findActorByParamAlias( Schema * schema, const QString & alias, QString & attrName ) {
-    assert( schema != NULL );
-    QList<Actor*> actors;
-    foreach( Actor * actor, schema->getProcesses() ) {
-        assert( actor != NULL );
-        if( actor->getParamAliases().values().contains( alias ) ) {
-            actors << actor;
-        }
-    }
-
-    if ( actors.isEmpty() ) {
-        return NULL;
-    } else if( actors.size() > 1 ) {
-        log.error( WorkflowRunFromCMDLineBase::tr( "%1 actors in schema have '%2' alias" ).arg( actors.size() ).arg( alias ) );
-    }
-
-    Actor * ret = actors.first();
-    attrName = ret->getParamAliases().key( alias );
-    return ret;
-}
-
 static void setSchemaCMDLineOptions( Schema * schema, int optionsStartAtIdx ) {
     assert( schema != NULL && optionsStartAtIdx > 0 );
 
@@ -121,23 +111,23 @@ static void setSchemaCMDLineOptions( Schema * schema, int optionsStartAtIdx ) {
 
         QString paramAlias = param.first;
         QString paramName;
-        Actor * actor = findActorByParamAlias( schema, paramAlias, paramName );
+        Actor * actor = WorkflowUtils::findActorByParamAlias( schema->getProcesses(), paramAlias, paramName );
         if( actor == NULL ) {
             assert( paramName.isEmpty() );
-            log.info( WorkflowRunFromCMDLineBase::tr( "alias '%1' not set in schema" ).arg( paramAlias ) );
+            coreLog.info( WorkflowRunFromCMDLineBase::tr( "alias '%1' not set in schema" ).arg( paramAlias ) );
             continue;
         }
 
         Attribute * attr = actor->getParameter( paramName );
         if( attr == NULL ) {
-            log.error( WorkflowRunFromCMDLineBase::tr( "actor parameter '%1' not found" ).arg( paramName ) );
+            coreLog.error( WorkflowRunFromCMDLineBase::tr( "actor parameter '%1' not found" ).arg( paramName ) );
             continue;
         }
 
         DataTypeValueFactory * valueFactory = WorkflowEnv::getDataTypeValueFactoryRegistry()->
             getById( attr->getAttributeType()->getId() );
         if( valueFactory == NULL ) {
-            log.error( WorkflowRunFromCMDLineBase::tr( "cannot parse value from '%1'" ).arg( param.second ) );
+            coreLog.error( WorkflowRunFromCMDLineBase::tr( "cannot parse value from '%1'" ).arg( param.second ) );
             continue;
         }
 
@@ -145,7 +135,7 @@ static void setSchemaCMDLineOptions( Schema * schema, int optionsStartAtIdx ) {
         bool isOk;
         QVariant value = valueFactory->getValueFromString( param.second, &isOk );
         if(!isOk){
-            log.error( WorkflowRunFromCMDLineBase::tr( "Incorrect value for '%1', null or default value passed to schema" ).
+            coreLog.error( WorkflowRunFromCMDLineBase::tr( "Incorrect value for '%1', null or default value passed to schema" ).
                 arg( param.first ));
             continue;
         }
@@ -163,15 +153,16 @@ QList<Task*> WorkflowRunFromCMDLineBase::onSubTaskFinished( Task* subTask ) {
     QList<Task*> res;
 
     propagateSubtaskError();
-    if( hasErrors() || isCanceled() ) {
+    if( hasError() || isCanceled() ) {
         return res;
     }
-    assert( !hasErrors() ); // if error, we won't be here
+    assert( !hasError() ); // if error, we won't be here
 
     if( loadTask == subTask ) {
         Schema * schema = loadTask->getSchema();
         assert( schema != NULL );
-
+        remapping = loadTask->getRemapping();
+        
         setSchemaCMDLineOptions( schema, optionsStartAt );
         if( schema->getDomain().isEmpty() ) {
             QList<QString> domainsId = WorkflowEnv::getDomainRegistry()->getAllIds();
@@ -196,27 +187,13 @@ QList<Task*> WorkflowRunFromCMDLineBase::onSubTaskFinished( Task* subTask ) {
 * WorkflowRunFromCMDLineTask
 *******************************************/
 Task * WorkflowRunFromCMDLineTask::getWorkflowRunTask() const {
-    return new WorkflowRunTask(*schema, schema->getIterations());
+    return new WorkflowRunTask(*schema, schema->getIterations(), remapping);
 }
 
 /*******************************************
 * WorkflowRemoteRunFromCMDLineTask
 *******************************************/
 WorkflowRemoteRunFromCMDLineTask::WorkflowRemoteRunFromCMDLineTask() {
-    CMDLineRegistry * cmdlineReg = AppContext::getCMDLineRegistry();
-    assert(cmdlineReg != NULL);
-    QString filePath = cmdlineReg->getParameterValue(WorkflowDesignerPlugin::REMOTE_MACHINE);
-    if( filePath.isEmpty() ) {
-        stateInfo.setError(tr("%1 parameter expected, but not set").arg(WorkflowDesignerPlugin::REMOTE_MACHINE));
-        return;
-    }
-    
-    if( !SerializeUtils::deserializeRemoteMachineSettingsFromFile(filePath, &settings) ) {
-        assert(settings == NULL);
-        stateInfo.setError(tr("Cannot read remote machine settings from %2").arg(filePath));
-        return;
-    }
-    assert(settings != NULL);
 }
 
 Task * WorkflowRemoteRunFromCMDLineTask::getWorkflowRunTask() const {
@@ -224,4 +201,23 @@ Task * WorkflowRemoteRunFromCMDLineTask::getWorkflowRunTask() const {
     return new RemoteWorkflowRunTask( settings, *schema, schema->getIterations());
 }
 
+void WorkflowRemoteRunFromCMDLineTask::prepare()
+{
+    CMDLineRegistry * cmdlineReg = AppContext::getCMDLineRegistry();
+    assert(cmdlineReg != NULL);
+    QString filePath = cmdlineReg->getParameterValue(WorkflowDesignerPlugin::REMOTE_MACHINE);
+    if( filePath.isEmpty() ) {
+        stateInfo.setError(tr("%1 parameter expected, but not set").arg(WorkflowDesignerPlugin::REMOTE_MACHINE));
+        return;
+    }
+
+    if( !SerializeUtils::deserializeRemoteMachineSettingsFromFile(filePath, &settings) ) {
+        //assert(settings == NULL);
+        stateInfo.setError(tr("Cannot read remote machine settings from %2").arg(filePath));
+        return;
+    }
+    assert(settings != NULL);
+
+}
+
 } // U2
