@@ -1,19 +1,30 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_WORKFLOW_CMDLINE_TASKS_H_
 #define _U2_WORKFLOW_CMDLINE_TASKS_H_
 
 #include <U2Core/Task.h>
-#include <U2Lang/WorkflowRunTask.h>
 #include <U2Remote/RemoteMachine.h>
+#include <U2Lang/WorkflowIOTasks.h>
 
 namespace U2 {
 
@@ -36,6 +47,7 @@ protected:
     int                 optionsStartAt;
     LoadWorkflowTask *  loadTask;
     QString             schemaName;
+    QMap<ActorId, ActorId> remapping;
     
 }; // WorkflowRunFromCMDLineBase
 
@@ -49,6 +61,7 @@ class WorkflowRemoteRunFromCMDLineTask : public WorkflowRunFromCMDLineBase {
     Q_OBJECT
 public:
     WorkflowRemoteRunFromCMDLineTask();
+    virtual void prepare();
     virtual Task * getWorkflowRunTask() const;
     
 private:
