@@ -1,23 +1,34 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "DocWorkers.h"
 #include "CoreLib.h"
 #include "GenericReadWorker.h"
 
 #include <U2Lang/WorkflowEnv.h>
-#include <U2Lang/CoreDataTypes.h>
 #include <U2Core/QVariantUtils.h>
 #include <U2Lang/CoreLibConstants.h>
-#include <U2Lang/BioDatatypes.h>
-#include <U2Lang/BioActorLibrary.h>
+#include <U2Lang/BaseTypes.h>
+#include <U2Lang/BaseSlots.h>
+#include <U2Lang/BaseAttributes.h>
 #include <U2Core/Log.h>
 #include <U2Core/DocumentModel.h>
 #include <U2Core/AnnotationTableObject.h>
@@ -45,7 +56,7 @@ static int ct = 0;
  * TextReader
  *************************************/
 void TextReader::init() {
-    urls = WorkflowUtils::expandToUrls(actor->getParameter(CoreLibConstants::URL_IN_ATTR().getId())->getAttributeValue<QString>());
+    urls = WorkflowUtils::expandToUrls(actor->getParameter(BaseAttributes::URL_IN_ATTRIBUTE().getId())->getAttributeValue<QString>());
 
     assert(ports.size() == 1);
     ch = ports.values().first();
@@ -67,8 +78,8 @@ Task *TextReader::tick() {
         int read = io->readLine(buf.data(), 1024);
         buf.resize(read);
         QVariantMap m; 
-        m[CoreLibConstants::TEXT_SLOT().getId()] = QString(buf);
-        m[CoreLibConstants::URL_SLOT().getId()] = url;
+        m[BaseSlots::TEXT_SLOT().getId()] = QString(buf);
+        m[BaseSlots::URL_SLOT().getId()] = url;
         ch->put( Message(mtype, m));
         if(io->isEof()) {
             io->close();
@@ -80,7 +91,7 @@ Task *TextReader::tick() {
         if(!io->open(url,IOAdapterMode_Read)) {
             return new FailTask(tr("Can't load file %1").arg(url));
         }
-        if(actor->getParameter(CoreLibConstants::READ_LINES_ID)->getAttributeValue<bool>() == false) {
+        if(actor->getParameter(BaseAttributes::READ_BY_LINES_ATTRIBUTE().getId())->getAttributeValue<bool>() == false) {
             QByteArray buf;
             int read = 0;
             int offs = 0;
@@ -99,8 +110,8 @@ Task *TextReader::tick() {
             } while(read == READ_BLOCK_SZ);
             
             QVariantMap m; 
-            m[CoreLibConstants::TEXT_SLOT().getId()] = QString(buf);
-            m[CoreLibConstants::URL_SLOT().getId()] = url;
+            m[BaseSlots::TEXT_SLOT().getId()] = QString(buf);
+            m[BaseSlots::URL_SLOT().getId()] = url;
             ch->put( Message(mtype, m));
             io->close();
         } else {
@@ -111,8 +122,8 @@ Task *TextReader::tick() {
             buf.resize(read);
             QVariantMap m; 
             QString str(buf);
-            m[CoreLibConstants::TEXT_SLOT().getId()] = QString(buf);
-            m[CoreLibConstants::URL_SLOT().getId()] = url;
+            m[BaseSlots::TEXT_SLOT().getId()] = QString(buf);
+            m[BaseSlots::URL_SLOT().getId()] = url;
             ch->put( Message(mtype, m));
             if(io->isEof()) {
                 io->close();
@@ -132,8 +143,8 @@ void TextReader::doc2data(Document* doc) {
         TextObject* txtObject = qobject_cast<TextObject*>(go);
         assert(txtObject);
         QVariantMap m; 
-        m[CoreLibConstants::TEXT_SLOT().getId()] = txtObject->getText();
-        m[CoreLibConstants::URL_SLOT().getId()] = doc->getURLString();
+        m[BaseSlots::TEXT_SLOT().getId()] = txtObject->getText();
+        m[BaseSlots::URL_SLOT().getId()] = doc->getURLString();
         cache << Message(mtype, m);
     }
 }
@@ -142,7 +153,7 @@ void TextReader::doc2data(Document* doc) {
 * TextWriter
 *************************************/
 void TextWriter::data2doc(Document* doc, const QVariantMap& data) {
-    QStringList list = data.value(CoreLibConstants::TEXT_SLOT().getId()).toStringList();
+    QStringList list = data.value(BaseSlots::TEXT_SLOT().getId()).toStringList();
     QString text = list.join("\n");
     TextObject* to = qobject_cast<TextObject*>(GObjectUtils::selectOne(doc->getObjects(), GObjectTypes::TEXT, UOF_LoadedOnly));
     if (!to) {
@@ -161,8 +172,8 @@ void FastaWriter::data2doc(Document* doc, const QVariantMap& data) {
 }
 
 void FastaWriter::data2document(Document* doc, const QVariantMap& data) {
-    DNASequence seq = qVariantValue<DNASequence>(data.value(BioActorLibrary::SEQ_SLOT().getId()));
-    QString sequenceName = data.value(CoreLibConstants::FASTA_HEADER_SLOT_ID).toString();
+    DNASequence seq = qVariantValue<DNASequence>(data.value(BaseSlots::DNA_SEQUENCE_SLOT().getId()));
+    QString sequenceName = data.value(BaseSlots::FASTA_HEADER_SLOT().getId()).toString();
     if (sequenceName.isEmpty()) {
         sequenceName = seq.getName();
     } else {
@@ -185,7 +196,7 @@ void FastQWriter::data2doc(Document* doc, const QVariantMap& data) {
 }
 
 void FastQWriter::data2document(Document* doc, const QVariantMap& data) {
-    DNASequence seq = qVariantValue<DNASequence>(data.value(BioActorLibrary::SEQ_SLOT().getId()));
+    DNASequence seq = qVariantValue<DNASequence>(data.value(BaseSlots::DNA_SEQUENCE_SLOT().getId()));
     QString sequenceName = seq.getName(); 
     if (sequenceName.isEmpty()) {
         sequenceName = QString("unknown sequence %1").arg(doc->getObjects().size());
@@ -206,7 +217,7 @@ void RawSeqWriter::data2doc(Document* doc, const QVariantMap& data) {
 
 // same as FastQWriter::data2document
 void RawSeqWriter::data2document(Document* doc, const QVariantMap& data) {
-    DNASequence seq = qVariantValue<DNASequence>(data.value(BioActorLibrary::SEQ_SLOT().getId()));
+    DNASequence seq = qVariantValue<DNASequence>(data.value(BaseSlots::DNA_SEQUENCE_SLOT().getId()));
     QString sequenceName = seq.getName(); 
     if (sequenceName.isEmpty()) {
         sequenceName = QString("unknown sequence %1").arg(doc->getObjects().size());
@@ -230,7 +241,7 @@ void GenbankWriter::data2doc(Document* doc, const QVariantMap& data) {
 }
 
 void GenbankWriter::data2document(Document* doc, const QVariantMap& data) {
-    DNASequence seq = qVariantValue<DNASequence>(data.value(BioActorLibrary::SEQ_SLOT().getId()));
+    DNASequence seq = qVariantValue<DNASequence>(data.value(BaseSlots::DNA_SEQUENCE_SLOT().getId()));
     
     /*QStringList order;
     order << DNAInfo::DEFINITION << DNAInfo::ACCESSION << DNAInfo::VERSION;
@@ -259,12 +270,13 @@ void GenbankWriter::data2document(Document* doc, const QVariantMap& data) {
     if (sequenceName.isEmpty()) {
         int num = doc->findGObjectByType(GObjectTypes::SEQUENCE).size();
         sequenceName = QString("unknown sequence %1").arg(num);
-        annotationName = QString("unknown features %1").arg(num);
+        int featuresNum = doc->findGObjectByType(GObjectTypes::ANNOTATION_TABLE).size();
+        annotationName = QString("unknown features %1").arg(featuresNum);
     } else {
         annotationName = sequenceName + " features";
     }
 
-    QList<SharedAnnotationData> atl = QVariantUtils::var2ftl(data.value(BioActorLibrary::FEATURE_TABLE_SLOT().getId()).toList());
+    QList<SharedAnnotationData> atl = QVariantUtils::var2ftl(data.value(BaseSlots::ANNOTATION_TABLE_SLOT().getId()).toList());
     DNASequenceObject* dna = qobject_cast<DNASequenceObject*>(doc->findGObjectByName(sequenceName));
     if (!dna && !seq.isNull()) {
         doc->addObject(dna = new DNASequenceObject(sequenceName, seq));
@@ -316,7 +328,7 @@ void SeqWriter::data2doc(Document* doc, const QVariantMap& data){
 * MSAWriter
 *************************************/
 void MSAWriter::data2doc(Document* doc, const QVariantMap& data) {
-    MAlignment ma = data.value(BioActorLibrary::MA_SLOT().getId()).value<MAlignment>();
+    MAlignment ma = data.value(BaseSlots::MULTIPLE_ALIGNMENT_SLOT().getId()).value<MAlignment>();
     if (ma.isEmpty()) {
         algoLog.error(tr("Empty alignment passed for writing to %1").arg(doc->getURLString()));
         return; //FIXME
