@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_WORKFLOW_READ_SEQ_WORKER_H_
 #define _U2_WORKFLOW_READ_SEQ_WORKER_H_
@@ -31,6 +42,7 @@ public:
     LoadSeqTask(QString url, const QVariantMap& cfg, DNASelector* sel) 
         : Task(tr("Read sequences from %1").arg(url), TaskFlag_None),
         url(url), selector(sel), cfg(cfg) {}
+    virtual void prepare();
     virtual void run();
 
     QString url;
@@ -43,6 +55,7 @@ class LoadMSATask : public Task {
     Q_OBJECT
 public:
     LoadMSATask(QString url) : Task(tr("Read MSA from %1").arg(url), TaskFlag_None), url(url) {}
+    virtual void prepare();
     virtual void run();
 
     QString url;
