@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "BowtieConstants.h"
 #include "BowtieAdapter.h"
@@ -68,7 +79,10 @@ void BowtieAdapter::doBowtie(const QString& ebwtFileName, BowtieReadsReader* rea
 			ti.setError(QString("Bowtie exits with error code %1").arg(e));
 			ctx->hasError = true;
 		}
-	}
+    } catch (QString exceptionMessage) {
+        ti.setError(exceptionMessage);
+        ctx->hasError = true;
+    }
 	if(ctx->hasError) {
 		for(int i=0;i<ctx->search.nthreads-1;i++) {
 			ctx->workerList[i]->start.release();
