@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "stdint.h"
 #include <U2Core/MAlignment.h>
@@ -35,9 +46,9 @@ bool BowtieUrlReadsReader::isEnd() {
 	return !reader.hasNext();
 }
 
-U2::DNASequence BowtieUrlReadsReader::read() {
+U2::DNASequence *BowtieUrlReadsReader::read() {
     BowtieContext::getContext()->ti.progress = reader.getProgress();
-	return reader.getNextSequenceObject()->getDNASequence();
+	return reader.getNextSequenceObject();
 }
 
 /************************************************************************/
@@ -50,6 +61,10 @@ BowtieUrlReadsWriter::BowtieUrlReadsWriter(const U2::GUrl& resultFile, const QSt
 	//do nothing	
 }
 
+void BowtieUrlReadsWriter::setRefSeqLength(int refLength) {
+    seqWriter.setRefSeqLength(refLength);
+}
+
 void BowtieUrlReadsWriter::write(const U2::DNASequence& seq, int offset) {
 	seqWriter.writeNextAlignedRead(offset, seq);
 }
@@ -58,6 +73,65 @@ void BowtieUrlReadsWriter::close() {
 	seqWriter.close();
 }
 
+/************************************************************************/
+/* BowtieDbiReadsWriter                                                 */
+/************************************************************************/
+const qint64 BowtieDbiReadsWriter::readBunchSize = 10000;
+
+inline void checkOperationStatus(const U2::U2OpStatus &status) {
+    if (status.hasError()) {
+        throw status.getError();
+    }
+}
+
+BowtieDbiReadsWriter::BowtieDbiReadsWriter(const U2::GUrl& dbiFilePath, const QString& refName) {
+    //TODO: support several assemblies.
+    dbiHandle = QSharedPointer<U2::DbiHandle>(new U2::DbiHandle("SQLiteDbi", dbiFilePath.getURLString(), true, status));
+    checkOperationStatus(status);
+    sqliteDbi = dbiHandle->dbi;
+    wDbi = sqliteDbi->getAssemblyDbi();
+
+    sqliteDbi->getObjectDbi()->createFolder("/", status);
+    checkOperationStatus(status);
+    assembly.visualName = refName;
+    U2::U2AssemblyReadsImportInfo importInfo;
+    wDbi->createAssemblyObject(assembly, "/", NULL, importInfo, status);
+    checkOperationStatus(status);
+}
+
+void BowtieDbiReadsWriter::write(const U2::DNASequence& seq, int offset) {
+    U2::U2AssemblyRead read(new U2::U2AssemblyReadData());
+
+    read->name = seq.getName().toAscii();
+    read->leftmostPos = offset;
+    read->effectiveLen = seq.length();
+    read->readSequence = seq.constSequence();
+    read->quality = seq.hasQualityScores() ? seq.quality.qualCodes : "";
+    read->flags = U2::None;
+    read->cigar.append(U2::U2CigarToken(U2::U2CigarOp_M, seq.length()));
+
+    reads.append(read);
+    if (reads.size() >= readBunchSize) {
+        U2::BufferedDbiIterator<U2::U2AssemblyRead> readsIterator(reads);
+        wDbi->addReads(assembly.id, &readsIterator, status);
+        checkOperationStatus(status);
+        reads.clear();
+    }
+}
+
+void BowtieDbiReadsWriter::close() {
+    if (reads.size() > 0) {
+        U2::BufferedDbiIterator<U2::U2AssemblyRead> readsIterator(reads);
+        wDbi->addReads(assembly.id, &readsIterator, status);
+        checkOperationStatus(status);
+        reads.clear();
+    }
+
+    U2::U2AssemblyPackStat packStatus;
+    wDbi->pack(assembly.id, packStatus, status);
+    checkOperationStatus(status);
+}
+
 /************************************************************************/
 /* DNASequencesPatternSource                                            */
 /************************************************************************/
@@ -69,7 +143,7 @@ DNASequencesPatternSource::DNASequencesPatternSource( uint32_t seed, U2::BowtieR
 
 void DNASequencesPatternSource::nextReadImpl( ReadBuf& r, uint32_t& patid )
 {
-  U2::DNASequence dna;
+  U2::DNASequence *dna;
    
   {
     QMutexLocker lock(&mutex);
@@ -78,7 +152,7 @@ void DNASequencesPatternSource::nextReadImpl( ReadBuf& r, uint32_t& patid )
        return;
     }
     ++readCnt_;
-    dna = reader->read();
+    dna = new U2::DNASequence(*reader->read());
   }
        
   
@@ -88,8 +162,8 @@ void DNASequencesPatternSource::nextReadImpl( ReadBuf& r, uint32_t& patid )
   BowtieContext::Search* ctx = BowtieContext::getSearchContext();
   bool doquals = false; //TODO: quals
 
-  int nameLen = dna.getName().length();
-  strcpy(r.nameBuf, dna.getName().toAscii().constData());
+  int nameLen = dna->getName().length();
+  strcpy(r.nameBuf, dna->getName().toAscii().constData());
   _setBegin(r.name, r.nameBuf);
   _setLength(r.name, nameLen);
 
@@ -100,8 +174,8 @@ void DNASequencesPatternSource::nextReadImpl( ReadBuf& r, uint32_t& patid )
 	  _setLength(r.name, nameLen);
   }
 
-  const char* row = dna.seq.constData();
-  const int seqLen = dna.length();
+  const char* row = dna->seq.constData();
+  const int seqLen = dna->length();
   if(seqLen+1 > 1024) {
       tooManySeqChars(r.name);
   }
@@ -117,12 +191,12 @@ void DNASequencesPatternSource::nextReadImpl( ReadBuf& r, uint32_t& patid )
     r.patBufFw[i] = charToDna5[(int)c];
   }
   if(!doquals) {
-	  if(!dna.quality.isEmpty()) {
-		  switch(dna.quality.type) {
+	  if(!dna->quality.isEmpty()) {
+		  switch(dna->quality.type) {
 			  case U2::DnaQualityType_Solexa: 
-				  for(int i=0;i<seqLen;i++) r.qualBuf[i] = solexaToPhred(dna.quality.getValue(i)+33); break;
+				  for(int i=0;i<seqLen;i++) r.qualBuf[i] = solexaToPhred(dna->quality.getValue(i)+33); break;
 			  case U2::DNAQualityType_Sanger: 
-				  for(int i=0;i<seqLen;i++) r.qualBuf[i] = dna.quality.getValue(i)+33; break;
+				  for(int i=0;i<seqLen;i++) r.qualBuf[i] = dna->quality.getValue(i)+33; break;
 			  default: for(int i=0;i<seqLen;i++) r.qualBuf[i] = 'I';
 		  }
 	  } else {
