@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "BowtieConstants.h"
 #include "BowtiePlugin.h"
@@ -80,7 +91,7 @@ BowtiePlugin::BowtiePlugin() : Plugin(tr("Bowtie"),
     
     bool guiMode = AppContext::getMainWindow()!=NULL;
     DnaAssemblyGUIExtensionsFactory* guiFactory = guiMode ? new BWTGuiExtFactory(): NULL;
-    DnaAssemblyAlgorithmEnv* algo = new DnaAssemblyAlgorithmEnv(BowtieTask::taskName, new BowtieTask::Factory(), guiFactory, true);
+    DnaAssemblyAlgorithmEnv* algo = new DnaAssemblyAlgorithmEnv(BowtieBaseTask::taskName, new BowtieBaseTask::Factory(), guiFactory, true, false);
     bool res = registry->registerAlgorithm(algo);
     Q_UNUSED(res);
     assert(res);
@@ -92,10 +103,9 @@ BowtiePlugin::BowtiePlugin() : Plugin(tr("Bowtie"),
 
 BowtiePlugin::~BowtiePlugin() {
     DnaAssemblyAlgRegistry* registry = AppContext::getDnaAssemblyAlgRegistry();
-    DnaAssemblyAlgorithmEnv* algo = registry->unregisterAlgorithm(BowtieTask::taskName);
+    DnaAssemblyAlgorithmEnv* algo = registry->unregisterAlgorithm(BowtieBaseTask::taskName);
     assert(algo!=NULL);
     delete algo;
 }
 
 }//namespace
-
