@@ -1,13 +1,3 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #include "BowtieConstants.h"
 #include "BowtieAdapter.h"
 #include "BowtieIOAdapter.h"
@@ -1864,6 +1854,13 @@ static void driver(U2::BowtieReadsReader* reader,
 		ctx->startVerbose, // talkative during initialization
 		false /*passMemExc*/,
 		ctx->sanityCheck);
+        ctx->refLength = ebwt.plen()[0];
+        {
+            BowtieUrlReadsWriter *urlWriter = dynamic_cast<BowtieUrlReadsWriter *>(writer);
+            if(NULL != urlWriter) {
+                urlWriter->setRefSeqLength(ctx->refLength);
+            }
+        }
 	Ebwt<TStr>* ebwtBw = NULL;
 	// We need the mirror index if mismatches are allowed
 	if(ctx->mismatches > 0 || ctx->maqLike) {
