@@ -1,13 +1,3 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #ifndef PAT_H_
 #define PAT_H_
 
@@ -112,7 +102,7 @@ struct ReadBuf {
 	}
 
 #define RESET_BUF(str, buf, typ) _setBegin(str, (typ*)buf); _setLength(str, 0); _setCapacity(str, BUF_SIZE);
-#define RESET_BUF_LEN(str, buf, len, typ) _setBegin(str, (typ*)buf); _setLength(str, len); _setCapacity(str, BUF_SIZE);
+#define RESET_BUF_LEN(str, buf, length, typ) _setBegin(str, (typ*)buf); _setLength(str, length); _setCapacity(str, BUF_SIZE);
 
 	/// Point all Strings to the beginning of their respective buffers
 	/// and set all lengths to 0
