@@ -1,25 +1,34 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "BowtieConstants.h"
 #include "bowtieTests.h"
 
 #include <U2Core/LoadDocumentTask.h>
 #include <U2Core/SaveDocumentTask.h>
-
 #include <U2Core/DocumentModel.h>
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/AppContext.h>
 #include <U2Core/IOAdapter.h>
 #include <U2Core/Log.h>
-
 #include <U2Core/GObjectTypes.h>
 #include <U2Core/MAlignmentObject.h>
 #include <U2Core/DNASequenceObject.h>
@@ -28,11 +37,13 @@
 #include <U2Core/DNATranslation.h>
 #include <U2Core/AppContext.h>
 
+#include <U2Formats/SAMFormat.h>
+
+#include <U2View/DnaAssemblyUtils.h>
 
 #include <QtCore/QDir>
 #include <QtCore/QRegExp>
 
-#include <U2View/DnaAssemblyUtils.h>
 
 
 /* TRANSLATOR U2::GTest*/
@@ -56,6 +67,8 @@ namespace U2 {
 #define NORC_ATTR "norc"
 #define TRYHARD_ATTR "tryhard"
 #define FORMAT_ATTR "format"
+#define BEST_ATTR "best"
+#define ALL_ATTR "all"
 
 void GTest_Bowtie::init(XMLTestFormat *tf, const QDomElement& el) {
 	Q_UNUSED(tf);
@@ -200,10 +213,10 @@ void GTest_Bowtie::prepare() {
     
     config.shortReadUrls.append(readsFileUrl);
     config.refSeqUrl = GUrl(env->getVar("COMMON_DATA_DIR")+"/"+indexName);
-    config.setCustomValue(BowtieTask::OPTION_PREBUILT_INDEX, usePrebuildIndex);
+    config.prebuiltIndex = usePrebuildIndex;
     config.resultFileName = GUrl(tmpDataDir+"/"+QString::number(getTaskId()));
     config.algName = BOWTIE_ALG_NAME;
-    config.loadResultDocument = true;
+    config.openView = false;
     bowtieTask = new BowtieTask(config);
 
 	addSubTask(bowtieTask);
@@ -212,18 +225,27 @@ void GTest_Bowtie::prepare() {
 QList<Task*> GTest_Bowtie::onSubTaskFinished(Task* subTask) {
 	Q_UNUSED(subTask);
 	QList<Task*> res;
-	if (hasErrors() || subTask->hasErrors() || isCanceled()) {
+	if (hasError() || subTask->hasError() || isCanceled()) {
 		subTaskFailed = true;
 		return res;
 	}
 		
 	if(subTask == bowtieTask) {
-		if(bowtieTask->hasErrors()) {
+		if(bowtieTask->hasError()) {
 			subTaskFailed = true;
 			return res;
 		}
+        if (!bowtieTask->isHaveResult()) {
+            subTaskFailed = true;
+            bowtieTask->setError("Reference assembly failed - no possible alignment found");
+            return res;
+        }
         IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(config.resultFileName));
-        resultLoadTask = new LoadDocumentTask(BaseDocumentFormats::SAM, config.resultFileName,iof);
+        // SAM format is removed from supported formats list and supported only by BAM plugin
+        // Create it manually and provide to LoadDocumentTask
+        SAMFormat* samFormat = new SAMFormat();
+        resultLoadTask = new LoadDocumentTask(samFormat, config.resultFileName,iof);
+        samFormat->setParent(resultLoadTask);
         res << resultLoadTask;
 		
     }else if (subTask == resultLoadTask) {
@@ -238,12 +260,20 @@ QList<Task*> GTest_Bowtie::onSubTaskFinished(Task* subTask) {
 		
 		QFileInfo patternFile(env->getVar("COMMON_DATA_DIR")+"/"+patternFileName);
 		IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(patternFile.absoluteFilePath()));
-		patternLoadTask = new LoadDocumentTask(patternFormat, patternFile.absoluteFilePath(), iof);
+        if (patternFormat == BaseDocumentFormats::SAM) {
+            // SAM format is removed from supported formats list and supported only by BAM plugin
+            // Create it manually and provide to LoadDocumentTask
+            SAMFormat* samFormat = new SAMFormat();
+            patternLoadTask = new LoadDocumentTask(samFormat, patternFile.absoluteFilePath(), iof);
+            samFormat->setParent(patternLoadTask);
+        } else {
+		    patternLoadTask = new LoadDocumentTask(patternFormat, patternFile.absoluteFilePath(), iof);
+        }
 		patternLoadTask->setSubtaskProgressWeight(0);
 		res << patternLoadTask;
 
 	} else if(subTask == patternLoadTask) {
-		if(patternLoadTask->hasErrors()) {
+		if(patternLoadTask->hasError()) {
 			subTaskFailed = true;
 			return res;
 		}
