@@ -1,43 +1,43 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="en_US">
-<context>
-    <name>GB2::GorIVAlgTask</name>
-    <message>
-        <location filename="../src/GorIVAlgTask.cpp" line="10"/>
-        <source>GORIV</source>
-        <translation></translation>
-    </message>
-</context>
-<context>
-    <name>GB2::SecStructPredictPlugin</name>
-    <message>
-        <location filename="../src/GorIVPlugin.cpp" line="33"/>
-        <source>GORIV</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/GorIVPlugin.cpp" line="33"/>
-        <source>GORIV protein secondary structure prediction</source>
-        <translation></translation>
-    </message>
-</context>
 <context>
     <name>SecStructPredictTask</name>
     <message>
-        <location filename="../src/GorIVAlgTask.cpp" line="26"/>
+        <location filename="../src/GorIVAlgTask.cpp" line="27"/>
         <source>seq database not found</source>
         <translation>Sequence database not found</translation>
     </message>
     <message>
-        <location filename="../src/GorIVAlgTask.cpp" line="32"/>
+        <location filename="../src/GorIVAlgTask.cpp" line="33"/>
         <source>observed structures database not found</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/GorIVAlgTask.cpp" line="39"/>
+        <location filename="../src/GorIVAlgTask.cpp" line="40"/>
         <source>sequence is too long, max seq size is 10000</source>
         <translation>Too long input sequence: maximum allowed length is 10000</translation>
     </message>
 </context>
+<context>
+    <name>U2</name>
+    <message>
+        <location filename="../src/GorIVAlgTask.cpp" line="11"/>
+        <source>GORIV</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>U2::SecStructPredictPlugin</name>
+    <message>
+        <location filename="../src/GorIVPlugin.cpp" line="30"/>
+        <source>GORIV</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/GorIVPlugin.cpp" line="30"/>
+        <source>GORIV protein secondary structure prediction</source>
+        <translation></translation>
+    </message>
+</context>
 </TS>
