@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "HMMIO.h"
 #include "hmmer2/funcs.h"
@@ -353,7 +364,7 @@ void HMMIO::readHMM2(IOAdapterFactory* iof, const QString& url, TaskStateInfo& s
                 break;
             }
         }
-        if (si.hasErrors()) {
+        if (si.hasError()) {
             break;
         }
         // partial check for mandatory fields
@@ -494,7 +505,7 @@ void HMMIO::readHMM2(IOAdapterFactory* iof, const QString& url, TaskStateInfo& s
             hmm->end[k] = ascii2prob(s, 1.0);
 
         } // end loop over main model
-        if (si.hasErrors()) {
+        if (si.hasError()) {
             break;
         }
 
@@ -506,7 +517,7 @@ void HMMIO::readHMM2(IOAdapterFactory* iof, const QString& url, TaskStateInfo& s
                 break;
             }
         } while (strncmp(buffer, "//", 2) != 0);
-        if (si.hasErrors()) {
+        if (si.hasError()) {
             break;
         }
 
@@ -519,7 +530,7 @@ void HMMIO::readHMM2(IOAdapterFactory* iof, const QString& url, TaskStateInfo& s
     
     io->close();
     
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         if (hmm  != NULL) {
             FreePlan7(hmm);
         }
