@@ -1,13 +1,3 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #include "HMMBuildWorker.h"
 #include "HMMIOWorker.h"
 #include "HMMBuildDialogController.h"
@@ -17,9 +7,10 @@
 #include <U2Lang/IntegralBusModel.h>
 #include <U2Lang/WorkflowEnv.h>
 #include <U2Lang/ActorPrototypeRegistry.h>
-#include <U2Lang/CoreDataTypes.h>
-#include <U2Lang/BioDatatypes.h>
-#include <U2Lang/BioActorLibrary.h>
+#include <U2Lang/BaseTypes.h>
+#include <U2Lang/BaseSlots.h>
+#include <U2Lang/BasePorts.h>
+#include <U2Lang/BaseActorCategories.h>
 #include <U2Designer/DelegateEditors.h>
 #include <U2Lang/CoreLibConstants.h>
 
@@ -55,6 +46,8 @@ static const QString NUM_ATTR("samples-num");
 static const QString LENDEV_ATTR("deviation");
 static const QString SEED_ATTR("seed");
 
+static const QString HMM_PROFILE_DEFAULT_NAME("hmm_profile");
+
 static bool isDefaultCfg(PrompterBaseImpl* actor) {
     return int(P7_LS_CONFIG) == actor->getParameter(MODE_ATTR).toInt()
         && 5000 == actor->getParameter(NUM_ATTR).toInt()
@@ -67,12 +60,12 @@ static bool isDefaultCfg(PrompterBaseImpl* actor) {
 void HMMBuildWorkerFactory::init() {
     QList<PortDescriptor*> p; QList<Attribute*> a;
     {
-        Descriptor id(CoreLibConstants::IN_MSA_PORT_ID, HMMBuildWorker::tr("Input MSA"), 
+        Descriptor id(BasePorts::IN_MSA_PORT_ID(), HMMBuildWorker::tr("Input MSA"), 
             HMMBuildWorker::tr("Input multiple sequence alignment for building statistical model."));
         Descriptor od(OUT_HMM_PORT_ID, HMMBuildWorker::tr("HMM profile"), HMMBuildWorker::tr("Produced HMM profile"));
         
         QMap<Descriptor, DataTypePtr> inM;
-        inM[BioActorLibrary::MA_SLOT()] = BioDataTypes::MULTIPLE_ALIGNMENT_TYPE();
+        inM[BaseSlots::MULTIPLE_ALIGNMENT_SLOT()] = BaseTypes::MULTIPLE_ALIGNMENT_TYPE();
         p << new PortDescriptor(id, DataTypePtr(new MapDataType("hmm.build.in", inM)), true /*input*/);
         QMap<Descriptor, DataTypePtr> outM;
         outM[HMMLib::HMM2_SLOT] = HMMLib::HMM_PROFILE_TYPE();
@@ -108,15 +101,15 @@ void HMMBuildWorkerFactory::init() {
 //     lensd        = 200.;
 //     seed         = (int) time ((time_t *) NULL);
 
-    a << new Attribute(nad, CoreDataTypes::STRING_TYPE());
-    a << new Attribute(cad, CoreDataTypes::BOOL_TYPE(), false, QVariant(true));
-    a << new Attribute(mod, CoreDataTypes::NUM_TYPE(), false, QVariant(int(P7_LS_CONFIG)));
-    a << new Attribute(nud, CoreDataTypes::NUM_TYPE(), false, QVariant(5000));
-    a << new Attribute(sed, CoreDataTypes::NUM_TYPE(), false, QVariant(0));
-    a << new Attribute(fid, CoreDataTypes::NUM_TYPE(), false, QVariant(0));
-    a << new Attribute(lmd, CoreDataTypes::NUM_TYPE(), false, QVariant(325));
-    a << new Attribute(ldd, CoreDataTypes::NUM_TYPE(), false, QVariant(double(200)));
-    a << new Attribute(td, CoreDataTypes::NUM_TYPE(), false, QVariant(1));
+    a << new Attribute(nad, BaseTypes::STRING_TYPE(), false, QVariant(HMM_PROFILE_DEFAULT_NAME));
+    a << new Attribute(cad, BaseTypes::BOOL_TYPE(), false, QVariant(true));
+    a << new Attribute(mod, BaseTypes::NUM_TYPE(), false, QVariant(int(P7_LS_CONFIG)));
+    a << new Attribute(nud, BaseTypes::NUM_TYPE(), false, QVariant(5000));
+    a << new Attribute(sed, BaseTypes::NUM_TYPE(), false, QVariant(0));
+    a << new Attribute(fid, BaseTypes::NUM_TYPE(), false, QVariant(0));
+    a << new Attribute(lmd, BaseTypes::NUM_TYPE(), false, QVariant(325));
+    a << new Attribute(ldd, BaseTypes::NUM_TYPE(), false, QVariant(double(200)));
+    a << new Attribute(td, BaseTypes::NUM_TYPE(), false, QVariant(1));
 
     Descriptor desc(HMMBuildWorkerFactory::ACTOR, HMMBuildWorker::tr("HMM build"), HMMBuildWorker::tr("Builds a HMM profile from a multiple sequence alignment."
         "<p>The HMM profile is a statistical model which captures position-specific information"
@@ -175,8 +168,8 @@ void HMMBuildWorkerFactory::cleanup() {
  * HMMBuildPrompter
  ******************************/
 QString HMMBuildPrompter::composeRichDoc() {
-    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(CoreLibConstants::IN_MSA_PORT_ID));
-    Actor* msaProducer = input->getProducer(CoreLibConstants::IN_MSA_PORT_ID);
+    IntegralBusPort* input = qobject_cast<IntegralBusPort*>(target->getPort(BasePorts::IN_MSA_PORT_ID()));
+    Actor* msaProducer = input->getProducer(BasePorts::IN_MSA_PORT_ID());
 
     QString msaName = msaProducer ? tr("For each MSA from <u>%1</u>,").arg(msaProducer->getLabel()) : "";
 
@@ -201,7 +194,7 @@ HMMBuildWorker::HMMBuildWorker(Actor* a) : BaseWorker(a), input(NULL), output(NU
 }
 
 void HMMBuildWorker::init() {
-    input = ports.value(CoreLibConstants::IN_MSA_PORT_ID);
+    input = ports.value(BasePorts::IN_MSA_PORT_ID());
     output = ports.value(OUT_HMM_PORT_ID);
 }
 
@@ -224,8 +217,8 @@ Task* HMMBuildWorker::tick() {
         Message inputMessage = getMessageAndSetupScriptValues(input);
         cfg.name = actor->getParameter(NAME_ATTR)->getAttributeValue<QString>();
         if(cfg.name.isEmpty()){
-            cfg.name = "hmm_profile";
-            algoLog.error(tr("Value for attribute name is empty, '%1' used").arg(cfg.name));
+            cfg.name = HMM_PROFILE_DEFAULT_NAME;
+            algoLog.details(tr("Schema name not specified. Using default value: '%1'").arg(cfg.name));
         }
         cfg.strategy = HMMBuildStrategy(actor->getParameter(MODE_ATTR)->getAttributeValue<int>());
         calSettings.fixedlen = actor->getParameter(FIXEDLEN_ATTR)->getAttributeValue<int>();
@@ -235,7 +228,7 @@ Task* HMMBuildWorker::tick() {
         calSettings.seed = actor->getParameter(SEED_ATTR)->getAttributeValue<int>();
         calSettings.nThreads = actor->getParameter(THREADS_ATTR)->getAttributeValue<int>();
         calibrate = actor->getParameter(CALIBRATE_ATTR)->getAttributeValue<bool>();
-        const MAlignment& ma = inputMessage.getData().toMap().value(BioActorLibrary::MA_SLOT().getId()).value<MAlignment>();
+        const MAlignment& ma = inputMessage.getData().toMap().value(BaseSlots::MULTIPLE_ALIGNMENT_SLOT().getId()).value<MAlignment>();
         
         Task* t = new HMMBuildTask(cfg, ma);
         connect(new TaskSignalMapper(t), SIGNAL(si_taskFinished(Task*)), SLOT(sl_taskFinished(Task*)));
