@@ -1,13 +1,3 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #include "HMMCalibrateDialogController.h"
 
 #include "HMMCalibrateTask.h"
@@ -126,7 +116,7 @@ void HMMCalibrateDialogController::sl_onStateChanged() {
     }
     task->disconnect(this);
     const TaskStateInfo& si = task->getStateInfo();
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         statusLabel->setText(tr("calibration_finished_with_errors_%1").arg(si.getError()));
     } else if (task->isCanceled()) {
         statusLabel->setText(tr("calibration_canceled"));
