@@ -1,19 +1,9 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #ifndef _U2_HMMSEARCH_TASK_H_
 #define _U2_HMMSEARCH_TASK_H_
 
 #include "uhmmsearch.h"
 #include <QtCore/QMutex>
-#include <U2Core/LRegion.h>
+#include <U2Core/U2Region.h>
 #include <U2Core/Task.h>
 #include <U2Core/DNASequence.h>
 #include <U2Core/AnnotationData.h>
@@ -34,7 +24,7 @@ public:
     bool    onAmino;
     bool    borderResult;
     bool    filtered;
-    LRegion r;
+    U2Region r;
 
 };
 
