@@ -1,13 +1,3 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #include "HMMSearchWorker.h"
 #include "HMMIOWorker.h"
 #include "HMMSearchTask.h"
@@ -18,9 +8,10 @@
 #include <U2Lang/IntegralBusModel.h>
 #include <U2Lang/WorkflowEnv.h>
 #include <U2Lang/ActorPrototypeRegistry.h>
-#include <U2Lang/CoreDataTypes.h>
-#include <U2Lang/BioDatatypes.h>
-#include <U2Lang/BioActorLibrary.h>
+#include <U2Lang/BaseTypes.h>
+#include <U2Lang/BaseSlots.h>
+#include <U2Lang/BasePorts.h>
+#include <U2Lang/BaseActorCategories.h>
 #include <U2Designer/DelegateEditors.h>
 #include <U2Lang/CoreLibConstants.h>
 
@@ -57,19 +48,19 @@ void HMMSearchWorkerFactory::init() {
     QList<PortDescriptor*> p; QList<Attribute*> a;
     {
         Descriptor hd(HMM_PORT, HMMSearchWorker::tr("HMM profile"), HMMSearchWorker::tr("HMM profile(s) to search with."));
-        Descriptor sd(CoreLibConstants::IN_SEQ_PORT_ID, HMMSearchWorker::tr("Input sequence"), 
+        Descriptor sd(BasePorts::IN_SEQ_PORT_ID(), HMMSearchWorker::tr("Input sequence"), 
             HMMSearchWorker::tr("An input sequence (nucleotide or protein) to search in."));
-        Descriptor od(CoreLibConstants::OUT_ANNOTATIONS_PORT_ID, HMMSearchWorker::tr("HMM annotations"), 
+        Descriptor od(BasePorts::OUT_ANNOTATIONS_PORT_ID(), HMMSearchWorker::tr("HMM annotations"), 
             HMMSearchWorker::tr("Annotations marking found similar sequence regions."));
         
         QMap<Descriptor, DataTypePtr> hmmM;
         hmmM[HMMLib::HMM2_SLOT] = HMMLib::HMM_PROFILE_TYPE();
         p << new PortDescriptor(hd, DataTypePtr(new MapDataType("hmm.search.hmm", hmmM)), true /*input*/, false, IntegralBusPort::BLIND_INPUT);
         QMap<Descriptor, DataTypePtr> seqM;
-        seqM[BioActorLibrary::SEQ_SLOT()] = BioDataTypes::DNA_SEQUENCE_TYPE();
+        seqM[BaseSlots::DNA_SEQUENCE_SLOT()] = BaseTypes::DNA_SEQUENCE_TYPE();
         p << new PortDescriptor(sd, DataTypePtr(new MapDataType("hmm.search.sequence", seqM)), true /*input*/);
         QMap<Descriptor, DataTypePtr> outM;
-        outM[BioActorLibrary::FEATURE_TABLE_SLOT()] = BioDataTypes::ANNOTATION_TABLE_TYPE();
+        outM[BaseSlots::ANNOTATION_TABLE_SLOT()] = BaseTypes::ANNOTATION_TABLE_TYPE();
         p << new PortDescriptor(od, DataTypePtr(new MapDataType("hmm.search.out", outM)), false /*input*/, true);
     }
     
@@ -79,10 +70,10 @@ void HMMSearchWorkerFactory::init() {
         Descriptor ded(DOM_E_ATTR, HMMSearchWorker::tr("Filter by high E-value"), QApplication::translate("HMMSearchDialog", "results_evalue_cutoff_tip", 0, QApplication::UnicodeUTF8));
         Descriptor dtd(DOM_T_ATTR, HMMSearchWorker::tr("Filter by low score"), QApplication::translate("HMMSearchDialog", "results_score_cutoff_tip", 0, QApplication::UnicodeUTF8));
 
-        a << new Attribute(nd, CoreDataTypes::STRING_TYPE(), true, QVariant("hmm_signal"));
-        a << new Attribute(nsd, CoreDataTypes::NUM_TYPE(), false, QVariant(1));
-        a << new Attribute(ded, CoreDataTypes::NUM_TYPE(), false, QVariant(-1));
-        a << new Attribute(dtd, CoreDataTypes::NUM_TYPE(), false, QVariant((double)-1e+09));
+        a << new Attribute(nd, BaseTypes::STRING_TYPE(), true, QVariant("hmm_signal"));
+        a << new Attribute(nsd, BaseTypes::NUM_TYPE(), false, QVariant(1));
+        a << new Attribute(ded, BaseTypes::NUM_TYPE(), false, QVariant(-1));
+        a << new Attribute(dtd, BaseTypes::NUM_TYPE(), false, QVariant((double)-1e+09));
     }
  
     Descriptor desc(HMMSearchWorkerFactory::ACTOR, HMMSearchWorker::tr("HMM search"), 
@@ -125,12 +116,12 @@ static bool isDefaultCfg(PrompterBaseImpl* actor) {
  *******************************/
 QString HMMSearchPrompter::composeRichDoc() {
     Actor* hmmProducer = qobject_cast<IntegralBusPort*>(target->getPort(HMM_PORT))->getProducer(HMM_PORT);
-    Actor* seqProducer = qobject_cast<IntegralBusPort*>(target->getPort(CoreLibConstants::IN_SEQ_PORT_ID))->getProducer(CoreLibConstants::IN_SEQ_PORT_ID);
+    Actor* seqProducer = qobject_cast<IntegralBusPort*>(target->getPort(BasePorts::IN_SEQ_PORT_ID()))->getProducer(BasePorts::IN_SEQ_PORT_ID());
 
     QString seqName = seqProducer ? tr("For each sequence from <u>%1</u>,").arg(seqProducer->getLabel()) : "";
     QString hmmName = hmmProducer ? tr("using all profiles provided by <u>%1</u>,").arg(hmmProducer->getLabel()) : "";
 
-    QString resultName = getRequiredParam(NAME_ATTR);
+    QString resultName = getHyperlink(NAME_ATTR, getRequiredParam(NAME_ATTR));
     QString cfg = isDefaultCfg(this) ? tr("Use <u>default</u> settings.") : tr("Use <u>custom</u> settings.");
 
     QString doc = tr("%1 search HMM signals %2. %3"
@@ -151,17 +142,23 @@ HMMSearchWorker::HMMSearchWorker(Actor* a) : BaseWorker(a, false), hmmPort(NULL)
  
 void HMMSearchWorker::init() {
     hmmPort = ports.value(HMM_PORT);
-    seqPort = ports.value(CoreLibConstants::IN_SEQ_PORT_ID);
-    output = ports.value(CoreLibConstants::OUT_ANNOTATIONS_PORT_ID);
+    seqPort = ports.value(BasePorts::IN_SEQ_PORT_ID());
+    output = ports.value(BasePorts::OUT_ANNOTATIONS_PORT_ID());
     seqPort->addComplement(output);
     output->addComplement(seqPort);
 
-    cfg.domE = pow(10,(float) actor->getParameter(DOM_E_ATTR)->getAttributeValue<int>());
+    float domENum = actor->getParameter(DOM_E_ATTR)->getAttributeValue<int>();
+    if(domENum > 0) {
+        algoLog.details(tr("Power of e-value must be less or equal to zero. Using default value: 1e-1"));
+        domENum = -1;
+    }
+    cfg.domE = pow(10, domENum);
+    
     cfg.domT = (float)actor->getParameter(DOM_T_ATTR)->getAttributeValue<double>();
     cfg.eValueNSeqs = actor->getParameter(NSEQ_ATTR)->getAttributeValue<int>();
     resultName = actor->getParameter(NAME_ATTR)->getAttributeValue<QString>();
     if(resultName.isEmpty()){
-        algoLog.error(tr("Value for attribute name is empty, default name used"));
+        algoLog.details(tr("Value for attribute name is empty, default name used"));
         resultName = "hmm_signal";
     }
 }
@@ -171,11 +168,6 @@ bool HMMSearchWorker::isReady() {
 }
  
 Task* HMMSearchWorker::tick() {
-	if(cfg.domE < 1){
-		 algoLog.error(tr("Incorrect value: e-value must be greater then zero"));
-         cfg.domE = 1;
-	}
-    
     while (hmmPort->hasMessage()) {
         hmms << hmmPort->get().getData().toMap().value(HMMLib::HMM2_SLOT.getId()).value<plan7_s*>();
     }
@@ -184,7 +176,7 @@ Task* HMMSearchWorker::tick() {
         return NULL;
     }
     
-    DNASequence dnaSequence = seqPort->get().getData().toMap().value(BioActorLibrary::SEQ_SLOT().getId()).value<DNASequence>();
+    DNASequence dnaSequence = seqPort->get().getData().toMap().value(BaseSlots::DNA_SEQUENCE_SLOT().getId()).value<DNASequence>();
     if (dnaSequence.alphabet->getType() != DNAAlphabet_RAW) {
         QList<Task*> subtasks;
         foreach(plan7_s* hmm, hmms) {
@@ -215,7 +207,7 @@ void HMMSearchWorker::sl_taskFinished(Task* t) {
             list += hst->getResultsAsAnnotations(resultName);
         }
         QVariant v = qVariantFromValue<QList<SharedAnnotationData> >(list);
-        output->put(Message(BioDataTypes::ANNOTATION_TABLE_TYPE(), v));
+        output->put(Message(BaseTypes::ANNOTATION_TABLE_TYPE(), v));
         if (seqPort->isEnded()) {
             output->setEnded();
         }
