@@ -1,13 +1,3 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #include "uhmmsearch.h"
 #include <U2Core/Task.h>
 
@@ -140,7 +130,7 @@ QList<UHMMSearchResult> UHMMSearch::search(plan7_s* _hmm, const char* seq, int s
             continue;
         } else if (evalue <= thresh.domE && sc >= thresh.domT) {
             // hmm reports results in range [1...N] -> translate it to [0..N)
-            res.append(UHMMSearchResult(LRegion(sqfrom-1, sqto-sqfrom+1), sc, evalue));
+            res.append(UHMMSearchResult(U2Region(sqfrom-1, sqto-sqfrom+1), sc, evalue));
         }
     }
 
