@@ -1,22 +1,13 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #ifndef __UHMMSEARCH_OPT_H__
 #define __UHMMSEARCH_OPT_H__
 
+#include <QtCore/QVector>
+
 #include <hmmer2/config.h>
 #include <hmmer2/structs.h>
-#include <QtCore/QList>
 
 namespace U2 {
-    class LRegion;
+    class U2Region;
     class TaskStateInfo;
 }
 
@@ -25,7 +16,7 @@ struct HMMSeqGranulation {
     int overlap;
     int chunksize;
     int exOverlap;
-    QList<U2::LRegion> regions;
+    QVector<U2::U2Region> regions;
 };
 
 typedef QList<float> (*hmmScoringFunction)( unsigned char * dsq, int seqlen, plan7_s* hmm, HMMSeqGranulation * gr, U2::TaskStateInfo& ti );
