@@ -1,20 +1,35 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QByteArray>
 
 #include <U2Core/L10n.h>
 #include <U2Core/TextUtils.h>
+#include <U2Core/DNAAlphabet.h>
+#include <U2Core/AppContext.h>
 
 #include "uHMMFormatReader.h"
 
+#include <math.h>
+
 using namespace U2;
 
 const int BUF_SZ        = 1024;
@@ -42,30 +57,36 @@ enum HMMERHeaderTags {
     TC,
     NC,
     NULE, // in HMMER2 only
-    HMM
+    HMM,
+    BM,
+    SM
 }; // HMMERHeaderTags
 
 static QMap< QByteArray, HMMERHeaderTags > getHeaderTagsMap() {
-    QMap< QByteArray, HMMERHeaderTags > ret;
-    ret["NAME"]     = NAME;
-    ret["ACC"]      = ACC;
-    ret["DESC"]     = DESC;
-    ret["LENG"]     = LENG;
-    ret["ALPH"]     = ALPH;
-    ret["RF"]       = RF;
-    ret["CS"]       = CS;
-    ret["MAP"]      = MAP;
-    ret["DATE"]     = DATE;
-    ret["COM"]      = COM;
-    ret["NSEQ"]     = NSEQ;
-    ret["EFFN"]     = EFFN;
-    ret["CKSUM"]    = CKSUM;
-    ret["STATS"]    = STATS;
-    ret["GA"]       = GA;
-    ret["TC"]       = TC;
-    ret["NC"]       = NC;
-    ret["NULE"]     = NULE;
-    ret["HMM"]      = HMM;
+    static QMap< QByteArray, HMMERHeaderTags > ret;
+    if (ret.isEmpty()) {
+        ret["NAME"]     = NAME;
+        ret["ACC"]      = ACC;
+        ret["DESC"]     = DESC;
+        ret["LENG"]     = LENG;
+        ret["ALPH"]     = ALPH;
+        ret["RF"]       = RF;
+        ret["CS"]       = CS;
+        ret["MAP"]      = MAP;
+        ret["DATE"]     = DATE;
+        ret["COM"]      = COM;
+        ret["NSEQ"]     = NSEQ;
+        ret["EFFN"]     = EFFN;
+        ret["CKSUM"]    = CKSUM;
+        ret["STATS"]    = STATS;
+        ret["GA"]       = GA;
+        ret["TC"]       = TC;
+        ret["NC"]       = NC;
+        ret["NULE"]     = NULE;
+        ret["HMM"]      = HMM;
+        ret["BM"]       = BM;
+        ret["SM"]       = SM;
+    }
     return ret;
 }
 
@@ -97,13 +118,18 @@ static void getTagValue( const QByteArray& ln, QByteArray& tag, QByteArray& val
     QStringList words = line.split( QRegExp( "\\s+" ), QString::SkipEmptyParts );
     
     if( 1 >= words.size() ) {
-        throw UHMMFormatReader::UHMMFormatReaderException( UHMMFormatReader::tr( "bad_line_in_header_section:%1" ).arg( QString( ln ) ) );
+        if( words.size() == 1 && getHeaderTagsMap().value(words.at(0).toAscii(), BAD_TAG) == NAME ) {
+            tag = words.at(0).toAscii();
+            val = "hmm_profile";
+        } else {
+            throw UHMMFormatReader::UHMMFormatReaderException(UHMMFormatReader::tr("bad_line_in_header_section:%1").arg(QString(ln)));
+        }
     } else {
         tag = words.first().toAscii();
         val = ln.mid( tag.size() ).trimmed();
         assert( !tag.isEmpty() );
         if( val.isEmpty() ) {
-            throw UHMMFormatReader::UHMMFormatReaderException( UHMMFormatReader::tr( "no_value_found_in_line:%1" ).arg( QString(ln) ) );
+            throw UHMMFormatReader::UHMMFormatReaderException(UHMMFormatReader::tr("Empty value in header line:%1").arg(QString(ln)));
         }
     }
 }
@@ -131,7 +157,11 @@ static void setFloat( float& num, const QByteArray& numStr ) {
 }
 
 static void set2Floats( float& f1, float& f2, const QByteArray& str ) {
-    QString line( str );
+    QString line(str.trimmed());
+    if (line.endsWith(";"))  { //PFAM compatibility fix
+        line = line.mid(0, line.length()-1);
+    }
+
     QStringList words = line.split( QRegExp( "\\s+" ), QString::SkipEmptyParts );
 
     if( 2 != words.size() ) {
@@ -308,7 +338,7 @@ const QString UHMMFormatReader::HMMER2_VERSION_HEADER           = "HMMER2";
 const QString UHMMFormatReader::HMMER3_VERSION_HEADER           = "HMMER3";
 
 UHMMFormatReader::UHMMFormatReader( IOAdapter * i, TaskStateInfo & tsi ) : io( i ), ti( tsi ) {
-    if( ti.hasErrors() || ti.cancelFlag ) {
+    if( ti.hasError() || ti.cancelFlag ) {
         return;
     }
     
@@ -330,7 +360,7 @@ UHMMFormatReader::HMMER_VERSIONS UHMMFormatReader::getVersion( const QByteArray
 }
 
 P7_HMM * UHMMFormatReader::getNextHmm() {
-    if( ti.hasErrors() || ti.cancelFlag ) {
+    if( ti.hasError() || ti.cancelFlag ) {
         return NULL;
     }
     
@@ -462,6 +492,10 @@ P7_HMM * UHMMFormatReader::readHMMER3ASCII() {
             case HMM:
                 isHeaderSection = false;
                 continue;
+            case BM:
+            case SM:
+                //TODO: update HMMER and start use these fields too
+                break;
             case BAD_TAG:
                 throw UHMMFormatReader::UHMMFormatReaderException(
                     UHMMFormatReader::tr( "unrecognized_tag_in_header_section:%1" ).arg( QString(tagStr) ) );
@@ -596,7 +630,7 @@ P7_HMM * UHMMFormatReader::readHMMER3ASCII() {
     }
     esl_alphabet_Destroy( abc );
     
-    if( ti.hasErrors() ) {
+    if( ti.hasError() ) {
         p7_hmm_Destroy( hmm );
         return NULL;
     }
@@ -628,6 +662,7 @@ P7_HMM * UHMMFormatReader::readHMMER2ASCII() {
         */
         QMap< QByteArray, HMMERHeaderTags > headerTagsMap = getHeaderTagsMap();
         bool isHeaderSection = true;
+        bool triedToSetAlph = false;
         int tagsNum = 0;
         while( isHeaderSection && ++tagsNum < MAX_HMM_HEADER_TAGS  ) {
             QByteArray line;
@@ -658,12 +693,15 @@ P7_HMM * UHMMFormatReader::readHMMER2ASCII() {
                 break;
             case ALPH:
                 {
-                    int abcType = esl_abc_EncodeType( valueStr.data() );
-                    if( eslUNKNOWN == abcType ) {
-                        throw UHMMFormatReader::UHMMFormatReaderException(
-                            tr( "unrecognized_alphabet_type:%1\n" ).arg( QString(valueStr) ) );
+                    triedToSetAlph = true;
+                    if(valueStr.toLower() != "nucleic") { // try to encode abc in hmm section
+                        int abcType = esl_abc_EncodeType( valueStr.data() );
+                        if( eslUNKNOWN == abcType ) {
+                            throw UHMMFormatReader::UHMMFormatReaderException(
+                                tr( "unrecognized_alphabet_type:%1\n" ).arg( QString(valueStr) ) );
+                        }
+                        abc = esl_alphabet_Create( abcType );
                     }
-                    abc = esl_alphabet_Create( abcType );
                 }
                 break;
             case RF:
@@ -701,21 +739,42 @@ P7_HMM * UHMMFormatReader::readHMMER2ASCII() {
                 break;
             case NULE:
                 {
-                    if( NULL == abc ) {
+                    int K = 0;
+                    if( !triedToSetAlph) {
                         throw UHMMFormatReaderException( tr( "ALPH must precede NULE in HMMER2 save files" ) );
+                    } else if(abc != NULL){
+                        K = abc->K;
+                    } else {
+                        K = 4; // because it is dna or rna
                     }
-                    assert( eslUNKNOWN != abc->type );
                     
                     getNextToken( tokens ); // skip NULE word
-                    for (x = 0; x < abc->K; x++) {
+                    for (x = 0; x < K; x++) {
                         QByteArray curToken = getNextToken( tokens );
                         assert( 1 <= curToken.size() );
-                        null[x] = h2ascii2prob( curToken, 1.0/(float)abc->K );
+                        null[x] = h2ascii2prob( curToken, 1.0/(float)K );
                     }
                 }
                 break;
             case HMM:
-                isHeaderSection = false;
+                {
+                    if(abc == NULL) {
+                        if(!triedToSetAlph) {
+                            throw UHMMFormatReaderException(tr("ALPH section must precede HMM"));
+                        } else {
+                            QString val(valueStr);
+                            DNAAlphabet* al = AppContext::getDNAAlphabetRegistry()->findAlphabet(val.remove(QRegExp("\\s+")).toAscii());
+                            if(al == NULL || !al->isNucleic()) {
+                                throw UHMMFormatReaderException(tr("Unknown alphabet"));
+                            } else {
+                                int abcT = al->getId() == BaseDNAAlphabetIds::NUCL_DNA_DEFAULT() ||
+                                    al->getId() == BaseDNAAlphabetIds::NUCL_DNA_EXTENDED() ? eslDNA : eslRNA;;
+                                abc = esl_alphabet_Create(abcT);
+                            }
+                        }
+                    }
+                    isHeaderSection = false;
+                }
                 continue;
             default:
                 continue;
@@ -852,7 +911,7 @@ P7_HMM * UHMMFormatReader::readHMMER2ASCII() {
     p7_bg_Destroy(bg);
     esl_alphabet_Destroy( abc );
     
-    if( ti.hasErrors() ) {
+    if( ti.hasError() ) {
         p7_hmm_Destroy( hmm );
         return NULL;
     }
