@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QMutexLocker>
 
@@ -31,7 +42,6 @@ using namespace U2;
 
 namespace U2 {
 
-static Logger log( UHMM3_PHMMER_LOG_CAT );
 
 static int countPhmmerMemInMB( qint64 dbLen, int queryLen ) {
     assert( 0 < dbLen && 0 < queryLen );
@@ -108,8 +118,8 @@ void UHMM3PhmmerTask::addMemResource() {
     assert( !db.isNull() && !query.isNull() );
     
     int howManyMem = countPhmmerMemInMB( db.length(), query.length() );
-    taskResources.append( TaskResourceUsage( RESOURCE_MEMORY, howManyMem ) );
-    log.trace( QString( "%1 needs %2 of memory" ).arg( getTaskName() ).arg( howManyMem ) );
+    addTaskResource(TaskResourceUsage( RESOURCE_MEMORY, howManyMem ));
+    algoLog.trace( QString( "%1 requires %2 of memory" ).arg( getTaskName() ).arg( howManyMem ) );
 }
 
 DNASequence UHMM3PhmmerTask::getSequenceFromDocument( Document * doc, TaskStateInfo & ti ) {
@@ -141,23 +151,23 @@ QList< Task* > UHMM3PhmmerTask::onSubTaskFinished( Task* subTask ) {
     QMutexLocker locker( &loadTasksMtx );
     QList< Task* > ret;
     assert( NULL != subTask );
-    if( hasErrors() ) {
+    if( hasError() ) {
         return ret;
     }
-    if( subTask->hasErrors() ) {
+    if( subTask->hasError() ) {
         stateInfo.setError( subTask->getError() );
         return ret;
     }
     
     if( loadQueryTask == subTask ) {
         query = getSequenceFromDocument( loadQueryTask->getDocument(), stateInfo );
-        if( hasErrors() ) {
+        if( hasError() ) {
             stateInfo.setError( getError() + tr( "query sequence" ) );
         }
         loadQueryTask = NULL;
     } else if( loadDbTask == subTask ) {
         db = getSequenceFromDocument( loadDbTask->getDocument(), stateInfo );
-        if( hasErrors() ) {
+        if( hasError() ) {
             stateInfo.setError( getError() + tr( "db sequence" ) );
         }
         loadDbTask = NULL;
@@ -183,10 +193,9 @@ QList< SharedAnnotationData > UHMM3PhmmerTask::getResultsAsAnnotations( const QS
         AnnotationData * annData = new AnnotationData();
         
         annData->name = name;
-        annData->complement = false;
-        annData->aminoFrame = TriState_No;
-        annData->location << domain.seqRegion;
-        annData->qualifiers << Qualifier( "Query sequence", query.getName() );
+        annData->setStrand(U2Strand::Direct);
+        annData->location->regions << domain.seqRegion;
+        annData->qualifiers << U2Qualifier( "Query sequence", query.getName() );
         domain.writeQualifiersToAnnotation( annData );
         
         annotations << SharedAnnotationData( annData );
@@ -196,7 +205,7 @@ QList< SharedAnnotationData > UHMM3PhmmerTask::getResultsAsAnnotations( const QS
 }
 
 void UHMM3PhmmerTask::run() {
-    if( hasErrors() ) {
+    if( hasError() ) {
         return;
     }
     
@@ -235,14 +244,14 @@ UHMM3SWPhmmerTask::UHMM3SWPhmmerTask(const QString & qF, const DNASequence & db,
 QList<Task*> UHMM3SWPhmmerTask::onSubTaskFinished(Task* subTask) {
     assert(subTask != NULL);
     QList<Task*> res;
-    if( subTask->hasErrors() ) {
+    if( subTask->hasError() ) {
         stateInfo.setError(subTask->getError());
         return res;
     }
     
     if( loadQueryTask == subTask ) {
         querySeq = UHMM3PhmmerTask::getSequenceFromDocument( loadQueryTask->getDocument(), stateInfo );
-        if( hasErrors() ) {
+        if( hasError() ) {
             setError(getError() + tr( "querySeq sequence" ));
         }
         swTask = getSWSubtask();
@@ -254,7 +263,7 @@ QList<Task*> UHMM3SWPhmmerTask::onSubTaskFinished(Task* subTask) {
 }
 
 void UHMM3SWPhmmerTask::checkAlphabets() {
-    assert(!hasErrors());
+    assert(!hasError());
     if(dbSeq.alphabet->isRaw()) {
         setError(tr("Invalid db sequence alphabet: %1").arg(dbSeq.alphabet->getName()));
         return;
@@ -266,7 +275,7 @@ void UHMM3SWPhmmerTask::checkAlphabets() {
 }
 
 void UHMM3SWPhmmerTask::setTranslations() {
-    assert(!hasErrors());
+    assert(!hasError());
     if(dbSeq.alphabet->isNucleic()) {
         DNATranslationRegistry* transReg = AppContext::getDNATranslationRegistry();
         assert( NULL != transReg );
@@ -290,15 +299,15 @@ void UHMM3SWPhmmerTask::setTranslations() {
 }
 
 SequenceWalkerTask * UHMM3SWPhmmerTask::getSWSubtask() {
-    assert(!hasErrors());
+    assert(!hasError());
     assert(querySeq.length());
     
     checkAlphabets();
-    if(hasErrors()) {
+    if(hasError()) {
         return NULL;
     }
     setTranslations();
-    if(hasErrors()) {
+    if(hasError()) {
         return NULL;
     }
     
@@ -319,22 +328,21 @@ SequenceWalkerTask * UHMM3SWPhmmerTask::getSWSubtask() {
 
 void UHMM3SWPhmmerTask::onRegion(SequenceWalkerSubtask * t, TaskStateInfo & ti) {
     assert(t != NULL);
-    if(hasErrors() || ti.hasErrors() || isCanceled() || ti.cancelFlag) {
+    if(hasError() || ti.hasError() || isCanceled() || ti.cancelFlag) {
         return;
     }
     
     const char * seq    = t->getRegionSequence();
     int seqLen          = t->getRegionSequenceLen();
-    bool isCompl        = t->isDNAComplemented();
     bool isAmino        = t->isAminoTranslated();
-    LRegion globalRegion = t->getGlobalRegion();
+    U2Region globalRegion = t->getGlobalRegion();
     
     UHMM3SearchTaskLocalStorage::createTaskContext( t->getTaskId() );
     int wholeSeqSz = t->getGlobalConfig().seqSize;
     wholeSeqSz = isAmino ? (wholeSeqSz / 3) : wholeSeqSz;
     UHMM3SearchResult generalRes = UHMM3Phmmer::phmmer(querySeq.seq.constData(), querySeq.length(), 
                                                        seq, seqLen, settings, stateInfo, wholeSeqSz);
-    if( ti.hasErrors() ) {
+    if( ti.hasError() ) {
         UHMM3SearchTaskLocalStorage::freeTaskContext( t->getTaskId() );
         return;
     }
@@ -345,7 +353,7 @@ void UHMM3SWPhmmerTask::onRegion(SequenceWalkerSubtask * t, TaskStateInfo & ti)
 }
 
 Task::ReportResult UHMM3SWPhmmerTask::report() {
-    if(hasErrors()) {
+    if(hasError()) {
         return ReportResult_Finished;
     }
     UHMM3SWSearchTask::processOverlaps(overlaps, results, querySeq.length() / 2);
@@ -358,7 +366,7 @@ QList<TaskResourceUsage> UHMM3SWPhmmerTask::getResources(SequenceWalkerSubtask *
     QList<TaskResourceUsage> res;
     int howManyMem = countPhmmerMemInMB( dbSeq.length(), querySeq.length() );
     res << TaskResourceUsage( RESOURCE_MEMORY, howManyMem );
-    log.trace( QString( "%1 needs %2 of memory" ).arg( getTaskName() ).arg( howManyMem ) );
+    algoLog.trace( QString( "%1 requires %2 of memory" ).arg( getTaskName() ).arg( howManyMem ) );
     return res;
 }
 
@@ -369,10 +377,9 @@ UHMM3SWPhmmerTask::getResultsAsAnnotations( const QString & name ) const {
     foreach( const UHMM3SWSearchTaskDomainResult & res, results ) {
         AnnotationData * annData = new AnnotationData();
         annData->name = name;
-        annData->complement = res.onCompl;
-        annData->aminoFrame = res.onAmino ? TriState_Yes :TriState_No;
-        annData->location << res.generalResult.seqRegion;
-        annData->qualifiers << Qualifier( "Query sequence", querySeq.getName() );
+        annData->setStrand(res.onCompl ? U2Strand::Complementary : U2Strand::Direct);
+        annData->location->regions << res.generalResult.seqRegion;
+        annData->qualifiers << U2Qualifier( "Query sequence", querySeq.getName() );
         res.generalResult.writeQualifiersToAnnotation( annData );
         annotations << SharedAnnotationData( annData );
     }
@@ -417,7 +424,7 @@ queryfile( qfile ), dbSeq( db ), annotationObj( o ), annGroup( gr ), annName( na
 phmmerTask( NULL ), createAnnotationsTask( NULL ) {
     
     checkArgs();
-    if( hasErrors() ) {
+    if( hasError() ) {
         return;
     }
     setTaskName( tr( "HMM Phmmer search %1 sequence with %2 database" ).arg( queryfile ).arg( dbSeq.getName() ) );
@@ -428,10 +435,10 @@ phmmerTask( NULL ), createAnnotationsTask( NULL ) {
 QList< Task* > UHMM3PhmmerToAnnotationsTask::onSubTaskFinished( Task * subTask ) {
     assert( NULL != subTask );
     QList< Task* > res;
-    if( hasErrors() ) {
+    if( hasError() ) {
         return res;
     }
-    if( subTask->hasErrors() ) {
+    if( subTask->hasError() ) {
         stateInfo.setError( subTask->getError() );
         return res;
     }
@@ -460,7 +467,7 @@ QString UHMM3PhmmerToAnnotationsTask::generateReport() const {
     res += "<table>";
     res+="<tr><td width=200><b>" + tr("Query sequence") + "</b></td><td>" + QFileInfo( queryfile ).absoluteFilePath() + "</td></tr>";
     
-    if( hasErrors() || isCanceled() ) {
+    if( hasError() || isCanceled() ) {
         res += "<tr><td width=200><b>" + tr("Task was not finished") + "</b></td><td></td></tr>";
         res += "</table>";
         return res;
