@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QByteArray>
 
@@ -33,8 +44,6 @@ using namespace U2;
 
 namespace U2 {
 
-static Logger log( UHMM3_SEARCH_LOG_CAT );
-
 static int countSearchMemInMB( qint64 seqLen, int hmmLen ) {
     return ( ( 77 * seqLen + 10500 * hmmLen ) / ( 1024 * 1024 ) ) + 2;
 }
@@ -43,18 +52,18 @@ static int countSearchMemInMB( qint64 seqLen, int hmmLen ) {
 * UHMM3SWSearchTask
 *****************************************************/
 
-static void recountRegion( LRegion& region, bool isAmino, bool isCompl, LRegion globalR ) {
-    int len = isAmino? region.len * 3 : region.len;
+static void recountRegion( U2Region& region, bool isAmino, bool isCompl, U2Region globalR ) {
+    int len = isAmino? region.length * 3 : region.length;
     int start = isAmino? region.startPos * 3 : region.startPos;
 
     if( isCompl ) {
-        start = globalR.len - start - len;
+        start = globalR.length - start - len;
     }
     region.startPos = globalR.startPos + start;
-    region.len = len;
+    region.length = len;
 }
 
-static void recountUHMM3SWSearchRegions( UHMM3SearchSeqDomainResult& res, bool isAmino, bool isCompl, LRegion globalR ) {
+static void recountUHMM3SWSearchRegions( UHMM3SearchSeqDomainResult& res, bool isAmino, bool isCompl, U2Region globalR ) {
     recountRegion( res.seqRegion, isAmino, isCompl, globalR );
     recountRegion( res.envRegion, isAmino, isCompl, globalR );
 }
@@ -98,17 +107,17 @@ UHMM3SWSearchTask::UHMM3SWSearchTask( const QString& hF, const DNASequence& seq,
 }
 
 SequenceWalkerTask* UHMM3SWSearchTask::getSWSubtask() {
-    assert( !hasErrors() );
+    assert( !hasError() );
     assert( NULL != hmm );
     
     bool ok = checkAlphabets( hmm->abc->type, sequence.alphabet );
     if( !ok ) {
-        assert( hasErrors() );
+        assert( hasError() );
         return NULL;
     }
     ok = setTranslations( hmm->abc->type, sequence.alphabet );
     if( !ok ) {
-        assert( hasErrors() );
+        assert( hasError() );
         return NULL;
     }
     
@@ -129,14 +138,14 @@ SequenceWalkerTask* UHMM3SWSearchTask::getSWSubtask() {
 }
 
 void UHMM3SWSearchTask::prepare() {
-    if( hasErrors() ) {
+    if( hasError() ) {
         return;
     }
     
     if( NULL != hmm ) {
         swTask = getSWSubtask();
         if( NULL == swTask ) {
-            assert( hasErrors() );
+            assert( hasError() );
             return;
         }
         addSubTask( swTask );
@@ -151,7 +160,7 @@ void UHMM3SWSearchTask::prepare() {
 QList< Task* > UHMM3SWSearchTask::onSubTaskFinished( Task* subTask ) {
     assert( NULL != subTask );
     QList< Task* > res;
-    if( subTask->hasErrors() ) {
+    if( subTask->hasError() ) {
         stateInfo.setError(subTask->getError());
         return res;
     }
@@ -160,7 +169,7 @@ QList< Task* > UHMM3SWSearchTask::onSubTaskFinished( Task* subTask ) {
         hmm = UHMM3Utilities::getHmmFromDocument( loadHmmTask->getDocument(), stateInfo );
         swTask = getSWSubtask();
         if( NULL == swTask ) {
-            assert( hasErrors() );
+            assert( hasError() );
             return res;
         }
         res << swTask;
@@ -175,7 +184,7 @@ QList< Task* > UHMM3SWSearchTask::onSubTaskFinished( Task* subTask ) {
 
 void UHMM3SWSearchTask::onRegion( SequenceWalkerSubtask* t, TaskStateInfo& ti ) {
     assert( NULL != t );
-    if( stateInfo.hasErrors() || ti.hasErrors() ) {
+    if( stateInfo.hasError() || ti.hasError() ) {
         return;
     }
     
@@ -186,7 +195,7 @@ void UHMM3SWSearchTask::onRegion( SequenceWalkerSubtask* t, TaskStateInfo& ti )
     int wholeSeqSz = t->getGlobalConfig().seqSize;
     wholeSeqSz = t->isAminoTranslated() ? (wholeSeqSz / 3) : wholeSeqSz;
     UHMM3SearchResult generalRes = UHMM3Search::search( hmm, seq, seqLen, settings.inner, ti, wholeSeqSz );
-    if( ti.hasErrors() ) {
+    if( ti.hasError() ) {
         UHMM3SearchTaskLocalStorage::freeTaskContext( t->getTaskId() );
         return;
     }
@@ -200,7 +209,7 @@ void UHMM3SWSearchTask::writeResults(const QList<UHMM3SearchSeqDomainResult> & d
         QList<UHMM3SWSearchTaskDomainResult> & results, QList<UHMM3SWSearchTaskDomainResult> & overlaps, int halfOverlap) {
     bool isCompl     = t->isDNAComplemented();
     bool isAmino    = t->isAminoTranslated();
-    LRegion globalRegion = t->getGlobalRegion();
+    U2Region globalRegion = t->getGlobalRegion();
     foreach( const UHMM3SearchSeqDomainResult& domainRes, domains ) {
         UHMM3SWSearchTaskDomainResult res;
         res.generalResult = domainRes;
@@ -210,10 +219,10 @@ void UHMM3SWSearchTask::writeResults(const QList<UHMM3SearchSeqDomainResult> & d
         if(t->intersectsWithOverlaps(res.generalResult.seqRegion)) {
             bool add = true;
             if(!res.onCompl && t->hasRightOverlap()) { // if it will be found in a next chunk
-                    LRegion nextChunkRegion(globalRegion.endPos() - halfOverlap, halfOverlap);
+                    U2Region nextChunkRegion(globalRegion.endPos() - halfOverlap, halfOverlap);
                     add = !nextChunkRegion.contains(res.generalResult.seqRegion);
             } else if(res.onCompl && t->hasLeftOverlap()) { // if it will be found on prev chunk
-                LRegion prevChunkRegion(globalRegion.startPos, halfOverlap);
+                U2Region prevChunkRegion(globalRegion.startPos, halfOverlap);
                 add = !prevChunkRegion.contains(res.generalResult.seqRegion);
             }
             if(add) {
@@ -234,7 +243,7 @@ QList< TaskResourceUsage > UHMM3SWSearchTask::getResources( SequenceWalkerSubtas
     QList< TaskResourceUsage > res;
     int howManyMem = countSearchMemInMB( t->getRegionSequenceLen(), hmm->M );
     res << TaskResourceUsage( RESOURCE_MEMORY, howManyMem );
-    log.trace( QString( "%1 needs %2 of memory" ).arg( getTaskName() ).arg( howManyMem ) );
+    algoLog.trace( QString( "%1 requires %2 of memory" ).arg( getTaskName() ).arg( howManyMem ) );
     return res;
 }
 
@@ -269,7 +278,7 @@ UHMM3SWSearchTask::processOverlaps(QList<UHMM3SWSearchTaskDomainResult> & overla
                 r2.generalResult.seqRegion != r1.generalResult.seqRegion) {
                     r1.filtered = true;
                     break;
-            } else if (r1.generalResult.seqRegion.intersect(r2.generalResult.seqRegion).len >= maxCommonLen) {
+            } else if (r1.generalResult.seqRegion.intersect(r2.generalResult.seqRegion).length >= maxCommonLen) {
                 bool useR1 = r2.generalResult.score <= r1.generalResult.score;
                 if (r1.generalResult.score == r2.generalResult.score && r1.generalResult.ival == r2.generalResult.ival
                     && r1.borderResult && !r2.borderResult) {
@@ -307,7 +316,7 @@ UHMM3SWSearchTask::uhmm3SearchDomainResultLessThan(const UHMM3SWSearchTaskDomain
 }
 
 Task::ReportResult UHMM3SWSearchTask::report() {
-    if(hasErrors()) {
+    if(hasError()) {
         return ReportResult_Finished;
     }
     processOverlaps(overlaps, results, hmm->M / 2);
@@ -316,7 +325,7 @@ Task::ReportResult UHMM3SWSearchTask::report() {
 }
 
 bool UHMM3SWSearchTask::checkAlphabets( int hmmAl, DNAAlphabet* seqAl ) {
-    assert( !hasErrors() );
+    assert( !hasError() );
     assert( NULL != seqAl );
     assert( 0 <= hmmAl );
     
@@ -339,7 +348,7 @@ bool UHMM3SWSearchTask::checkAlphabets( int hmmAl, DNAAlphabet* seqAl ) {
 }
 
 bool UHMM3SWSearchTask::setTranslations( int hmmAl, DNAAlphabet* seqAl ) {
-    assert( !hasErrors() );
+    assert( !hasError() );
     assert( NULL != seqAl );
     assert( 0 <= hmmAl );
     
@@ -378,9 +387,8 @@ UHMM3SWSearchTask::getResultsAsAnnotations( const QList<UHMM3SWSearchTaskDomainR
     foreach( const UHMM3SWSearchTaskDomainResult & res, results ) {
         AnnotationData * annData = new AnnotationData();
         annData->name = name;
-        annData->complement = res.onCompl;
-        annData->aminoFrame = res.onAmino ? TriState_Yes :TriState_No;
-        annData->location << res.generalResult.seqRegion;
+        annData->setStrand(res.onCompl ? U2Strand::Complementary : U2Strand::Direct);
+        annData->location->regions << res.generalResult.seqRegion;
         
         assert( NULL != hmm );
         QString hmmInfo = hmm->name;
@@ -391,7 +399,7 @@ UHMM3SWSearchTask::getResultsAsAnnotations( const QList<UHMM3SWSearchTaskDomainR
             hmmInfo += QString().sprintf( "\n Description: %s", hmm->desc );
         }
         assert( !hmmInfo.isEmpty() );
-        annData->qualifiers << Qualifier( "HMM model", hmmInfo );
+        annData->qualifiers << U2Qualifier( "HMM model", hmmInfo );
         res.generalResult.writeQualifiersToAnnotation( annData );
         
         annotations << SharedAnnotationData( annData );
@@ -416,88 +424,73 @@ UHMM3SearchTaskSettings::UHMM3SearchTaskSettings() {
 * UHMM3SearchTask
 *****************************************************/
 
-UHMM3SearchTask::UHMM3SearchTask( const UHMM3SearchTaskSettings& s, P7_HMM* h, const char* se, int l )
-: Task( "", TaskFlag_None ), settings( s ), hmm( h ), seq( se ), seqLen( l ) {
-    if( NULL == hmm ) {
-        setTaskName( tr( "HMM search task" ) );
-        stateInfo.setError( tr( "no_hmm_given" ) );
-        return;
-    }
-    assert( NULL != hmm->name );
-    setTaskName( tr( "HMM search with '%1'" ).arg( hmm->name ) );
-    
-    if( NULL == seq || ( 0 >= seqLen ) ) {
-        stateInfo.setError( tr( "empty_sequence_given" ) );
-        return;
-    }
-    
-    addMemResource();
+UHMM3SearchTask::UHMM3SearchTask(const UHMM3SearchTaskSettings &_settings, P7_HMM *_hmmProfile, const QByteArray &_sequence)
+        : Task(tr("HMM search task"), TaskFlag_None),
+          settings(_settings), hmmProfile(_hmmProfile), sequence(_sequence)
+{
+    assert(hmmProfile && "Bad HMM profile given");
+    assert(hmmProfile->name);
+
+    setTaskName(tr("HMM search with '%1'").arg(hmmProfile->name));
 }
 
-UHMM3SearchTask::UHMM3SearchTask( const UHMM3SearchTaskSettings& s, const QString& hf, const char* se, int l )
-: Task( "", TaskFlag_None ), settings( s ), hmm( NULL ), seq( se ), seqLen( l ) {
-    const QString& hmmFilename = hf;
-    if( hmmFilename.isEmpty() ) {
-        setTaskName( tr( "HMM search task" ) );
-        stateInfo.setError( tr( "no_hmm_file_given" ) );
-        return;
-    }
-    setTaskName( tr( "HMM search with '%1' file" ).arg( hmmFilename ) );
-    
-    if( NULL == seq || ( 0 >= seqLen ) ) {
-        stateInfo.setError( tr( "empty_sequence_given" ) );
-        return;
-    }
-    
-    IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById( BaseIOAdapters::url2io( hmmFilename ) );
-    assert( NULL != iof );
-    
-    loadHmmTask = new LoadDocumentTask( UHMMFormat::UHHMER_FORMAT_ID, hmmFilename, iof, QVariantMap() );
-    addSubTask( loadHmmTask );
+void UHMM3SearchTask::prepare() {
+    assert(hmmProfile->M > 0);
+
+    int howManyMem = countSearchMemInMB(sequence.length(), hmmProfile->M);
+    addTaskResource(TaskResourceUsage(RESOURCE_MEMORY, howManyMem));
+
+    algoLog.trace(QString("%1 needs %2 of memory").arg(getTaskName()).arg(howManyMem));
 }
 
-void UHMM3SearchTask::addMemResource() {
-    assert( 0 < seqLen && NULL != hmm && 0 < hmm->M );
-    
-    int howManyMem = countSearchMemInMB( seqLen, hmm->M );
-    taskResources.append( TaskResourceUsage( RESOURCE_MEMORY, howManyMem ) );
-    log.trace( QString( "%1 needs %2 of memory" ).arg( getTaskName() ).arg( howManyMem ) );
-}
-
-QList< Task* > UHMM3SearchTask::onSubTaskFinished( Task* subTask ) {
-    assert( NULL != subTask );
-    QList< Task* > res;
-    if( subTask->hasErrors() || subTask->isCanceled() ) {
-        stateInfo.setError( subTask->getError() );
-        return res;
-    }
-    
-    if( loadHmmTask == subTask ) {
-        hmm = UHMM3Utilities::getHmmFromDocument( loadHmmTask->getDocument(), stateInfo );
-        if( NULL != hmm ) {
-            addMemResource();
-        }
-    } else {
-        assert( 0 && "undefined_subtask_finished" );
-    }
-    return res;
-}
-
-UHMM3SearchResult UHMM3SearchTask::getResult() const {
-    return result;
-}
-
-void UHMM3SearchTask::run() {
-    if( stateInfo.hasErrors() ) {
-        return;
-    }
-    assert( NULL != hmm );
-    
+void UHMM3SearchTask::run() {   
     UHMM3SearchTaskLocalStorage::createTaskContext( getTaskId() );
-    result = UHMM3Search::search( hmm, seq, seqLen, settings.inner, stateInfo, seqLen );
+    result = UHMM3Search::search(hmmProfile, sequence.data(), sequence.length(), settings.inner, stateInfo, sequence.length());
     UHMM3SearchTaskLocalStorage::freeTaskContext( getTaskId() );
 }
 
+/*****************************************************
+* UHMM3LoadProfileAndSearchTask
+*****************************************************/
+
+UHMM3LoadProfileAndSearchTask::UHMM3LoadProfileAndSearchTask(const UHMM3SearchTaskSettings &_settings, const QString &_hmmProfileFile, const QByteArray &_sequence)
+        : Task(tr("HMM search with '%1' HMM profile file").arg(_hmmProfileFile), TaskFlags_NR_FOSCOE),
+          loadHmmProfileTask(0), hmmSearchTask(0),
+          hmmProfile(0), settings(_settings), sequence(_sequence)
+{
+    IOAdapterFactory *iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(_hmmProfileFile));
+    assert(iof);
+
+    loadHmmProfileTask = new LoadDocumentTask(UHMMFormat::UHHMER_FORMAT_ID, _hmmProfileFile, iof);
+    addSubTask(loadHmmProfileTask);
+}
+
+QList<Task*> UHMM3LoadProfileAndSearchTask::onSubTaskFinished(Task* subTask) {
+    QList<Task*> subTasks;
+
+    propagateSubtaskError();
+    if(subTask->hasError() || subTask->isCanceled()) {
+        return subTasks;
+    }
+
+    if (loadHmmProfileTask == subTask) {
+        hmmProfile = UHMM3Utilities::getHmmFromDocument(loadHmmProfileTask->getDocument(), stateInfo);
+        assert(hmmProfile && "Bad HMM profile");
+
+        hmmSearchTask = new UHMM3SearchTask(settings, hmmProfile, sequence);
+        subTasks << hmmSearchTask;
+    }
+    else if (hmmSearchTask == subTask) {
+        // pass
+    }
+    else {
+        assert(!"Undefined task");
+    }
+
+    return subTasks;
+}
+
+
 /*****************************************************
 * UHMM3SWSearchToAnnotationsTask
 *****************************************************/
@@ -533,7 +526,7 @@ loadSequenceTask( NULL ), searchTask( NULL ), createAnnotationsTask( NULL ) {
     if( sequence.isNull() ) {
         stateInfo.setError( L10N::badArgument( tr("dna sequence" ) ) );
     }
-    if( stateInfo.hasErrors() ) {
+    if( stateInfo.hasError() ) {
         return;
     }
     setTaskName( tr( "HMMER3 search task with '%1' profile" ).arg( hmmfile ) );
@@ -555,7 +548,7 @@ loadSequenceTask( NULL ), searchTask( NULL ), createAnnotationsTask( NULL ) {
     if( seqFile.isEmpty() ) {
         stateInfo.setError( L10N::badArgument( tr( "Sequence file" ) ) );
     }
-    if( stateInfo.hasErrors() ) {
+    if( stateInfo.hasError() ) {
         return;
     }
     setTaskName( tr( "HMMER3 search task with '%1' profile" ).arg( hmmfile ) );
@@ -574,7 +567,7 @@ QString UHMM3SWSearchToAnnotationsTask::generateReport() const {
     res += "<table>";
     res+="<tr><td width=200><b>" + tr("HMM profile used") + "</b></td><td>" + QFileInfo( hmmfile ).absoluteFilePath() + "</td></tr>";
     
-    if( hasErrors() || isCanceled() ) {
+    if( hasError() || isCanceled() ) {
         res += "<tr><td width=200><b>" + tr("Task was not finished") + "</b></td><td></td></tr>";
         res += "</table>";
         return res;
@@ -619,11 +612,11 @@ void UHMM3SWSearchToAnnotationsTask::setSequence() {
 QList< Task* > UHMM3SWSearchToAnnotationsTask::onSubTaskFinished( Task * subTask ) {
     QMutexLocker locker( &mtx );
     QList< Task* > res;
-    if( hasErrors() ) {
+    if( hasError() ) {
         return res;
     }
     assert( NULL != subTask );
-    if( subTask->hasErrors() ) {
+    if( subTask->hasError() ) {
         stateInfo.setError( subTask->getError() );
         return res;
     }
@@ -635,7 +628,7 @@ QList< Task* > UHMM3SWSearchToAnnotationsTask::onSubTaskFinished( Task * subTask
     
     if( loadSequenceTask == subTask ) {
         setSequence();
-        if( hasErrors() ) {
+        if( hasError() ) {
             return res;
         }
         searchTask = new UHMM3SWSearchTask( hmmfile, sequence, searchSettings );
