@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _GB2_UHMM3_SEARCH_TASK_H_
 #define _GB2_UHMM3_SEARCH_TASK_H_
@@ -38,29 +49,51 @@ public:
 
 class UHMM3SearchTask : public Task {
     Q_OBJECT
+
 public:
-    UHMM3SearchTask( const UHMM3SearchTaskSettings& settings, P7_HMM* hmm, const char* seq, int seqLen );
-    UHMM3SearchTask( const UHMM3SearchTaskSettings& settings, const QString& hmmFilename, const char* seq, int sqLen );
+    UHMM3SearchTask(const UHMM3SearchTaskSettings &settings, P7_HMM *hmmProfile, const QByteArray &sequence);
     
-    void run();
-    
-    QList< Task* > onSubTaskFinished( Task* subTask );
-    
-    UHMM3SearchResult getResult() const;
+    virtual void prepare();
+    virtual void run();
+
+    UHMM3SearchResult getResult() const {
+        assert(isFinished());
+        return result;
+    }
 
-private:
-    void addMemResource();
-    
 private:
     UHMM3SearchTaskSettings settings;
-    P7_HMM*                 hmm;
-    const char*             seq;
-    int                     seqLen;
+    P7_HMM                  *hmmProfile;
+    QByteArray              sequence;
     UHMM3SearchResult       result;
-    LoadDocumentTask*       loadHmmTask;
-    
+
 }; // UHMM3SearchTask
 
+class UHMM3LoadProfileAndSearchTask : public Task {
+    Q_OBJECT
+
+public:
+    UHMM3LoadProfileAndSearchTask(const UHMM3SearchTaskSettings &settings, const QString &hmmProfileFile, const QByteArray &sequence);
+
+    UHMM3SearchResult getResult() const {
+        assert(isFinished());
+        return hmmSearchTask->getResult();
+    }
+
+protected:
+    virtual QList<Task*> onSubTaskFinished(Task *subTask);
+
+private:
+    LoadDocumentTask        *loadHmmProfileTask;
+    UHMM3SearchTask         *hmmSearchTask;
+
+    P7_HMM                  *hmmProfile;
+    UHMM3SearchTaskSettings settings;
+    QByteArray              sequence;
+
+}; // UHMM3LoadProfileAndSearchTask
+
+
 /**************************************
 * Sequence walker version of hmmer3 search task.
 **************************************/
