@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <math.h>
 #include <cassert>
@@ -26,9 +37,9 @@ static UHMM3SearchSeqDomainResult getDomainRes( const P7_HIT* hit, int dom, cons
     res.bias        = domain.dombias;
     res.ival        = domain.pvalue * pli->Z;
     res.cval        = domain.pvalue * pli->domZ;
-    res.queryRegion = LRegion( domain.ad->hmmfrom, domain.ad->hmmto - domain.ad->hmmfrom );
-    res.seqRegion   = LRegion( domain.ad->sqfrom - 1, domain.ad->sqto - domain.ad->sqfrom + 1 );
-    res.envRegion   = LRegion( domain.ienv, domain.jenv - domain.ienv );
+    res.queryRegion = U2Region( domain.ad->hmmfrom, domain.ad->hmmto - domain.ad->hmmfrom );
+    res.seqRegion   = U2Region( domain.ad->sqfrom - 1, domain.ad->sqto - domain.ad->sqfrom + 1 );
+    res.envRegion   = U2Region( domain.ienv, domain.jenv - domain.ienv );
     res.acc         = domain.oasc / ( 1.0 + fabs( (float)( domain.jenv - domain.ienv ) ) );
     return res;
 }
@@ -37,13 +48,13 @@ namespace U2 {
 
 void UHMM3SearchSeqDomainResult::writeQualifiersToAnnotation( AnnotationData * annData ) const {
     assert( NULL != annData );
-    annData->qualifiers << Qualifier( "Independent e-value", QString().sprintf( "%.5e", ival ) );
-    annData->qualifiers << Qualifier( "Conditional e-value", QString().sprintf( "%.5e", cval ) );
-    annData->qualifiers << Qualifier( "Score", QString().sprintf( "%1.f", score ) );
-    annData->qualifiers << Qualifier( "Bias", QString().sprintf( "%.5e", bias ) );
-    annData->qualifiers << Qualifier( "Accuracy per residue", QString().sprintf( "%.5e", acc ) );
-    annData->qualifiers << Qualifier( "HMM region", QString().sprintf( "%d...%d", queryRegion.startPos, queryRegion.endPos()) );
-    annData->qualifiers << Qualifier( "Envelope of domain location", QString().sprintf( "%d...%d", 
+    annData->qualifiers << U2Qualifier( "Independent e-value", QString().sprintf( "%.5e", ival ) );
+    annData->qualifiers << U2Qualifier( "Conditional e-value", QString().sprintf( "%.5e", cval ) );
+    annData->qualifiers << U2Qualifier( "Score", QString().sprintf( "%1.f", score ) );
+    annData->qualifiers << U2Qualifier( "Bias", QString().sprintf( "%.5e", bias ) );
+    annData->qualifiers << U2Qualifier( "Accuracy per residue", QString().sprintf( "%.5e", acc ) );
+    annData->qualifiers << U2Qualifier( "HMM region", QString().sprintf( "%d...%d", queryRegion.startPos, queryRegion.endPos()) );
+    annData->qualifiers << U2Qualifier( "Envelope of domain location", QString().sprintf( "%d...%d", 
         envRegion.startPos, envRegion.endPos() ) );
 }
 
