@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <memory>
 
@@ -210,7 +221,7 @@ void GTest_UHMMER3Build::setBuildSettings( UHMM3BuildSettings & settings, const
 }
 
 void GTest_UHMMER3Build::setAndCheckArgs() {
-    if( hasErrors() ) {
+    if( hasError() ) {
         return;
     }
 
@@ -232,7 +243,7 @@ void GTest_UHMMER3Build::setAndCheckArgs() {
 
 void GTest_UHMMER3Build::prepare() {
     setAndCheckArgs();
-    if( hasErrors() ) {
+    if( hasError() ) {
         return;
     }
 
@@ -241,7 +252,7 @@ void GTest_UHMMER3Build::prepare() {
 }
 
 Task::ReportResult GTest_UHMMER3Build::report() {
-    if( buildTask->hasErrors() ) {
+    if( buildTask->hasError() ) {
         if( delOutFile ) {
             QFile::remove( outFile );
         }
@@ -348,9 +359,9 @@ static bool compareStr( const QString& s1, const QString& s2 ) {
 }
 
 Task::ReportResult GTest_CompareHmmFiles::report() {
-    assert( !hasErrors() );
+    assert( !hasError() );
     setAndCheckArgs();
-    if( hasErrors() ) {
+    if( hasError() ) {
         return ReportResult_Finished;
     }
 
