@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "uhmmer3SearchTests.h"
 #include <gobject/uHMMObject.h>
@@ -53,7 +64,7 @@ const QString GTest_UHMM3Search::SEED_OPTION_TAG             = "seed";
 const QString GTest_UHMM3Search::REMOTE_MACHINE_VAR          = "MACHINE";
 
 static void setDoubleOption( double& num, const QDomElement& el, const QString& optionName, TaskStateInfo& si ) {
-    if( si.hasErrors() ) {
+    if( si.hasError() ) {
         return;
     }
     QString numStr = el.attribute( optionName );
@@ -71,7 +82,7 @@ static void setDoubleOption( double& num, const QDomElement& el, const QString&
 }
 
 static void setUseBitCutoffsOption( int& ret, const QDomElement& el, const QString& opName, TaskStateInfo& si ) {
-    if( si.hasErrors() ) {
+    if( si.hasError() ) {
         return;
     }
 
@@ -89,7 +100,7 @@ static void setUseBitCutoffsOption( int& ret, const QDomElement& el, const QStri
 }
 
 static void setBooleanOption( int& ret, const QDomElement& el, const QString& opName, TaskStateInfo& si ) {
-    if( si.hasErrors() ) {
+    if( si.hasError() ) {
         return;
     }
     QString str = el.attribute( opName ).toLower();
@@ -102,7 +113,7 @@ static void setBooleanOption( int& ret, const QDomElement& el, const QString& op
 }
 
 static void setIntegerOption( int& num, const QDomElement& el, const QString& optionName, TaskStateInfo& si ) {
-    if( si.hasErrors() ) {
+    if( si.hasError() ) {
         return;
     }
     QString numStr = el.attribute( optionName );
@@ -199,7 +210,7 @@ void GTest_UHMM3Search::init( XMLTestFormat *tf, const QDomElement& el ) {
 }
 
 void GTest_UHMM3Search::setAndCheckArgs() {
-    assert( !stateInfo.hasErrors() );
+    assert( !stateInfo.hasError() );
     if( hmmFilename.isEmpty() ) {
         stateInfo.setError( "hmm_filename_is_empty" );
         return;
@@ -248,15 +259,15 @@ void GTest_UHMM3Search::setAndCheckArgs() {
 }
 
 void GTest_UHMM3Search::prepare() {
-    assert( !hasErrors() );
+    assert( !hasError() );
     setAndCheckArgs();
-    if( hasErrors() ) {
+    if( hasError() ) {
         return;
     }
 
     switch( algo ) {
     case GENERAL_SEARCH:
-        searchTaskToCtx = new UHMM3SearchTask( settings, hmmFilename, sequence.seq.data(), sequence.seq.size() );
+        searchTaskToCtx = new UHMM3LoadProfileAndSearchTask(settings, hmmFilename, sequence.seq);
         addSubTask( searchTaskToCtx );
         break;
     case SEQUENCE_WALKER_SEARCH:
@@ -279,7 +290,7 @@ QList< Task* > GTest_UHMM3Search::onSubTaskFinished( Task * sub ) {
     if( NULL == loadHmmTask ) {
         return res;
     }
-    if( loadHmmTask->hasErrors() ) {
+    if( loadHmmTask->hasError() ) {
         setError( loadHmmTask->getError() );
         return res;
     }
@@ -290,11 +301,11 @@ QList< Task* > GTest_UHMM3Search::onSubTaskFinished( Task * sub ) {
 }
 
 Task::ReportResult GTest_UHMM3Search::report() {
-    if( stateInfo.hasErrors() ) {
+    if( stateInfo.hasError() ) {
         return ReportResult_Finished;
     }
     assert( NULL != searchTaskToCtx );
-    if( !searchTaskToCtx->hasErrors() && !searchTaskToCtx->isCanceled() ) {
+    if( !searchTaskToCtx->hasError() && !searchTaskToCtx->isCanceled() ) {
         addContext( searchTaskCtxName, searchTaskToCtx );
         ctxAdded = true;
     }
@@ -395,17 +406,17 @@ static UHMM3SearchSeqDomainResult getDomainRes( QStringList& tokens ) {
 
     int hmmFrom = (int)getFloat( getNextToken( tokens ) );
     int hmmTo   = (int)getFloat( getNextToken( tokens ) );
-    res.queryRegion = LRegion( hmmFrom, hmmTo - hmmFrom );
+    res.queryRegion = U2Region( hmmFrom, hmmTo - hmmFrom );
     getNextToken( tokens );
 
     int aliFrom = (int)getFloat( getNextToken( tokens ) );
     int aliTo   = (int)getFloat( getNextToken( tokens ) );
-    res.seqRegion = LRegion( aliFrom - 1, aliTo - aliFrom + 1 );
+    res.seqRegion = U2Region( aliFrom - 1, aliTo - aliFrom + 1 );
     getNextToken( tokens );
 
     int envFrom = (int)getFloat( getNextToken( tokens ) );
     int envTo   = (int)getFloat( getNextToken( tokens ) );
-    res.envRegion = LRegion( envFrom, envTo - envFrom );
+    res.envRegion = U2Region( envFrom, envTo - envFrom );
     getNextToken( tokens );
 
     res.acc = getDouble( getNextToken( tokens ) );
@@ -487,18 +498,18 @@ void GTest_UHMM3SearchCompare::generalCompareResults( const UHMM3SearchResult& m
         }
         if( myCurDom.envRegion != trueCurDom.envRegion ) { 
             ti.setError( QString( "dom_env_region_not_matched: %1---%2 and %3---%4" ).
-                arg( myCurDom.envRegion.startPos ).arg( myCurDom.envRegion.len ).arg( trueCurDom.envRegion.startPos ).
-                arg( trueCurDom.envRegion.len ) ); return;
+                arg( myCurDom.envRegion.startPos ).arg( myCurDom.envRegion.length ).arg( trueCurDom.envRegion.startPos ).
+                arg( trueCurDom.envRegion.length ) ); return;
         }
         if( myCurDom.queryRegion != trueCurDom.queryRegion ) { 
             ti.setError( QString( "dom_hmm_region_not_matched: %1---%2 and %3---%4" ).
-                arg( myCurDom.queryRegion.startPos ).arg( myCurDom.queryRegion.len ).arg( trueCurDom.queryRegion.startPos ).
-                arg( trueCurDom.queryRegion.len ) ); return;
+                arg( myCurDom.queryRegion.startPos ).arg( myCurDom.queryRegion.length ).arg( trueCurDom.queryRegion.startPos ).
+                arg( trueCurDom.queryRegion.length ) ); return;
         }
         if( myCurDom.seqRegion != trueCurDom.seqRegion ) {
             ti.setError( QString( "dom_seq_region_not_matched: %1---%2 and %3---%4" ).
-                arg( myCurDom.seqRegion.startPos ).arg( myCurDom.seqRegion.len ).arg( trueCurDom.seqRegion.startPos ).
-                arg( trueCurDom.seqRegion.len ) ); return;
+                arg( myCurDom.seqRegion.startPos ).arg( myCurDom.seqRegion.length ).arg( trueCurDom.seqRegion.startPos ).
+                arg( trueCurDom.seqRegion.length ) ); return;
         }
         if( myCurDom.isSignificant != trueCurDom.isSignificant ) { 
             ti.setError( QString( "dom_sign_not_matched: %1 and %2" ).arg( myCurDom.isSignificant ).arg( trueCurDom.isSignificant ) );
@@ -580,7 +591,7 @@ void GTest_UHMM3SearchCompare::init( XMLTestFormat *tf, const QDomElement& el )
 }
 
 void GTest_UHMM3SearchCompare::setAndCheckArgs() {
-    assert( !hasErrors() );
+    assert( !hasError() );
 
     if( searchTaskCtxName.isEmpty() ) {
         stateInfo.setError( "search_task_ctx_name_is_empty" );
@@ -599,7 +610,7 @@ void GTest_UHMM3SearchCompare::setAndCheckArgs() {
         return;
     }
     
-    generalTask = qobject_cast< UHMM3SearchTask*    >( searchTask );
+    generalTask = qobject_cast< UHMM3LoadProfileAndSearchTask* >( searchTask );
     swTask      = qobject_cast< UHMM3SWSearchTask*  >( searchTask );
     
     if( NULL != generalTask ) {
@@ -696,9 +707,9 @@ UHMM3SearchResult GTest_UHMM3SearchCompare::getOriginalSearchResult( const QStri
 }
 
 Task::ReportResult GTest_UHMM3SearchCompare::report() {
-    assert( !hasErrors() );
+    assert( !hasError() );
     setAndCheckArgs();
-    if( hasErrors() ) {
+    if( hasError() ) {
         return ReportResult_Finished;
     }
     
@@ -711,7 +722,7 @@ Task::ReportResult GTest_UHMM3SearchCompare::report() {
         stateInfo.setError( "undefined_error_occurred" );
     }
 
-    if( hasErrors() ) {
+    if( hasError() ) {
         return ReportResult_Finished;
     }
 
