@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "KalignTests.h"
 #include "KalignTask.h"
@@ -113,13 +124,13 @@ MAlignment Kalign_Load_Align_Compare_Task::dna_to_ma(QList<GObject*> dnaSeqs) {
 QList<Task*> Kalign_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
     Q_UNUSED(subTask);
     QList<Task*> res;
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return res;
     }
 
     if (subTask == loadTask1) {
         Document *doc = loadTask1->getDocument();
-        if(loadTask1->hasErrors()) {
+        if(loadTask1->hasError()) {
             return res;
         }
         assert(doc!=NULL);
@@ -132,7 +143,7 @@ QList<Task*> Kalign_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
         }
 
         const MAlignment &mailgn = dna_to_ma(list);
-        if(hasErrors()) {
+        if(hasError()) {
             return res;
         }
 
@@ -148,7 +159,7 @@ QList<Task*> Kalign_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
         this->connect(kalignTask,SIGNAL(si_progressChanged()),SLOT(sl_kalignProgressChg()));
     }
     else if (subTask == kalignTask) {
-        if(kalignTask->hasErrors()) {
+        if(kalignTask->hasError()) {
             setError( kalignTask->getError() );
             return res;
         }
@@ -157,11 +168,11 @@ QList<Task*> Kalign_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
         ma1->setMAlignment( localKalign->resultMA );
     }
     else if (subTask == loadTask2) {
-        if (loadTask2->hasErrors()) {
+        if (loadTask2->hasError()) {
             return res;
         }
         Document *doc = loadTask2->getDocument();
-        if(loadTask2->hasErrors()) {
+        if(loadTask2->hasError()) {
             return res;
         }
         assert(doc!=NULL);
@@ -174,7 +185,7 @@ QList<Task*> Kalign_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
         }
 
         const MAlignment &mailgn = dna_to_ma(list);
-        if(hasErrors()) {
+        if(hasError()) {
             return res;
         }
 
@@ -223,7 +234,7 @@ void Kalign_Load_Align_Compare_Task::cleanup() {
 
 Task::ReportResult Kalign_Load_Align_Compare_Task::report() {
     propagateSubtaskError();
-    if(hasErrors()) {
+    if(hasError()) {
         stateInfo.setError(  QString("input file \"%1\", pattern file \"%2\":\n").arg(str_inFileURL).arg(str_patFileURL) + stateInfo.getError() );
     }
     return ReportResult_Finished;
@@ -363,13 +374,13 @@ MAlignment GTest_Kalign_Load_Align_QScore::dna_to_ma(QList<GObject*> dnaSeqs) {
 QList<Task*> GTest_Kalign_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
     Q_UNUSED(subTask);
     QList<Task*> res;
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return res;
     }
 
     if (subTask == loadTask1) {
         Document *doc = loadTask1->getDocument();
-        if(loadTask1->hasErrors()) {
+        if(loadTask1->hasError()) {
             return res;
         }
         assert(doc!=NULL);
@@ -382,7 +393,7 @@ QList<Task*> GTest_Kalign_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
         }
 
         const MAlignment &mailgn = dna_to_ma(list);
-        if(hasErrors()) {
+        if(hasError()) {
             return res;
         }
 
@@ -398,7 +409,7 @@ QList<Task*> GTest_Kalign_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
         this->connect(kalignTask,SIGNAL(si_progressChanged()),SLOT(sl_kalignProgressChg()));
     }
     else if (subTask == kalignTask) {
-        if(kalignTask->hasErrors()) {
+        if(kalignTask->hasError()) {
             setError( kalignTask->getError() );
             return res;
         }
@@ -407,11 +418,11 @@ QList<Task*> GTest_Kalign_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
         ma1->setMAlignment( localKalign->resultMA );
     }
     else if (subTask == loadTask2) {
-        if (loadTask2->hasErrors()) {
+        if (loadTask2->hasError()) {
             return res;
         }
         Document *doc = loadTask2->getDocument();
-        if(loadTask2->hasErrors()) {
+        if(loadTask2->hasError()) {
             return res;
         }
         assert(doc!=NULL);
@@ -424,7 +435,7 @@ QList<Task*> GTest_Kalign_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
         }
 
         const MAlignment &mailgn = dna_to_ma(list);
-        if(hasErrors()) {
+        if(hasError()) {
             return res;
         }
 
@@ -440,7 +451,7 @@ QList<Task*> GTest_Kalign_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
 
 void GTest_Kalign_Load_Align_QScore::run() {
     double qscore = QScore(ma1->getMAlignment(), ma2->getMAlignment(), stateInfo);
-    if (stateInfo.hasErrors()) {
+    if (stateInfo.hasError()) {
         return;
     }
 
