@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "PhylipPlugin.h"
 #include "PhylipPluginTests.h"
@@ -50,6 +61,13 @@ void GTest_NeighborJoin::init(XMLTestFormat *tf, const QDomElement& el) {
         return;
     }
     resultCtxName = el.attribute("sample");
+    QString bootstrSeed;
+    bootstrSeed = el.attribute("bootstrapSeed");
+    if(bootstrSeed == NULL){
+        bootStrapSeed = -1;
+    }else{
+        bootStrapSeed = bootstrSeed.toInt();
+    }
 }
 
 void GTest_NeighborJoin::prepare() {
@@ -101,7 +119,7 @@ void GTest_NeighborJoin::prepare() {
 	treeObjFromDoc = qobject_cast<PhyTreeObject*>(obj2);
 	
 	if(treeObjFromDoc == NULL){
-		stateInfo.setError(  QString("error can't cast to philogenetic tree from GObject") );
+		stateInfo.setError(  QString("error can't cast to phylogenetic tree from GObject") );
 		return;
 	}
 	assert( obj != NULL);
@@ -109,12 +127,19 @@ void GTest_NeighborJoin::prepare() {
     CreatePhyTreeSettings settings;
     settings.algorithmId = PhylipPlugin::PHYLIP_NEIGHBOUR_JOIN;
 
+    if(bootStrapSeed != -1){
+        settings.bootstrap = true;
+        settings.seed = bootStrapSeed;
+        settings.consensusID =  "Majority Rule (extended)";
+        settings.replicates = 100;
+    }
+
     task = new PhyTreeGeneratorTask(input->getMAlignment(), settings);
     addSubTask(task);
 }
 
 Task::ReportResult GTest_NeighborJoin::report() {
-    if (!task->hasErrors()) {
+    if (!task->hasError()) {
         const PhyTree computedTree = task->getResult();
         const PhyTree& treeFromDoc = treeObjFromDoc->getTree(); 
         bool same = PhyTreeObject::treesAreAlike(computedTree, treeFromDoc);
