@@ -1,13 +1,3 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 //#include "phylip.h"
 //#include "seq.h"
 #include "dnadist.h"
@@ -103,7 +93,7 @@ void getoptions()
   progress = true;
   interleaved = true;
   loopcount = 0;
-  
+
   QString matrixModel = getDNADistSettings().matrixId;
   if (matrixModel == DNADistModelTypes::F84) {
       f84 = true;
@@ -111,12 +101,16 @@ void getoptions()
       jukes = false;
       freqsfrom = true;
       logdet = false;
+      ttratio = getDNADistSettings().ttRatio;
+      ttr = true;
   } else if (matrixModel == DNADistModelTypes::Kimura) {
       f84 = false;
       kimura = true;
       jukes = false;
       freqsfrom = false;
       logdet = false;
+      ttratio = getDNADistSettings().ttRatio;
+      ttr = true;
   } else if (matrixModel == DNADistModelTypes::JukesCantor) {
       f84 = false;
       kimura = false;
@@ -1283,7 +1277,7 @@ void makedists()
       U2::TaskStateInfo* ts = U2::getTaskInfo();
       if (ts->cancelFlag != 0) {
           ugene_exit("Task canceled!");
-      } else {
+      } else if(!U2::isBootstr()){
           cur_prog += step;
           ts->progress = int (cur_prog);   
       }
