@@ -1,13 +1,3 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #ifndef _PHYLIP_H_
 #define _PHYLIP_H_
 
@@ -38,7 +28,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-void ugene_exit(const char* message) throw();
+void ugene_exit(const char* message);
 
 
 namespace U2 {
@@ -48,6 +38,9 @@ namespace U2 {
     TaskStateInfo* getTaskInfo();
     void setTaskInfo(TaskStateInfo* ts);
 
+    bool isBootstr();
+    void setBootstr(bool bootstr);
+
 }
 
 
@@ -274,8 +267,8 @@ MALLOCRETURN    *mymalloc(long);
 /*** Static memory parameters ***/
 
 #define FNMLNGTH        200  /* length of array to store a file name */
-#define nmlngth         10   /* number of characters in species name    */
-#define MAXNCH          20   /* must be greater than or equal to nmlngth */
+#define nmlngth         20   /* number of characters in species name    */
+#define MAXNCH          30   /* must be greater than or equal to nmlngth */
 #define maxcategs       9    /* maximum number of site types */
 #define maxcategs2     11    /* maximum number of site types + 2 */
 #define point           "."
