@@ -1,13 +1,3 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
-
 #include "phylip.h"
 #include "seq.h"
 #include "protdist.h"
@@ -1546,7 +1536,7 @@ void prot_makedists()
       U2::TaskStateInfo* ts = U2::getTaskInfo();
       if (ts->cancelFlag != 0) {
           ugene_exit("Task canceled!");
-      } else {
+      } else if(!U2::isBootstr()){
           cur_prog += step;
           ts->progress = int (cur_prog);   
       }
