@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <cfloat>
 #include <QtGui/QMessageBox>
@@ -24,7 +35,7 @@ Primer3Dialog::Primer3Dialog(const Primer3TaskSettings &defaultSettings, ADVSequ
 
     {
         CreateAnnotationModel createAnnotationModel;
-        createAnnotationModel.data->name = "top primers";
+        createAnnotationModel.data->name = "top_primers";
         createAnnotationModel.sequenceObjectRef = GObjectReference(context->getSequenceGObject());
         createAnnotationModel.hideAnnotationName = false;
         createAnnotationModel.hideLocation = true;
@@ -579,6 +590,11 @@ void Primer3Dialog::showInvalidInputMessage(QWidget *field, QString fieldLabel)
 
 void Primer3Dialog::on_pbPick_clicked()
 {
+    QString err = createAnnotationWidgetController->validate();
+    if (!err.isEmpty()) {
+        QMessageBox::warning(QApplication::activeWindow(), windowTitle(), err);
+        return;
+    }
     if(doDataExchange())
     {
         accept();
