@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <cstdlib>
 #include <U2Core/AppContext.h>
@@ -504,14 +515,13 @@ void Primer3SWTask::prepare()
         setError("invalid included region");
         return;
     }
-    QList<LRegion> regions = SequenceWalkerTask::splitRange(
-        LRegion(settings.getIncludedRegion().first, settings.getIncludedRegion().second),
+    QVector<U2Region> regions = SequenceWalkerTask::splitRange(
+        U2Region(settings.getIncludedRegion().first, settings.getIncludedRegion().second),
         CHUNK_SIZE, 0, CHUNK_SIZE/2, false);
-    foreach(LRegion region, regions)
+    foreach(U2Region region, regions)
     {
         Primer3TaskSettings regionSettings = settings;
-        regionSettings.setIncludedRegion(
-                qMakePair(region.startPos, region.len));
+        regionSettings.setIncludedRegion(qMakePair((int)region.startPos, (int)region.length));
         Primer3Task *task = new Primer3Task(regionSettings);
         regionTasks.append(task);
         addSubTask(task);
@@ -585,7 +595,7 @@ QString Primer3ToAnnotationsTask::generateReport() const {
 
     res += QString("<tr><th></th> <th>con</th> <th>too</th> <th>in</th> <th>in</th> <th></th> <th>no</th> <th>tm</th> <th>tm</th> <th>high</th> <th>high</th> <th></th> <th>high</th> <th></th></tr>");
     res += QString("<tr><th></th> <th>sid</th> <th>many</th> <th>tar</th> <th>excl</th> <th>bag</th> <th>GC</th> <th>too</th> <th>too</th> <th>any</th> <th>3'</th> <th>poly</th> <th>end</th> <th></th></tr>");
-    res += QString("<tr><th></th> <th>ered</th> <th>Ns</th> <th>get</th> <th>reg</th> <th>GC\%</th> <th>clamp</th> <th>low</th> <th>high</th> <th>compl</th> <th>compl</th> <th>X</th> <th>stab</th> <th>ok</th></tr>");
+    res += QString("<tr><th></th> <th>ered</th> <th>Ns</th> <th>get</th> <th>reg</th> <th>GC&#37;</th> <th>clamp</th> <th>low</th> <th>high</th> <th>compl</th> <th>compl</th> <th>X</th> <th>stab</th> <th>ok</th></tr>");
 
     res += QString("<tr><th>Left</th><th> %1 </th><th> %2 </th><th> %3 </th><th> %4 </th><th> %5 </th><th> %6 </th><th> %7 </th><th> %8 </th><th> %9 </th><th> %10 </th><th> %11 </th><th> %12 </th><th> %13 </th></tr>")
         .arg(leftStats.considered).arg(leftStats.ns).arg(leftStats.target).arg(leftStats.excluded).arg(leftStats.gc).arg(leftStats.gc_clamp).arg(leftStats.temp_min).arg(leftStats.temp_max)
@@ -614,15 +624,15 @@ Task::ReportResult Primer3ToAnnotationsTask::report()
         QList<SharedAnnotationData> annotations;
         if(NULL != pair.getLeftPrimer())
         {
-            annotations.append(oligoToAnnotation("primer", *pair.getLeftPrimer(), false));
+            annotations.append(oligoToAnnotation("primer", *pair.getLeftPrimer(), U2Strand::Direct));
         }
         if(NULL != pair.getInternalOligo())
         {
-            annotations.append(oligoToAnnotation("internalOligo", *pair.getInternalOligo(), false));
+            annotations.append(oligoToAnnotation("internalOligo", *pair.getInternalOligo(), U2Strand::Direct));
         }
         if(NULL != pair.getRightPrimer())
         {
-            annotations.append(oligoToAnnotation("primer", *pair.getRightPrimer(), true));
+            annotations.append(oligoToAnnotation("primer", *pair.getRightPrimer(), U2Strand::Complementary));
         }
         AppContext::getTaskScheduler()->registerTopLevelTask(
                 new CreateAnnotationsTask(aobj, groupName + "/pair " + QString::number(index + 1), annotations));
@@ -631,22 +641,21 @@ Task::ReportResult Primer3ToAnnotationsTask::report()
     return ReportResult_Finished;
 }
 
-SharedAnnotationData Primer3ToAnnotationsTask::oligoToAnnotation(QString title, const Primer &primer, bool complement)
+SharedAnnotationData Primer3ToAnnotationsTask::oligoToAnnotation(QString title, const Primer &primer, U2Strand strand)
 {
     SharedAnnotationData annotationData(new AnnotationData());
     annotationData->name = title;
     int start = primer.getStart();
     int length = primer.getLength();
-    if(complement)
-    {
+    if (strand == U2Strand::Complementary) {
         start -= length - 1;
     }
-    annotationData->complement = complement;
-    annotationData->location.append(LRegion(start, length));
-    annotationData->qualifiers.append(Qualifier("tm", QString::number(primer.getMeltingTemperature())));
-    annotationData->qualifiers.append(Qualifier("gc%", QString::number(primer.getGcContent())));
-    annotationData->qualifiers.append(Qualifier("any", QString::number(0.01*primer.getSelfAny())));
-    annotationData->qualifiers.append(Qualifier("3'", QString::number(0.01*primer.getSelfEnd())));
+    annotationData->setStrand(strand);
+    annotationData->location->regions << U2Region(start, length);
+    annotationData->qualifiers.append(U2Qualifier("tm", QString::number(primer.getMeltingTemperature())));
+    annotationData->qualifiers.append(U2Qualifier("gc%", QString::number(primer.getGcContent())));
+    annotationData->qualifiers.append(U2Qualifier("any", QString::number(0.01*primer.getSelfAny())));
+    annotationData->qualifiers.append(U2Qualifier("3'", QString::number(0.01*primer.getSelfEnd())));
     return annotationData;
 }
 
