@@ -1,151 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="ru_RU">
-<context>
-    <name>GB2::Primer3ADVContext</name>
-    <message>
-        <location filename="../src/Primer3Plugin.cpp" line="106"/>
-        <source>Primer 3</source>
-        <translation></translation>
-    </message>
-</context>
-<context>
-    <name>GB2::Primer3Dialog</name>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="39"/>
-        <source>NONE</source>
-        <translation type="unfinished">нет</translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="40"/>
-        <source>HUMAN</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="41"/>
-        <source>RODENT_AND_SIMPLE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="42"/>
-        <source>RODENT</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="43"/>
-        <source>DROSOPHILA</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="335"/>
-        <source>Start Codon Position</source>
-        <translation type="unfinished">Позиция стартового кодона</translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="349"/>
-        <source>Product Min Tm</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="363"/>
-        <source>Product Opt Tm</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="377"/>
-        <source>Product Max Tm</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="391"/>
-        <source>Opt GC%</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="405"/>
-        <source>Inside Penalty</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="419"/>
-        <source>Internal Oligo Opt Tm</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="431"/>
-        <source>Excluded Regions</source>
-        <translation type="unfinished">Исключаемые регионы</translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="443"/>
-        <source>Internal Oligo Excluded Regions</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="455"/>
-        <source>Targets</source>
-        <translation type="unfinished">Целевые регионы</translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="467"/>
-        <source>Product Size Ranges</source>
-        <translation type="unfinished">Диапазоны размеров продукта</translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="504"/>
-        <source>Sequence Quality</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="511"/>
-        <source>Sequence quality list length must be equal to the sequence length</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="533"/>
-        <source>Can&apos;t pick hyb oligo and only one primer</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="553"/>
-        <source>Nothing to pick</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Dialog.cpp" line="572"/>
-        <source>The field &apos;%1&apos; has invalid value</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>GB2::Primer3Plugin</name>
-    <message>
-        <location filename="../src/Primer3Plugin.cpp" line="33"/>
-        <source>primer 3</source>
-        <translation>Primer 3</translation>
-    </message>
-    <message>
-        <location filename="../src/Primer3Plugin.cpp" line="33"/>
-        <source>primer 3 description</source>
-        <translation>Инструмент для дизайна праймеров</translation>
-    </message>
-</context>
-<context>
-    <name>GB2::Primer3Task</name>
-    <message>
-        <location filename="../src/Primer3Task.cpp" line="210"/>
-        <source>Pick primers task</source>
-        <translation>Выбор праймеров</translation>
-    </message>
-</context>
-<context>
-    <name>GB2::Primer3ToAnnotationsTask</name>
-    <message>
-        <location filename="../src/Primer3Task.cpp" line="323"/>
-        <source>Search primers to annotations</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>GTest</name>
     <message>
@@ -205,24 +60,24 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Primer3Tests.cpp" line="524"/>
+        <location filename="../src/Primer3Tests.cpp" line="523"/>
         <source>%1 is incorrect. Expected:%2,%3, but Actual:NULL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Primer3Tests.cpp" line="533"/>
+        <location filename="../src/Primer3Tests.cpp" line="532"/>
         <source>%1 is incorrect. Expected:NULL, but Actual:%2,%3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Primer3Tests.cpp" line="543"/>
+        <location filename="../src/Primer3Tests.cpp" line="542"/>
         <source>%1 is incorrect. Expected:%2,%3, but Actual:%4,%5</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Primer3Tests.cpp" line="582"/>
-        <location filename="../src/Primer3Tests.cpp" line="592"/>
-        <location filename="../src/Primer3Tests.cpp" line="602"/>
+        <location filename="../src/Primer3Tests.cpp" line="581"/>
+        <location filename="../src/Primer3Tests.cpp" line="591"/>
+        <location filename="../src/Primer3Tests.cpp" line="601"/>
         <source>%1 is incorrect. Expected:%2, but Actual:%3</source>
         <translation type="unfinished"></translation>
     </message>
@@ -832,4 +687,225 @@ p, li { white-space: pre-wrap; }
         <translation>Подобрать</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="173"/>
+        <source>Primer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="174"/>
+        <source>PCR primer design</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="176"/>
+        <source>Excluded regions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="177"/>
+        <source>Targets</source>
+        <translation type="unfinished">Целевые регионы</translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="178"/>
+        <source>Product size ranges</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="179"/>
+        <source>Number to return</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="181"/>
+        <source>Max repeat mispriming</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="182"/>
+        <source>Max template mispriming</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="183"/>
+        <source>Max 3&apos; stability</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="184"/>
+        <source>Pair max repeat mispriming</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="185"/>
+        <source>Pair max template mispriming</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>U2::Primer3ADVContext</name>
+    <message>
+        <location filename="../src/Primer3Plugin.cpp" line="110"/>
+        <source>Primer3...</source>
+        <translation type="unfinished">Подбор праймеров...</translation>
+    </message>
+</context>
+<context>
+    <name>U2::Primer3Dialog</name>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="39"/>
+        <source>NONE</source>
+        <translation type="unfinished">нет</translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="40"/>
+        <source>HUMAN</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="41"/>
+        <source>RODENT_AND_SIMPLE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="42"/>
+        <source>RODENT</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="43"/>
+        <source>DROSOPHILA</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="330"/>
+        <source>Start Codon Position</source>
+        <translation type="unfinished">Позиция стартового кодона</translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="344"/>
+        <source>Product Min Tm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="358"/>
+        <source>Product Opt Tm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="372"/>
+        <source>Product Max Tm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="386"/>
+        <source>Opt GC%</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="400"/>
+        <source>Inside Penalty</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="414"/>
+        <source>Internal Oligo Opt Tm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="426"/>
+        <source>Excluded Regions</source>
+        <translation type="unfinished">Исключаемые регионы</translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="438"/>
+        <source>Internal Oligo Excluded Regions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="450"/>
+        <source>Targets</source>
+        <translation type="unfinished">Целевые регионы</translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="462"/>
+        <source>Product Size Ranges</source>
+        <translation type="unfinished">Диапазоны размеров продукта</translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="499"/>
+        <source>Sequence Quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="506"/>
+        <source>Sequence quality list length must be equal to the sequence length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="528"/>
+        <source>Can&apos;t pick hyb oligo and only one primer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="548"/>
+        <source>Nothing to pick</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Dialog.cpp" line="567"/>
+        <source>The field &apos;%1&apos; has invalid value</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>U2::Primer3Plugin</name>
+    <message>
+        <location filename="../src/Primer3Plugin.cpp" line="34"/>
+        <source>Primer3</source>
+        <translation>Primer3</translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Plugin.cpp" line="34"/>
+        <source>Integrated tool for PCR primers design.</source>
+        <translation>Инструмент для дизайна праймеров.</translation>
+    </message>
+</context>
+<context>
+    <name>U2::Primer3Task</name>
+    <message>
+        <location filename="../src/Primer3Task.cpp" line="309"/>
+        <source>Pick primers task</source>
+        <translation>Выбор праймеров</translation>
+    </message>
+</context>
+<context>
+    <name>U2::Primer3ToAnnotationsTask</name>
+    <message>
+        <location filename="../src/Primer3Task.cpp" line="541"/>
+        <source>Search primers to annotations</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>U2::QDPrimerActor</name>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="62"/>
+        <source>%1 invalid input. Excluded regions.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="72"/>
+        <source>%1 invalid input. Targets.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Primer3Query.cpp" line="82"/>
+        <source>%1 invalid input. Product size ranges.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
