@@ -1,33 +1,33 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="en">
-<context>
-    <name>GB2::PsipredAlgTask</name>
-    <message>
-        <location filename="../src/PsipredAlgTask.cpp" line="13"/>
-        <source>PsiPred</source>
-        <translation></translation>
-    </message>
-</context>
-<context>
-    <name>GB2::PsipredPlugin</name>
-    <message>
-        <location filename="../src/PsipredPlugin.cpp" line="37"/>
-        <source>PsiPred</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/PsipredPlugin.cpp" line="37"/>
-        <source>PsiPred protein secondary structure prediction</source>
-        <translation></translation>
-    </message>
-</context>
 <context>
     <name>SecStructPredictTask</name>
     <message>
-        <location filename="../src/PsipredAlgTask.cpp" line="29"/>
+        <location filename="../src/PsipredAlgTask.cpp" line="30"/>
         <source>psipred: sequence is too long, max seq size is 10000</source>
         <translation>Sequence is too long: maximum allowed length is 10000</translation>
     </message>
 </context>
+<context>
+    <name>U2</name>
+    <message>
+        <location filename="../src/PsipredAlgTask.cpp" line="14"/>
+        <source>PsiPred</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>U2::PsipredPlugin</name>
+    <message>
+        <location filename="../src/PsipredPlugin.cpp" line="34"/>
+        <source>PsiPred</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/PsipredPlugin.cpp" line="34"/>
+        <source>PsiPred protein secondary structure prediction</source>
+        <translation></translation>
+    </message>
+</context>
 </TS>
