@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "SiteconAlgorithmTests.h"
 #include "DIPropertiesSitecon.h"
@@ -451,14 +462,14 @@ void GTest_SiteconSearchTask::init(XMLTestFormat *tf, const QDomElement& el) {
                 stateInfo.setError(  QString("unable to convert %1 to integer").arg(EXPECTED_RESULTS_ATTR) );
                 return;
             }
-            bool compl_;
-            LRegion reg;
-            reg.len = model.settings.windowSize;
+            U2Strand strand;
+            U2Region reg;
+            reg.length = model.settings.windowSize;
             if (strStr == "direct") {
-                compl_ = false;
+                strand = U2Strand::Direct;
                 reg.startPos = middle - (int)(model.settings.windowSize/2);
-            }else if(strStr == "compliment") {
-                compl_ = true;
+            } else if(strStr == "compliment") {
+                strand = U2Strand::Complementary;
                 reg.startPos = middle - (int)(model.settings.windowSize/2) + 1;
                 /*
                 if(model.settings.weightAlg == SiteconWeightAlg_Alg2){
@@ -477,7 +488,7 @@ void GTest_SiteconSearchTask::init(XMLTestFormat *tf, const QDomElement& el) {
             SiteconSearchResult ssr;
             ssr.psum = psum;
             ssr.region = reg;
-            ssr.complement = compl_;
+            ssr.strand = strand;
             expectedResults.append(ssr);
         }
     }
@@ -531,7 +542,7 @@ Task::ReportResult GTest_SiteconSearchTask::report() {
     foreach(SiteconSearchResult exp, expectedResults) {
         foreach(SiteconSearchResult act, results) {
             int ePsum = qRound(exp.psum * 10), aPsum = qRound(act.psum * 10);
-            if (exp.region == act.region && aPsum == ePsum && exp.complement == act.complement) {
+            if (exp.region == act.region && aPsum == ePsum && exp.strand == act.strand) {
                 matchesCount++;
             }
         }
