@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "SiteconIO.h"
 #include "DIPropertiesSitecon.h"
@@ -81,7 +92,7 @@ SiteconModel SiteconIO::readModel(IOAdapterFactory* iof, const QString& url, Tas
         }
     }
     io->close();
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return model;
     }
 
@@ -97,7 +108,7 @@ SiteconModel SiteconIO::readModel(IOAdapterFactory* iof, const QString& url, Tas
     QSet<int> passedPropsSDev;
     QSet<int> passedPropsWeight;
 
-    while (!reader.atEnd() && !si.hasErrors()) {
+    while (!reader.atEnd() && !si.hasError()) {
         line = reader.readLine();
         if (line.isEmpty()) {
             continue;
@@ -220,7 +231,7 @@ SiteconModel SiteconIO::readModel(IOAdapterFactory* iof, const QString& url, Tas
                             break;
                         }
                     }
-                    if (si.hasErrors()) {
+                    if (si.hasError()) {
                         break;
                     }
                     if (idx == -1) {
@@ -290,7 +301,7 @@ SiteconModel SiteconIO::readModel(IOAdapterFactory* iof, const QString& url, Tas
         }
     }
     
-    if (si.hasErrors()) {
+    if (si.hasError()) {
         return model;
     }
 
