@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "MuscleParallel.h"
 #include "MuscleUtils.h"
@@ -72,6 +83,7 @@ MusclePrepareTask::MusclePrepareTask(MuscleWorkPool *wp)
 }
 
 void MusclePrepareTask::run() {
+    algoLog.details(tr("Preparing MUSCLE alignment..."));
     TaskLocalData::bindToMuscleTLSContext(workpool->ctx);
     try {
         workpool->ph = new MuscleParamsHelper(workpool->ti, workpool->ctx);
@@ -83,6 +95,7 @@ void MusclePrepareTask::run() {
         }
     }
     TaskLocalData::detachMuscleTLSContext();
+    algoLog.details(tr("MUSCLE prepared successfully"));
 }
 
 void MusclePrepareTask::_run() {
@@ -110,7 +123,7 @@ void MusclePrepareTask::alignPrepareUnsafe()
     SetSeqWeightMethod(ctx->params.g_SeqWeight1);
 
     setupAlphaAndScore(workpool->ma.getAlphabet(), stateInfo);
-    if (stateInfo.hasErrors()) {
+    if (stateInfo.hasError()) {
         return;
     }
 
@@ -230,7 +243,7 @@ void MusclePrepareTask::refinePrepareUnsafe() {
     SetSeqWeightMethod(ctx->params.g_SeqWeight1);
 
     setupAlphaAndScore(workpool->ma.getAlphabet(), workpool->ti);
-    if (workpool->ti.hasErrors()) {
+    if (workpool->ti.hasError()) {
         return;
     }
     MSA &msa = workpool->a;
@@ -293,7 +306,7 @@ void ProgressiveAlignTask::_run() {
     if (!workpool->res.isEmpty())  {
         return;// no more need in align
     }
-	if (workpool->ti.hasErrors())  {
+	if (workpool->ti.hasError())  {
 		return; // cancel on error
 	}
     MuscleContext* ctx = workpool->ctx;
