@@ -1,12 +1,25 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
+
+#include <memory>
 
 #include "MuscleTask.h"
 #include "MuscleParallel.h"
@@ -26,11 +39,14 @@
 #include <U2Core/AddDocumentTask.h>
 #include <U2Core/LoadDocumentTask.h>
 #include <U2Core/DocumentUtils.h>
+#include <U2Core/BaseDocumentFormats.h>
 #include <U2Gui/OpenViewTask.h>
+#include <U2Lang/WorkflowSettings.h>
 
 #include "muscle/muscle.h" 
 #include "muscle/muscle_context.h" 
 
+#define MUSCLE_LOCK_REASON "Muscle lock"
 
 namespace U2 {
 
@@ -40,10 +56,11 @@ void MuscleTaskSettings::reset() {
     maxIterations = 8;
     maxSecs = 0;
     stableMode = true;
-    regionToAlign.startPos = regionToAlign.len = 0;
+    regionToAlign.startPos = regionToAlign.length = 0;
     profile.clear();
     alignRegion = false;
     inputFilePath = "";
+    mode = Default;
 }
 
 MuscleTask::MuscleTask(const MAlignment& ma, const MuscleTaskSettings& _config) 
@@ -54,6 +71,8 @@ MuscleTask::MuscleTask(const MAlignment& ma, const MuscleTaskSettings& _config)
     assert(config.nThreads > 0);
     setMaxParallelSubtasks(config.nThreads);
 
+    algoLog.info(tr("MUSCLE alignment started"));
+
     ctx = new MuscleContext(config.nThreads);
     ctx->params.g_bStable = config.stableMode;
     ctx->params.g_uMaxIters = config.maxIterations;
@@ -63,13 +82,13 @@ MuscleTask::MuscleTask(const MAlignment& ma, const MuscleTaskSettings& _config)
     //todo: make more precise estimation, use config.op mode
     int aliLen = ma.getLength();
     int nSeq = ma.getNumRows();
-    int memUseMB = int(quint64(200 * aliLen * nSeq) / (1024 * 1024)); //200x per char in alignment
+    int memUseMB = qint64(aliLen) * qint64(nSeq) * 200 / (1024 * 1024); //200x per char in alignment
     TaskResourceUsage tru(RESOURCE_MEMORY, memUseMB);
     
     inputSubMA = inputMA;
-    if (config.alignRegion && config.regionToAlign.len != inputMA.getLength()) {
-        assert(config.regionToAlign.len > 0);
-        inputSubMA = inputMA.mid(config.regionToAlign.startPos, config.regionToAlign.len);
+    if (config.alignRegion && config.regionToAlign.length != inputMA.getLength()) {
+        assert(config.regionToAlign.length > 0);
+        inputSubMA = inputMA.mid(config.regionToAlign.startPos, config.regionToAlign.length);
     }
     
     ctx->input_uIds = new unsigned[inputSubMA.getNumRows()];
@@ -86,14 +105,16 @@ MuscleTask::MuscleTask(const MAlignment& ma, const MuscleTaskSettings& _config)
         addSubTask(parallelSubTask);
         tru.prepareStageLock = true;
     }
-    taskResources.append(tru);
+    addTaskResource(tru);
 }
 
 void MuscleTask::run() {
     TaskLocalData::bindToMuscleTLSContext(ctx);
 
-    assert(!hasErrors());
-    
+    assert(!hasError());
+
+    algoLog.details(tr("Performing MUSCLE alignment..."));
+
     switch(config.op) {
         case MuscleTaskOp_Align:
             doAlign(false); 
@@ -108,10 +129,14 @@ void MuscleTask::run() {
             doProfile2Profile();
             break;
     }
-    if (!hasErrors() && !isCanceled()) {
+    if (!hasError() && !isCanceled()) {
         assert(resultMA.getAlphabet() != NULL);
     }
     TaskLocalData::detachMuscleTLSContext();
+
+    if(!stateInfo.isCoR()) {
+        algoLog.info(tr("MUSCLE alignment successfully finished"));
+    }
 }
 
 void MuscleTask::doAlign(bool refine) {
@@ -122,48 +147,49 @@ void MuscleTask::doAlign(bool refine) {
         } else {
             MuscleAdapter::align(inputSubMA, resultSubMA, stateInfo, true);
         }
-        if (hasErrors()) {
+        if (hasError()) {
             return;
         }
     } 
-    assert(!hasErrors());
+    assert(!hasError());
     if(!isCanceled()) {
         assert(!resultSubMA.isEmpty());
-        if (config.alignRegion && config.regionToAlign.len != inputMA.getLength()) {
-            resultMA.setAlphabet(inputMA.getAlphabet());
-            QByteArray emptySeq;
-            const int nSeq = inputMA.getNumRows();
-            int *ids = new int[nSeq];
+        resultMA.setAlphabet(inputMA.getAlphabet());
+        QByteArray emptySeq;
+        const int nSeq = inputMA.getNumRows();
+        int *ids = new int[nSeq];
 
-            const int resNSeq = resultSubMA.getNumRows();
-            bool *existID = new bool[nSeq];
-            memset(existID,0,sizeof(bool)*nSeq);
-            for(int i=0, n = resNSeq; i < n; i++) {
-                ids[i] = ctx->output_uIds[i];
-                existID[ids[i]] = true;
+        const int resNSeq = resultSubMA.getNumRows();
+        bool *existID = new bool[nSeq];
+        memset(existID,0,sizeof(bool)*nSeq);
+        for(int i=0, n = resNSeq; i < n; i++) {
+            ids[i] = ctx->output_uIds[i];
+            existID[ids[i]] = true;
+        }
+        if(config.stableMode) {
+            for(int i = 0; i<nSeq;i++) {
+                ids[i] = i;
             }
-            if(config.stableMode) {
-                for(int i = 0; i<nSeq;i++) {
-                    ids[i] = i;
+        }
+        int j = resNSeq;
+        QByteArray gapSeq(resultSubMA.getLength(),MAlignment_GapChar);
+        for(int i=0, n = nSeq; i < n; i++) {
+            if(!existID[i]) {
+                MAlignmentRow row(inputMA.getRow(i).getName(), gapSeq);
+                if(config.stableMode) {
+                    resultSubMA.addRow(row,i);
+                } else {
+                    ids[j] = i;
+                    resultSubMA.addRow(row);
                 }
+                j++;
             }
-            int j = resNSeq;
-            QByteArray gapSeq(resultSubMA.getLength(),MAlignment_GapChar);
-            for(int i=0, n = nSeq; i < n; i++) {
-                if(!existID[i]) {
-					MAlignmentRow row(inputMA.getRow(i).getName(), gapSeq);
-                    if(config.stableMode) {
-                        resultSubMA.addRow(row,i);
-                    } else {
-                        ids[j] = i;
-                        resultSubMA.addRow(row);
-                    }
-                    j++;
-                }
-            }
-            delete[] existID;
-            assert(resultSubMA.getNumRows() == inputMA.getNumRows());
+        }
+        delete[] existID;
 
+        assert(resultSubMA.getNumRows() == inputMA.getNumRows());
+
+        if (config.alignRegion && config.regionToAlign.length != inputMA.getLength()) {                        
 
             for(int i=0, n = inputMA.getNumRows(); i < n; i++) {
                 const MAlignmentRow& row= inputMA.getRow(ids[i]);
@@ -242,11 +268,11 @@ MuscleAddSequencesToProfileTask::MuscleAddSequencesToProfileTask(MAlignmentObjec
 //             return;
 //         }
 //     }
-    QList<DocumentFormat*> detectedFormats = DocumentUtils::detectFormat(fileWithSequencesOrProfile);    
+    QList<FormatDetectionResult> detectedFormats = DocumentUtils::detectFormat(fileWithSequencesOrProfile);    
     if (detectedFormats.isEmpty()) {
         setError("Unknown format");
     }
-    DocumentFormat* format = detectedFormats.first();
+    DocumentFormat* format = detectedFormats.first().format;
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(fileWithSequencesOrProfile));
     loadTask = new LoadDocumentTask(format->getFormatId(), fileWithSequencesOrProfile, iof);
     loadTask->setSubtaskProgressWeight(0.01f);
@@ -256,12 +282,12 @@ MuscleAddSequencesToProfileTask::MuscleAddSequencesToProfileTask(MAlignmentObjec
 QList<Task*> MuscleAddSequencesToProfileTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
 
-    if (subTask != loadTask || isCanceled() || hasErrors()) {
+    if (subTask != loadTask || isCanceled() || hasError()) {
         return res;
     }
 
     propagateSubtaskError();
-    if (hasErrors()) {
+    if (hasError()) {
         return res;
     }
 
@@ -311,7 +337,7 @@ QList<Task*> MuscleAddSequencesToProfileTask::onSubTaskFinished(Task* subTask) {
 }
 
 Task::ReportResult MuscleAddSequencesToProfileTask::report() {
-    if (!hasErrors()) {
+    if (!hasError()) {
         propagateSubtaskError();
     }
     return ReportResult_Finished;
@@ -321,7 +347,7 @@ Task::ReportResult MuscleAddSequencesToProfileTask::report() {
 // MuscleGObjectTask
 
 MuscleGObjectTask::MuscleGObjectTask(MAlignmentObject* _obj, const MuscleTaskSettings& _config) 
-: Task("", TaskFlags_NR_FOSCOE), obj(_obj), lock(NULL), muscleTask(NULL), config(_config)
+: MAlignmentGObjectTask("", TaskFlags_NR_FOSCOE,_obj), lock(NULL), muscleTask(NULL), config(_config)
 {
     QString aliName = obj->getDocument()->getName();
     QString tn;
@@ -359,7 +385,7 @@ void MuscleGObjectTask::prepare() {
         return;
     }
 
-    lock = new StateLock("muscle_lock");
+    lock = new StateLock(MUSCLE_LOCK_REASON, StateLockFlag_LiveLock);
     obj->lockState(lock);
     muscleTask = new MuscleTask(obj->getMAlignment(), config);
 
@@ -373,7 +399,7 @@ Task::ReportResult MuscleGObjectTask::report() {
         lock = NULL;
     }
     propagateSubtaskError();
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return ReportResult_Finished;
     }
     assert(!obj.isNull());
@@ -405,6 +431,13 @@ MuscleWithExtFileSpecifySupportTask::MuscleWithExtFileSpecifySupportTask(const M
     saveDocumentTask = NULL;
     loadDocumentTask = NULL;
     muscleGObjectTask = NULL;
+    cleanDoc = true;
+}
+
+MuscleWithExtFileSpecifySupportTask::~MuscleWithExtFileSpecifySupportTask() {
+    if (cleanDoc) {
+        delete currentDocument;
+    }
 }
 
 void MuscleWithExtFileSpecifySupportTask::prepare(){
@@ -419,67 +452,206 @@ void MuscleWithExtFileSpecifySupportTask::prepare(){
     }
 
     DocumentFormatId alnFormat = formats.first();
-    loadDocumentTask=
-            new LoadDocumentTask(alnFormat,
-                                 config.inputFilePath,
-                                 AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(config.inputFilePath)));
+    IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(config.inputFilePath));
+    QVariantMap hints;
+    hints[DocumentReadingMode_SequenceAsAlignmentHint] = true;
+    loadDocumentTask = new LoadDocumentTask(alnFormat, config.inputFilePath, iof, hints);
     addSubTask(loadDocumentTask);
 }
+
 QList<Task*> MuscleWithExtFileSpecifySupportTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
-    if(subTask->hasErrors()) {
+    if (subTask->hasError()) {
         stateInfo.setError(subTask->getError());
         return res;
     }
-    if(hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return res;
     }
-    if(subTask==loadDocumentTask){
-        currentDocument=loadDocumentTask->takeDocument();
+    if (subTask == loadDocumentTask){
+        currentDocument = loadDocumentTask->getDocument()->clone(); //clone -> to move to main thread here
         assert(currentDocument!=NULL);
         assert(currentDocument->getObjects().length()==1);
         mAObject=qobject_cast<MAlignmentObject*>(currentDocument->getObjects().first());
         assert(mAObject!=NULL);
         if (config.alignRegion) {
             if((config.regionToAlign.startPos > mAObject->getLength())
-                || ((config.regionToAlign.startPos + config.regionToAlign.len) > mAObject->getLength()))
+                || ((config.regionToAlign.startPos + config.regionToAlign.length) > mAObject->getLength()))
                 {
                     config.alignRegion=false;
-                    config.regionToAlign = LRegion(0, mAObject->getLength());
+                    config.regionToAlign = U2Region(0, mAObject->getLength());
                 }
         } else {
-            config.regionToAlign = LRegion(0, mAObject->getLength());
+            config.regionToAlign = U2Region(0, mAObject->getLength());
         }
 
-        muscleGObjectTask=new MuscleGObjectTask(mAObject, config);
+#ifndef RUN_WORKFLOW_IN_THREADS
+        if (WorkflowSettings::runInSeparateProcess() && !WorkflowSettings::getCmdlineUgenePath().isEmpty()) {
+            muscleGObjectTask = new MuscleGObjectRunFromSchemaTask(mAObject, config);
+        } else {
+            muscleGObjectTask = new MuscleGObjectTask(mAObject, config);
+        }
+#else
+        muscleGObjectTask = new MuscleGObjectTask(mAObject, config);
+#endif // RUN_WORKFLOW_IN_THREADS
+        assert(muscleGObjectTask != NULL);
         res.append(muscleGObjectTask);
-    }else if(subTask == muscleGObjectTask){
+    } else if (subTask == muscleGObjectTask){
         saveDocumentTask = new SaveDocumentTask(currentDocument,AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(config.inputFilePath)),config.inputFilePath);
         res.append(saveDocumentTask);
-    }else if(subTask==saveDocumentTask){
+    } else if (subTask == saveDocumentTask){
         Project* proj = AppContext::getProject();
         if (proj == NULL) {
-            res.append(AppContext::getProjectLoader()->openProjectTask(currentDocument->getURLString(), false));
+            res.append(AppContext::getProjectLoader()->openWithProjectTask(currentDocument->getURL(), currentDocument->getGHintsMap()));
         } else {
-            bool docAlreadyInProject=false;
-            foreach(Document* doc, proj->getDocuments()){
-                if(doc->getURL() == currentDocument->getURL()){
-                    docAlreadyInProject=true;
-                }
-            }
-            if (docAlreadyInProject) {
-                res.append(new LoadUnloadedDocumentAndOpenViewTask(currentDocument));
+            Document* projDoc = proj->findDocumentByURL(currentDocument->getURL());
+            if (projDoc) {
+                projDoc->setLastUpdateTime();
+                res.append(new LoadUnloadedDocumentAndOpenViewTask(projDoc));
             } else {
                 // Add document to project
-                res.append(new AddDocumentTask(currentDocument));
-                res.append(new LoadUnloadedDocumentAndOpenViewTask(currentDocument));
+                res.append(new AddDocumentAndOpenViewTask(currentDocument));
+                cleanDoc = false;
             }
         }
     }
     return res;
 }
+
 Task::ReportResult MuscleWithExtFileSpecifySupportTask::report(){
     return ReportResult_Finished;
 }
 
+#ifndef RUN_WORKFLOW_IN_THREADS
+
+//////////////////////////////////
+//MuscleGObjectRunFromSchemaTask
+static const QString LOCK_NAME("muscle state lock");
+static const QString MUSCLE_SCHEMA_NAME("muscle");
+
+MuscleGObjectRunFromSchemaTask::MuscleGObjectRunFromSchemaTask(MAlignmentObject * o, const MuscleTaskSettings & c) :
+MAlignmentGObjectTask("", TaskFlags_NR_FOSCOE, o), objName(o->getDocument()->getName()), config(c), runSchemaTask(NULL), lock(NULL){
+    assertConfig();
+    assert(!objName.isEmpty());
+    
+    QString name;
+    switch(config.op) {
+        case MuscleTaskOp_Align:
+            name = tr("MUSCLE run in separate process align '%1'").arg(objName);
+            break;
+        case MuscleTaskOp_Refine: 
+            name = tr("MUSCLE run in separate process refine '%1'").arg(objName);
+            break;
+        default: 
+            assert(false);
+    }
+    setTaskName(name);
+    setUseDescriptionFromSubtask(true);
+    setVerboseLogMode(true);
+}
+
+MuscleGObjectRunFromSchemaTask::~MuscleGObjectRunFromSchemaTask() {
+    assert(lock == NULL);
+}
+
+void MuscleGObjectRunFromSchemaTask::assertConfig() {
+    assert(config.op == MuscleTaskOp_Align || config.op == MuscleTaskOp_Refine);
+    assert(config.profile.isEmpty());
+}
+
+void MuscleGObjectRunFromSchemaTask::prepare() {
+    if (obj.isNull()) {
+        stateInfo.setError(tr("Object '%1' removed").arg(objName));
+        return;
+    }
+    if (obj->isStateLocked()) {
+        stateInfo.setError(tr("Object '%1' is locked").arg(objName));
+        return;
+    }
+    algoLog.info(tr("MUSCLE alignment started"));
+    
+    lock = new StateLock(MUSCLE_LOCK_REASON, StateLockFlag_LiveLock);
+    obj->lockState(lock);
+    QVariantMap hints;
+    hints[DocumentReadingMode_SequenceAsAlignmentHint] = true;
+    runSchemaTask = new WorkflowRunSchemaForTask(MUSCLE_SCHEMA_NAME, this, hints);
+    addSubTask(runSchemaTask);
+}
+
+Task::ReportResult MuscleGObjectRunFromSchemaTask::report() {
+    if (lock!=NULL) {
+        obj->unlockState(lock);
+        delete lock;
+        lock = NULL;
+    }
+    
+    propagateSubtaskError();
+    if(hasError() || isCanceled()) {
+        return ReportResult_Finished;
+    }
+    
+    if (obj->isStateLocked()) {
+        setError(tr("Object '%1' is locked").arg(objName));
+        return ReportResult_Finished;
+    }
+    
+    std::auto_ptr<Document> result(runSchemaTask->takeDocument());
+    QList<GObject*> objs = result->getObjects();
+    assert(objs.size() == 1);
+    const QString MUSCLE_TASK_NO_RESULT_ERROR(tr("Undefined error: muscle task did not produced result"));
+    if( objs.isEmpty() ) {
+        setError(MUSCLE_TASK_NO_RESULT_ERROR);
+        return ReportResult_Finished;
+    }
+    MAlignmentObject * maObj = qobject_cast<MAlignmentObject*>(objs.first());
+    if(maObj == NULL) {
+        setError(MUSCLE_TASK_NO_RESULT_ERROR);
+        return ReportResult_Finished;
+    }
+    obj->setMAlignment(maObj->getMAlignment());
+    algoLog.info(tr("MUSCLE alignment successfully finished"));
+    return ReportResult_Finished;
+}
+
+bool MuscleGObjectRunFromSchemaTask::saveInput() const {
+    return true;
+}
+
+QList<GObject*> MuscleGObjectRunFromSchemaTask::createInputData() const {
+    QList<GObject*> objs;
+    objs << obj.data()->clone();
+    return objs;
+}
+
+QVariantMap MuscleGObjectRunFromSchemaTask::getSchemaData() const {
+    QVariantMap res;
+    res["mode"] = qVariantFromValue((int)config.mode);
+    res["max-iterations"] = qVariantFromValue(config.maxIterations);
+    res["stable"] = qVariantFromValue(config.stableMode);
+    if(!config.alignRegion) {
+        res["range"] = qVariantFromValue(QString("Whole alignment"));
+    } else {
+        res["range"] = qVariantFromValue(QString("%1..%2").arg(config.regionToAlign.startPos + 1).arg(config.regionToAlign.endPos()));
+    }
+    return res;
+}
+
+DocumentFormatId MuscleGObjectRunFromSchemaTask::outputFileFormat() const {
+    return inputFileFormat();
+}
+
+DocumentFormatId MuscleGObjectRunFromSchemaTask::inputFileFormat() const {
+    if(obj != NULL && obj->getDocument() != NULL && obj->getDocument()->getDocumentFormat() != NULL) {
+        return obj->getDocument()->getDocumentFormat()->getFormatId();
+    } else {
+        return BaseDocumentFormats::CLUSTAL_ALN;
+    }
+}
+
+bool MuscleGObjectRunFromSchemaTask::saveOutput() const {
+    return true;
+}
+
+#endif // RUN_WORKFLOW_IN_THREADS
+
 } //namespace
