@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 /// various helper methods and structures
 #include "MuscleUtils.h"
@@ -55,7 +66,7 @@ int ugene_printf(FILE *f, const char *format, ...) {
     Q_UNUSED(n);
 
     FILEStub* s = (FILEStub*)f;
-    s->tsi.setStateDesc(QString::fromAscii(str));
+    s->tsi.setDescription(QString::fromAscii(str));
     return 0;
 }
 
@@ -86,7 +97,8 @@ void setupAlphaAndScore(DNAAlphabet* al, TaskStateInfo& ti) {
     }
 }
 
-void convertMAlignment2MSA(MSA& muscleMSA, const MAlignment& ma, bool fixAlpha) {
+void convertMAlignment2MSA(MSA& muscleMSA, const MAlignment& ma, bool fixAlpha) {    
+    MuscleContext *ctx = getMuscleContext();
     for (int i=0, n = ma.getNumRows(); i<n; i++) {
         const MAlignmentRow& row = ma.getRow(i);
         
@@ -100,6 +112,7 @@ void convertMAlignment2MSA(MSA& muscleMSA, const MAlignment& ma, bool fixAlpha)
         name[row.getName().length()] = '\0';
         
         muscleMSA.AppendSeq(seq, coreLen, name);
+        ctx->tmp_uIds[i] = ctx->input_uIds[i];
     }
     if (fixAlpha) {
         muscleMSA.FixAlpha();
