@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "umuscleTests.h"
 #include "MuscleConstants.h"
@@ -111,7 +122,7 @@ void GTest_uMuscle::init(XMLTestFormat *tf, const QDomElement& el) {
             int start = rx.cap(1).toInt(&ok1) - 1;
             int end = rx.cap(2).toInt(&ok2);
             if (ok1 && ok2) {
-                region = LRegion(start, end - start);
+                region = U2Region(start, end - start);
                 alignRegion = true;
             } else {
                 failMissingValue(REGION_ATTR);
@@ -178,8 +189,8 @@ void GTest_uMuscle::prepare() {
 }
 
 Task::ReportResult GTest_uMuscle::report() {
-    if (!hasErrors()) {
-        if(mTask->hasErrors()) {
+    if (!hasError()) {
+        if(mTask->hasError()) {
             stateInfo.setError(  mTask->getError() );
             return ReportResult_Finished;
         }
@@ -314,7 +325,7 @@ void GTest_uMuscleAddUnalignedSequenceToProfile::init(XMLTestFormat *tf, const Q
 }
 
 void GTest_uMuscleAddUnalignedSequenceToProfile::prepare() {
-    if (hasErrors()) {
+    if (hasError()) {
         return;
     }
     Document* aliDoc = getContext<Document>(this, aliDocName);
@@ -367,7 +378,7 @@ void GTest_uMuscleAddUnalignedSequenceToProfile::prepare() {
 
 Task::ReportResult GTest_uMuscleAddUnalignedSequenceToProfile::report() {
     propagateSubtaskError();
-    if (hasErrors()) {
+    if (hasError()) {
         return ReportResult_Finished;
     }
     MAlignment ma = aliObj->getMAlignment();
@@ -504,13 +515,13 @@ MAlignment GTest_Muscle_Load_Align_QScore::dna_to_ma(QList<GObject*> dnaSeqs) {
 QList<Task*> GTest_Muscle_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
     Q_UNUSED(subTask);
     QList<Task*> res;
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return res;
     }
 
     if (subTask == loadTask1) {
         Document *doc = loadTask1->getDocument();
-        if(loadTask1->hasErrors()) {
+        if(loadTask1->hasError()) {
             return res;
         }
         assert(doc!=NULL);
@@ -523,7 +534,7 @@ QList<Task*> GTest_Muscle_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
         }
 
         const MAlignment &mailgn = dna_to_ma(list);
-        if(hasErrors()) {
+        if(hasError()) {
             return res;
         }
 
@@ -539,7 +550,7 @@ QList<Task*> GTest_Muscle_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
         this->connect(muscleTask,SIGNAL(si_progressChanged()),SLOT(sl_muscleProgressChg()));
     }
     else if (subTask == muscleTask) {
-        if(muscleTask->hasErrors()) {
+        if(muscleTask->hasError()) {
             setError( muscleTask->getError() );
             return res;
         }
@@ -550,11 +561,11 @@ QList<Task*> GTest_Muscle_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
         
     }
     else if (subTask == loadTask2) {
-        if (loadTask2->hasErrors()) {
+        if (loadTask2->hasError()) {
             return res;
         }
         Document *doc = loadTask2->getDocument();
-        if(loadTask2->hasErrors()) {
+        if(loadTask2->hasError()) {
             return res;
         }
         assert(doc!=NULL);
@@ -567,7 +578,7 @@ QList<Task*> GTest_Muscle_Load_Align_QScore::onSubTaskFinished(Task* subTask) {
         }
 
         const MAlignment &mailgn = dna_to_ma(list);
-        if(hasErrors()) {
+        if(hasError()) {
             return res;
         }
 
@@ -586,7 +597,7 @@ void GTest_Muscle_Load_Align_QScore::run() {
     const QList<MAlignmentRow> &alignedSeqs2 = ma2->getMAlignment().getRows();
 
     double qscore = QScore(ma1->getMAlignment(), ma2->getMAlignment(), stateInfo);
-    if(stateInfo.hasErrors()) {
+    if(stateInfo.hasError()) {
         return;
     }
 
@@ -648,13 +659,13 @@ MAlignment Muscle_Load_Align_Compare_Task::dna_to_ma(QList<GObject*> dnaSeqs) {
 
 QList<Task*> Muscle_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
-    if (hasErrors() || isCanceled()) {
+    if (hasError() || isCanceled()) {
         return res;
     }
 
     if (subTask == loadTask1) {
         Document *doc = loadTask1->getDocument();
-        if(loadTask1->hasErrors()) {
+        if(loadTask1->hasError()) {
             return res;
         }
         assert(doc!=NULL);
@@ -667,7 +678,7 @@ QList<Task*> Muscle_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
         }
 
         const MAlignment &mailgn = dna_to_ma(list);
-        if(hasErrors()) {
+        if(hasError()) {
             return res;
         }
 
@@ -684,7 +695,7 @@ QList<Task*> Muscle_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
         this->connect(muscleTask,SIGNAL(si_progressChanged()),SLOT(sl_muscleProgressChg()));
     }
     else if (subTask == muscleTask) {
-        if(muscleTask->hasErrors()) {
+        if(muscleTask->hasError()) {
             setError( muscleTask->getError() );
             return res;
         }
@@ -694,11 +705,11 @@ QList<Task*> Muscle_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
 
     }
     else if (subTask == loadTask2) {
-        if (loadTask2->hasErrors()) {
+        if (loadTask2->hasError()) {
             return res;
         }
         Document *doc = loadTask2->getDocument();
-        if(loadTask2->hasErrors()) {
+        if(loadTask2->hasError()) {
             return res;
         }
         assert(doc!=NULL);
@@ -711,7 +722,7 @@ QList<Task*> Muscle_Load_Align_Compare_Task::onSubTaskFinished(Task* subTask) {
         }
 
         const MAlignment &mailgn = dna_to_ma(list);
-        if(hasErrors()) {
+        if(hasError()) {
             return res;
         }
 
@@ -762,7 +773,7 @@ void Muscle_Load_Align_Compare_Task::cleanup() {
 
 Task::ReportResult Muscle_Load_Align_Compare_Task::report() {
     propagateSubtaskError();
-    if(hasErrors()) {
+    if(hasError()) {
         stateInfo.setError(  QString("input file \"%1\", pattern file \"%2\":\n").arg(str_inFileURL).arg(str_patFileURL) + stateInfo.getError() );
     }
     return ReportResult_Finished;
@@ -878,7 +889,7 @@ void GTest_uMusclePacketTest::prepare() {
 
 Task::ReportResult GTest_uMusclePacketTest::report() {
     propagateSubtaskError();
-    if (!hasErrors()) {
+    if (!hasError()) {
         algoLog.trace(QString("uMusclePacketTest: \"%1\" accomplished. Time elapsed: %2 ms").arg(inDirName).arg(timer.elapsed()));
     }
     return ReportResult_Finished;
