@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_LOG_DRIVER_H_
 #define _U2_LOG_DRIVER_H_
@@ -29,9 +40,11 @@ public:
     static const QString LOG_LEVEL_TRACE_CMD_OPTION;
     static const QString LOG_SETTINGS_ACTIVE_FLAG;
     static const QString COLOR_OUTPUT_CMD_OPTION;
-    static const QString TEAMCITY_OUTPUT_CMD_OPTION;
+    //static const QString LOG_FORMAT;
+    //static const QString LOG_LEVEL;
     
     static void setLogCmdlineHelp();
+    void setLogSettings();
 
 private:
     static bool helpRegistered;
@@ -44,13 +57,14 @@ public:
 private:
     void setCmdLineSettings();
     QString getEffectiveCategory(const LogMessage& msg) const;
+    QString getLevelName(int i) const;
     
 private slots:
     void sl_onMessage(const LogMessage& msg);
     QString prepareText(const LogMessage& msg) const;
-
 private:
     bool printToConsole;
+    bool colored;
 
 };
 
