@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <AppContextImpl.h>
 #include <SettingsImpl.h>
@@ -32,6 +43,8 @@
 #include <U2Algorithm/SmithWatermanTaskFactoryRegistry.h>
 #include <U2Algorithm/SubstMatrixRegistry.h>
 #include <U2Algorithm/SWResultFilterRegistry.h>
+#include <U2Algorithm/CDSearchTaskFactoryRegistry.h>
+#include <U2Algorithm/StructuralAlignmentAlgorithmRegistry.h>
 
 #include <U2Core/AnnotationSettings.h>
 #include <U2Core/CMDLineCoreOptions.h>
@@ -43,6 +56,7 @@
 #include <U2Core/DNATranslation.h>
 #include <U2Core/DocumentFormatConfigurators.h>
 #include <U2Core/ExternalToolRegistry.h>
+#include <U2Core/U2DbiRegistry.h>
 #include <U2Core/GObjectTypes.h>
 #include <U2Core/LoadRemoteDocumentTask.h>
 #include <U2Core/Log.h>
@@ -54,10 +68,10 @@
 
 #include <U2Formats/DocumentFormatUtils.h>
 #include <U2Gui/BaseDocumentFormatConfigurators.h>
-#include <U2Lang/BioActorLibrary.h>
 #include <U2Lang/QueryDesignerRegistry.h>
 #include <U2Lang/WorkflowEnvImpl.h>
 #include <U2Lang/WorkflowRunTask.h>
+#include <U2Lang/LocalDomain.h>
 #include <U2Remote/DistributedComputingUtil.h>
 #include <U2Test/GTestFrameworkComponents.h>
 #include <U2Test/TestRunnerTask.h>
@@ -68,6 +82,7 @@
 #include "TestStarter.h"
 #include "TaskStatusBar.h"
 #include "DumpLicenseTask.h"
+#include "DumpVersionTask.h"
 #include "DumpHelpTask.h"
 
 #include <QtCore/QCoreApplication>
@@ -87,9 +102,9 @@ static void registerCoreServices() {
 }
 
 // we will run task that don't die
-static void setCongeneStayAlive() {
-    AppContext::getTaskScheduler()->registerTopLevelTask( new ForeverTask() );
-}
+//static void setCongeneStayAlive() {
+//    AppContext::getTaskScheduler()->registerTopLevelTask( new ForeverTask() );
+//}
 
 static bool openDocs() {
     bool ret = false;
@@ -107,7 +122,6 @@ static bool openDocs() {
     return ret;
 }
 
-
 static void updateStaticTranslations() {
     GObjectTypes::initTypeTranslations();
 }
@@ -133,13 +147,6 @@ static void setScriptsSearchPath() {
 static void setDataSearchPaths() {
     //set search paths for data files
     QStringList dataSearchPaths;
-#if (defined(Q_OS_LINUX) || defined(Q_OS_UNIX)) && defined( UGENE_DATA_DIR )
-    //using directory which is set during installation process on linux
-    QString ugene_data_dir( UGENE_DATA_DIR );
-    if( QDir(ugene_data_dir).exists() ) {
-        dataSearchPaths.push_back( QString(UGENE_DATA_DIR) );
-    }
-#endif
     const static char * RELATIVE_DATA_DIR = "/data";
     const static char * RELATIVE_DEV_DATA_DIR = "/../../data";
     //on windows data is normally located in the application directory
@@ -153,6 +160,15 @@ static void setDataSearchPaths() {
     if( dataSearchPaths.empty() ) {
         dataSearchPaths.push_back("/");
     }
+
+#if (defined(Q_OS_LINUX) || defined(Q_OS_UNIX)) && defined( UGENE_DATA_DIR )
+    //using directory which is set during installation process on linux
+    QString ugene_data_dir( UGENE_DATA_DIR );
+    if( QDir(ugene_data_dir).exists() ) {
+        dataSearchPaths.push_back( QString(UGENE_DATA_DIR) );
+    }
+#endif
+
     QDir::setSearchPaths( PATH_PREFIX_DATA, dataSearchPaths );
     //now data files may be opened using QFile( "data:some_data_file" )
 }
@@ -166,7 +182,7 @@ class GApplication: public QCoreApplication { //Move to the core? same code in u
 public:
     GApplication(int & argc, char ** argv): QCoreApplication(argc, argv) {}
     virtual bool notify(QObject * receiver, QEvent * event ) {
-        bool res;
+        bool res = false;
 #if defined(USE_CRASHHANDLER) && defined(NDEBUG)
         try {
             res = QCoreApplication::notify(receiver, event);
@@ -208,8 +224,7 @@ int main(int argc, char **argv)
             "Hint: Use 'ugene -ui' command to run GUI version of UGENE\n"
             "Hint: Use 'ugene --help' or 'ugene --help=<sectionName>' for more information\n"
 #endif
-            "\nError: missing operands!\n", version.text.toAscii().constData()
-            );
+            , version.text.toAscii().constData());
         return -1;   
     }
 
@@ -297,6 +312,7 @@ int main(int argc, char **argv)
 
     CMDLineUtils::init();
     DumpLicenseTask::initHelp();
+    DumpVersionTask::initHelp();
     
     PhyTreeGeneratorRegistry* phyreg = new PhyTreeGeneratorRegistry();
     appContext->setPhyTreeGeneratorRegistry(phyreg);
@@ -306,6 +322,9 @@ int main(int argc, char **argv)
     ExternalToolRegistry* etr = new ExternalToolRegistry();
     appContext->setExternalToolRegistry(etr);
 
+    U2DbiRegistry *dbiRegistry = new U2DbiRegistry();
+    appContext->setDbiRegistry(dbiRegistry);
+
     PluginSupportImpl* psp = new PluginSupportImpl();
     appContext->setPluginSupport(psp);
     
@@ -371,7 +390,7 @@ int main(int argc, char **argv)
     appContext->setVirtualFileSystemRegistry( vfsReg );
     
     Workflow::WorkflowEnv::init(new Workflow::WorkflowEnvImpl());
-    Workflow::BioActorLibrary::init();
+    Workflow::WorkflowEnv::getDomainRegistry()->registerEntry(new LocalWorkflow::LocalDomainFactory());
 
     DnaAssemblyAlgRegistry* assemblyReg = new DnaAssemblyAlgRegistry();
     appContext->setDnaAssemblyAlgRegistry(assemblyReg);
@@ -381,15 +400,20 @@ int main(int argc, char **argv)
 
     DataBaseRegistry* dbr = new DataBaseRegistry();
     appContext->setDataBaseRegistry(dbr);
+
+    CDSearchFactoryRegistry* cdsfr = new CDSearchFactoryRegistry();
+    appContext->setCDSearchFactoryRegistry(cdsfr);
     
+    StructuralAlignmentAlgorithmRegistry *saar = new StructuralAlignmentAlgorithmRegistry();
+    appContext->setStructuralAlignmentAlgorithmRegistry(saar);
+
     TaskStatusBarCon* tsbc=new TaskStatusBarCon();
     
-    if( cmdLineRegistry->hasParameter( CMDLineCoreOptions::STAY_ALIVE ) ) {
-        setCongeneStayAlive();
-    }
-    
     // show help if need
-    bool showHelp = cmdLineRegistry->hasParameter( CMDLineCoreOptions::HELP );
+    bool showHelp = cmdLineRegistry->hasParameter(CMDLineCoreOptions::HELP) || 
+        cmdLineRegistry->hasParameter(CMDLineCoreOptions::USAGE) ||
+        cmdLineRegistry->hasParameter(CMDLineCoreOptions::HELP_SHORT);
+    
     if( showHelp ) {
         QObject::connect( psp, SIGNAL( si_allStartUpPluginsLoaded()), new TaskStarter(new DumpHelpTask()), SLOT(registerTask()));
     }
@@ -399,8 +423,16 @@ int main(int argc, char **argv)
         QObject::connect(psp, SIGNAL(si_allStartUpPluginsLoaded()), new TaskStarter(new DumpLicenseTask()), SLOT(registerTask()));
     }
     
+    bool showVersion = cmdLineRegistry->hasParameter(DumpVersionTask::VERSION_CMDLINE_OPTION);
+    showVersion = showVersion || cmdLineRegistry->hasParameter(DumpVersionTask::VERSION_CMDLINE_OPTION_SHORT);
+    if(showVersion) {
+        QObject::connect(psp, SIGNAL(si_allStartUpPluginsLoaded()), new TaskStarter(new DumpVersionTask()), SLOT(registerTask()));
+    }
+    
     openDocs();
     registerCoreServices();
+
+    GCOUNTER(cvar, tvar, "ugenecl launch");
     
     //3 run QT 
     t1.stop();
@@ -508,5 +540,11 @@ int main(int argc, char **argv)
     appContext->setQDActorFactoryRegistry(NULL);
     delete qpr;
 
+    delete cdsfr;
+    appContext->setCDSearchFactoryRegistry(NULL);
+
+    appContext->setStructuralAlignmentAlgorithmRegistry(NULL);
+    delete saar;
+
     return rc;
 }
