@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <AppContextImpl.h>
 #include <SettingsImpl.h>
@@ -23,6 +34,7 @@
 #include "plugin_viewer/PluginViewerImpl.h"
 #include "project_support/ProjectLoaderImpl.h"
 #include "main_window/MainWindowImpl.h"
+#include "main_window/CheckUpdatesTask.h"
 #include "project_view/ProjectViewImpl.h"
 
 #include "task_view/TaskViewController.h"
@@ -43,7 +55,7 @@
 #include <U2Algorithm/SecStructPredictAlgRegistry.h>
 #include <U2Algorithm/CudaGpuRegistry.h>
 #include <U2Algorithm/OpenCLGpuRegistry.h>
-//#include <U2Core/VirtualFileSystem.h>
+#include <U2Core/AutoAnnotationsSupport.h>
 #include <CrashHandler.h>
 
 #include <U2Algorithm/SubstMatrixRegistry.h>
@@ -54,6 +66,7 @@
 #include <U2Core/DataBaseRegistry.h>
 #include <U2Algorithm/RepeatFinderTaskFactoryRegistry.h>
 #include <U2Core/ExternalToolRegistry.h>
+#include <U2Core/U2DbiRegistry.h>
 
 #include <U2Core/CMDLineRegistry.h>
 #include <U2Core/CMDLineUtils.h>
@@ -61,6 +74,8 @@
 
 #include <U2Algorithm/MolecularSurfaceFactoryRegistry.h>
 #include <U2Algorithm/PhyTreeGeneratorRegistry.h>
+#include <U2Algorithm/StructuralAlignmentAlgorithmRegistry.h>
+#include <U2Algorithm/CDSearchTaskFactoryRegistry.h>
 
 #include <U2Core/DNAAlphabetRegistryImpl.h>
 #include <U2Core/AnnotationSettings.h>
@@ -70,12 +85,13 @@
 #include <U2View/MSAColorScheme.h>
 
 #include <U2Lang/WorkflowEnvImpl.h>
-#include <U2Lang/BioActorLibrary.h>
+#include <U2Lang/LocalDomain.h>
+#include <U2Lang/WorkflowSettings.h>
+#include <U2Lang/WorkflowRunTask.h>
 #include <U2Core/TaskStarter.h>
 #include <U2Core/LoadRemoteDocumentTask.h>
 #include <U2View/UIndexSupport.h>
 #include <U2View/DnaAssemblyUtils.h>
-#include <U2View/MSAAlignUtils.h>
 #include <U2Lang/QueryDesignerRegistry.h>
 #include <U2Core/LogCache.h>
 #include <U2Gui/LogView.h>
@@ -87,6 +103,8 @@
 #include <U2Formats/DocumentFormatUtils.h>
 #include <U2Test/XMLTestFormat.h>
 #include <project_support/ProjectTasksGui.h>
+#include <U2Test/GUITestService.h>
+#include <U2Test/GUITestBase.h>
 
 /* TRANSLATOR U2::AppContextImpl */
 
@@ -100,6 +118,8 @@ QT_END_NAMESPACE
 #undef USE_CRASHHANDLER
 #endif
 
+
+
 namespace U2 {
 
 static void registerCoreServices() {
@@ -122,13 +142,6 @@ static void updateStaticTranslations() {
 static void setDataSearchPaths() {
     //set search paths for data files
     QStringList dataSearchPaths;
-#if (defined(Q_OS_LINUX) || defined(Q_OS_UNIX)) && defined( UGENE_DATA_DIR )
-    //using directory which is set during installation process on Linux
-    QString ugene_data_dir( UGENE_DATA_DIR );
-    if( QDir(ugene_data_dir).exists() ) {
-        dataSearchPaths.push_back( QString(UGENE_DATA_DIR) );
-    }
-#endif
     const static char * RELATIVE_DATA_DIR = "/data";
     const static char * RELATIVE_DEV_DATA_DIR = "/../../data";
     //on windows data is normally located in the application directory
@@ -141,6 +154,15 @@ static void setDataSearchPaths() {
     if( dataSearchPaths.empty() ) {
         dataSearchPaths.push_back("/");
     }
+
+#if (defined(Q_OS_LINUX) || defined(Q_OS_UNIX)) && defined( UGENE_DATA_DIR )
+    //using directory which is set during installation process on Linux
+    QString ugene_data_dir( UGENE_DATA_DIR );
+    if( QDir(ugene_data_dir).exists() ) {
+        dataSearchPaths.push_back( QString(UGENE_DATA_DIR) );
+    }
+#endif
+
     QDir::setSearchPaths( PATH_PREFIX_DATA, dataSearchPaths );
     //now data files may be opened using QFile( "data:some_data_file" )
 } 
@@ -150,7 +172,7 @@ static void setSearchPaths() {
 }
 
 
-static void initLogsCache(LogCacheExt& logsCache, const QStringList& envList) {
+static void initLogsCache(LogCacheExt& logsCache, const QStringList& ) {
 #ifdef _DEBUG
     logsCache.setConsoleOutputEnabled(true);
 #else
@@ -167,7 +189,7 @@ class GApplication: public QApplication {
 public:
     GApplication(int & argc, char ** argv): QApplication(argc, argv) {}
     virtual bool notify(QObject * receiver, QEvent * event ) {
-        bool res;
+        bool res = false;
 #if defined(USE_CRASHHANDLER)
         try {
             res = QApplication::notify(receiver, event);
@@ -183,7 +205,6 @@ public:
 #endif
         return res;
     }
-
 };
 
 int main(int argc, char **argv) 
@@ -309,7 +330,7 @@ int main(int argc, char **argv)
     MainWindowImpl* mw = new MainWindowImpl();
     appContext->setMainWindow(mw);
     mw->show();
-
+   
     AppSettingsGUI* appSettingsGUI = new AppSettingsGUIImpl();
     appContext->setAppSettingsGUI(appSettingsGUI);
 
@@ -377,9 +398,18 @@ int main(int argc, char **argv)
     ExternalToolRegistry* etr = new ExternalToolRegistry();
     appContext->setExternalToolRegistry(etr);
 
+    U2DbiRegistry *dbiRegistry = new U2DbiRegistry();
+    appContext->setDbiRegistry(dbiRegistry);
+
     QDActorPrototypeRegistry* qpr = new QDActorPrototypeRegistry();
     appContext->setQDActorFactoryRegistry(qpr);
 
+    CDSearchFactoryRegistry* cdsfr = new CDSearchFactoryRegistry();
+    appContext->setCDSearchFactoryRegistry(cdsfr);
+
+    StructuralAlignmentAlgorithmRegistry *saar = new StructuralAlignmentAlgorithmRegistry();
+    appContext->setStructuralAlignmentAlgorithmRegistry(saar);
+
     CMDLineUtils::init();
     
     PhyTreeGeneratorRegistry* genRegistry = new PhyTreeGeneratorRegistry();
@@ -409,7 +439,7 @@ int main(int argc, char **argv)
     appContext->setVirtualFileSystemRegistry( vfsReg );
     
     Workflow::WorkflowEnv::init(new Workflow::WorkflowEnvImpl());
-    Workflow::BioActorLibrary::init();
+    Workflow::WorkflowEnv::getDomainRegistry()->registerEntry(new LocalWorkflow::LocalDomainFactory());
     
     UIndexSupport indexSupport;
 
@@ -423,36 +453,52 @@ int main(int argc, char **argv)
     DataBaseRegistry *dbr = new DataBaseRegistry();
     appContext->setDataBaseRegistry(dbr);
 
+    AutoAnnotationsSupport* aaSupport = new AutoAnnotationsSupport();
+    appContext->setAutoAnnotationsSupport(aaSupport);
+
+    GUITestBase *tb = new GUITestBase();
+    appContext->setGUITestBase(tb);
+    
+#ifndef RUN_WORKFLOW_IN_THREADS
+    CheckCmdlineUgeneUtils::setCmdlineUgenePath();
+#endif // RUN_WORKFLOW_IN_THREADS
+    
+    if(!cmdLineRegistry->hasParameter(CMDLineCoreOptions::LAUNCH_TEST)) {
     QStringList urls = CMDLineRegistryUtils::getPureValues();
     if( !urls.isEmpty() ) {
-        QList<GUrl> gurls;
-        foreach( const QString & url, urls ) {
-            gurls << GUrl(url);
-        }
-        Task * t = AppContext::getProjectLoader()->openProjectTask( gurls, false );
         // defer loading until all plugins/services loaded
         QObject::connect( AppContext::getPluginSupport(), SIGNAL( si_allStartUpPluginsLoaded() ), 
-            new TaskStarter( t ), SLOT( registerTask() ) );
+            new TaskStarter( new OpenWithProjectTask(urls) ), SLOT( registerTask() ) );
         
     } else if (AppContext::getAppSettings()->getUserAppsSettings()->openLastProjectAtStartup()) {
         QString lastProject = ProjectLoaderImpl::getLastProjectURL();
         if (!lastProject.isEmpty()) {
-            Task* t = AppContext::getProjectLoader()->openProjectTask(lastProject, false);
+            Task* t = AppContext::getProjectLoader()->openWithProjectTask(lastProject);
             // defer project start until all plugins/services loaded
             QObject::connect(AppContext::getPluginSupport(), SIGNAL(si_allStartUpPluginsLoaded()), 
                 new TaskStarter(t), SLOT(registerTask()));
         }
     }
+    }
     
     registerCoreServices();
+#ifdef _DEBUG 
+    GUITestService *guiTestService = new GUITestService();
+    Q_UNUSED(guiTestService);
+#endif
     
     if ( !envList.contains(ENV_UGENE_DEV+QString("=1")) ) {
         Shtirlitz::wakeup();
     }
 
+    GCOUNTER(cvar, tvar, "ugeneui launch");
+
     //3 run QT GUI
     t1.stop();
     coreLog.info(AppContextImpl::tr("UGENE started"));
+    if(AppContext::getSettings()->getValue(ASK_VESRION_SETTING, true).toBool()) {
+        ts->registerTopLevelTask(new CheckUpdatesTask(true));
+    }
     int rc = app.exec();
 
     //4 deallocate resources
@@ -463,6 +509,9 @@ int main(int argc, char **argv)
     Workflow::WorkflowEnv::shutdown();
     
     delete dcu;
+
+    appContext->setGUITestBase(NULL);
+    delete tb;
     
     appContext->setVirtualFileSystemRegistry( NULL );
     delete vfsReg;
@@ -563,9 +612,18 @@ int main(int argc, char **argv)
     appContext->setDataBaseRegistry(NULL);
     delete dbr;
 
+    appContext->setAutoAnnotationsSupport(NULL);
+    delete aaSupport;
+
     appContext->setQDActorFactoryRegistry(NULL);
     delete qpr;
 
+    appContext->setCDSearchFactoryRegistry(NULL);
+    delete cdsfr;
+
+    appContext->setStructuralAlignmentAlgorithmRegistry(NULL);
+    delete saar;
+
     appContext->setAppSettingsGUI(NULL);
     delete appSettingsGUI;
 
