@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "AboutDialogController.h"
 
@@ -73,6 +84,7 @@ void AboutDialogController::installTWidget() {
     QHBoxLayout* l = (QHBoxLayout*)frame->layout();
     l->insertWidget(0, pan);
     l->insertWidget(0, tWidget);
+    tWidget->setObjectName("tetris_widget");
     QRect cRect = frame->contentsRect();
     int height = tWidget->heightForWidth(cRect.width());
     tWidget->setFixedSize(cRect.width() * cRect.height() / height, cRect.height());
@@ -137,6 +149,7 @@ void AboutDialogController::mousePressEvent(QMouseEvent *e) {
 }
 
 AWidget::AWidget() {
+    setObjectName("about_widget");
     setMouseTracking(true);
 
     QImage image(":ugene/images/about.png");
@@ -235,13 +248,13 @@ void AWidget::addBlob(int x, int y, int radius, int height) {
 
     // Set up the pointers
     int *newptr;
-    int *oldptr;
+    //int *oldptr;
     if (page == 0) {
         newptr = &heightField1.front();
-        oldptr = &heightField2.front();
+        //oldptr = &heightField2.front();
     } else {
         newptr = &heightField2.front();
-        oldptr = &heightField1.front();
+        //oldptr = &heightField1.front();
     }
 
     int rquad = radius * radius;
