@@ -1,25 +1,34 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_MDI_MANAGER_IMPL_H_
 #define _U2_MDI_MANAGER_IMPL_H_
 
-#include <U2Gui/MainWindow.h>
+#include "MainWindowImpl.h"
 
 #include <QtCore/QSignalMapper>
 #include <QtCore/QEvent>
 
 #include <QtGui/QMdiArea>
 #include <QtGui/QMdiSubWindow>
-#include <QtGui/QTextEdit>
-
 
 namespace U2 {
 
@@ -37,7 +46,7 @@ typedef QList<MDIItem*> MDIItems;
 class MWMDIManagerImpl : public MWMDIManager {
 	Q_OBJECT
 public:
-    MWMDIManagerImpl(MainWindow* _mw, QMdiArea* _mdiArea) 
+    MWMDIManagerImpl(MainWindow* _mw, FixedMdiArea* _mdiArea) 
 		: MWMDIManager(_mw), mw(_mw), mdiArea(_mdiArea){ prepareGUI();}
 
 	~MWMDIManagerImpl();
@@ -50,14 +59,10 @@ public:
 
 	virtual MWMDIWindow* getWindowById(int id) const;
 
-	virtual Qt::WindowStates getWindowState(MWMDIWindow* w) const;
-
 	virtual void activateWindow(MWMDIWindow* w);
 	
 	virtual MWMDIWindow* getActiveWindow() const;
 
-    virtual MWMDIWindow* addTextWindow(const QString& title, const QString& textOrHtml);
-
 protected:
 	bool eventFilter(QObject *obj, QEvent *event);
 	
@@ -65,6 +70,7 @@ private slots:
 	void sl_setActiveSubWindow(QWidget *);
 	void sl_updateWindowMenu();
 	void sl_onSubWindowActivated(QMdiSubWindow *);
+    void sl_updateWindowLayout();
 	
 private:
 	MDIItem* getMDIItem(int id) const;
@@ -81,7 +87,7 @@ private:
 
 
 	MainWindow* mw;
-	QMdiArea*	mdiArea;
+	FixedMdiArea*	mdiArea;
 	MDIItems	items;
 
 
@@ -98,12 +104,6 @@ private:
 	MDIItem*        mdiContentOwner;
 };
 
-class HTMLMDIWindow : public MWMDIWindow {
-    Q_OBJECT
-public:
-    HTMLMDIWindow(const QString& title, const QString& content);
-};
-
 } //namespace
 
 #endif
