@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "MainWindowImpl.h"
 #include "DockManagerImpl.h"
@@ -52,7 +63,7 @@ public:
     MWStub(MainWindowImpl* _owner)  : owner(_owner){
         setAttribute(Qt::WA_NativeWindow);
         setAcceptDrops(true);
-        setWindowIcon(QIcon(":/ugene/images/ugene.icl"));
+        //setWindowIcon(QIcon(":/ugene/images/ugene.icl"));
 //        setWindowIcon(QIcon(":/ugene/images/ugene_16.png"));
     }
     virtual QMenu * createPopupMenu () {return NULL;} //todo: decide if we do really need this menu and fix it if yes?
@@ -65,7 +76,7 @@ protected:
 };
 
 void MWStub::closeEvent(QCloseEvent* e) {
-    if (owner->getMenuManager() == NULL) {
+    if (owner->getMDIManager() == NULL) {
         QMainWindow::closeEvent(e);
     } else {
         owner->runClosingTask();
@@ -84,9 +95,13 @@ void MWStub::dropEvent(QDropEvent *event)
 {
     if (event->mimeData()->hasUrls()) {
         QList<GUrl> urls = GUrlUtils::qUrls2gUrls(event->mimeData()->urls());
-        Task* t = AppContext::getProjectLoader()->openProjectTask(urls, true);
-        AppContext::getTaskScheduler()->registerTopLevelTask(t);
-        event->acceptProposedAction();
+        QVariantMap hints;
+        hints[ProjectLoaderHint_CloseActiveProject] = true;
+        Task* t = AppContext::getProjectLoader()->openWithProjectTask(urls, hints);
+        if (t) {
+            AppContext::getTaskScheduler()->registerTopLevelTask(t);
+            event->acceptProposedAction();
+        }
     } else {
         if(event->mimeData()->hasFormat(DocumentMimeData::MIME_TYPE)) {
             const DocumentMimeData *docData = static_cast<const DocumentMimeData *>(event->mimeData());
@@ -211,7 +226,7 @@ void MainWindowImpl::prepareGUI() {
     mw->setObjectName("main_window");
     setWindowTitle("");
 
-    mdi = new QMdiArea(mw);
+    mdi = new FixedMdiArea(mw);
     mdi->setObjectName("MDI_Area");
 
 	mw->setCentralWidget(mdi);
@@ -223,9 +238,11 @@ void MainWindowImpl::prepareGUI() {
 	menuManager = new MWMenuManagerImpl(this, mw->menuBar());
 
 	exitAction->setObjectName(ACTION__EXIT);
+    exitAction->setParent(mw);
     menuManager->getTopLevelMenu(MWMENU_FILE)->addAction(exitAction);
 
     aboutAction->setObjectName(ACTION__ABOUT);
+    aboutAction->setParent(mw);
     menuManager->getTopLevelMenu(MWMENU_HELP)->addAction(checkUpdateAction);
     menuManager->getTopLevelMenu(MWMENU_HELP)->addAction(downloadManualAction);
     menuManager->getTopLevelMenu(MWMENU_HELP)->addAction(visitWebAction);
@@ -246,7 +263,7 @@ void MainWindowImpl::runClosingTask() {
         msgBox->setWindowTitle(tr("UGENE"));
         msgBox->setText(tr("Shutdown already in process. Close UGENE immediately"));
         QPushButton *closeButton = msgBox->addButton(tr("Close"), QMessageBox::ActionRole);
-        QPushButton *waitButton = msgBox->addButton(tr("Wait"), QMessageBox::ActionRole);
+        /*QPushButton *waitButton =*/ msgBox->addButton(tr("Wait"), QMessageBox::ActionRole);
         msgBox->exec();
         if(getQMainWindow()) {
             if(msgBox->clickedButton() == closeButton) {
@@ -266,4 +283,67 @@ void MainWindowImpl::sl_downloadManualAction()
     GUIUtils::runWebBrowser("http://ugene.unipro.ru/downloads/UniproUGENE_UserManual.pdf");
 }
 
+QMenu* MainWindowImpl::getTopLevelMenu( const QString& sysName ) const
+{
+    return menuManager->getTopLevelMenu(sysName);
+}
+
+QToolBar* MainWindowImpl::getToolbar( const QString& sysName ) const
+{
+    return toolbarManager->getToolbar(sysName);
+}
+
+///////////////////////////////////////////////////////////////////
+
+FixedMdiArea::FixedMdiArea(QWidget * parent) : QMdiArea(parent)
+{
+    setDocumentMode(true);
+    setTabShape(QTabWidget::Rounded);
+    setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
+}
+
+void FixedMdiArea::setViewMode( QMdiArea::ViewMode mode )
+{
+    if (mode == viewMode()) {
+        return;
+    }
+    QMdiArea::setViewMode(mode);
+    if (mode == QMdiArea::TabbedView) {
+        //FIXME QTBUG-9293, Adding a close button to tabbed QMdiSubWindows
+        QList<QTabBar*> tb = findChildren<QTabBar*>();
+        assert(tb.size() == 1);
+        if (tb.size() == 1) {
+            tb.first()->setTabsClosable(true);
+            connect(tb.first(), SIGNAL(tabCloseRequested(int)), SLOT(closeSubWindow(int)));
+        }
+    } else {
+        //TODO QTBUG-3269: switching between TabbedView and SubWindowView does not preserve maximized window state
+    }
+}
+
+void FixedMdiArea::closeSubWindow(int idx) {
+    subWindowList().at(idx)->close();
+}
+
+//Workaround for QTBUG-17428: Superfluous RestoreAction for tabbed QMdiSubWindows
+void FixedMdiArea::sysContextMenuAction(QAction* action) {
+    if (viewMode() == QMdiArea::TabbedView && activeSubWindow())
+    {
+        QList<QAction*> lst = activeSubWindow()->actions();
+        if (!lst.isEmpty() && action == lst.first() ) { //RestoreAction always comes before CloseAction
+            //FIXME better to detect via shortcut or icon ???
+            assert(action->icon().pixmap(32).toImage() == style()->standardIcon(QStyle::SP_TitleBarNormalButton).pixmap(32).toImage() );
+            activeSubWindow()->showMaximized(); 
+        }
+    }
+}
+
+QMdiSubWindow* FixedMdiArea::addSubWindow(QWidget* widget)
+{
+    QMdiSubWindow* subWindow = QMdiArea::addSubWindow(widget);
+    //Workaround for QTBUG-17428
+    connect(subWindow->systemMenu(), SIGNAL(triggered(QAction*)), SLOT(sysContextMenuAction(QAction*)));
+    return subWindow;
+}
+
 }//namespace
