@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ShutdownTask.h"
 #include "MainWindowImpl.h"
@@ -23,7 +34,7 @@
 
 namespace U2 {
 
-ShutdownTask::ShutdownTask(MainWindowImpl* _mw) : Task(tr("shutdown_task_name"), TaskFlags_NR_FOSCOE), mw(_mw) 
+ShutdownTask::ShutdownTask(MainWindowImpl* _mw) : Task(tr("shutdown_task_name"), TaskFlags(TaskFlag_NoRun)), mw(_mw) 
 {
 }
 
@@ -75,20 +86,20 @@ static bool closeViews() {
 
 class CloseWindowsTask : public Task {
 public:
-    CloseWindowsTask() : Task(U2::ShutdownTask::tr("Close windows"), TaskFlags_NR_FOSCOE) {}
+    CloseWindowsTask() : Task(U2::ShutdownTask::tr("Close windows"), TaskFlags(TaskFlag_NoRun)) {}
     void prepare() {
         Project* proj = AppContext::getProject();
         if (proj == NULL) {
             return;
         }
-        if ( proj->isTreeItemModified() ) {
+        if ( proj->isTreeItemModified() || proj->getProjectURL().isEmpty() ) {
             addSubTask(AppContext::getProjectService()->saveProjectTask(SaveProjectTaskKind_SaveProjectAndDocumentsAskEach));
-        }
+        } 
     }
 
     QList<Task*> onSubTaskFinished(Task* subTask) {
         if (subTask->isCanceled()) {
-            setError("Shutdown is canceled by user");
+            stateInfo.cancelFlag = true;
             return QList<Task*>();
         }
         coreLog.trace("Closing views");
@@ -179,7 +190,8 @@ void ShutdownTask::prepare() {
 QList<Task*> ShutdownTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
     
-    if (isCanceled() || subTask->hasErrors()) {
+    stateInfo.cancelFlag = subTask->isCanceled();
+    if (isCanceled() || subTask->hasError() ) {
         mw->setShutDownInProcess(false);
         return res; //stop shutdown process
     }
@@ -193,8 +205,8 @@ QList<Task*> ShutdownTask::onSubTaskFinished(Task* subTask) {
 }
 
 Task::ReportResult ShutdownTask::report() {
-    if (propagateSubtaskError() || hasErrors() || isCanceled()) {
-        setErrorNotificationSuppression(isCanceled());
+    if (propagateSubtaskError() || hasError() || isCanceled()) {
+        setErrorNotificationSuppression(true);
         return Task::ReportResult_Finished;
     }
 
