@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ExportProjectDialogController.h"
 
@@ -14,8 +25,8 @@
 #include <U2Core/GUrlUtils.h>
 #include <U2Core/ProjectModel.h>
 
-#include <QtGui/qfiledialog.h>
-#include <QtGui/qmessagebox.h>
+#include <QtGui/QFileDialog>
+#include <QtGui/QMessageBox>
 
 namespace U2{
 
@@ -36,6 +47,10 @@ ExportProjectDialogController::ExportProjectDialogController(QWidget *p, const Q
     setModal(true);
     projectFile = fixProjectFile(defaultProjectFileName);
     projectFileEdit->setText(projectFile);
+    Project* proj = AppContext::getProject();
+    if (proj == NULL || !proj->isItemModified()) {
+        warningLabel->setVisible(false);
+    }
 	connect(browseButton, SIGNAL(clicked()), this, SLOT(sl_onBrowseButton()));
 }
 
