@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_PROJECT_SUPPORT_H_
 #define _U2_PROJECT_SUPPORT_H_
@@ -25,25 +36,33 @@ namespace U2 {
 #define RECENT_ITEMS_SETTINGS_NAME "recentItems"
 #define RECENT_PROJECTS_SETTINGS_NAME "recentProjects"
 
+class DocumentProviderTask;
+class FormatDetectionResult;
+
 class ProjectLoaderImpl : public ProjectLoader {
     Q_OBJECT
 public:
     ProjectLoaderImpl();
-	~ProjectLoaderImpl();
+	
+    virtual Task* openWithProjectTask(const QList<GUrl>& urls, const QVariantMap& hints = QVariantMap());
 
-    virtual Task* openProjectTask(const QString& file, bool closeActiveProject);
-    virtual Task* openProjectTask(const QList<GUrl>& urls, bool closeActiveProject);
+    virtual Task* createNewProjectTask(const GUrl& url = GUrl());
+
+    virtual Task* createProjectLoadingTask(const GUrl& url, const QVariantMap& hints = QVariantMap());
+    
     virtual Project* createProject(const QString& name, const QString& url, QList<Document*>& documents, QList<GObjectViewState*>& states);
-
+    
     static QString getLastProjectURL();
 
 private:
+
     void updateState();
 	void updateRecentProjectsMenu();
     void prependToRecentProjects(const QString& pFile);
     void updateRecentItemsMenu();
     void prependToRecentItems(const QString& url);
     void rememberProjectURL();
+    bool processHints(FormatDetectionResult& dr);
 
 private slots:
     void sl_newProject();
@@ -55,7 +74,7 @@ private slots:
     void sl_documentAdded(Document* doc);
     void sl_documentStateChanged();
     void sl_projectURLChanged(const QString& oldURL);
-
+    
 	void sl_downloadRemoteFile();
 
 
@@ -87,19 +106,64 @@ public:
     enum Mode {New_Project, Save_Project};
     ProjectDialogController(Mode m, QWidget *p);
 
+    void accept();
     void updateState();
 
 protected:
     void keyPressEvent ( QKeyEvent * event );
-
+    
 private slots:
     void sl_folderSelectClicked();
     void sl_fileNameEdited(const QString&);
     void sl_projectNameEdited(const QString&);
 private:
+    void setupDefaults();
     bool fileEditIsEmpty;
 };
 
 
+class AD2P_DocumentInfo {
+public:
+    AD2P_DocumentInfo() : iof (NULL), openView(false), loadDocuments(false) {}
+    GUrl                    url;
+    DocumentFormatId        formatId;
+    IOAdapterFactory*       iof;
+    QVariantMap             hints;
+    bool                    openView;
+    bool                    loadDocuments;
+};
+
+class AD2P_ProviderInfo {
+public:
+    AD2P_ProviderInfo() : dp (NULL), openView(false){}
+    DocumentProviderTask*   dp;
+    bool                    openView;
+};
+
+class AddDocumentsToProjectTask: public Task {
+    Q_OBJECT
+public:
+    AddDocumentsToProjectTask(const QList<AD2P_DocumentInfo>& docsInfo, const QList<AD2P_ProviderInfo>& providersInfo);
+    ~AddDocumentsToProjectTask();
+
+    virtual QList<Task*> onSubTaskFinished(Task* subTask);
+private:
+    QList<Task*> prepareLoadTasks();
+
+    QList<AD2P_DocumentInfo> docsInfo;
+    QList<AD2P_ProviderInfo> providersInfo;
+    bool loadTasksAdded;
+};
+
+class OpenWithProjectTask : public Task {
+    Q_OBJECT
+public:
+    OpenWithProjectTask(const QStringList& urls);
+    void prepare();
+private:
+    QList<GUrl> urls;
+};
+
+
 }//namespace
 #endif
