@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ProjectServiceImpl.h"
 
@@ -153,17 +164,14 @@ Task::ReportResult ProjectServiceEnableTask::report() {
     connect(psi->exportProjectAction, SIGNAL(triggered()), psi, SLOT(sl_exportProject()));
 
     MainWindow* mw = AppContext::getMainWindow();
-
-    MWMenuManager* mm = mw->getMenuManager();
-    QMenu* fileMenu = mm->getTopLevelMenu(MWMENU_FILE);
+    QMenu* fileMenu = mw->getTopLevelMenu(MWMENU_FILE);
     QAction* beforeAction= GUIUtils::findActionAfter(fileMenu->actions(), ACTION_PROJECTSUPPORT__OPEN_PROJECT);
     fileMenu->insertAction(beforeAction,  psi->saveAction);
     fileMenu->insertAction(beforeAction,  psi->saveAsAction);
     fileMenu->insertAction(beforeAction,  psi->exportProjectAction);
         fileMenu->insertAction(beforeAction,  psi->closeProjectAction);
     
-    MWToolBarManager* tm = mw->getToolBarManager();
-    QToolBar* tb = tm->getToolbar(MWTOOLBAR_MAIN);
+    QToolBar* tb = mw->getToolbar(MWTOOLBAR_MAIN);
     beforeAction= GUIUtils::findActionAfter(tb->actions(), ACTION_PROJECTSUPPORT__OPEN_PROJECT);
     tb->insertAction(beforeAction,  psi->saveAction);
     
