@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ProjectTasksGui.h"
 
@@ -17,31 +28,25 @@
 #include <AppContextImpl.h>
 
 #include <U2Core/SaveDocumentTask.h>
-#include <U2Core/AddDocumentTask.h>
 #include <U2Core/LoadDocumentTask.h>
 #include <U2Core/RemoveDocumentTask.h>
-#include <U2Gui/OpenViewTask.h>
-#include <U2Gui/UnloadDocumentTask.h>
-
 #include <U2Core/DocumentUtils.h>
-
-#include <U2Core/IOAdapter.h>
-#include <U2Core/Log.h>
-#include <U2Core/GUrlUtils.h>
-#include <U2Gui/ObjectViewModel.h>
 #include <U2Core/DocumentModel.h>
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/GHints.h>
-#include <U2Gui/ProjectView.h>
 #include <U2Core/GObject.h>
 #include <U2Core/AppSettings.h>
 #include <U2Core/L10n.h>
-
+#include <U2Core/IOAdapter.h>
+#include <U2Core/Log.h>
+#include <U2Core/GUrlUtils.h>
 #include <U2Core/CMDLineUtils.h>
-
 #include <U2Core/UnloadedObject.h>
 #include <U2Core/GObjectUtils.h>
 
+
+#include <U2Gui/ObjectViewModel.h>
+#include <U2Gui/UnloadDocumentTask.h>
 #include <U2Gui/ProjectParsing.h>
 
 #include <QtXml/QDomDocument>
@@ -83,156 +88,34 @@ void CloseProjectTask::prepare() {
 
 //////////////////////////////////////////////////////////////////////////
 /// OpenProjectTask
-OpenProjectTask::OpenProjectTask(const QString& _url, bool _closeActiveProject, const QString& _name) 
-    : Task(tr("open_project_task_name"), TaskFlags_NR_FOSCOE), url(_url), name(_name), loadProjectTask(NULL), closeActiveProject(_closeActiveProject)
+OpenProjectTask::OpenProjectTask(const QString& _url, const QString& _name) 
+    : Task(tr("open_project_task_name"), TaskFlags_NR_FOSCOE), url(_url), name(_name), loadProjectTask(NULL)
 {
 }
 
-OpenProjectTask::OpenProjectTask(const QList<GUrl>& list, bool _closeActiveProject) 
-    : Task(tr("open_project_task_name"), TaskFlags_NR_FOSCOE), urlList(list), loadProjectTask(NULL), closeActiveProject(_closeActiveProject) 
-{
-}
-
-
-
 void OpenProjectTask::prepare() {
-    if (urlList.size() == 1 && url.isEmpty()) {
-        //FIXME issue 534
-        GUrl tmp = urlList.takeFirst();
-        url = tmp.getURLString();
+    QFileInfo f(url);
+    if (f.exists() && !(f.isFile() && f.isReadable())) {
+        stateInfo.setError(  tr("invalid_url%1").arg(url) );
+        return;
     }
+    if (AppContext::getProject() != NULL) {
+        addSubTask(new CloseProjectTask());
+    }        
 
-    if (url.endsWith(PROJECTFILE_EXT)) { // open a project
-        QFileInfo f(url);
-        if (f.exists() && !(f.isFile() && f.isReadable())) {
-            stateInfo.setError(  tr("invalid_url%1").arg(url) );
-            return;
-        }
-
-        // close current
-        if (AppContext::getProject()!=NULL) {
-            if(url == AppContext::getProject()->getProjectURL()) {
-                coreLog.info(tr("Project already opened"));
-                QMessageBox::critical(AppContext::getMainWindow()->getQMainWindow(),"UGENE", tr("Project already opened"));
-                return ;
-            }
-
-            QMessageBox msgBox(AppContext::getMainWindow()->getQMainWindow());
-            msgBox.setWindowTitle(tr("UGENE"));
-            msgBox.setText(tr("New project can either be opened in a new window or replace the project in the existing. How would you like to open the project?"));
-            QPushButton *newWindow = msgBox.addButton(tr("New Window"), QMessageBox::ActionRole);
-            QPushButton *oldWindow = msgBox.addButton(tr("This Window"), QMessageBox::ActionRole);
-            QPushButton *abort = msgBox.addButton(QMessageBox::Abort);
-            msgBox.exec();
-
-            if(msgBox.clickedButton() == newWindow) {
-                QStringList params =  CMDLineRegistryUtils::getPureValues(0);
-                bool b = QProcess::startDetached(params.first(), QStringList() << url);
-                if(!b) {
-                    coreLog.error(tr("Failed to open new instance of UGENE"));
-                }
-                return;
-            } else if(msgBox.clickedButton() == oldWindow) {
-                if (!closeActiveProject) {
-                    stateInfo.cancelFlag = true;
-                    coreLog.info(tr("Stopped loading project: %1. Reason: active project found").arg(url));
-                    return;
-                }
-                addSubTask(new CloseProjectTask());
-            } else {
-                return;
-            }        
-        }
-
-        if (f.exists()) {
-            loadProjectTask = new LoadProjectTask(url);
-            addSubTask(loadProjectTask);
-        } else {
-            ProjectImpl* p =  new ProjectImpl(name, url);
-            //addSubTask(new SaveProjectTask(SaveProjectTaskKind_SaveProjectOnly, p));
-            addSubTask(new RegisterProjectServiceTask(p));
-        }
-    } else { // load a (bunch of) documents
-        if (!url.isEmpty()) {
-            urlList << GUrl(url);
-        }
-        Project* p = AppContext::getProject();
-        if (!p) {
-            // create anonymous project
-            coreLog.info(tr("Creating new project"));
-            p = new ProjectImpl("", "");
-            Task* rpt = new RegisterProjectServiceTask(p);
-            rpt->setSubtaskProgressWeight(0);
-            addSubTask(rpt);
-        }
-        foreach(const GUrl& _url, urlList) {
-            //FIXME issue 534
-            if (_url.lastFileSuffix() == PROJECTFILE_EXT) {
-                // skip extra project files
-                stateInfo.setError(  tr("ignore %1").arg(url) );
-                continue;
-            }
-            Document * doc = p->findDocumentByURL(_url);
-            if (!doc) {
-                QList<DocumentFormat*> fs = DocumentUtils::detectFormat(_url);
-                if (fs.isEmpty()) {
-                    stateInfo.setError(  tr("unsupported_document%1").arg(_url.fileName()) );
-                    continue;
-                }
-
-                DocumentFormat* format = fs.first();
-                assert(format);
-                IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::url2io(_url));
-                doc = new Document(format, iof, _url);
-                GObjectType t = format->getSupportedObjectTypes().toList().first();
-                if(GObjectTypes::getTypeInfo(t).type != GObjectTypes::UNKNOWN) {
-                    Task * adt = new AddDocumentTask(doc);
-                    adt->setSubtaskProgressWeight(0);
-                    addSubTask(adt);
-                }
-                else {
-                    coreLog.info(tr("Document wasn't added to project: unsupported format"));
-                }
-            } else{
-                QWidget *p = AppContextImpl::getMainWindow()->getQMainWindow();
-                coreLog.details("The document already in the project");
-                QMessageBox::warning(p, tr("warning"), tr("The document already in the project"));
-                if (doc->isLoaded()) {
-                    const QList<GObject*>& docObjects = doc->getObjects();
-                    QList<GObjectViewWindow*> viewsList = GObjectViewUtils::findViewsWithAnyOfObjects(docObjects);
-                    if (!viewsList.isEmpty()) {
-                        AppContext::getMainWindow()->getMDIManager()->activateWindow(viewsList.first());
-                    }else{
-                        AppContext::getProjectView()->highlightItem(doc);
-                    }
-                    coreLog.info(tr("The document is already opened: %1").arg(_url.fileName()));
-                    continue;
-                }else if(!doc->isLoaded() && AppContext::getProjectView()){
-                    AppContext::getProjectView()->highlightItem(doc);
-                    continue;
-                }
-            }
-
-            if (getSubtasks().size() < 50) {
-                addSubTask(new LoadUnloadedDocumentAndOpenViewTask(doc));
-            }
-        }
+    if (f.exists()) {
+        loadProjectTask = new LoadProjectTask(url);
+        addSubTask(loadProjectTask);
+    } else {
+        ProjectImpl* p =  new ProjectImpl(name, url);
+        addSubTask(new RegisterProjectServiceTask(p));
+        //     addSubTask(new SaveProjectTask(SaveProjectTaskKind_SaveProjectOnly, p));
     }
 }
 
 QList<Task*> OpenProjectTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
-    if(subTask->hasErrors()) {
-        if (subTask == loadProjectTask) {
-            return res;
-        }
-        Project *p = AppContext::getProject();
-        Document * doc = p->findDocumentByURL(url);
-        if(doc) {
-            p->removeDocument(doc);
-        }
-    } 
-    if (!isCanceled() && subTask == loadProjectTask && !loadProjectTask->hasErrors()) {
+    if (!isCanceled() && subTask == loadProjectTask && !loadProjectTask->hasError()) {
         Project* p =  loadProjectTask->detachProject();
         res.append(new RegisterProjectServiceTask(p));
     }
@@ -258,14 +141,12 @@ void SaveProjectTask::prepare() {
         url = proj->getProjectURL();
     }
     QList<Task *> ssTasks;
-    if (url.isEmpty() && (!proj->getGObjectViewStates().isEmpty() || proj->getDocuments().size() > 1)) {
+    if (url.isEmpty() && (!proj->getGObjectViewStates().isEmpty() || proj->getDocuments().size() > 0)) {
         //ask if to save project
         QWidget* w  = AppContext::getMainWindow()->getQMainWindow();
         int code = QMessageBox::question(w, tr("UGENE"), tr("Save current project?"), QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel, QMessageBox::Yes);
         if (code == QMessageBox::Yes) {
             ProjectDialogController d(ProjectDialogController::Save_Project, w);
-            d.projectFolderEdit->setText(QDir::home().absolutePath());
-            d.projectNameEdit->setText(tr("My project"));
             int rc = d.exec();
             if (rc == QDialog::Accepted) {
                 AppContext::getProject()->setProjectName(d.projectNameEdit->text());
@@ -308,9 +189,9 @@ Task::ReportResult SaveProjectTask::report() {
 /// SaveOnlyProjectTask
 
 SaveOnlyProjectTask::SaveOnlyProjectTask(Project* p, const QString& _url)
-    :Task(tr("Save project"), TaskFlag_NoRun), sub(NULL), proj(p), url(_url){
+: Task(tr("Save project"), TaskFlag_NoRun), sub(NULL), proj(p), url(_url)
+{
         lock = NULL;
-        //assert(!url.isEmpty());
 }
 
 SaveOnlyProjectTask::~SaveOnlyProjectTask(){
@@ -329,7 +210,7 @@ void SaveOnlyProjectTask::prepare(){
     foreach(Document *d, proj->getDocuments()){
         if (d->getURL().isLocalFile()) {
             QFile pathToDoc(d->getURLString());
-            if(!pathToDoc.exists()){
+            if (!pathToDoc.exists()){
                 phantomDocs.append(d);
             }
         }
@@ -337,7 +218,7 @@ void SaveOnlyProjectTask::prepare(){
     if (!phantomDocs.isEmpty()){   
         sub = new RemoveMultipleDocumentsTask(proj, phantomDocs, false, false);
         addSubTask(sub);
-    }else{
+    } else {
         _run();
     }
 }
@@ -359,7 +240,7 @@ void SaveOnlyProjectTask::_run(){
 }
 
 Task::ReportResult SaveOnlyProjectTask::report(){
-    if (!stateInfo.hasErrors() && url == proj->getProjectURL()) {
+    if (!stateInfo.hasError() && url == proj->getProjectURL()) {
         proj->setModified(false);
     }
     proj->unlockState(lock);
@@ -387,7 +268,7 @@ void LoadProjectTask::run() {
 }
 
 Task::ReportResult LoadProjectTask::report() {
-    if (!stateInfo.hasErrors()) {
+    if (!stateInfo.hasError()) {
         ProjectParserRegistry *ppr = ProjectParserRegistry::instance();
         ProjectParser *parser = ppr->getProjectParserByVersion(version);
         if(parser == NULL){
@@ -425,52 +306,65 @@ Task(tr("Export project task"), TaskFlags_NR_FOSCOE), compress(_compress), desti
 
 void ExportProjectTask::prepare(){
     Project *pr = AppContext::getProject();
+    if (pr->isItemModified()) {
+        addSubTask(new SaveProjectTask(SaveProjectTaskKind_SaveProjectAndDocuments, pr));
+    }
+}
 
+Task::ReportResult ExportProjectTask::report() {
+    if (hasError() || isCanceled()) {
+        return ReportResult_Finished;
+    }
+    Project *pr = AppContext::getProject();
     QList<Document*> docList = pr->getDocuments();
     foreach(Document* doc, docList){
         if(doc->getURL().isEmpty()){
-            coreLog.error(tr("One of the documents has empty URL"));
-            return;
+            setError(tr("One of the project documents has empty URL"));
+            return ReportResult_Finished;
         }
     }
-
+    
     QString error;
     QDir dDir(GUrlUtils::prepareDirLocation(destinationDir, error));
     if (!error.isEmpty()){
-        coreLog.error(error);
         setError(error);
-        return;
+        return ReportResult_Finished;
     }
 
     QMap<QString, QString> urlRemap;
-    /*foreach(Document* doc, docList){
+    foreach(Document* doc, docList){
         QString origPath = doc->getURLString();
         IOAdapterId id = doc->getIOAdapterFactory()->getAdapterId();
         if (id == BaseIOAdapters::LOCAL_FILE || id == BaseIOAdapters::GZIPPED_LOCAL_FILE){
             QFile f(origPath);
             QFileInfo fi(f);
             QString resultPath = destinationDir + "/" + fi.fileName();
-            if (!f.copy(resultPath)){
-                log.error(tr("Error during coping documents"));
-                return;
+            if (resultPath != origPath && !f.copy(resultPath)){
+                if (QFile::exists(resultPath)) {
+                    setError(tr("Error during coping documents: file already exist"));
+                } else {
+                    setError(tr("Error during coping documents"));
+                }
+                return ReportResult_Finished;
             }
-            urlRemap[origPath] = resultPath;
+            urlRemap[origPath] = GUrl(resultPath).getURLString();
         }
-    }*/
+    }
     if(pr->getProjectName().isEmpty()){
         QFileInfo fi(projectFile);
         pr->setProjectName(fi.baseName());
     }
  
     ProjectFileUtils::saveProjectFile(stateInfo, pr, destinationDir + "/" + projectFile, urlRemap);
+    return ReportResult_Finished;
 }
 
 
-void GTest_LoadProject::init(XMLTestFormat* tf, const QDomElement& el) {
-    Q_UNUSED(tf);
+//////////////////////////////////////////////////////////////////////////
+// tests
 
-    TaskResourceUsage tru( RESOURCE_PROJECT, 1, true);
-    taskResources.append(tru);
+void GTest_LoadProject::init(XMLTestFormat*, const QDomElement& el) {
+    addTaskResource(TaskResourceUsage( RESOURCE_PROJECT, 1, true));
     projContextName = el.attribute("index");
     if(!el.attribute("load_from_temp").isEmpty()){
         url = env->getVar("TEMP_DATA_DIR") + "/" + el.attribute("url");
@@ -482,14 +376,13 @@ void GTest_LoadProject::init(XMLTestFormat* tf, const QDomElement& el) {
 void GTest_LoadProject::prepare(){
     QList<Task*> tasks;
     Project *previousProject = AppContext::getProject();
-    Task *tt;
     ServiceRegistry* sr = AppContext::getServiceRegistry();
     QList<Service*> services = sr->findServices(Service_Project);
     int servSize = services.size();
     assert(servSize <= 1);
     if(servSize == 1){
-        if(previousProject->metaObject() != NULL){
-            tt  = new CloseProjectTask();
+        if (previousProject->metaObject() != NULL){
+            Task *tt  = new CloseProjectTask();
             tasks.append(tt);
         }
     } else if(previousProject != NULL) {
@@ -504,7 +397,7 @@ void GTest_LoadProject::prepare(){
 }
 
 Task::ReportResult GTest_LoadProject::report() {
-    if (loadTask!=NULL && loadTask->hasErrors()) {
+    if (loadTask!=NULL && loadTask->hasError()) {
         stateInfo.setError( loadTask->getError());
     } else if (!projContextName.isEmpty()) {
         addContext(projContextName, loadTask->getProject());
@@ -515,7 +408,7 @@ Task::ReportResult GTest_LoadProject::report() {
 
 QList<Task*> GTest_LoadProject::onSubTaskFinished( Task* subTask ){
     QList<Task*> subTasks;
-    if (subTask->hasErrors()) {
+    if (subTask->hasError()) {
         return subTasks;
     }
     if (subTask == mt) {
@@ -566,7 +459,7 @@ void GTest_ExportProject::prepare(){
 
 Task::ReportResult GTest_ExportProject::report(){
     if(exportTask!=NULL){
-        if (exportTask->hasErrors()) {
+        if (exportTask->hasError()) {
             stateInfo.setError(exportTask->getError());
         }
     }
@@ -637,11 +530,11 @@ void GTest_LoadDocumentFromProject::init(XMLTestFormat* tf, const QDomElement& e
 
 void GTest_LoadDocumentFromProject::prepare(){
     Project *pr = AppContext::getProject();
-    if(pr == NULL){
+    if (pr == NULL){
         stateInfo.setError(tr("No project loaded"));
         return;
     }
-    if(documentFileName.isEmpty()){
+    if (documentFileName.isEmpty()){
         stateInfo.setError(tr("Document name to load is empty"));
         return;
     }
@@ -674,7 +567,7 @@ void GTest_LoadDocumentFromProject::cleanup(){
 
 Task::ReportResult GTest_LoadDocumentFromProject::report(){
     if(loadTask!=NULL){
-        if(!loadTask->hasErrors()){
+        if(!loadTask->hasError()){
             addContext(documentFileName, loadedDoc);
             contextAdded = true;
         }
