@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_PROJECT_TASKS_GUI_H_
 #define _U2_PROJECT_TASKS_GUI_H_
@@ -54,9 +65,8 @@ class OpenProjectTask : public Task {
     Q_OBJECT
 
 public:
-	OpenProjectTask(const QString& url, bool closeActiveProject, const QString& name = QString::null);
-    OpenProjectTask(const QList<GUrl>& list, bool closeActiveProject);
-	
+	OpenProjectTask(const QString& url, const QString& name = QString::null);
+    
 	virtual void prepare();
 	
 protected:
@@ -65,9 +75,7 @@ protected:
 private:
 	QString url;
 	QString name;
-    QList<GUrl> urlList;
 	LoadProjectTask* loadProjectTask;
-    bool closeActiveProject;
 };
 
 /// SaveProjectTask schema:
@@ -152,6 +160,7 @@ public:
 	ExportProjectTask(const QString& _destinationDir, const QString& projectFile, bool _compress = false);
 
 	void prepare();
+    ReportResult report();
 
 private:
 	void _run(TaskStateInfo& ts, Project* p, QString url, QStringList paths);
@@ -161,7 +170,6 @@ private:
     QString     projectFile;
 };
 
-
 //cppcheck-suppress noConstructor
 class GTest_LoadProject : public GTest {
 	Q_OBJECT
