@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "ProjectViewImpl.h"
 
@@ -20,10 +31,12 @@
 #include <U2Core/Log.h>
 #include <U2Core/GObject.h>
 #include <U2Core/GUrl.h>
+#include <U2Core/U2SafePoints.h>
 
 #include <U2Core/GObjectTypes.h>
 #include <U2Core/GObjectUtils.h>
 #include <U2Core/DNASequenceObject.h>
+#include <U2Core/DbiDocumentFormat.h>
 
 #include <U2Core/SaveDocumentTask.h>
 #include <U2Core/LoadDocumentTask.h>
@@ -32,9 +45,8 @@
 #include <U2Core/AddDocumentTask.h>
 #include <U2Core/SaveDocumentTask.h>
 #include <U2Gui/OpenViewTask.h>
+#include <U2Gui/UnloadDocumentTask.h>
 
-#include <U2Gui/AddNewDocumentDialogController.h>
-#include <U2Gui/AddExistingDocumentDialogController.h>
 #include <U2Gui/GUIUtils.h>
 #include <U2Misc/DialogUtils.h>
 #include <U2Gui/CopyDocumentDialogController.h>
@@ -55,6 +67,215 @@ namespace U2 {
 
 #define SETTINGS_ROOT QString("projecview/")
 
+#define UPDATER_TIMEOUT 3000
+
+DocumentUpdater::DocumentUpdater(QObject* p) : QObject(p) {
+    QTimer* timer = new QTimer(this);
+    connect(timer, SIGNAL(timeout()), this, SLOT(sl_update()));
+    timer->start(UPDATER_TIMEOUT);
+    recursion = false;
+    updateTask = NULL;
+}
+
+void DocumentUpdater::sl_update() {
+    if (recursion || updateTask != NULL) {
+        return;
+    }
+    recursion = true;
+    update();
+    recursion = false;
+}
+
+static bool hasActiveDialogs(QObject* o) {
+    const QObjectList& childObjects = o->children();
+    bool res = false;
+    foreach(QObject* o, childObjects) {
+        if (hasActiveDialogs(o)) {
+            return true;
+        }
+    }
+    QDialog* d = qobject_cast<QDialog*>(o);
+    if ( d != NULL && d->isVisible() ) {
+        //coreLog.trace(QString("Rejecting dialog %1").arg(o->metaObject()->className()));
+        return true;
+    }
+    return false;
+}
+
+void DocumentUpdater::update() {
+    Project* prj = AppContext::getProject();
+    assert(prj);
+
+    // don't check documents currently used by save/load tasks
+    QList<Document*> docs2check = prj->getDocuments();
+    excludeDocumentsInTasks(AppContext::getTaskScheduler()->getTopLevelTasks(), docs2check);
+
+    // build list of documents which files were modified between calls to sl_update()
+    QList<Document*> outdatedDocs;
+    foreach(Document* doc, docs2check) {
+        if (!doc->isLoaded()) {
+            continue;
+        }
+
+        DbiDocumentFormat* dbiFormat = qobject_cast<DbiDocumentFormat*>(doc->getDocumentFormat());
+        if (dbiFormat) {
+            continue;
+        }
+
+        QFileInfo fi(doc->getURLString());
+        QDateTime updTime = doc->getLastUpdateTime();
+
+        // last update time is updated by save/load tasks
+        // if it's a null the document was not loaded or saved => reload is pointless
+        // if it's not a null and file not exists => file was deleted (don't reload)
+        if (updTime.isNull() || !fi.exists()) {
+            continue;
+        }
+        if (fi.lastModified() != updTime) { // file was modified
+            outdatedDocs.append(doc);
+        }
+    }
+
+    if (outdatedDocs.isEmpty()) {
+        return;
+    }
+    
+    coreLog.trace(QString("Found %1 outdated docs!").arg(outdatedDocs.size()));
+    foreach(GObjectViewWindow*  vw, GObjectViewUtils::getAllActiveViews()) {
+        if (hasActiveDialogs(vw)) {
+            coreLog.trace(QString("View: '%1' has active dialogs, skipping reload").arg(vw->windowTitle()));
+            return;
+        }
+    }
+
+    
+    // query user what documents he wants to reload
+    // reloaded document modification time will be updated in load task
+    QList<Document*> docs2Reload;
+    QListIterator<Document*> iter(outdatedDocs);
+    while (iter.hasNext()) {
+        Document* doc = iter.next();
+        QMessageBox::StandardButton btn = QMessageBox::question(
+            QApplication::activeWindow(),
+            tr("UGENE"),
+            tr("Document '%1' was modified. Do you wish to reload it?").arg(doc->getName()),
+            QMessageBox::Yes | QMessageBox::YesToAll | QMessageBox::No | QMessageBox::NoToAll);
+
+        switch (btn) {
+            case QMessageBox::Yes:
+                docs2Reload.append(doc);
+                break;
+            case QMessageBox::YesToAll:
+                docs2Reload.append(doc);
+                while (iter.hasNext()) {
+                    doc = iter.next();
+                    docs2Reload.append(doc);
+                }
+                break;
+            case QMessageBox::No:
+                doc->setLastUpdateTime();
+                break;
+            case QMessageBox::NoToAll:
+                doc->setLastUpdateTime();
+                while (iter.hasNext()) {
+                    doc = iter.next();
+                    doc->setLastUpdateTime();
+                }
+                break;
+                default:;
+        }
+    }
+
+    if (docs2Reload.isEmpty()) {
+        return;
+    }
+
+    // setup multi task : reload documents + open views
+
+    Task* reloadTask = new Task(tr("Reload documents task"), TaskFlag_NoRun);
+
+    QList<GObjectViewState*> states;
+    QList<GObjectViewWindow*> viewWindows;
+
+    foreach(Document* doc, docs2Reload) {
+        QList<GObjectViewWindow*> viewWnds = GObjectViewUtils::findViewsWithAnyOfObjects(doc->getObjects());
+        foreach(GObjectViewWindow* vw, viewWnds) {
+            if (viewWindows.contains(vw)) {
+                continue;
+            }
+            viewWindows.append(vw);
+
+            GObjectViewFactoryId id = vw->getViewFactoryId();
+            QVariantMap stateData = vw->getObjectView()->saveState();
+            if (stateData.isEmpty()) {
+                continue;
+            }
+            states << new GObjectViewState(id, vw->getViewName(), "", stateData);
+
+            vw->closeView();
+        }
+
+        QString unloadErr = UnloadDocumentTask::checkSafeUnload(doc);
+        if (!unloadErr.isEmpty()) {
+            QMessageBox::warning(QApplication::activeWindow(),
+                tr("UGENE"),
+                tr("Unable to unload '%1'").arg(doc->getName())
+                );
+            doc->setLastUpdateTime();
+            continue;
+        }
+
+        QList<Task*> subs;
+        subs << new UnloadDocumentTask(doc, false);
+        subs << new LoadUnloadedDocumentTask(doc);
+        reloadTask->addSubTask(new MultiTask(tr("Reload '%1' task").arg(doc->getName()), subs));
+    }
+
+    Task* updateViewTask = new Task(tr("Restore state task"), TaskFlag_NoRun);
+
+    foreach(GObjectViewState* state, states) {
+        GObjectViewWindow* view = GObjectViewUtils::findViewByName(state->getViewName());
+        if (view!=NULL) {
+            assert(view->isPersistent());
+            AppContext::getMainWindow()->getMDIManager()->activateWindow(view);
+            updateViewTask->addSubTask(view->getObjectView()->updateViewTask(state->getStateName(), state->getStateData()));
+        } else {
+            GObjectViewFactory* f = AppContext::getObjectViewFactoryRegistry()->getFactoryById(state->getViewFactoryId());
+            assert(f!=NULL);
+            updateViewTask->addSubTask(f->createViewTask(state->getViewName(), state->getStateData()));
+        }
+        delete state;
+    }
+
+    QList<Task*> subs;
+    subs << reloadTask << updateViewTask;
+    updateTask = new MultiTask(tr("Reload documents and restore view state task"), subs);
+    connect(updateTask, SIGNAL(si_stateChanged()), SLOT(sl_updateTaskStateChanged()));
+    AppContext::getTaskScheduler()->registerTopLevelTask(updateTask);
+}
+
+void DocumentUpdater::sl_updateTaskStateChanged() {
+    SAFE_POINT(updateTask != NULL, "updateTask is NULL?", );
+    if (updateTask->isFinished()) {
+        updateTask = NULL;
+    }
+}
+
+void DocumentUpdater::excludeDocumentsInTasks(const QList<Task*>& tasks, QList<Document*>& documents) {
+    foreach(Task* task, tasks) {
+        excludeDocumentsInTasks(task->getSubtasks(), documents);
+        SaveDocumentTask* saveTask = qobject_cast<SaveDocumentTask*>(task);
+        if (saveTask) {
+            documents.removeAll(saveTask->getDocument());
+        } else {
+            LoadDocumentTask* loadTask = qobject_cast<LoadDocumentTask*>(task);
+            if (loadTask) {
+                documents.removeAll(loadTask->getDocument());
+            }
+        }
+    }
+}
+
 ProjectViewWidget::ProjectViewWidget() {
     setupUi(this);
     groupModeMenu = new QMenu(tr("Group mode"), this);
@@ -66,6 +287,8 @@ ProjectViewWidget::ProjectViewWidget() {
     setObjectName(DOCK_PROJECT_VIEW);
     setWindowTitle(tr("Project"));
     setWindowIcon(QIcon(":ugene/images/project.png"));
+
+    updater = new DocumentUpdater(this);
 }
 
 static ProjectTreeGroupMode getLastGroupMode() {
@@ -91,7 +314,6 @@ ProjectViewImpl::ProjectViewImpl()
 //    addNewDocumentAction = NULL;
     saveSelectedDocsAction = NULL;
     relocateDocumentAction = NULL;
-    addExistingDocumentAction = NULL;
     saveProjectOnClose = false;
 
     //todo: move it somewhere else -> object views could be openend without project view service active
@@ -119,6 +341,8 @@ void ProjectViewImpl::enable() {
     connect(pr, SIGNAL(si_documentRemoved(Document*)), SLOT(sl_onDocumentRemoved(Document*)));
     connect(pr, SIGNAL(si_modifiedStateChanged()), SLOT(sl_onProjectModifiedStateChanged()));
     
+    pr->setMainThreadModificationOnly(true);
+    
     MWMDIManager* mdi = AppContext::getMainWindow()->getMDIManager();
     connect(mdi, SIGNAL(si_windowAdded(MWMDIWindow*)), SLOT(sl_onMDIWindowAdded(MWMDIWindow*)));
         
@@ -131,9 +355,6 @@ void ProjectViewImpl::enable() {
     addExistingDocumentAction->setShortcutContext(Qt::ApplicationShortcut);
     connect(addExistingDocumentAction, SIGNAL(triggered()), SLOT(sl_onAddExistingDocument()));
 
-    //addNewDocumentAction = new QAction(QIcon(":ugene/images/add_new_document.png"), tr("add_new_document_action"), w);
-    //connect(addNewDocumentAction, SIGNAL(triggered()), SLOT(sl_onAddNewDocument()));
-
     saveSelectedDocsAction = new QAction(QIcon(":ugene/images/save_selected_documents.png"), tr("save_selected_modified_docs_action"), w);
     connect(saveSelectedDocsAction, SIGNAL(triggered()), SLOT(sl_onSaveSelectedDocs()));
 
@@ -156,15 +377,9 @@ void ProjectViewImpl::enable() {
         AppContext::getSettings()->setValue(SETTINGS_ROOT + "firstShow", false);
     }
     
-    MWMenuManager* mm = mw->getMenuManager();
-    QMenu* fm = mm->getTopLevelMenu(MWMENU_FILE);
+    QMenu* fm = mw->getTopLevelMenu(MWMENU_FILE);
     fm->insertAction(GUIUtils::findActionAfter(fm->actions(), ACTION_PROJECTSUPPORT__OPEN_PROJECT), addExistingDocumentAction);
 
-    //QToolBar* tb = mw->getToolBarManager()->getToolbar(MWTOOLBAR_MAIN);
-    //tb->addAction(addNewDocumentAction);
-    //tb->addAction(addExistingDocumentAction);
-
-
     AppContextImpl::getApplicationContext()->setProjectView(this);
 
     updateMWTitle();
@@ -183,8 +398,6 @@ void ProjectViewImpl::disable() {
         saveWidgetState(w);
         saveGroupMode(projectTreeController->getModeSettings().groupMode);
     }	
-    delete w;
-    w = NULL;
 
     Project* pr = AppContext::getProject();
     pr->disconnect(this);
@@ -204,6 +417,9 @@ void ProjectViewImpl::disable() {
         mdiManager->closeMDIWindow(view);
     }
     mw->setWindowTitle("");
+
+    delete w;
+    w = NULL;
 }
 
 
@@ -232,9 +448,9 @@ void ProjectViewImpl::initView() {
     projectTreeController = new ProjectTreeController(w, w->documentTreeWidget, s);
     projectTreeController->setObjectName("document_Filter_Tree_Controller");
     connect(projectTreeController, SIGNAL(si_onPopupMenuRequested(QMenu&)), SLOT(sl_onDocTreePopupMenuRequested(QMenu&)));
-    connect(projectTreeController, SIGNAL(si_doubleClicked(GObject*)), SLOT(sl_onDoubleClicked(GObject*)));
-    connect(projectTreeController, SIGNAL(si_nameChanged(GObject *)), SLOT(sl_onNameChanged(GObject *)));
-
+    connect(projectTreeController, SIGNAL(si_doubleClicked(GObject*)), SLOT(sl_onActivated(GObject*)));
+    connect(projectTreeController, SIGNAL(si_returnPressed(GObject*)), SLOT(sl_onActivated(GObject*)));
+    
     w->groupModeMenu->addAction(projectTreeController->getGroupByDocumentAction());
     w->groupModeMenu->addAction(projectTreeController->getGroupByTypeAction());
     w->groupModeMenu->addAction(projectTreeController->getGroupFlatAction());
@@ -296,23 +512,6 @@ void ProjectViewImpl::sl_onDocumentRemoved(Document* doc) {
     doc->disconnect(this);
 }
 
-void ProjectViewImpl::sl_onAddNewDocument() {
-    AddNewDocumentDialogModel m;
-    DocumentFormatConstraints c;
-    c.supportedObjectTypes+=GObjectTypes::ANNOTATION_TABLE; //TODO: we can't create other data types on the fly..
-    c.addFlagToSupport(DocumentFormatFlag_SupportWriting);
-    AddNewDocumentDialogController::run(NULL, m, c);
-    if (m.successful) {
-        DocumentFormat* format = AppContext::getDocumentFormatRegistry()->getFormatById(m.format);
-        IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(m.io);
-        coreLog.info(tr("Creating new document %1").arg(m.url));
-        Document* doc = format->createNewDocument(iof, m.url);
-        doc->setModified(true);
-        AppContext::getProject()->addDocument(doc);
-    }
-}
-
-
 void ProjectViewImpl::sl_onSaveSelectedDocs() {
     const DocumentSelection* docSelection = getDocumentSelection();
     QList<Document*> modifiedDocs;
@@ -358,38 +557,22 @@ void ProjectViewImpl::sl_onViewPersistentStateChanged(GObjectViewWindow* v) {
 }
 
 void ProjectViewImpl::sl_onAddExistingDocument() {
-    AddExistingDocumentDialogModel m;
-	AddExistingDocumentDialogController::run(NULL, m, false);
-	if (!m.successful) {
+    LastOpenDirHelper h;
+    QString filter = DialogUtils::prepareDocumentsFileFilter(true);
+    QString file = QFileDialog::getOpenFileName(QApplication::activeWindow(), tr("Select files to open..."), h.dir,  filter);
+    if (file.isEmpty()) {
         return;
     }
-
-    DocumentFormat* format = AppContext::getDocumentFormatRegistry()->getFormatById(m.format);
-    IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(m.io);
-
-    coreLog.info(tr("Adding existing document %1").arg(m.url));
-
-    QList<Task *> tasks;
-    Document * newdoc = 0;
-    QString multiTaskName;
-    if( !m.dwnldPath.isEmpty() ) {
-        IOAdapterFactory * iow = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(BaseIOAdapters::LOCAL_FILE);
-        QString url_w = m.dwnldPath;
-        tasks.push_back( new CopyDataTask(iof, m.url, iow, url_w) );
-        multiTaskName += "download_";
-        newdoc = new Document(format, iow, url_w, QList<UnloadedObjectInfo>(), m.formatSettings);
-    } else {
-        newdoc = new Document(format, iof, m.url, QList<UnloadedObjectInfo>(), m.formatSettings);
+    if (QFileInfo(file).exists()) {
+        h.url = file;
     }
-    if (m.readOnly) {
-        newdoc->setUserModLock(true);
+    QList<GUrl> urls; urls << GUrl(file, GUrl_File);
+    QVariantMap hints;
+    hints[ProjectLoaderHint_ForceFormatOptions] = true;
+    Task* openTask = AppContext::getProjectLoader()->openWithProjectTask(urls, hints);
+    if (openTask != NULL) {
+        AppContext::getTaskScheduler()->registerTopLevelTask(openTask);	
     }
-    Task * adt = new AddDocumentTask(newdoc);
-    adt->setSubtaskProgressWeight(0);
-    tasks.append(adt);
-    tasks.append(new LoadUnloadedDocumentAndOpenViewTask(newdoc));
-    multiTaskName += tr("Add and load document");
-    AppContext::getTaskScheduler()->registerTopLevelTask( new MultiTask(multiTaskName, tasks) );
 
 }
 
@@ -398,9 +581,20 @@ void ProjectViewImpl::sl_onDocTreePopupMenuRequested(QMenu& m) {
     emit si_onDocTreePopupMenuRequested(m);
 }
 
-
-Task* ProjectViewImpl::createLoadDocumentTask(Document* doc) const {
-    return new LoadUnloadedDocumentAndOpenViewTask(doc);
+#define MAX_DOCS_TO_OPEN_VIEWS 5
+QList<Task*> ProjectViewImpl::createLoadDocumentTasks(const QList<Document*>& docs) const {
+    bool openViews = docs.size() <= MAX_DOCS_TO_OPEN_VIEWS;
+    QList<Task*> res;
+    foreach(Document* doc, docs) {
+        Task* t = NULL;
+        if (openViews) {
+            t = new LoadUnloadedDocumentAndOpenViewTask(doc);
+        } else {
+            t = new LoadUnloadedDocumentTask(doc);
+        }
+        res.append(t);
+    }
+    return res;
 }
 
 //TODO: selection could be modified before slot activation!
@@ -428,8 +622,9 @@ public:
     QList<QPointer<GObject> >	objects;
 };
 
-void ProjectViewImpl::sl_onDoubleClicked(GObject* o) {
-    assert(o!=NULL);
+void ProjectViewImpl::sl_onActivated(GObject* o) {
+    SAFE_POINT(o != NULL, "No double-clicked object found", );
+
     GObjectSelection os; os.addToSelection(o);
     MultiGSelection ms; ms.addSelection(&os);
 
@@ -685,42 +880,9 @@ void ProjectViewImpl::sl_openStateView() {
     }
 }
 
-void ProjectViewImpl::sl_onNameChanged(GObject *obj) {
-    QList<GObjectViewWindow*> wList = GObjectViewUtils::findViewsWithObject(obj);
-    //GObjectViewFactory* f = wList.first()->getViewFactory();
-    foreach(GObjectViewWindow* w, wList) {
-        OVTViewItem* bookmark = objectViewController->findViewItem(w->getWindowName());
-        QString newName = GObjectViewUtils::genUniqueViewName(obj->getDocument(),obj);
-        w->setWindowName(newName);
-        bookmark->viewName = newName;
-        bookmark->setText(0,newName);
 
-        if(obj->getGObjectType() == GObjectTypes::SEQUENCE) {
-            AnnotatedDNAView* objView = qobject_cast<AnnotatedDNAView*>(w->getObjectView());
-            foreach(ADVSequenceWidget * seqWidget, objView->getSequenceWidgets()) {
-                if(seqWidget->isWidgetOnlyObject(obj)) {
-                    ADVSingleSequenceWidget *sSeqWidget = qobject_cast<ADVSingleSequenceWidget*>(seqWidget);
-                    sSeqWidget->setTitle(obj->getGObjectName());
-                    break;
-                }
-            }
-        }
-    }
-
-    /*w->closeView();
-    GObjectSelection os; os.addToSelection(obj);
-    MultiGSelection ms; ms.addSelection(&os);
-    OpenViewContext* c = new OpenViewContext(this,ms,f);
-    assert(c->factory->canCreateView(c->selection));
-    AppContext::getTaskScheduler()->registerTopLevelTask(c->factory->createViewTask(c->selection));*/
-}
-
-void ProjectViewImpl::sl_onDocumentAdded(Document* d) {
-    connect(d, SIGNAL(si_loadedStateChanged()), SLOT(sl_onDocumentLoadedStateChanged()));
-}
-
-void ProjectViewImpl::sl_onDocumentLoadedStateChanged() {
-    //do nothing..
+void ProjectViewImpl::sl_onDocumentAdded(Document* /*d*/) {
+//    connect(d, SIGNAL(si_loadedStateChanged()), SLOT(sl_onDocumentLoadedStateChanged()));
 }
 
 void ProjectViewImpl::sl_filterTextChanged(const QString& t) {
@@ -780,6 +942,11 @@ void ProjectViewImpl::sl_saveCopy() {
         foreach(GObject* go, objs){
             if(df->isObjectOpSupported(dd, DocumentFormat::DocObjectOp_Add, go->getGObjectType())){
                 GObject *cl = go->clone();
+                if (cl->getGObjectType() == GObjectTypes::MULTIPLE_ALIGNMENT){
+                    QString name=QFileInfo(dialog.getDocumentURL()).baseName();
+                    cl->setGObjectName(name);
+                    cl->setModified(false);
+                }
                 dd->addObject(cl);
             }
         }
