@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #ifndef _U2_PROJECT_VIEW_WIDGET_
 #define _U2_PROJECT_VIEW_WIDGET_
@@ -30,11 +41,27 @@ class EnableProjectViewTask;
 class DisableProjectViewTask;
 class ProjectViewWidgetFactory;
 
+class DocumentUpdater : public QObject {
+    Q_OBJECT
+public:
+    DocumentUpdater(QObject* p=NULL);
+private slots:
+    void sl_update();
+    void sl_updateTaskStateChanged();
+private:
+    void excludeDocumentsInTasks(const QList<Task*>& tasks, QList<Document*>& documents);
+    void update();
+    Task* updateTask;
+    bool recursion;
+};
+
 class ProjectViewWidget : public QWidget, public Ui_ProjectViewWidget {
     Q_OBJECT
 public:
     ProjectViewWidget();
     QMenu*      groupModeMenu;
+private:
+    DocumentUpdater* updater;
 };
 
 class ProjectViewImpl: public ProjectView , public LoadDocumentTaskProvider {
@@ -53,11 +80,9 @@ public:
 	
 	void initView();
 
-	//QAction* getAddNewDocumentAction() const {return addNewDocumentAction;}
-
 	QAction* getAddExistingDocumentAction() const {return addExistingDocumentAction;}
 
-    virtual Task* createLoadDocumentTask(Document* doc) const;
+    virtual QList<Task*> createLoadDocumentTasks(const QList<Document*>& docs) const;
 
     void highlightItem(Document*);
 
@@ -79,12 +104,10 @@ protected:
 
 private slots: 
     void sl_onDocumentAdded(Document* d);
-    void sl_onDocumentLoadedStateChanged();
-
+    
 	void sl_onProjectModifiedStateChanged();
 	void sl_onDocumentRemoved(Document* d);
 	void sl_onAddExistingDocument();
-	void sl_onAddNewDocument();
 	void sl_onSaveSelectedDocs();
 	void sl_onDocTreePopupMenuRequested(QMenu& popup);
 	void sl_openNewView();
@@ -93,14 +116,12 @@ private slots:
 	void sl_addToView();
 	void sl_onMDIWindowAdded(MWMDIWindow*);
 	void sl_onViewPersistentStateChanged(GObjectViewWindow* thiz);
-	void sl_onDoubleClicked(GObject*);
+	void sl_onActivated(GObject*);
     void sl_filterTextChanged(const QString& t);
     void sl_relocate();
     void sl_saveCopy();
-    void sl_onNameChanged(GObject *);
 
 private:
-
     void saveWidgetState(ProjectViewWidget* w);
     void restoreWidgetState(ProjectViewWidget* w);
     void buildViewMenu(QMenu& m);
@@ -117,7 +138,6 @@ private:
 
 
     QAction*    addExistingDocumentAction;
-    //QAction*  addNewDocumentAction;
     QAction*    saveSelectedDocsAction;
     QAction*    relocateDocumentAction;
     QAction*    saveCopyAction;
