@@ -1,16 +1,29 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include <QtCore/QSysInfo>
 #include <QtCore/QDate>
 #include <QtCore/QBuffer>
+#include <QtCore/QProcess>
+#include <QtCore/QUrl>
 
 #include <QtGui/QMessageBox>
 #include <QtGui/QApplication>
@@ -88,9 +101,18 @@ void Shtirlitz::wakeup() {
     if (thisVersionFirstLaunch) {
         s->setValue(thisVersionsKey, QVariant(true));
     }
+    
+    // Do nothing if Shtirlitz was disabled
+    if (QProcess::systemEnvironment().contains(ENV_UGENE_DEV)) {
+        return;
+    }
 
-    //1. Check if UGENE is launched for the first time
-    if( thisVersionFirstLaunch ) {
+    bool enabledByUser = AppContext::getAppSettings()->getUserAppsSettings()->isStatisticsCollectionEnabled();
+    
+    // Check if this version of UGENE is launched for the first time 
+    // and user did not enabled stats before -> ask to enable
+    // Do not ask to enable it twice for different versions!
+    if( thisVersionFirstLaunch && !enabledByUser) {
         QMessageBox::StandardButton answ = QMessageBox::question(QApplication::activeWindow(), tr("Statistical reports"), tr(firstTimeNotice), QMessageBox::Yes | QMessageBox::No );
         if( QMessageBox::Yes != answ ) {
             AppContext::getAppSettings()->getUserAppsSettings()->setEnableCollectingStatistics( false );
@@ -102,12 +124,7 @@ void Shtirlitz::wakeup() {
         //Leave a mark that the first-time report was sent
     } 
 
-    //2. Do nothing if Shtirlitz was disabled
-    if( !enabled() ) {
-        return;
-    }
-
-    //3. Check if previous report was sent more than a week ago
+    // Check if previous report was sent more than a week ago
     if( !allVersionsFirstLaunch  ) {
         QVariant prevDateQvar = AppContext::getSettings()->getValue( SETTINGS_PREVIOUS_REPORT_DATE );
         QDate prevDate = prevDateQvar.toDate();
@@ -149,11 +166,11 @@ void Shtirlitz::saveGatheredInfo() {
 }
 
 bool Shtirlitz::enabled() {
-    //1. Check environment variable for developers
+    // Check environment variable for developers
     if( QProcess::systemEnvironment().contains(ENV_UGENE_DEV) ) {
         return false;
     }
-    return AppContext::getAppSettings()->getUserAppsSettings()->enableCollectingStatistics();
+    return AppContext::getAppSettings()->getUserAppsSettings()->isStatisticsCollectionEnabled();
 }
 
 void Shtirlitz::sendCountersReport() {
@@ -250,7 +267,7 @@ Task("Shtirlitz task", TaskFlag_None), report(_report) {
 }
 
 void ShtirlitzTask::run() {
-    stateInfo.setStateDesc( tr("Connecting to remote server") );
+    stateInfo.setDescription( tr("Connecting to remote server") );
 
     //Creating QHttp object and enabling proxy if needed.
     SyncHTTP http( QUrl(DESTINATION_URL_KEEPER_SRV).host() );
