@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "TaskStatusBar.h"
 
@@ -86,6 +97,7 @@ TaskStatusBar::TaskStatusBar() {
     taskProgressBar->setFixedHeight(16);
     l->insertWidget(2, taskProgressBar);
 
+    setObjectName("taskStatusBar");
     updateState();
 }
 
@@ -95,10 +107,10 @@ void TaskStatusBar::sl_newReport(Task* task) {
         QAction *action = new QAction("action", this);
         action->setData(QVariant(task->getTaskName() + "|" + QString::number(task->getTaskId()) + "|" + TVReportWindow::prepareReportHTML(task)));
         connect(action, SIGNAL(triggered()), SLOT(sl_showReport()));
-        NotificationType nType = task->hasErrors()? Error_Not : Report_Not;
+        NotificationType nType = task->hasError()? Error_Not : Report_Not;
         Notification *t = new Notification(tr("%1Report for task: '%2'").arg(time).arg(task->getTaskName()), nType, action);
         nStack->addNotification(t);
-    } else if (task->hasErrors() && !task->isErrorNotificationSuppressed()) {
+    } else if (task->hasError() && !task->isErrorNotificationSuppressed()) {
         Notification *t = new Notification(tr("%1'%2' task failed: %3").arg(time).arg(task->getTaskName()).arg(task->getError()), Error_Not);
         nStack->addNotification(t);
     }
@@ -142,7 +154,7 @@ void TaskStatusBar::updateState() {
         return;
     }
 
-    QString desc = taskToTrack->getStateInfo().getStateDesc();
+    QString desc = taskToTrack->getStateInfo().getDescription();
     QString text = tr("running_task_%1").arg(taskToTrack->getTaskName());
     if (taskToTrack->isCanceled() && !taskToTrack->isFinished()) {
         QString cancelStr = tr("canceling...");
