@@ -1,12 +1,23 @@
-/*****************************************************************
-* Unipro UGENE - Integrated Bioinformatics Suite
-* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
-* All Rights Reserved
-* 
-*     This source code is distributed under the terms of the
-*     GNU General Public License. See the files COPYING and LICENSE
-*     for details.
-*****************************************************************/
+/**
+ * UGENE - Integrated Bioinformatics Tools.
+ * Copyright (C) 2008-2011 UniPro <ugene@unipro.ru>
+ * http://ugene.unipro.ru
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
 
 #include "TaskViewController.h"
 
@@ -45,6 +56,7 @@ TaskViewDockWidget::TaskViewDockWidget() {
     setLayout(l);
 
     tree = new QTreeWidget(this);
+    tree->setObjectName("taskViewTree");
     l->addWidget(tree);
     
     buildTree();
@@ -336,7 +348,7 @@ void TaskViewDockWidget::sl_onStateChanged(Task* t) {
         return;
     }
     if (t->isFinished()) {
-        ti->wasError = t->hasErrors();
+        ti->wasError = t->hasError();
         ti->wasCanceled = t->isCanceled();
     }
     ti->updateVisual();
@@ -432,10 +444,10 @@ QString TVReportWindow::prepareReportHTML(Task* t) {
     report+="<tr><td>";
 
     report+="<table>";
-    QString status = t->hasErrors() ? tr("Failed") : t->isCanceled() ? tr("Canceled") : tr("Finished");
+    QString status = t->hasError() ? tr("Failed") : t->isCanceled() ? tr("Canceled") : tr("Finished");
     report+="<tr><td width=200><b>"+tr("status")+"</b></td><td>" +status+ "</td></tr>";
-    if (t->hasErrors()) {
-    report+="<tr><td><b>"+tr("error:")+"</b></td><td>" + t->getError()+ "</td></tr>";
+    if (t->hasError()) {
+    report+="<tr><td><b>"+tr("error:")+"</b></td><td>" + t->getError().replace('|',"&#124;") + "</td></tr>";
     }
 
     int msecs = GTimer::millisBetween(t->getTimeInfo().startTime, t->getTimeInfo().finishTime);
@@ -448,19 +460,21 @@ QString TVReportWindow::prepareReportHTML(Task* t) {
     report+="</td></tr><tr><td>";
 
 
-    report+=t->generateReport()+"<br>";
+    report+=t->generateReport().replace('|',"&#124;")+"<br>";
     report+="</td></tr></table>";
     return report;
 }
 
-bool TVReportWindow::eventFilter(QObject *o, QEvent *e) {
+bool TVReportWindow::eventFilter(QObject *, QEvent *e) {
     if(e->type() == QEvent::MouseButtonPress) {
         QMouseEvent *me = static_cast<QMouseEvent*>(e);
         if(me->button() == Qt::LeftButton) {
             QString url = textEdit->anchorAt(me->pos());
             if(!url.isEmpty()) {
-                Task *t = AppContext::getProjectLoader()->openProjectTask(url, false);
-                AppContext::getTaskScheduler()->registerTopLevelTask(t);
+                Task *t = AppContext::getProjectLoader()->openWithProjectTask(url);
+                if(t) {
+                    AppContext::getTaskScheduler()->registerTopLevelTask(t);
+                }
             }
         }
     } else if(e->type() == QEvent::MouseMove) {
@@ -508,14 +522,14 @@ void TVTreeItem::updateVisual() {
                 state = TaskViewDockWidget::tr("Canceling...");
             }
         } else {
-            state = task->getStateInfo().getStateDesc();
+            state = task->getStateInfo().getDescription();
             if (state.isEmpty() || task->isFinished()) {
                 state = AppContext::getTaskScheduler()->getStateName(task);
             }
         }
 
         setText(TVColumns_Desc, state);
-        if (task->hasErrors()) {
+        if (task->hasError()) {
             setToolTip(TVColumns_Name, task->getStateInfo().getError());
             setToolTip(TVColumns_Desc, task->getStateInfo().getError());
         }
