@@ -274,7 +274,7 @@
     <name>PluginViewWidget</name>
     <message>
         <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="13"/>
-        <source>plugin_viewer_widget_caption</source>
+        <source>Plugin Viewer</source>
         <translation>Prohlížeč přídavných modulů</translation>
     </message>
     <message>
